



/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* This SAS program is to aggregate the child/case-level Illinois CAN investigation records into reporting zip codes (the residential zip code of a victim child at reporting).
   Required Tables:
     - address 
     - allegation 
     - geography 
     - investigation 
     - investigation_address 
     - investigation_person_address 
     - person
     - invst_subj
   Visit the IL DCFS IRB (https://www2.illinois.gov/dcfs/aboutus/policy/Pages/com_communications_IRB.aspx) to obtain raw data.	 
   From the raw data, this program produces the per-zip code number of screened-in reports (unique counts per child per year) 
      for total and by child race/ethnicity, child sex, maltreatment type, reporter type, and substantiation status.
   Child race/ethnicity includes (1) non-Hispanic/Latino White alone, (2) Black alone, (3) Asian alone, (4) American Indian or Alaska Native alone, 
      (5) Native Hawaiian or Other Pacific Islander alone, (6) Two or More Races, and (7) Hispanic or Latino including all races.
      Racial groups other than White are categorized while including both Hispanic/Latino and non-Hispanic/Lation children to be consistent with Census data (ACS).
   Child sex includes male and female.
   Maltreatment type includes neglect, physical abuse, sexual abuse, and emotional abuse (emotional abuse may not be possible for Illinois data).
   Reporter type is categorized into professional and nonprofessional reporters. 
      Professional reporters include social services, medical, mental health, legal/law enforcement/criminal justice, education, child day care, & foster care personnel.
      Nonprofessional reporters include alleged victim, parent, other relative, friends/neighbor, alleged perpetrator, anonymous reporter, other, and unknown/missing reporters.
   Substantiation cases include "substantiated", "indicated", and "reason to suspect" cases. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Illinois Zip Codes, 2011-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 9/1/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output";
libname a "Z:\CDCK01\Data_Zip\CAN\RawData";
libname b "Z:\CDCK01\Data_Zip\CAN\RawData\US_ZIP";
libname c "Z:\CDCK01\Data_Zip\CAN";





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing Data */
/* Importing Data */
/* Importing Data */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/*******************************************************************************************************************************************************************************/
/* address - source_month=202009 (YYYYMM)*/
/*******************************************************************************************************************************************************************************/
DATA  address ;
LENGTH
 city $ 21
 state $ 2
 zip $ 10
 cnty_cd $ 3
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/address.txt" 
     DSD 
     LRECL= 67 ;
INPUT
 addr_id
 city
 state
 zip
 cnty_cd
 source_month
;
RUN; /*N=8754517*/

/*******************************************************************************************************************************************************************************/
/* allegation - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  allegation ;
LENGTH
 scrnum $ 8
 scrseq $ 2
 alleg_cd $ 3
 alleg_desc $ 164
 alleg_finding_desc $ 23
 relation_cd $ 2
 relation_desc $ 29
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/allegation.txt" 
     DSD 
     LRECL= 284 ;
INPUT
 alleg_id
 invst_id
 scrnum
 scrseq
 person_id_vic
 person_id_perp
 alleg_cd
 alleg_desc
 alleg_finding_cd
 alleg_finding_desc
 relation_cd
 relation_desc
 source_month
;
RUN; /*N=3994654*/

/*******************************************************************************************************************************************************************************/
/* geography - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  geography ;
LENGTH
 state_fips_10 $ 2
 county_fips_10 $ 3
 tract_fips_10 $ 6
 il_block_fips_10 $ 4
 state_fips_00 $ 2
 county_fips_00 $ 3
 tract_fips_00 $ 6
 il_block_fips_00 $ 4
 mcd_fips_10 $ 5
 mcd_name_10 $ 36
 place_fips $ 5
 place_name $ 57
 community_area_nm $ 22
;
INFORMAT
 insert_date
 YYMMDD10.
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/geography.txt" 
     DSD 
     LRECL= 179 ;
INPUT
 addr_id
 state_fips_10
 county_fips_10
 tract_fips_10
 il_block_fips_10
 state_fips_00
 county_fips_00
 tract_fips_00
 il_block_fips_00
 mcd_fips_10
 mcd_name_10
 place_fips
 place_name
 community_area_nm
 community_area_nbr
 source_month
 insert_date
;
FORMAT insert_date yymmdd10.;
RUN; /*N=8754517*/

/*******************************************************************************************************************************************************************************/
/* investigation - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  investigation ;
LENGTH
 scrnum $ 8
 scrseq $ 2
 finding_desc $ 23
 status_desc $ 16
 merge_desc $ 8
;
INFORMAT
 finding_date
 init_date
 report_date
 incident_date
 YYMMDD10.
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/investigation.txt" 
     DSD 
     LRECL= 144 ;
INPUT
 invst_id
 scrnum
 scrseq
 finding_cd
 finding_desc
 finding_date
 init_date
 status_cd
 status_desc
 report_date
 incident_date
 approx_date
 unk_date
 merge_cd
 merge_desc
 source_month
;
FORMAT finding_date yymmdd10.;
FORMAT init_date yymmdd10.;
FORMAT report_date yymmdd10.;
FORMAT incident_date yymmdd10.;
RUN; /*N=1488027*/

/*******************************************************************************************************************************************************************************/
/* investigation_address - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  investigation_address ;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/investigation_address.txt" 
     DSD 
     LRECL= 28 ;
INPUT
 invst_id
 addr_id
 source_month
;
RUN; /*N=1338311*/

/*******************************************************************************************************************************************************************************/
/* investigation_person_address - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  investigation_person_address ;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/investigation_person_address.txt" 
     DSD 
     LRECL= 37 ;
INPUT
 invst_id
 person_id
 addr_id
 source_month
;
RUN; /*N=4404926*/

/*******************************************************************************************************************************************************************************/
/* person - source_month=202009 (YYYYMM) */
/*******************************************************************************************************************************************************************************/
DATA  person ;
LENGTH
 cycis_cli_id $ 8
 fl_wkr $ 1
 person_status_cd $ 1
 person_status_desc $ 19
 ethn_desc $ 25
 sex $ 1
 citizenship_desc $ 26
 marital_desc $ 13
 suffix $ 5
;
INFORMAT
 bdate
 YYMMDD10.
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/person.txt" 
     DSD 
     LRECL= 167 ;
INPUT
 person_id
 cycis_cli_id
 rin
 fl_wkr
 person_status_cd
 person_status_desc
 bdate
 race_nat_amer
 race_asian
 race_black
 race_hpi
 race_white
 ethn_cd
 ethn_desc
 sex
 citizenship_cd
 citizenship_desc
 marital_cd
 marital_desc
 suffix
 unkwn_name
 source_month
;
FORMAT bdate yymmdd10.;
RUN; /*N=6741799*/

/*******************************************************************************************************************************************************************************/
/* invst_subj - ts_crte=03AUG20:13:32:31 */
/*******************************************************************************************************************************************************************************/
DATA  invst_subj ;
LENGTH
 id_badg_num $ 25
 id_beat_num $ 10
 id_case_rd_num $ 12
 fl_subj_ind $ 1
 fl_dsbl_ind $ 1
 fl_dcsd_ind $ 1
 fl_sec_race $ 1
 fl_dob_est $ 1
 fl_cfs_lic_fac_res $ 1
 fl_anon $ 1
 fl_natv_amer $ 1
 fl_dcfs_ward $ 1
 fl_occu_cd $ 1
 fl_il_res $ 1
 fl_chld_repl $ 1
 fl_repl_rpt_rslt $ 1
 fl_enrl_no_pub_sch $ 1
 fl_cants2f_to_scr $ 1
 fl_cncl_ind $ 1
 fl_prv $ 1
 fl_no_dob_age $ 1
 fl_dupuy_clas $ 1
 fl_cnsl_ntfy $ 1
 cd_parti_rol $ 1
 cd_gndr $ 1
;
INFORMAT
 dt_of_birth
 dt_remv
 YYMMDD10.
;
INFORMAT
 ts_crte
 ts_updt
 DATETIME18.
;
INFILE  "Z:/CDCK01/Data_Zip/CAN/RawData/invst_subj.txt" 
     DSD 
     LRECL= 325 ;
INPUT
 id_invst_subj
 id_invst
 id_pers
 id_badg_num
 id_beat_num
 id_case_rd_num
 id_remv_expl
 fl_subj_ind
 fl_dsbl_ind
 fl_dcsd_ind
 fl_sec_race
 fl_dob_est
 fl_cfs_lic_fac_res
 fl_anon
 fl_natv_amer
 fl_dcfs_ward
 fl_occu_cd
 fl_il_res
 fl_chld_repl
 fl_repl_rpt_rslt
 fl_enrl_no_pub_sch
 fl_cants2f_to_scr
 fl_cncl_ind
 fl_prv
 fl_no_dob_age
 fl_dupuy_clas
 fl_cnsl_ntfy
 cd_parti_rol
 cd_rptr_type
 cd_rptr_srce
 cd_rptr_grp
 cd_srch_stat
 cd_ethnc
 cd_gndr
 cd_prim_lang
 cd_prim_race
 cd_stat
 cd_milt_fam_mem
 cd_occu
 cd_marr_stat
 cd_us_ctzn
 cd_natl_orgn
 cd_intrp_need
 cd_cnfrm
 dt_of_birth
 dt_remv
 tm_remv
 id_crte
 id_dsgn_crte
 ts_crte
 id_updt
 id_dsgn_updt
 ts_updt
;
FORMAT dt_of_birth yymmdd10.;
FORMAT dt_remv yymmdd10.;
FORMAT ts_crte datetime18.;
FORMAT ts_updt datetime18.;
RUN; /*N=13649318*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Labeling Data */
/* Labeling Data */
/* Labeling Data */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data address;set address;
label 
city="City"
state="State"
zip="ZIP Code"
cnty_cd="DCFS county code (Not FIPS)"
addr_id="Chapin Hall-assigned unique identifier for a DCFS address"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=8754517*/

data allegation;set allegation;
label
scrnum="Unique identifier for a household"
scrseq="Investigation sequence number within a household"
alleg_cd="Code for type of allegation (defined by AFCARS reporting requirements)"
alleg_desc="Description of type of allegation"
alleg_finding_desc="Decision of the investigative worker about the validity of the allegations (description)"
relation_cd="Relationship between alleged perpetrator and alleged victim (code)"
relation_desc="Relationship between alleged perpetrator and alleged victim (description)"
alleg_id="Unique identifier for an allegation"
invst_id="Unique identifier for an investigation"
person_id_vic="Person ID for the alleged victim"
person_id_perp="Person ID for the alleged perpetrator"
alleg_finding_cd="Decision of the investigative worker about the validity of the allegations (code)"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=3994654*/

data geography;set geography;
label
state_fips_10="State FIPS code as of the 2010 census"
county_fips_10="County FIPS code as of the 2010 census"
tract_fips_10="FIPS code for census tract (2010 census); not unique without state and county"
il_block_fips_10="Final four digits of 15 digit FIPS code (2010 census)"
state_fips_00="State FIPS code as of the 2000 census"
county_fips_00="County FIPS code as of the 2000 census"
tract_fips_00="FIPS code for census tract (2000 census); not unique without state and county"
il_block_fips_00="Final four digits of 15 digit FIPS code (2000 census)"
mcd_fips_10="Minor civil division (township) FIPS code (2010 census; not part of 15 digit FIPS)"
mcd_name_10="Minor civil division (township) name (2010 census)"
place_fips="Place (municipality) FIPS code (not part of 15 digit FIPS)"
place_name="Place (municipality) name"
community_area_nm="Community area name (Chicago only)"
insert_date="Date the address was added to this table"
addr_id="Unique identifier for a DCFS address"
community_area_nbr="Community area number (Chicago only)"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=8754517*/

data investigation;set investigation;
label
scrnum="Unique identifier for a household"
scrseq="Investigation sequence number within a household"
finding_desc="Investigation finding (description)"
status_desc="Current state of the investigation (description)"
merge_desc="Value from SACWIS-indicates whether the investigation was merged/retained/removed (description)"
finding_date="Date the finding was updated"
init_date="Date when the first contact with the last victim in the investigation has been initiated"
report_date="Report date associated with investigation"
incident_date="Date of the incident under investigation"
invst_id="Unique identifier for an investigation"
finding_cd="Investigation finding (code)"
status_cd="Current state of the investigation (code)"
approx_date="Indicates that incident date specified is approximate"
unk_date="Indicates that incident date specified is unknown"
merge_cd="Value from SACWIS-indicates whether the investigation was merged/retained/removed (code)"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=1488027*/

data investigation_address;set investigation_address;
label
invst_id="Unique identifier for an investigation"
addr_id="Unique identifier for a DCFS address"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=1338311*/

data investigation_person_address;set investigation_person_address;
label
invst_id="Unique identifier for an investigation"
person_id="Unique identifier of an individual"
addr_id="Unique identifier for a DCFS address"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=4404926*/

data person;set person;
label
cycis_cli_id="Client/registration ID for this person in CYCIS/IMSA"
fl_wkr="Indicates if the person works for DCFS"
person_status_cd="Value from SACWIS - indicates the status of this record (active, deleted, etc.) (code)"
person_status_desc="Value from SACWIS - indicates the status of this record (active, deleted, etc.) (description)"
ethn_desc="Ethnicity of a person with Hispanic origin (description)"
sex="Gender (male, female, or unknown)"
citizenship_desc="Indicates whether the person is a US Citizen (description)"
marital_desc="Marital status of person (description)"
suffix="Name suffix (i.e. Jr, Sr, etc)"
bdate="Person's date of birth"
person_id="Unique identifier of an individual in SACWIS"
rin="Recipient number from DHS/DHFS for individuals who are served by multiple systems"
race_nat_amer="Indicates whether the person has ever reported a race of Native American"
race_asian="Indicates whether the person has ever reported a race of Asian"
race_black="Indicates whether the person has ever reported a race of black"
race_hpi="Indicates whether the person has ever reported a race of native Hawaiian or other Pacific Islander"
race_white="Indicates whether the person has ever reported a race of white"
ethn_cd="Ethnicity of a person with Hispanic origin (code)"
citizenship_cd="Indicates whether the person is a US Citizen (code)"
marital_cd="Marital status of person (code)"
unkwn_name="Indicates when the worker entering the person record does not have enough information to search for the person"
source_month="Indicates the month of the extract that added this record to the table"
;run; /*N=6741799*/

data invst_subj;set invst_subj(rename=(id_invst=invst_id id_invst_subj=invst_subj_id id_pers=person_id));
label
id_badg_num="Badge number of a police officer identified as eventparticipant"
id_beat_num="Beat number of a police officer identified as eventparticipant"
id_case_rd_num="Case number assigned by appropriate policeagencyaspartofidentifyingeventparticipant"
fl_subj_ind="Whether reporter/source is also subject of investigation. Y=Yes;N=No"
fl_dsbl_ind="Whether person has disability.Y=Yes;N=No"
fl_dcsd_ind="Whether victim has deceased. Y=Yes;N=No"
fl_sec_race="Whether additional race information is stored onRacetable. Y=Yes;N=No"
fl_dob_est="Whether date of birth is estimated based on input of age or an actual date of birth. Y=Yes;N=No"
fl_cfs_lic_fac_res="Whether intake participant is resident of DCFS licensed facility (b/wages18-22). Y=Yes;N=No"
fl_anon="Anonymous Indicator"
fl_natv_amer="Whether person has information stored onNative AmericanDemographictable. Y=Yes;N=No"
fl_dcfs_ward="Whether event participant is ward of DCFS. Y=Yes;N=No"
fl_occu_cd="Occupation of investigation subject if subject is perpetrator in investigation. Y=Yes;N=No"
fl_il_res="Whether investigation event participant is officialresidentofIllinois. Y=Yes;N=No"
fl_chld_repl="Whether child has been replaced due to this investigation. Y=Yes;N=No"
fl_repl_rpt_rslt="Whether DCFS Ward (child) was removed from current placement and placed elsewhere due to this investigation. Y=Yes;N=No"
fl_enrl_no_pub_sch="Non-public school enrollment flag indicates subject is enrolled in Non-Public School. Y=Yes;N=No"
fl_cants2f_to_scr="CANTS2F to SCR flag indicates the CANTS2f form has been sent to SCR. Y=Yes;N=No"
fl_cncl_ind="Whether investigation subject has been concealedaspartofpurgeprocess. Y=Yes;N=No"
fl_prv="Whether subject was provider at the time of creating investigation report. Y=Yes;N=No"
fl_no_dob_age="Whether subject's date of birth/age were unobtainable. Y=Yes;N=No"
fl_dupuy_clas="Whether subject is designated as dupuy class subject. Y=Yes;N=No"
fl_cnsl_ntfy="Wheter Notification to Mexican Consulate Formwascompleted. Y=Yes;N=No"
cd_parti_rol="Whether investigation subject is adult=A, kid=K, or both=B"
cd_gndr="Whether person is male=M, female=F, or unknown=U"
dt_of_birth="Date of birth captures month, day and year investigation event participant was born"
dt_remv="Date investigation subject was removed from investigation. NULL=0100-01-01or9999-12-31"
ts_crte="Date and time at which the row was created(defaultstosystemtimestamp)"
ts_updt="Date and time at which the row was updated(defaults to system timestamp)"
invst_subj_id="Unique system generated investigation subject identifier(Foreign key to INVST_SUBJ.ID_INVST_SUBJ)"
invst_id="Unique system generated investigation identifier(Foreign key to INVESTIGATION.ID_INVST)"
person_id="Person identifier(ForeignkeytoPERSON.ID_PERS)"
id_remv_expl="Unique system generated removal explanation identifier that associates text narrative fields in TEXT_EXTENDER table"
cd_rptr_type="Reporter type code(reporter, mandated reporter, source, OPWI)"
cd_rptr_srce="Reporter source code(1=reporter;2=source)"
cd_rptr_grp="Reporter group code(1=Med,2=Edu,3=SS,4=Law,5=Provider,6=DCFS,7=Court,8=Fam,9=Non-Mandated,10=Anonymous)"
cd_srch_stat="Whether worker has searched the system & found a match for the participant(1=not searched;2=found;3=not found;4=possible)"
cd_ethnc="Ethnicity(1=Not Hispanic;2-6,8-10=Hispanic;7,11-13=Unknown)"
cd_prim_lang="Primary language associated with a Participant(0=unknown;12=English;42=Spanish)"
cd_prim_race="Primary race code(1=NA/AN;2=Asian;3=Black;4=NH/PI;5=White;6-9=unknown)"
cd_stat="Whether Investigation Event Participant is currently 1=active or 2=inactive"
cd_milt_fam_mem="Whether person is military family member(1=Yes;2=No;3=Unknown;4=Missing)"
cd_occu="Occupation of investigation event participant(1=None;2=Edu;3=Other Professionals;4=DCFS;5=Child Care)"
cd_marr_stat="Marital status of investigation event participant(1=Never Married;2=Married;3=Divorced;4=Separated;5=Widowed)"
cd_us_ctzn="1=Citizen by Birth;2=Naturalized;3=Lawfully Admitted Resident;4=Undocumented Resident;5=Not Reported;6=Unknown"
cd_natl_orgn="Whether a subject is a Mexican National, other national, or unknown(1=Mexican National;2=Other National;3=Not a National)"
cd_intrp_need="Whether a subject requires an interpreter(1=Yes;2=No;3=Unknown)"
tm_remv="Time the investigation subject was removed from investigation"
id_crte="Identifier of the creator of the row(Foreign key to WORKER.ID_WKR)"
id_dsgn_crte="Identifier of the designee that created the row(ForeignkeytoWORKER.ID_WKR)"
id_updt="Identifier of the updater of the row(Foreign key to WORKER.ID_WKR)"
id_dsgn_updt="Identifier of the designee that updated the row(ForeignkeytoWORKER.ID_WKR)"
;run; /*N=13649318*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "investigation" table *******************************************************************************************************************************************************/
/* "investigation" table *******************************************************************************************************************************************************/
/* "investigation" table *******************************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - unit=investigation("invst_id")
   - no duplicate in "invst_id" [proc freq data=investigation nlevels;tables invst_id/noprint;run;]
   - for over 99% of records, "report_date" and "incident_date" were consistent (within 1 month:99.18%; Within 1 year:99.76%; Within 4 years:99.90%)
     [data junk;set investigation;diff=report_date-incident_date;diff2=int(diff/30.43685);run;  proc freq data=junk;tables diff2/missing;run;]
     this study will use "report_date" as it is the most usual application in prior studies
   - the only table has "report_date"; other tables should be merged with "investigation" table to select records in 2011-2018
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* (1) Select investigated reports from 2011 to 2018 (calendar years based on "report_date"); (2) Create "RptYear" (Report Year) variable; (3) Select variables */
data investigation2;set investigation;
if '01JAN2011'd<=report_date<='31DEC2018'd;
if '01JAN2011'd<=report_date<='31DEC2011'd then RptYear=2011;
if '01JAN2012'd<=report_date<='31DEC2012'd then RptYear=2012;
if '01JAN2013'd<=report_date<='31DEC2013'd then RptYear=2013;
if '01JAN2014'd<=report_date<='31DEC2014'd then RptYear=2014;
if '01JAN2015'd<=report_date<='31DEC2015'd then RptYear=2015;
if '01JAN2016'd<=report_date<='31DEC2016'd then RptYear=2016;
if '01JAN2017'd<=report_date<='31DEC2017'd then RptYear=2017;
if '01JAN2018'd<=report_date<='31DEC2018'd then RptYear=2018;
label RptYear="Report Calendar Year (based on report_date)";
keep finding_desc report_date invst_id RptYear;
run; /*N=580510*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "invst_subj" table **********************************************************************************************************************************************************/
/* "invst_subj" table **********************************************************************************************************************************************************/
/* "invst_subj" table **********************************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Unit=investigation subject("invst_subj_id"); group1=person("person_id"); group2=investigation("invst_id")
   - Three groups of persons ("cd_parti_rol" variable): reporters (missing or 0), adults (A=adult), and children (K=kid, B=both)
   - One child can have multiple investigations; one investigation can have multiple children
   - This table includes both alleged victim children (with allegations) and alleged non-victim children (with no allegation)
   - Alleged victim children are children reported to CPS for CAN allegations; alleged non-victim children are other children in the same family of alleged victim children
   - Both alleged victim and non-victim children are subject of an investigation in Illinois
   - To be consistent with national data (NCANDS Child Files for Illinois), this study will include both alleged victim and non-victim children
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Selecting children ("K" or "B" of "cd_parti_rol" variable) --i.e., excluding reporter and adult records; selecting variables */
data invst_subj2;set invst_subj;
if cd_parti_rol in ("B" "K");
keep cd_gndr dt_of_birth invst_subj_id invst_id person_id cd_ethnc cd_prim_race;
run; /*N=6094536*/

/* Merge "investigation2" and "invst_subj2" tables; Inner Join to select all investigation subjects from 01/01/2011 to 12/31/2018 */
proc sort data=investigation2;by invst_id;run; /*N= 580510*/
proc sort data=invst_subj2;by invst_id;run;    /*N=6094536*/
data invst_subj3;merge investigation2(IN=A) invst_subj2(IN=B);by invst_id;if (A=B);run; /*N=1334662*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "allegation" table **********************************************************************************************************************************************************/
/* "allegation" table **********************************************************************************************************************************************************/
/* "allegation" table **********************************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - unit=allegation("alleg_id"); group1=alleged victim child("person_id_vic"); group2=investigation("invst_id")
   - one person can have multiple investigations; one investigation can have multiple persons; one investigation-person can have multiple allegations
   - this table includes only alleged victim children; this table should be merged with "invst_subj" table to have alleged non-victim children
   - NCANDS Child Files have both alleged victim children and alleged non-victim children for Illinois and some other states
   - To be consistent with NCANDS Child Files for Illinois, this study will include both alleged victim children and alleged non-victim children
   - for further information regarding alleged victim and non-victim children, see the above explanations under the "invst_subj" table
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Merge "investigation2" and "allegation" tables; Inner Join to have all investigated allegations from 01/01/2011 to 12/31/2018 */
proc sort data=allegation;by invst_id;run;     /*N=3994654*/
data allegation2;merge investigation2(IN=A) allegation(IN=B);by invst_id;if (A=B);
drop relation_cd alleg_finding_cd source_month;run; /*N=1440161*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating investigation-person ID ("invst_pers_id") **************************************************************************************************************************/
/* Creating investigation-person ID ("invst_pers_id") **************************************************************************************************************************/
/* Creating investigation-person ID ("invst_pers_id") **************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - check missing "invst_id" and "person_id" ("person_id_vic") in "invst_subj3" and "allegation2"
     "invst_subj3" table has no missing in both ID variables                                    [proc means data=invst_subj3 nmiss min max;var invst_id person_id    ;run;]
     "allegation2" table has no missing in "invst_id", but 10 missing values in "person_id_vic" [proc means data=allegation2 nmiss min max;var invst_id person_id_vic;run;]
   - SOLUTION: delete records with missing "person_id_vic" from "allegation2" table
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Creating "invst_pers_id" and "flag_invst_subj" in "invst_subj4" table */
data invst_subj4;set invst_subj3;
invst_pers_id=invst_id||"-"||person_id;
flag_invst_subj=1;
label 
invst_pers_id="investigation person ID (=invst_id||"-"||person_id)"
flag_invst_subj="1='invst_subj' table record"
;
run; /*N=1334662*/

/* Deleting records with missing "person_id_vic"; Creating "invst_pers_id" and "flag_allegation" */
data allegation3;set allegation2;
invst_pers_id=invst_id||"-"||person_id_vic;
flag_allegation=1;
if person_id_vic^=.;
label 
invst_pers_id="investigation person ID (=invst_id||"-"||person_id)"
flag_allegation="1='allegation' table record"
;run; /*N=1440151 -- 10 (out of 1440161; <0.0007%) records with missing "person_id_vic" were deleted */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Managing dupulicate investigation-person ID ("invst_pers_id") ***************************************************************************************************************/
/* Managing dupulicate investigation-person ID ("invst_pers_id") ***************************************************************************************************************/
/* Managing dupulicate investigation-person ID ("invst_pers_id") ***************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - "allegation3" table has multiple records per "invst_pers_id" as a person (alleged victim child) in an investigation can have multiple allegations
   - "invst_subj4" table should have one record per "invst_pers_id" as a person in an investigation is one investigation subject
   - check duplicate records in "invst_subj4" table
     [proc sort data=invst_subj4;by invst_pers_id               ;run;  data junk;set invst_subj4;by invst_pers_id;retain num ;if first.invst_pers_id then num=0;num=num+1;run;]
     [proc sort data=junk       ;by invst_pers_id descending num;run;  data junk;set junk       ;by invst_pers_id;retain num2;if first.invst_pers_id then num2=num       ;run;]
     [proc freq data=junk;tables num2;run;]
     duplicate records exist in "invst_subj4" table -- 4442/2 = 2221 IDs have 2 records; 138/3 = 46 IDs have 3 records; 12/4 = 3 IDs have 4 records
   - Printout shows that these are indeed duplicate records [proc print data=junk;where num2>2;run;]
   - SOLUTION: select one unique record (the most current record) among duplicate records in "invst_subj4"
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Select one unique record (the most current record) among duplicate records in "invst_subj4" */
proc sort data=invst_subj4;by invst_pers_id invst_subj_id;run; /*N=1334662*/
data invst_subj5;set invst_subj4(rename=(RptYear=RptYear2 finding_desc=finding_desc2 invst_id=invst_id2 report_date=report_date2));by invst_pers_id;if last.invst_pers_id;run; 
/*N=1332340 -- 2322 (out of 1334662; 0.17%) duplicate records were deleted*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging "allegation3" and "invst_subj5" by "invst_pers_id" ******************************************************************************************************************/
/* Merging "allegation3" and "invst_subj5" by "invst_pers_id" ******************************************************************************************************************/
/* Merging "allegation3" and "invst_subj5" by "invst_pers_id" ******************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - "allegation3" table has multiple records per "invst_pers_id" as a person (alleged victim child) in an investigation can have multiple allegations
   - "invst_subj5" table has one record per "invst_pers_id"
   - Full outer join by "invst_pers_id" to keep all records from both tables -- some children may exist only in a table
   - Alleged victim children can have multiple records per child/investigation as a child can have multiple allegations per investigation; this will be handled later
   - Alleged non-victim children have one record per child/investigation, and their allegation will be missing (i.e., no allegation)
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Merging "allegation3" and "invst_subj5" by "invst_pers_id" -- full outer join */
/* Replacing missing "person_id" with "person_id_vic" */
proc sort data=allegation3;by invst_pers_id;run; /*N=1440151*/
proc sort data=invst_subj5;by invst_pers_id;run; /*N=1332340*/
data invst1;merge allegation3 invst_subj5;by invst_pers_id;
if RptYear=.       then RptYear     =RptYear2;
if finding_desc="" then finding_desc=finding_desc2;
if invst_id=.      then invst_id    =invst_id2;
if person_id=.     then person_id   =person_id_vic;
if report_date=.   then report_date =report_date2;
person_id_yr=person_id||"-"||RptYear;
drop RptYear2 finding_desc2 invst_id2 report_date2;
run; /*N=1835255*/

/* 429 records of 202 children only in "allegation" table (0.02% of 1835255)  [proc freq data=invst1 nlevels;tables person_id;where flag_allegation=1 & flag_invst_subj=.;run;]*/
/* 587,815     victim children; 937,505 investigations; 1,440,151 records  [proc freq data=invst1 nlevels;tables person_id invst_pers_id/noprint;where flag_allegation=1;run;]*/
/* 304,815 non-victim children; 395,104 investigations;   395,104 records  [proc freq data=invst1 nlevels;tables person_id invst_pers_id/noprint;where flag_allegation=.;run;]*/
/* 
# children per year
  119048 children in 2011 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2011;run;] 
  123030 children in 2012 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2012;run;] 
  128660 children in 2013 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2013;run;] 
  127154 children in 2014 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2014;run;] 
  136010 children in 2015 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2015;run;] 
  141826 children in 2016 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2016;run;] 
  142310 children in 2017 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2017;run;]
  155130 children in 2018 [proc freq data=invst1 nlevels;tables person_id/noprint;where RptYear=2018;run;]
  Total: 1073168 children had a maltreatment from 2011 to 2018 (annual unduplicate counts)
         [proc freq data=invst1 nlevels;tables person_id_yr/noprint;run;]
*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging "invst1" and "person" by "person_id" ********************************************************************************************************************************/
/* Merging "invst1" and "person" by "person_id" ********************************************************************************************************************************/
/* Merging "invst1" and "person" by "person_id" ********************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - no duplicate "person_id" (i.e., one record per "person_id") in "person" table  [proc freq data=person2 nlevels;tables person_id/noprint;run;]
   - multiple records per "person_id" in "invst1" table as a child can have multiple allegations and investigations per child/investigation
   - left join of "invst1" table and "person" table by "person_id"
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Creating flag_person; Selecting variables */
data person2;set person;
flag_person=1;
label flag_person="1='person' table record";
keep ethn_desc sex bdate person_id race_nat_amer race_asian race_black race_hpi race_white ethn_cd flag_person;run; /*N=6741799*/

/* Merging "invst1" and "person" by "person_id" */
proc sort data=invst1 ;by person_id;run; /*N=1835255, 22 variables*/
proc sort data=person2;by person_id;run; /*N=6741799, 11 variables*/
data invst2;merge invst1(IN=A) person2;by person_id;if A;run; /*N=1835255, 32 variables*/

/* All investigation subjects ("invst1" table) were in "person" table [proc freq data=invst2;tables flag_person/missing;run;] */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Managing date of birth (DOB) ************************************************************************************************************************************************/
/* Managing date of birth (DOB) ************************************************************************************************************************************************/
/* Managing date of birth (DOB) ************************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Check discrepancy in DOB between "invst1" and "person" tables
     -----------------------------------------------------------------------------------------------------------------------------------
     data junk;set invst2;
     flag1=0;if bdate^=dt_of_birth & bdate^=. & dt_of_birth^=. & dt_of_birth^='31DEC9999'd then flag1=1;
     flag2=0;if flag1=1 & (intck('year',bdate,dt_of_birth,'continuous')>0|intck('year',bdate,dt_of_birth,'continuous')<-1) then flag2=1;
     proc freq data=junk;tables flag1 flag2;run;
     -----------------------------------------------------------------------------------------------------------------------------------
     1.39% of records with different DOB between "invst1" and "person" tables
     0.26% of records with over 1 year difference in DOB between "invst1" and "person" tables
     SOLUTION: little discrepancy -- "bdate" from "person" table will be used; if missing, "dt_of_birth" from "invst1" table will be used
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Creating "bdate2" based on "bdate"; if missing, based on "dt_of_birth" */
data invst3;set invst2;
if bdate^=.                                              then bdate2=bdate;
if bdate =. & dt_of_birth^=. & dt_of_birth^='31DEC9999'd then bdate2=dt_of_birth;
label bdate2="Person's date of birth (based on primarily 'bdate' and secondarily 'dt_of_birth')";
run; /*N=1835255, 33 variables*/
/* Checking how many had missing "bdate" and how many were saved by "dt_of_birth"  [proc means data=invst3 n nmiss;var bdate bdate2;run;]
   - 11524 (0.628% of 1835255) missing "bdate"
   - 11501 (0.627% of 1835255) missing "bdate2"
   -    23 (0.001% of 1835255) were saved by "dt_of_birth"
   - A very small proportion of child records have missing DOB */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating age at reporting variable ******************************************************************************************************************************************/
/* Creating age at reporting variable ******************************************************************************************************************************************/
/* Creating age at reporting variable ******************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Age (in years) at reporting will be calculated based on DOB ("bdate2") and report date ("report_date")
   - Delete records with missing age, with age < 0 (unborn cases), and with age 18 or older
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data invst4;set invst3;
age=intck('year',bdate2,report_date,'continuous');
label age="child age in years at maltreatment report";
run; /*N=1835255, 34 variables*/

/* 99.05% records with age 0-17 years, 0.63% with missing age, 0.14% with age < 0 (unborn cases), and 0.19% with age 18 or older [proc freq data=invst4;tables age/missing;run; */

data invst5;set invst4;if 0<=age<=17;run; /*N=1817835 -- 17420 (0.95% of 1835255) records with missing age, age<0, and age>=18 were deleted; 34 variables */
                                          /*1058695 children aged 0-17 years (annual unduplicate counts) [proc freq data=invst1 nlevels;tables person_id_yr/noprint;run;]
                                              14473 children with missing, age<0, or age>17 (1.35%) */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating substantiation and maltreatment type variables *********************************************************************************************************************/
/* Creating substantiation and maltreatment type variables *********************************************************************************************************************/
/* Creating substantiation and maltreatment type variables *********************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Substantiated/indicated status variable ("Subst")
   - Alleged maltreatment type variables: neglect ("RptNG"), physical abuse ("RptPA"), sexual abuse ("RptSA"), emotional abuse ("RptEA"), and no alleged maltreatment ("RptNA")
     Maltreatment type is based on IL DCFS Procedure 300 - Appendix B - The Allegations System (www2.illinois.gov/dcfs/aboutus/notices/Documents/Procedures_300_Appendix_B.pdf)
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data invst6;set invst5;
Subst=0;if alleg_finding_desc="Indicated"|alleg_finding_desc="Indicated Allowed" then Subst=1;
RptNG=0;if alleg_cd in ("51" "52" "54" "55" "56" "57" "59" "60" "61" "62" "63" "65" "67" "74" "74a" "74b" "74c" "74d" "75" "76" "77" "78" "79" "81" "82" "83" "84" "84a" "84b" "84c" "85" "90") then RptNG=1;
RptPA=0;if alleg_cd in ("1" "2" "4" "5" "6" "7" "9" "10" "10a" "10b" "11" "12" "13" "14" "15" "16" "40") then RptPA=1;
RptSA=0;if alleg_cd in ("18" "19" "20" "21" "22a" "22b" "22c" "22d" "22e") then RptSA=1;
RptEA=0;if alleg_cd in ("17") then RptEA=1;
RptNA=0;if alleg_cd="" then RptNA=1;
label
Subst="1=substantiated/indicated allegation"
RptNG="1=neglect allegation"
RptPA="1=physical abuse allegation"
RptSA="1=sexual abuse allegation"
RptEA="1=emotional abuse allegation"
RptNA="1=no alleged maltreatment";
drop scrnum scrseq finding_desc alleg_cd alleg_desc alleg_finding_desc relation_desc person_id_perp person_id_vic dt_of_birth invst_subj_id bdate;
run; /*N=1817835, 28 variables*/

/* Substantiation and maltreatment type  [proc freq data=invst6;table Subst RptNG RptPA RptSA RptEA RptNA/missing;run;]
   - Substantiated/indicated allegations ("Subst"): 20.31% 
   - Neglect allegations                 ("RptNG"): 50.24%
   - Physical abuse allegations          ("RptPA"): 17.87%
   - Sexual abuse allegations            ("RptSA"): 10.42%
   - Emotional abuse allegations         ("RptEA"):  0.30% - IL CPS has only one allegation code (mental injury) for emotional abuse(EA); this may explain the low EA proportion
   - Records with no alleged maltreatment("RptNA"): 21.17% */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating dummies for child sex and race/ethnicity ***************************************************************************************************************************/
/* Creating dummies for child sex and race/ethnicity ***************************************************************************************************************************/
/* Creating dummies for child sex and race/ethnicity ***************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Creating dummies to aggregate the data at the zip code level (i.e., counting the number of children by zip code)
   - Child sex ("sex"): M=male, F=female
   - Child ethnicity ("ethn_cd"): 0=missing, 1=Not Hispanic, 2=Hispanic South American, 3=Hispanic Cuban, 4=Hispanic Mexican, 5=Hispanic Puerto Rican, 
                                  6=Hispanic Spanish Descent, 7=Not Reported, 8=Hispanic Other, 9=Hispanic Dominican, 10=Hispanic Central American, 
                                  11=Declined to Identify, 12=Could not be verified, and 13=Unknown
   - Child race: "race_white"(1=White), "race_black"(1=Black), "race_asian"(1=Asian), "race_nat_amer"(1=Native American), "race_hpi"(1=Native Hawaiian or other Pacific Islander)
   - It is worth noting that racial categories other than "non-Hispanic White alone" (e.g., "Black alone") include both Hispanic and non-Hispanic children
     This is to be consistent with the Census data; that is, other racial categories are overlapped with the Hispanic category (Hispanic including all racial groups)
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Create dummies for child sex and race/ethnicity */
data invst7;set invst6;
SexM=0;if sex="M"                                                                          then SexM=1;
SexF=0;if sex="F"                                                                          then SexF=1;
RacH=0;if ethn_cd in (2 3 4 5 6 8 9 10)                                                    then RacH=1;
RacW=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi+RacH=1 & race_white   =1 then RacW=1;
RacB=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi     =1 & race_black   =1 then RacB=1;
RacA=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi     =1 & race_asian   =1 then RacA=1;
RacN=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi     =1 & race_nat_amer=1 then RacN=1;
RacP=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi     =1 & race_hpi     =1 then RacP=1;
RacO=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi+RacH=0                   then RacO=1;
RacM=0;if race_white+race_black+race_asian+race_nat_amer+race_hpi     >1                   then RacM=1;
label 
SexM="1=child sex:male"
SexF="1=child sex:female"
RacH="1=child ethnicity:Hispanic/Latino & all races"
RacW="1=child race:White alone, non-Hispanic/Latino"
RacB="1=child race:Black alone"
RacA="1=child race:Asian alone"
RacN="1=child race:Native American alone"
RacP="1=child race:Native Hawaiian or other Pacific Islander alone"
RacO="1=child race:Other (non-Hispanic & none of 5 racial groups)"
RacM="1=child race:two or more races";
drop cd_gndr cd_ethnc cd_prim_race ethn_desc sex race_nat_amer race_asian race_black race_hpi race_white ethn_cd;
run; /*N=1817835, 27 variables*/

/* Child sex and child race/ethnicity
   - Child sex  [proc freq data=invst7;tables SexM*SexF/missing;run;]
                Male   (SexM=1):          49.54%
                Female (SexF=1):          49.83%
                Miss   (SexM=0 & SexF=0):  0.63%
   - Child race [proc freq data=invst7;tables RacH RacW RacB RacA RacN RacP RacO RacM/missing;run;]
                Hispanic/Latino, all races                      (RacH=1): 15.07%
                White alone, non-Hispanic/Latino                (RacW=1): 49.21%
                Black alone                                     (RacB=1): 32.21%
                Asian alone                                     (RacA=1):  0.99%
                Native American alone                           (RacN=1):  0.09%
                Native Hawaiian or other Pacific Islander alone (RacP=1):  0.07%
                Other (non-Hispanic & none of 5 racial groups)  (RacO=1):  1.27%
                two or more races                               (RacM=1):  1.94% 
   - Overlap between Black/Asian/NA/NHPI/Two+ and Hispanic  [proc freq data=invst7;tables RacB*RacH RacA*RacH RacN*RacH RacP*RacH RacM*RacH/missing;run;]
                % Hispanic among Black alone          :  1.79%
                % Hispanic among Asian alone          :  3.06%
                % Hispanic among Native American alone: 22.37%
                % Hispanic among NHPI alone           : 13.62%
                % Hispanic among two or more races    : 11.00%
*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Report Type: professional and nonprofessional *******************************************************************************************************************************/
/* Report Type: professional and nonprofessional *******************************************************************************************************************************/
/* Report Type: professional and nonprofessional *******************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Reporter group code ("cd_rptr_grp": 1=Med,2=Edu,3=SS,4=Law,5=Provider,6=DCFS,7=Court,8=Fam,9=Non-Mandated,10=Anonymous)
   - Professional reporter    ("RptP"): cd_rptr_grp in (1 2 3 4 5 6 7)
   - Nonprofessional reporter ("RptN"): cd_rptr_grp in (8 9 10)
   - "invst_subj" table (child/report-level data) --> "rptr" table (report-level data)
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

proc sort data=invst_subj;by invst_id;run; /*N=13649318*/
/***/
data rptr;set invst_subj;
by invst_id;
retain RptP RptN;
if first.invst_id then RptP=0;
if first.invst_id then RptN=0;
if cd_rptr_grp in (1 2 3 4 5 6 7) then RptP=1;
if cd_rptr_grp in (8 9 10)        then RptN=1;
if last.invst_id;
label
RptP="reporter type:pro"
RptN="reporter type:nonprof(fam,non-mand,anonymous)"
;
keep cd_rptr_grp invst_id RptP RptN;
run; /*N=2596641, 4 variables*/

/* % reports made by professionals    (RptP=1): 66.97%
   % reports made by nonprofessionals (RptN=1): 39.02%
--------------------------------------------------------------------
   % reports made by only professionals    (RptP=1 & RptN=0): 59.57% 
   % reports made by only nonprofessionals (RptP=0 & RptN=1): 31.62% 
   % reports made by both pro and nonpro   (RptP=1 & RptN=1):  7.40% 
   % reports with unknown reporter         (RptP=0 & RptN=0):  1.40% */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging "invst7" and "rptr" tables by "invst_id" ****************************************************************************************************************************/
/* Merging "invst7" and "rptr" tables by "invst_id" ****************************************************************************************************************************/
/* Merging "invst7" and "rptr" tables by "invst_id" ****************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Left join of "invst7" table and "rptr" table by "invst_id"
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

proc sort data=invst7;by invst_id;run; /*N=1817835, 27 variables*/
proc sort data=rptr  ;by invst_id;run; /*N=2596641,  4 variables*/
data invst8;merge invst7(IN=A) rptr;by invst_id;if A;run; /*N=1817835, 30 variables*/

/* Records by Reporter Type  [proc freq data=invst8;tables RptP*RptN/missing;run;]
   % records from reports made by professionals    (RptP=1): 76.03%
   % records from reports made by nonprofessionals (RptN=1): 36.16%
--------------------------------------------------------------------
   % records from reports made by only professionals    (RptP=1 & RptN=0): 63.63% 
   % records from reports made by only nonprofessionals (RptP=0 & RptN=1): 23.75% 
   % records from reports made by both pro and nonpro   (RptP=1 & RptN=1): 12.41% 
   % records from reports with unknown reporter         (RptP=0 & RptN=0):  0.21% */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging "address" and "geography" tables by "addr_id" ***********************************************************************************************************************/
/* Merging "address" and "geography" tables by "addr_id" ***********************************************************************************************************************/
/* Merging "address" and "geography" tables by "addr_id" ***********************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Full outer join (inner join will produce the same result as all records are completely matched between "address" and "geography" tables
   - "address" table contains residential zip codes of investigation subjects (since some zip codes are 9-digit codes, the first 5 digits will be selected)
   - "geography" table contains residential census tract codes of investigation subjects (concatenating state, county, and tract FIPS codes)
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Merge "address" and "geography" */
/* Create "tract" ID by concatenating "state_fips_10", "county_fips_10", and "tract_fips_10" */
proc sort data=address  ;by addr_id;run; /*N=8754517,  6 variables*/
proc sort data=geography;by addr_id;run; /*N=8754517, 17 variables*/
data AddGeo;merge address geography;by addr_id;
zip2=substr(zip,1,5);
tract=state_fips_10||county_fips_10||tract_fips_10;
label
zip2="5-digit Zip Code from address"
tract="11-digit tract FIPS"
;run; /*N=8754517, 23 variables */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Replacing missing zip codes with zip codes based on census tract codes ******************************************************************************************************/
/* Replacing missing zip codes with zip codes based on census tract codes ******************************************************************************************************/
/* Replacing missing zip codes with zip codes based on census tract codes ******************************************************************************************************/
/********************************************************************************************************************************************************************************
   - 11.37% records had missing zip code (i.e., having zip code not in Census data); among these records, 35.90% had a valid census tract code 
     I checked these after linking with "Tract Zip Code Crosswalk File", "US Zip Codes in Census data", and "Illinois Zip Codes in Census data"
     (see the below "Checking records with missing zip code from Address and Census Tract")
   - Tract Zip Code Crosswalk File (https://www.huduser.gov/portal/datasets/usps_crosswalk.html)
     Zip codes will be assigned to tract codes based on the "Tract Zip Code Crosswalk File"
     For tracts across multiple zip codes, one zip code will be assigned with the highest ratio of residential addresses
   - US Zip Codes in Census data and Illinois Zip Codes in Census data were used to identify "AddGeo" records with valid zip codes in Census data
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Importing Tract Zip Code Crosswalk File */
proc import out=tract_zip datafile="Z:\CDCK01\Data_Zip\CAN\RawData\TRACT_ZIP_032010.xlsx" dbms=xlsx replace;sheet="TRACT_ZIP_032010";getnames=yes;run; /*N=145629, 6 variables*/
data tract_zip;set tract_zip;
label
ZIP="5-digit Zip Code from tract"
TRACT="11-digit tract FIPS"
RES_RATIO="Ratio of residential addresses in ZIP  Tract part to total number of residential addresses in entire ZIP"
BUS_RATIO="Ratio of business addresses in ZIP  Tract part to total number of business addresses in entire ZIP"
OTH_RATIO="Ratio of other addresses in ZIP  Tract part to total number of other addresses in entire ZIP"
TOTAL_RATIO="Ratio of all addresses in ZIP  Tract part to total number of all types of addresses in entire ZIP"
;run; /*N=145629, 6 variables*/
proc sort data=tract_zip;by tract res_ratio;run; /*N=145629*/
data tract_zip;set tract_zip;by tract;
if last.tract;zip3=zip;
label 
zip3="5-digit Zip Code from tract";
keep tract zip3;run; /*N=65755, 2 variables*/

/* US Zip Codes in Census data (ACS 5-digit ZIP Code Tabulation Area, 5-Year Estimates -- https://www.socialexplorer.com/explore-tables) */
/* zip2011=ACS2011; zip2012=ACS2012; zip2013=ACS2013; zip2014=ACS2014; zip2015=ACS2015; zip2016=ACS2016; zip2017=ACS2017; zip2018=ACS2018; */
data zip11;set b.zip2011;zip=ZCTA5;flag11=1;keep zip flag11;run; /*N=33120, 2 variables*/
data zip12;set b.zip2012;zip=ZCTA5;flag12=1;keep zip flag12;run; /*N=33120, 2 variables*/
data zip13;set b.zip2013;zip=ZCTA5;flag13=1;keep zip flag13;run; /*N=33120, 2 variables*/
data zip14;set b.zip2014;zip=ZCTA5;flag14=1;keep zip flag14;run; /*N=33120, 2 variables*/
data zip15;set b.zip2015;zip=ZCTA5;flag15=1;keep zip flag15;run; /*N=33120, 2 variables*/
data zip16;set b.zip2016;zip=ZCTA5;flag16=1;keep zip flag16;run; /*N=33120, 2 variables*/
data zip17;set b.zip2017;zip=ZCTA5;flag17=1;keep zip flag17;run; /*N=33120, 2 variables*/
data zip18;set b.zip2018;zip=ZCTA5;flag18=1;keep zip flag18;run; /*N=33120, 2 variables*/
proc sort data=zip11;by zip;run; /*N=33120*/
proc sort data=zip12;by zip;run; /*N=33120*/
proc sort data=zip13;by zip;run; /*N=33120*/
proc sort data=zip14;by zip;run; /*N=33120*/
proc sort data=zip15;by zip;run; /*N=33120*/
proc sort data=zip16;by zip;run; /*N=33120*/
proc sort data=zip17;by zip;run; /*N=33120*/
proc sort data=zip18;by zip;run; /*N=33120*/
data USzip;merge zip11 zip12 zip13 zip14 zip15 zip16 zip17 zip18;by zip;flag_USzip=1;run; /*N=33120, 10 variables*/
/* proc freq data=USzip;tables flag11 flag12 flag13 flag14 flag15 flag16 flag17 flag18;run; /* No change in zip codes across 2011 - 2018 ACS data */
data USzip;set USzip;keep zip flag_USzip;
label
flag_USzip="1=valid US Zip Code in Census"
zip="5-digit Zip Code";
run; /*N=33120, 2 variables*/

/* Illinois Zip Codes in Census data (2010 ZCTA to County Relationship File -- https://www.census.gov/geographies/reference-files/time-series/geo/relationship-files.html) */
data Zip_County;
infile "Z:\CDCK01\Data_Zip\CAN\RawData\IL_ZIP\zcta_county_rel_10.txt" dsd truncover firstobs=2;
input ZCTA5 $ STATE COUNTY GEOID POPPT HUPT AREAPT AREALANDPT ZPOP ZHU ZAREA ZAREALAND COPOP COHU COAREA COAREALAND ZPOPPCT ZHUPCT ZAREAPCT ZAREALANDPCT COPOPPCT COHUPCT COAREAPCT COAREALANDPCT;
label
ZCTA5="2010 ZIP Code Tabulation Area"
STATE="2010 State FIPS Code"
ZPOPPCT="The Percentage of Total Population of the 2010 ZCTA represented by the record";
run; /*N=44410, 24 variables*/
/***/
/* Selecting IL Zip Codes and checking whether Zip Code boundaries across multiple states */
data ILzip;set Zip_County;IL=0;if STATE=17 then IL=1;run; /*N=44410, 25 variables*/
proc sort data=ILzip;by ZCTA5 IL;run; /*N=44410*/
data ILzip;set ILzip;by ZCTA5;retain count;
if first.ZCTA5 then count=1;
if IL=0 then count=count+1;
if IL=1 & last.ZCTA5;
zip=ZCTA5;
flag_ILzip=1;
label
flag_ILzip="1=valid IL Zip Code in Census"
zip="5-digit Zip Code";
keep zip flag_ILzip count;
run; /*N=1384, 3 variables*/
/***/
/* 1383 Zip Codes are entirely nested in IL State Boundary; 1 Zip Code is across multiple states [proc freq data=ILzip;tables count;run;] */
/* "Zip Code=63673" is across multiple states [proc print data=ILzip;where count>1;run;] */
/* 2.22% of the Zip Code(=63673) population are IL residents; 97.78% are MO residents [proc print data=Zip_County;var ZCTA5 STATE ZPOPPCT;where ZCTA5="63673";run;] */
/* SOLUTION: Delete "Zip Code = 63673 */
data ILzip;set ILzip;if count=1;drop count;run; /*N=1383, 2 variables*/

/* Merge USzip and ILzip */
proc sort data=USzip;by zip;run; /*N=33120, 2 variables*/
proc sort data=ILzip;by zip;run; /*N= 1383, 2 variables*/
data Zip;merge USzip ILzip;by zip;;run; /*N=33120, 3 variables*/ /* You can ignore the "multiple lengths" warning */

/* Merge "AddGeo" and "tract_zip" by tract -- adding zip codes (zip3) from census tract (Left Join) */
proc sort data=AddGeo   ;by tract;run;                       /*N=8754517, 23 variables*/
proc sort data=tract_zip;by tract;run;                       /*N=  65755,  2 variables*/
data AddGeo1;merge AddGeo(IN=A) tract_zip;by tract;if A;run; /*N=8754517, 24 variables*/

/* Merge "AddGeo1" and "Zip" by "zip2" - zip codes from address */
data Zip2;set Zip;
flag_USzip2=flag_USzip;
flag_ILzip2=flag_ILzip;
zip2=zip;
label
flag_USzip2="1=valid US Zip Code in Census-for zip2"
flag_ILzip2="1=valid IL Zip Code in Census-for zip2"
zip2="5-digit Zip Code from address";
keep flag_USzip2 flag_ILzip2 zip2;
run; /*N=33120*/
proc sort data=AddGeo1;by zip2;run; /*N=8754517, 24 variables*/
proc sort data=Zip2   ;by zip2;run; /*N=  33120,  3 variables*/
data AddGeo2;merge AddGeo1(IN=A) Zip2;by zip2;if A;run; /*N=8754517, 26 variables*/

/* Merge "AddGeo2" and "Zip" by "zip3" - zip codes from census tract */
data Zip3;set Zip;
flag_USzip3=flag_USzip;
flag_ILzip3=flag_ILzip;
zip3=zip;
label
flag_USzip3="1=valid US Zip Code in Census-for zip3"
flag_ILzip3="1=valid IL Zip Code in Census-for zip3"
zip3="5-digit Zip Code from tract";
keep flag_USzip3 flag_ILzip3 zip3;
run; /*N=33120*/
proc sort data=AddGeo2;by zip3;run; /*N=8754517, 26 variables*/
proc sort data=Zip3   ;by zip3;run; /*N=  33120,  3 variables*/
data AddGeo3;merge AddGeo2(IN=A) Zip3;by zip3;if A;run; /*N=8754517, 28 variables*/

/* Checking records with missing zip code from Address and Census Tract */
/* proc freq data=AddGeo3;tables flag_USzip2*flag_USzip3 flag_ILzip2*flag_ILzip3/missing;run; */
/*
********************************************************************
United States ******************************************************
********************************************************************
--------------------------------------------------------------------
            | flag_USzip3		
--------------------------------------------------------------------
flag_USzip2 | .                | 1                | Total
--------------------------------------------------------------------
 .          |  671396 ( 7.67%) |  323836 ( 3.70%) |  995232 (11.37%)
--------------------------------------------------------------------
 1          | 2785386 (31.82%) | 4973899 (56.82%) | 7759285 (88.63%)
--------------------------------------------------------------------
Total       | 3456782 (39.49%) | 5297735 (60.51%) | 8754517 (100%)
--------------------------------------------------------------------
***
********************************************************************			
Illinois ***********************************************************
********************************************************************
--------------------------------------------------------------------
            | flag_ILzip3
--------------------------------------------------------------------
flag_ILzip2 | .                | 1                | Total
--------------------------------------------------------------------
.           | 1060292 (12.11%) |  394025 ( 4.50%) | 1454317 (16.61%)
--------------------------------------------------------------------
1           | 2555093 (29.19%) | 4745107 (54.20%) | 7300200 (83.39%)
--------------------------------------------------------------------
Total       | 3615385 (41.30%) | 5139132 (58.70%) | 8754517 (100%)
--------------------------------------------------------------------
***
 7.67% of records have no valid US zip codes to link to Census data
12.11% of records have no valid IL zip codes to link to Census data
***
"address" and "geography" tables have very old records (1970s')
More recent records may have less invalid zip codes.
********************************************************************/

/* Clean Up AddGeo data */
data AddGeo4;set AddGeo3;
if flag_USzip2=1                 then ZipCode=zip2; 
if flag_USzip2=. & flag_USzip3=1 then ZipCode=zip3;
if flag_ILzip2=1                 then ZipCode=zip2;
if flag_ILzip2=. & flag_ILzip3=1 then ZipCode=zip3;
if flag_USzip2=. & flag_USzip3=. then ZipCode=""  ;
if flag_USzip2=1 | flag_USzip3=1 then flag_USzip=1;
if flag_USzip2=. & flag_USzip3=. then flag_USzip=.;
if flag_ILzip2=1 | flag_ILzip3=1 then flag_ILzip=1;
if flag_ILzip2=. & flag_ILzip3=. then flag_ILzip=.;
label
ZipCode="5-digit Zip Code"
flag_USzip="1=valid US Zip Code"
flag_ILzip="1=valid IL Zip Code"
;
keep addr_id ZipCode flag_USzip flag_ILzip;
run; /*N=8754517, 4 variables*/

/* Check Address+Geography records with valid US and IL Zip Codes of Census Data */
/* proc freq data=AddGeo4;tables flag_USzip*flag_ILzip/missing;run; */
/******************************************************************
 7.67% of records have no valid US zip codes to link to Census data
 4.44% of records have valid US zip codes outside IL
87.89% of records have valid US zip codes within IL
*******************************************************************/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging "invst8" table with "investigation_address" and "investigation_person_address" tables *******************************************************************************/
/* Merging "invst8" table with "investigation_address" and "investigation_person_address" tables *******************************************************************************/
/* Merging "invst8" table with "investigation_address" and "investigation_person_address" tables *******************************************************************************/
/********************************************************************************************************************************************************************************
   - To be linked with "AddGeo4" table, "invst8" table needs to be linked with address ID tables to have address ID ("addr_id")
   - Three address ID sources
     - Left join of "invst8" table and "investigation_address"        table by "invst_id"
     - Left join of "invst8" table and "investigation_person_address" table by "invst_id"
     - Left join of "invst8" table and "investigation_person_address" table by "person_id"
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Address ID by invst_id of investigation_address - left join */
proc sort data=invst8               ;by invst_id;run; /*N=1817835, 30 variables*/
proc sort data=investigation_address;by invst_id;run; /*N=1338311,  3 variables*/
data invst9;merge invst8(IN=A) investigation_address;by invst_id;if A;
addr_id1=addr_id;
label addr_id1="Address ID (by invst_id of investigation_address)";
drop addr_id source_month;
run; /*N=1817835, 31 variables*/
/***/
/* Address ID by invst_id of investigation_person_address - left join */
proc sort data=investigation_person_address;by invst_id person_id;run; /*N=4404926, 4 variables*/
data IP_address1;set investigation_person_address;by invst_id;if last.invst_id;
addr_id2=addr_id;
label addr_id2="Address ID (by invst_id of investigation_person_address)";
drop addr_id person_id source_month;run; /*N=1571105, 2 variables*/
proc sort data=invst9     ;by invst_id;run; /*N=1817835, 31 variables*/
proc sort data=IP_address1;by invst_id;run; /*N=1571105,  2 variables*/
data invst10;merge invst9(IN=A) IP_address1;by invst_id;if A;run; /*N=1817835, 32 variables*/
/***/
/* Address ID by person_id of investigation_person_address - left join */
data IP_address2;set investigation_person_address;
invst_pers_id=catx('-',invst_id,person_id);
addr_id3=addr_id;
label addr_id3="Address ID (by invst_pers_id of investigation_person_address)";
keep invst_pers_id addr_id3;run; /*N=2632211, 2 variables*/
data invst10;set invst10;invst_pers_id=catx('-',invst_id,person_id);run;
proc sort data=invst10    ;by invst_pers_id;run; /*N=1817835, 32 variables*/
proc sort data=IP_address2;by invst_pers_id;run; /*N=2632211,  2 variables*/
data invst11;merge invst10(IN=A) IP_address2;by invst_pers_id;if A;run; /*N=1817835, 33 variables*/

/* Check records with missing Address ID  
   [proc means data=invst11 nmiss n;var addr_id1 addr_id2 addr_id3;run;]
   [proc freq data=invst11;tables addr_id3;where addr_id3=. & addr_id2=. & addr_id1=.;run;]
   # records with missing addr_id1                             = 186513 (10.26% of 1817835 records)
   # records with missing addr_id2                             = 101911 ( 5.61% of 1817835 records)
   # records with missing addr_id3                             = 271297 (14.92% of 1817835 records)
   # records with missing all addr_id1, addr_id2, and addr_id3 =  13172 ( 0.72% of 1817835 records) */

/* Merge with Address+Geography by ZipCode1 */
data AddGeo41;set AddGeo4;
addr_id1=addr_id;ZipCode1=ZipCode;flag_USzip1=flag_USzip;flag_ILzip1=flag_ILzip;
label 
addr_id1="Address ID (by invst_id of investigation_address)"
ZipCode1="5-digit Zip Code (by invst_id of investigation_address)"
flag_USzip1="1=valid US Zip Code (by invst_id of investigation_address)"
flag_ILzip1="1=valid IL Zip Code (by invst_id of investigation_address)";
drop addr_id ZipCode flag_USzip flag_ILzip;run; /*N=8754517, 4 variables*/
proc sort data=invst11 ;by addr_id1;run; /*N=1817835, 33 variables*/
proc sort data=AddGeo41;by addr_id1;run; /*N=8754517,  4 variables*/
data invst12;merge invst11(IN=A) AddGeo41;by addr_id1;if A;run; /*N=1817835, 36 variables*/
/***/
/* Merge with Address+Geography by ZipCode2 */
data AddGeo42;set AddGeo4;
addr_id2=addr_id;ZipCode2=ZipCode;flag_USzip2=flag_USzip;flag_ILzip2=flag_ILzip;
label 
addr_id2="Address ID (by invst_id of investigation_person_address)"
ZipCode2="5-digit Zip Code (by invst_id of investigation_person_address)"
flag_USzip2="1=valid US Zip Code (by invst_id of investigation_person_address)"
flag_ILzip2="1=valid IL Zip Code (by invst_id of investigation_person_address)";
drop addr_id ZipCode flag_USzip flag_ILzip;run; /*N=8754517, 4 variables*/
proc sort data=invst12 ;by addr_id2;run; /*N=1817835, 36 variables*/
proc sort data=AddGeo42;by addr_id2;run; /*N=8754517,  4 variables*/
data invst13;merge invst12(IN=A) AddGeo42;by addr_id2;if A;run; /*N=1817835, 39 variables*/
/***/
/* Merge with Address+Geography by ZipCode3 */
data AddGeo43;set AddGeo4;
addr_id3=addr_id;ZipCode3=ZipCode;flag_USzip3=flag_USzip;flag_ILzip3=flag_ILzip;
label 
addr_id3="Address ID (by invst_pers_id of investigation_person_address)"
ZipCode3="5-digit Zip Code (by invst_pers_id of investigation_person_address)"
flag_USzip3="1=valid US Zip Code (by invst_pers_id of investigation_person_address)"
flag_ILzip3="1=valid IL Zip Code (by invst_pers_id of investigation_person_address)";
drop addr_id ZipCode flag_USzip flag_ILzip;run; /*N=8754517, 4 variables*/
proc sort data=invst13 ;by addr_id3;run; /*N=1817835, 39 variables*/
proc sort data=AddGeo43;by addr_id3;run; /*N=8754517,  4 variables*/
data invst14;merge invst13(IN=A) AddGeo43;by addr_id3;if A;run; /*N=1817835, 42 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating ZipCode based ZipCode3, ZipCode2, and ZipCode1 *********************************************************************************************************************/
/* Creating ZipCode based ZipCode3, ZipCode2, and ZipCode1 *********************************************************************************************************************/
/* Creating ZipCode based ZipCode3, ZipCode2, and ZipCode1 *********************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Priority: 
     - Address linked to invst_pers_id from investigation_person_address table - addr_id3 - ZipCode3
     - Address linked to investigation from investigation_person_address table - addr_id2 - ZipCode2
     - Address linked to investigation from investigation_address        table - addr_id1 - ZipCode1
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data invst15;set invst14;
ZipCode="     ";
if flag_USzip3^=.                                   then ZipCode=ZipCode3;
if flag_USzip3 =. & flag_USzip2^=.                  then ZipCode=ZipCode2;
if flag_USzip3 =. & flag_USzip2 =. & flag_USzip1^=. then ZipCode=ZipCode1;
if flag_ILzip3^=.                                   then ZipCode=ZipCode3;
if flag_ILzip3 =. & flag_ILzip2^=.                  then ZipCode=ZipCode2;
if flag_ILzip3 =. & flag_ILzip2 =. & flag_ILzip1^=. then ZipCode=ZipCode1;
flag_USzip=1;if flag_USzip3=. & flag_USzip2=. & flag_USzip1=. then flag_USzip=0;
flag_ILzip=1;if flag_ILzip3=. & flag_ILzip2=. & flag_ILzip1=. then flag_ILzip=0;
flag_AddrID=1;if addr_id3=. & addr_id2=. & addr_id1=. then flag_AddrID=0;
flag_sex=1;if SexM+SexF=0 then flag_sex=0;
flag_race=1;if RacH+RacW+RacB+RacA+RacN+RacP+RacM=0 then flag_race=0;
flag_rptr=1;if RptP+RptN=0 then flag_rptr=0;
label
ZipCode="5-digit Zip Code"
flag_USzip="1=valid US Zip Code"
flag_ILzip="1=valid IL Zip Code"
flag_AddrID="1=valid Address ID"
flag_sex="1=valid sex code"
flag_race="1=valid race code"
flag_rptr="1=valid reporter type code";
drop addr_id1 addr_id2 addr_id3 ZipCode1 flag_USzip1 flag_ILzip1 ZipCode2 flag_USzip2 flag_ILzip2 ZipCode3 flag_USzip3 flag_ILzip3;
run; /*N=1817835, 37 variables*/
proc freq data=invst15;tables flag_sex flag_race flag_rptr flag_USzip*flag_AddrID flag_ILzip*flag_USzip;run;
/* Check Missing Records ****************************************************************************************
   [proc freq data=invst15;tables flag_sex flag_race flag_rptr flag_USzip*flag_AddrID flag_ILzip*flag_USzip;run;]
       Total                : 1817835
       Missing sex          :   11455 (0.63%)
       Missing race         :   23111 (1.27%)
       Missing reporter type:    3898 (0.21%)
       No valid IL Zip Code :   36026 (1.98%) -> Missing Address ID (No Zip Code)  : 13172 (0.72%)
                                              -> Zip Code not in Census US Zip Code: 19906 (1.10%)
                                              -> Zip Code not in Census IL Zip Code:  2948 (0.16%)
   Overall, a very small proportion of records have no valid zip code
*****************************************************************************************************************/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Annual unduplicate counts of reported children ******************************************************************************************************************************/
/* Annual unduplicate counts of reported children ******************************************************************************************************************************/
/* Annual unduplicate counts of reported children ******************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Unduplicate counts of reported children per year for total, race, gender, age, maltreatment type, substantiation, and reporter source
     - Total          : # of children with a maltreatment report
     - Race           : # of "White/Black/Asian/Native American/NHPI/Multiple-race/Hispanic children" with a maltreatment report
       (non-Hispanic White alone, Black alone, Asian alone, Native American alone, Native Hawaiian/Other Pacific Island alone, Multiple races, and Hispanic including all races)
     - Sex            : # of "male/female" children with a maltreatment report
     - Age            : # of children aged "0-5 years/6-11 years/12-17 years" with a maltreatment report
     - Type           : # of children with a "neglect/physical abuse/sexual abuse/emotional abuse/no allegation" report
     - Substantiation : # of children with an indicated (substantiated) maltreatment report
     - Reporter source: # of with a maltreatment report made by a "professional/nonprofessional"
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Creating PersonYear ID (for annual unduplicate counts of reported children) */
data invst16;set invst15;PrsnYr=person_id*10000+RptYear;run; /*N=1817835, 38 variables*/

/* Sorting data by (ascending)  "PrsnYr" and "report_date"    to select the annual first report per child         */
/* Sorting data by (descending) "flag_ILzip" and "flag_USzip" to select records of a report with a valid Zip Code */
proc sort data=invst16;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=1817835, 38 variables*/

/* Annual first report = annual unduplicate counts of children with a maltreatment report */
data Rpt;set invst16;by PrsnYr;
Rpt=1;
Age1=0;if  0=<age=< 5 then Age1=1;
Age2=0;if  6=<age=<11 then Age2=1;
Age3=0;if 12=<age=<17 then Age3=1;
if first.PrsnYr;
run; /*N=1058695, 42 variables*/

proc freq data=Rpt;tables Rpt RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip flag_sex flag_race RacW RacB RacA RacN RacP RacM RacH RacO SexM SexF Age1 Age2 Age3;run;
proc freq data=Rpt;tables flag_sex flag_race;where flag_ILzip=1;run;

/* # children with a maltreatment report by year, valid zip code, total, race, gender, and age group *******************************************************
[proc freq data=Rpt;tables Rpt RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip RacW RacB RacA RacN RacP RacM RacH RacO SexM SexF Age1 Age2 Age3;run;]
************************************************************************************************************************************************************
1058695 children had a maltreatment from 2011 to 2018 (annual unduplicate counts)
************************************************************************************************************************************************************
Year  # children with a report
------------------------------
2011  117797
2012  121685
2013  127026
2014  125447
2015  134173
2016  139689
2017  140356
2018  152522
************************************************************************************************************************************************************
 6504 children with a report (0.61% out of 1058695) had no address ID
11511 chidlren with a report (1.09% out of 1058695) had an address ID but no valid US Zip Code linkable to Census data
 1908 children with a report (0.18% out of 1058695) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************
Race             # children with a report from 2011 to 2018
-----------------------------------------------------------
White            488996 (46.19%)
Black            357797 (33.80%)
Asian             12206 ( 1.15%)
Native American     987 ( 0.09%)
NHPI                776 ( 0.07%)
Multiple          17604 ( 1.66%)
Hispanic         170923 (16.14%)
Other             17937 ( 1.69%)
************************************************************************************************************************************************************
Sex     # children with a report from 2011 to 2018
--------------------------------------------------
Male    529109 (49.98%)
Female  521270 (49.24%)
************************************************************************************************************************************************************
Age group        # children with a report from 2011 to 2018
-----------------------------------------------------------
1 ( 0- 5 years)  399513 (37.74%)
2 ( 6-11 years)  367200 (34.68%)
3 (12-17 years)  291982 (27.58%)
************************************************************************************************************************************************************/

/* Annual first neglect report = annual unduplicate counts of children with a neglect report */
data RptNG;set invst16;if RptNG=1;run; /*N=913283, 38 variables*/
proc sort data=RptNG;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=913283*/
data RptNG;set RptNG;by PrsnYr;if first.PrsnYr;run; /*N=521609, 38 variables*/

/* # children with a neglect report by year and valid zip code *********************************************************************************************
[proc freq data=RptNG;tables RptNG RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
521609 children had a negelct report from 2011-2018 (49.27% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a neglect report
--------------------------------------
2011  57323
2012  58624
2013  62173
2014  60357
2015  65601
2016  69633
2017  69986
2018  77912
************************************************************************************************************************************************************
1929 children with a neglect report (0.37% out of 521609) had no address ID
3499 chidlren with a neglect report (0.67% out of 521609) had an address ID but no valid US Zip Code linkable to Census data
 607 children with a neglect report (0.12% out of 521609) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first physical abuse report = annual unduplicate counts of children with a physical abuse report */
data RptPA;set invst16;if RptPA=1;run; /*N=324900, 38 variables*/
proc sort data=RptPA;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=324900*/
data RptPA;set RptPA;by PrsnYr;if first.PrsnYr;run; /*N=249769, 38 variables*/

/* # children with a physical abuse report by year and valid zip code **************************************************************************************
[proc freq data=RptPA;tables RptPA RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
249769 children had a physical abuse report from 2011-2018 (23.59% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a physical abuse report
---------------------------------------------
2011  28687
2012  31109
2013  29287
2014  28363
2015  31742
2016  33672
2017  31512
2018  35397
************************************************************************************************************************************************************
1046 children with a physical abuse report (0.42% out of 249769) had no address ID
1308 chidlren with a physical abuse report (0.52% out of 249769) had an address ID but no valid US Zip Code linkable to Census data
 245 children with a physical abuse report (0.10% out of 249769) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first sexual abuse report = annual unduplicate counts of children with a sexual abuse report */
data RptSA;set invst16;if RptSA=1;run; /*N=189369, 38 variables*/
proc sort data=RptSA;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=189369*/
data RptSA;set RptSA;by PrsnYr;if first.PrsnYr;run; /*N=128710*/

/* # children with a sexual abuse report by year and valid zip code ****************************************************************************************
[proc freq data=RptSA;tables RptSA RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
128710 children had a sexual abuse report from 2011-2018 (12.16% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a sexual abuse report
-------------------------------------------
2011  14875
2012  15890
2013  15397
2014  15031
2015  15845
2016  16165
2017  16833
2018  18674
************************************************************************************************************************************************************
1101 children with a sexual abuse report (0.86% out of 128710) had no address ID
1254 chidlren with a sexual abuse report (0.97% out of 128710) had an address ID but no valid US Zip Code linkable to Census data
 392 children with a sexual abuse report (0.30% out of 128710) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first emotional abuse report = annual unduplicate counts of children with a sexual abuse report */
data RptEA;set invst16;if RptEA=1;run; /*N=5374*/
proc sort data=RptEA;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=5374*/
data RptEA;set RptEA;by PrsnYr;if first.PrsnYr;run; /*N=4581*/

/* # children with a emotional abuse report by year and valid zip code *************************************************************************************
[proc freq data=RptEA;tables RptEA RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
4581 children had a emotional abuse report from 2011-2018 (0.43% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a emotional abuse report
----------------------------------------------
2011   242
2012   322
2013   303
2014   311
2015   455
2016  1040
2017   953
2018   955
************************************************************************************************************************************************************
15 children with a emotional abuse report (0.33% out of 4581) had no address ID
14 chidlren with a emotional abuse report (0.31% out of 4581) had an address ID but no valid US Zip Code linkable to Census data
 2 children with a emotional abuse report (0.04% out of 4581) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first no maltreatment allegation report = annual unduplicate counts of reported children with no maltreatment allegation */
data RptNA;set invst16;if RptNA=1;run; /*N=384909*/
proc sort data=RptNA;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=384909*/
data RptNA;set RptNA;by PrsnYr;if first.PrsnYr;run; /*N=348622*/

/* # children with a "no allegation" report by year and valid zip code *************************************************************************************
[proc freq data=RptNA;tables RptNA RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
348622 children had a "no allegation" report from 2011-2018 (32.93% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a "no allegation" report
----------------------------------------------
2011  36102
2012  37480
2013  41820
2014  42367
2015  45291
2016  46629
2017  48082
2018  50851
************************************************************************************************************************************************************
1521 children with a "no allegation" report (0.44% out of 348622) had no address ID
2174 chidlren with a "no allegation" report (0.62% out of 348622) had an address ID but no valid US Zip Code linkable to Census data
 349 children with a "no allegation" report (0.10% out of 348622) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first substantiated report = annual unduplicate counts of children with a substantiated report */
data Subst;set invst16;if Subst=1;run; /*N=369238*/
proc sort data=Subst;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=369238*/
data Subst;set Subst;by PrsnYr;if first.PrsnYr;run; /*N=237827*/

/* # children with a substantiated report by year and valid zip code ***************************************************************************************
[proc freq data=Subst;tables Subst RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
237827 children had a substantiated report from 2011-2018 (22.46% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a substantiated report
--------------------------------------------
2011  26466
2012  27709
2013  29403
2014  30900
2015  30665
2016  28899
2017  31246
2018  32539
************************************************************************************************************************************************************
 656 children with a substantiated report (0.28% out of 237827) had no address ID
1065 chidlren with a substantiated report (0.45% out of 237827) had an address ID but no valid US Zip Code linkable to Census data
 321 children with a substantiated report (0.13% out of 237827) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first professional-source report = annual unduplicate counts of children with a report from a professional reporter */
data RptP;set invst16;if RptP=1;run; /*N=1382118*/
proc sort data=RptP;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=1382118*/
data RptP;set RptP;by PrsnYr;if first.PrsnYr;run; /*N=857259*/

/* # children with a professional-source report by year and valid zip code *********************************************************************************
[proc freq data=RptP;tables RptP RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
857259 children had a professional-source report from 2011-2018 (80.97% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a professional-source report
--------------------------------------------------
2011   92488
2012   94546
2013   99669
2014  101658
2015  109769
2016  114800
2017  116863
2018  127466
************************************************************************************************************************************************************
3716 children with a professional-source report (0.43% out of 857259) had no address ID
4446 chidlren with a professional-source report (0.52% out of 857259) had an address ID but no valid US Zip Code linkable to Census data
1232 children with a professional-source report (0.14% out of 857259) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/

/* Annual first nonprofessional-source report = annual unduplicate counts of children with a report from a nonprofessional reporter */
data RptN;set invst16;if RptN=1;run; /*N=657337*/
proc sort data=RptN;by PrsnYr report_date descending flag_ILzip descending flag_USzip;run; /*N=657337*/
data RptN;set RptN;by PrsnYr;if first.PrsnYr;run; /*N=387061*/

/* # children with a nonprofessional-source report by year and valid zip code ******************************************************************************
[proc freq data=RptN;tables RptN RptYear flag_AddrID*flag_USzip flag_USzip*flag_ILzip;run;]
************************************************************************************************************************************************************
387061 children had a nonprofessional-source report from 2011-2018 (36.56% of 1058695 children with a maltreatment report)
************************************************************************************************************************************************************
Year  # children with a nonprofessional-source report
-----------------------------------------------------
2011  45603
2012  49745
2013  49980
2014  45459
2015  48728
2016  49974
2017  47205
2018  50367
************************************************************************************************************************************************************
1875 children with a nonprofessional-source report (0.48% out of 387061) had no address ID
4016 chidlren with a nonprofessional-source report (1.04% out of 387061) had an address ID but no valid US Zip Code linkable to Census data
 538 children with a nonprofessional-source report (0.14% out of 387061) had a valid US Zip Code but out of Illinois
************************************************************************************************************************************************************/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Selecting children with a maltreatment report within Illinois Zip Codes *****************************************************************************************************/
/* Selecting children with a maltreatment report within Illinois Zip Codes *****************************************************************************************************/
/* Selecting children with a maltreatment report within Illinois Zip Codes *****************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data Rpt2  ;set Rpt  ;if flag_ILzip=1;run; /*N=1058695 -> 1038772*/
data RptNG2;set RptNG;if flag_ILzip=1;run; /*N= 521609 ->  512750*/
data RptPA2;set RptPA;if flag_ILzip=1;run; /*N= 249769 ->  245942*/
data RptSA2;set RptSA;if flag_ILzip=1;run; /*N= 128710 ->  124517*/
data RptEA2;set RptEA;if flag_ILzip=1;run; /*N=   4581 ->    4525*/
data RptNA2;set RptNA;if flag_ILzip=1;run; /*N= 348622 ->  339072*/
data Subst2;set Subst;if flag_ILzip=1;run; /*N= 237827 ->  234607*/
data RptP2 ;set RptP ;if flag_ILzip=1;run; /*N= 857259 ->  843270*/
data RptN2 ;set RptN ;if flag_ILzip=1;run; /*N= 387061 ->  377134*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Aggregating children with a maltreatment report by Zip Code *****************************************************************************************************************/
/* Aggregating children with a maltreatment report by Zip Code *****************************************************************************************************************/
/* Aggregating children with a maltreatment report by Zip Code *****************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

proc sort data=Rpt2  ;by RptYear ZipCode;run;
proc sort data=RptNG2;by RptYear ZipCode;run;
proc sort data=RptPA2;by RptYear ZipCode;run;
proc sort data=RptSA2;by RptYear ZipCode;run;
proc sort data=RptEA2;by RptYear ZipCode;run;
proc sort data=RptNA2;by RptYear ZipCode;run;
proc sort data=Subst2;by RptYear ZipCode;run;
proc sort data=RptP2 ;by RptYear ZipCode;run;
proc sort data=RptN2 ;by RptYear ZipCode;run;

proc summary data=Rpt2   nway;class RptYear ZipCode;var Rpt RacW RacB RacA RacN RacP RacM RacH RacO SexM SexF Age1 Age2 Age3;output out=Rpt3 sum=;run; /*N=10355*/
proc summary data=RptNG2 nway;class RptYear ZipCode;var RptNG;output out=RptNG3 sum=;run; /*N= 9892*/
proc summary data=RptPA2 nway;class RptYear ZipCode;var RptPA;output out=RptPA3 sum=;run; /*N= 9267*/
proc summary data=RptSA2 nway;class RptYear ZipCode;var RptSA;output out=RptSA3 sum=;run; /*N= 7937*/
proc summary data=RptEA2 nway;class RptYear ZipCode;var RptEA;output out=RptEA3 sum=;run; /*N= 2291*/
proc summary data=RptNA2 nway;class RptYear ZipCode;var RptNA;output out=RptNA3 sum=;run; /*N= 9145*/
proc summary data=Subst2 nway;class RptYear ZipCode;var Subst;output out=Subst3 sum=;run; /*N= 8730*/
proc summary data=RptP2  nway;class RptYear ZipCode;var RptP ;output out=RptP3  sum=;run; /*N=10123*/
proc summary data=RptN2  nway;class RptYear ZipCode;var RptN ;output out=RptN3  sum=;run; /*N= 9388*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Creating ZipYear; Labeling Variables; Dropping Variables ********************************************************************************************************************/
/* Creating ZipYear; Labeling Variables; Dropping Variables ********************************************************************************************************************/
/* Creating ZipYear; Labeling Variables; Dropping Variables ********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data Rpt4;set Rpt3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
Rpt ="# of children with a maltreatment report in Zip Code"
RacW="# of non-Hispanic White alone children with a maltreatment report in Zip Code"
RacB="# of Black alone children with a maltreatment report in Zip Code"
RacA="# of Asian alone children with a maltreatment report in Zip Code"
RacN="# of Native American alone children with a maltreatment report in Zip Code"
RacP="# of Native Hawaiian or Other Pacific Island alone children with a maltreatment report in Zip Code"
RacM="# of two or more races children with a maltreatment report in Zip Code"
RacH="# of Hispanic (including all races) children with a maltreatment report in Zip Code"
RacO="# of other race (none of racial groups) children with a maltreatment report in Zip Code"
SexM="# of male children with a maltreatment report in Zip Code"
SexF="# of female children with a maltreatment report in Zip Code"
Age1="# of children aged 0-5 years with a maltreatment report in Zip Code"
Age2="# of children aged 6-11 years with a maltreatment report in Zip Code"
Age3="# of children aged 12-17 years with a maltreatment report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N=10355*/

data RptNG4;set RptNG3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptNG="# of children with a neglect report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N=9892*/

data RptPA4;set RptPA3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptPA="# of children with a physical abuse report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 9267*/

data RptSA4;set RptSA3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptSA="# of children with a sexual abuse report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 7937*/

data RptEA4;set RptEA3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptEA="# of children with an emotional abuse report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 2291*/

data RptNA4;set RptNA3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptNA="# of children with a 'no allegation' report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 9145*/

data Subst4;set Subst3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
Subst="# of children with an indicated (substantiated) report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 8730*/

data RptP4;set RptP3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptP="# of children with a professional-source report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N=10123*/

data RptN4;set RptN3;
ZipYear=ZipCode*10000+RptYear;
label
ZipYear="ZipCode*10000+RptYear"
RptN="# of children with a nonprofessional-source report in Zip Code";
drop _TYPE_ _FREQ_;
run; /*N= 9388*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging tables by ZipYear & Saving Permanent Data ***************************************************************************************************************************/
/* Merging tables by ZipYear & Saving Permanent Data ***************************************************************************************************************************/
/* Merging tables by ZipYear & Saving Permanent Data ***************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Sorting Data */
proc sort data=Rpt4  ;by ZipYear;run; /*N=10355*/
proc sort data=RptNG4;by ZipYear;run; /*N=9892*/
proc sort data=RptPA4;by ZipYear;run; /*N= 9267*/
proc sort data=RptSA4;by ZipYear;run; /*N= 7937*/
proc sort data=RptEA4;by ZipYear;run; /*N= 2291*/
proc sort data=RptNA4;by ZipYear;run; /*N= 9145*/
proc sort data=Subst4;by ZipYear;run; /*N= 8730*/
proc sort data=RptP4 ;by ZipYear;run; /*N=10123*/
proc sort data=RptN4 ;by ZipYear;run; /*N= 9388*/



/* Merging Data and Saving Permanent Data
   Converting ZipCode from character to numeric
   Replacing missing with 0 (missing means no report in that zip code in that year) */
data c.CAN(rename=(ZipCode2=ZipCode));retain RptYear ZipCode2 ZipYear;
merge Rpt4 RptNG4 RptPA4 RptSA4 RptEA4 RptNA4 Subst4 RptP4 RptN4;by ZipYear;
ZipCode2=ZipCode+0;
array change _numeric_;do over change;if change=. then change=0;end;
label ZipCode2="5-digit Zip Code";
run; /*N=10384*/
proc contents data=c.CAN varnum;run;

