




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import the CPRD data (Source: https://cprd.illinois.edu/expertise/child-and-family-programs/miechv/) and manage the data.
   Among 3439 children served by MIECHV in Illinois from 2015-2018, 95 children (2.76%) had no zip code and were deleted. 
   3344 children were aggregated by zip code from 2015-2018.
*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Illinois Zip Codes, 2015-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 03/30/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_Zip\MHV";             /* Telling SAS where to load/save SAS data */





/* Importing Data */;
proc import datafile="Z:\CDCK01\Data_Zip\MHV\Raw\MIECHV_Illinois_2015_2018.xlsx" out=MHV1 dbms=xlsx replace;getnames=yes;run;
/*N=3439, 4 variables*/



/* Creating ID */;
data MHV1;set MHV1;if ZipCode^=.;
ZipYear=ZipCode*10000+Year;
PID=catx("-",Year,ZipCode,Provider_ID);
run;
/*N=3439-->3344, 6 variables*/



/* Counting Served Children by Zip Code */;
proc sort data=MHV1;by ZipYear;run;
data MHV_C;set MHV1;by ZipYear;retain MHV_C;
if first.ZipYear then MHV_C=0;
MHV_C+1;
if last.ZipYear;
keep Year ZipCode ZipYear MHV_C;
run;
/*N=382, 4 variables*/



/* Counting Serving Agencies by Zip Code */;
proc sort data=MHV1;by PID;run;
data MHV_P;set MHV1;by PID;if first.PID;run;
/*N=665, 6 variables*/
proc sort data=MHV_P;by ZipYear;run;
data MHV_P;set MHV_P;by ZipYear;retain MHV_P;
if first.ZipYear then MHV_P=0;
MHV_P+1;
if last.ZipYear;
keep ZipYear MHV_P;
run;
/*N=382, 2 variables*/



/* Merging # children and # providers per zip code */;
proc sort data=MHV_C;by ZipYear;run; /*N=382, 4 variables*/
proc sort data=MHV_P;by ZipYear;run; /*N=382, 2 variables*/
data MHV2;merge MHV_C MHV_P;by ZipYear;run; /*N=382, 5 variables*/



/* Saving Permanent Data and Labeling Variables */
data a.MHV;set MHV2;
label
Year="Calendar Year"
ZipCode="5-digit Zip Code"
ZipYear="ZipCode*10000+RptYear"
MHV_C="# children served by MIECHV in the area (zip code)"
MHV_P="# MIECHV providers serving the area (zip code)"
;
run;
proc contents data=a.MHV varnum;run;





