




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2022 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* This SAS program is to merge the following zip code-level datasets:
   (a) CAN report rate
   (b) Census (ACS) data
   (c) Urban/Rural Code (NCHS) - County-level data
   (d) Spatial (latitude and longitude) data 
   (e) IECAM data 
   (f) MIECHV provision 
   (g) Food insecurity 

   For the documentation of these datasets, please see the SAS program for the each dataset.

   *** Child care availability data and health service availability data are proposed to drop.
   *** IECAM data will be added, which have child care data and preventive service data (eg, Head Start, DHS home visitation).

/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Illinois Statewide, 2011-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 02/08/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output";
libname a  "Z:\CDCK01\Data_Zip\CAN";
libname b  "Z:\CDCK01\Data_Zip\Census";
libname c1 "Z:\CDCK01\Data_Zip\NCHS_RUC"; /* County-level data */
libname c2 "Z:\CDCK01\Data_Zip\USDA_RUC"; /* County-level data */
libname d  "Z:\CDCK01\Data_Zip\Spatial";
libname e  "Z:\CDCK01\Data_Zip\IECAM";
libname f  "Z:\CDCK01\Data_Zip\MHV";
libname g  "Z:\CDCK01\Data_Zip\Food";
libname z  "Z:\CDCK01\Data_Zip";

 



/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* CAN data ************************************************************************************************************************************/
/********************************* CAN data ************************************************************************************************************************************/
/********************************* CAN data ************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
data CAN;retain Year ZipCode ZipYear CANFlag;set a.CAN(rename=(RptYear=Year));CANFlag=1;
label 
Year="Calendar Year" 
ZipYear="ZipCode & Year (ZZZZZYYYY)";
run; 
/*N=10504, 26 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Census data *********************************************************************************************************************************/
/********************************* Census data *********************************************************************************************************************************/
/********************************* Census data *********************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
data Census;retain Year ZipCode ZipYear CensusFlag;set b.Census(rename=(ZipCode=ZipCode2));CensusFlag=1;ZipCode=ZipCode2+0;
label ZipCode="5-digit Zip Code";
drop ZipCode2;run; 
/*N=11064, 725 variables */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* A01: Merging CAN data and Census data & Computing CAN rates *********************************************************************************/
/********************************* A01: Merging CAN data and Census data & Computing CAN rates *********************************************************************************/
/********************************* A01: Merging CAN data and Census data & Computing CAN rates *********************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/***/
/* Sorting data */;
proc sort data=CAN   ;by ZipYear;run;     /*N=10503,  26 variables*/
proc sort data=Census;by ZipYear;run;     /*N=11064, 725 variables*/
/***/
/* Merging data */;
data A01;retain Year ZipCode ZipYear CANFlag Rpt RacW RacB RacA RacN RacP RacM RacH RacO SexM SexF Age1 Age2 Age3 RptNG RptPA RptSA RptEA RptNA Subst RptP RptN RptTr RptWr RptBr 
RptAr RptIr RptPr RptUr RptHr RptMr RptFr Rpt1r Rpt2r Rpt3r NegTr PhyTr SexTr EmoTr NoaTr VicTr RprTr RnpTr;
merge CAN Census;by ZipYear;
/* Replacing missing CANFlag with 1 */
CANFlag=1;
/* Missing CAN report indicates no report in that zip code in that year -- SOLUTION: replacing missing with 0 */
array change Rpt RacW RacB RacA RacN RacP RacM RacH RacO SexM SexF Age1 Age2 Age3 RptNG RptPA RptSA RptEA RptNA Subst RptP RptN;
do over change;if change=. then change=0;end;
/* Computing CAN Rates */
if CPopT =0 then RptTr=0;if CPopT ^=0 then RptTr=Rpt  /CPopT *1000;label RptTr="CAN report rate per 1k children,Total";
if CPopW =0 then RptWr=0;if CPopW ^=0 then RptWr=RacW /CPopW *1000;label RptWr="CAN report rate per 1k children,non-Hispanic/Latino White alone";
if CPopB =0 then RptBr=0;if CPopB ^=0 then RptBr=RacB /CPopB *1000;label RptBr="CAN report rate per 1k children,Black alone";
if CPopA =0 then RptAr=0;if CPopA ^=0 then RptAr=RacA /CPopA *1000;label RptAr="CAN report rate per 1k children,Asian alone";
if CPopN =0 then RptIr=0;if CPopN ^=0 then RptIr=RacN /CPopN *1000;label RptIr="CAN report rate per 1k children,American Indian/Alaska Native alone";
if CPopP =0 then RptPr=0;if CPopP ^=0 then RptPr=RacP /CPopP *1000;label RptPr="CAN report rate per 1k children,Native Hawaiian/Other Pacific Islander alone";
if CPopM =0 then RptUr=0;if CPopM ^=0 then RptUr=RacM /CPopM *1000;label RptUr="CAN report rate per 1k children,Two or more races";
if CPopH =0 then RptHr=0;if CPopH ^=0 then RptHr=RacH /CPopH *1000;label RptHr="CAN report rate per 1k children,Hispanic/Latino";
if CPopTM=0 then RptMr=0;if CPopTM^=0 then RptMr=SexM /CPopTM*1000;label RptMr="CAN report rate per 1k male children";
if CPopTF=0 then RptFr=0;if CPopTF^=0 then RptFr=SexF /CPopTF*1000;label RptFr="CAN report rate per 1k female children";
if CPop1 =0 then Rpt1r=0;if CPop1 ^=0 then Rpt1r=Age1 /CPop1 *1000;label Rpt1r="CAN report rate per 1k children aged 0-5 years";
if CPop2 =0 then Rpt2r=0;if CPop2 ^=0 then Rpt2r=Age2 /CPop2 *1000;label Rpt2r="CAN report rate per 1k children aged 6-11 years";
if CPop3 =0 then Rpt3r=0;if CPop3 ^=0 then Rpt3r=Age3 /CPop3 *1000;label Rpt3r="CAN report rate per 1k children aged 12-17 years";
if CPopT =0 then NegTr=0;if CPopT ^=0 then NegTr=RptNG/CPopT *1000;label NegTr="Neglect report rate per 1k children";
if CPopT =0 then PhyTr=0;if CPopT ^=0 then PhyTr=RptPA/CPopT *1000;label PhyTr="Physical abuse report rate per 1k children";
if CPopT =0 then SexTr=0;if CPopT ^=0 then SexTr=RptSA/CPopT *1000;label SexTr="Sexual abuse report rate per 1k children";
if CPopT =0 then EmoTr=0;if CPopT ^=0 then EmoTr=RptEA/CPopT *1000;label EmoTr="Emotional abuse report rate per 1k children";
if CPopT =0 then NoaTr=0;if CPopT ^=0 then NoaTr=RptNA/CPopT *1000;label NoaTr="'no-alleged-maltreatment' report rate per 1k children";
if CPopT =0 then VicTr=0;if CPopT ^=0 then VicTr=Subst/CPopT *1000;label VicTr="Substantiated CAN report rate per 1k children";
if CPopT =0 then RprTr=0;if CPopT ^=0 then RprTr=RptP /CPopT *1000;label RprTr="Professional-source CAN report rate per 1k children";
if CPopT =0 then RnpTr=0;if CPopT ^=0 then RnpTr=RptN /CPopT *1000;label RnpTr="Nonprofessional-source CAN report rate per 1k children";
run; 
/*N=11064, 769 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Urban/Rural Code (NCHS) *********************************************************************************************************************/
/********************************* Urban/Rural Code (NCHS) *********************************************************************************************************************/
/********************************* Urban/Rural Code (NCHS) *********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDC NCHS provide county-level Urban/Rural codes. This section will link county-level UR codes to zip code-level data using the 2010 ZCTA to County relationship file.
   When a zip code is entirely nested in a county, the zip code's UR code would be the county's UR code.
   When a zip code is nested in multiple counties, the zip code's UR code would be the zip-code-population-weighted average of the counties' UR codes.
   ***
   The relationship file is "zip code-county" pair level data. For example, zip code 60013 is nested in two counties 17097 and 17111. 
   3.97% of Zip Code 60013's population are residing in County 17097 and 96.03% are residing in County 17111.   
   Zip Code 60013's UR code would be "0.0397*(County 17097's UR code) + 0.9603*(County 17111's UR code)". Then, zip code UR codes will be round to the closest integer. */
/***/
/***/
/***/
/* 2010 ZCTA to County Relationship File 
   Website -- https://www.census.gov/geographies/reference-files/time-series/geo/relationship-files.2010.html 
   File    -- https://www2.census.gov/geo/docs/maps-data/data/rel/zcta_county_rel_10.txt */;
data Zip_County;
/* Importing 2010 ZCTA to County Relationship File */
infile "Z:\CDCK01\Data_Zip\CAN\RawData\IL_ZIP\zcta_county_rel_10.txt" dsd truncover firstobs=2;
input ZCTA5 $ STATE COUNTY GEOID POPPT HUPT AREAPT AREALANDPT ZPOP ZHU ZAREA ZAREALAND COPOP COHU COAREA COAREALAND ZPOPPCT ZHUPCT ZAREAPCT ZAREALANDPCT COPOPPCT COHUPCT COAREAPCT COAREALANDPCT;
/* Selecting IL data */
if State=17; 
/* Excluding Zip Code 63673 -- 2.22% of the Zip Code(=63673) population are IL residents; 97.78% are MO residents */
if ZCTA5=63673 then delete;
/* Renaming, labeling, selecting variables */
ZipCode=ZCTA5+0;
CountyFIPS=GEOID;
label 
ZipCode="5-digit Zip Code"
CountyFIPS="County FIPS code"
ZPOPPCT="The Percentage of Total Population of the 2010 ZCTA represented by the record";
keep ZipCode CountyFIPS ZPOPPCT;
run; 
/*N=1924 -- 1383 zip codes (proc freq data=Zip_County nlevels;tables ZipCode/noprint;run;) */
/***/
/* Importing NCHS_RUC */;
data NCHS1;set c1.NCHS_RUC;keep CountyFIPS NCHS_RUC0;run; /*N=3149*/
/***/
/* Merging Zip_County and URCode; Weighting URCode by zip code population; Rounding URCode */;
proc sort data=Zip_County;by CountyFIPS;run;
proc sort data=NCHS1     ;by CountyFIPS;run;
data NCHS2;merge NCHS1 Zip_County(IN=A);by CountyFIPS;if A;
NCHS_RUC0w=NCHS_RUC0*ZPOPPCT/100; /* Weighting URCode by zip code population */
run; 
/*N=1924*/
proc summary data=NCHS2 nway;class ZipCode;var NCHS_RUC0w;output out=NCHS3 sum=;run;/*N=1383*/
data NCHS4;set NCHS3;
NCHS_RUCFlag=1;
NCHS_RUC0=round(NCHS_RUC0w);
if NCHS_RUC0 in (1 2) then NCHS_RUC=1;
if NCHS_RUC0 in (3 4) then NCHS_RUC=2;
if NCHS_RUC0 in (5 6) then NCHS_RUC=3;
drop _TYPE_ _FREQ_ NCHS_RUC0w;
label
NCHS_RUC0="NCHS 2013 RUC: 1=large central metro;2=large fringe metro;3=medium metro;4=small metro;5=micropolitan;6=noncore"
NCHS_RUC ="NCHS 2013 RUC-collapsed: 1=large central/fringe metro; 2=medium/small metro; 3=micropolitan/noncore";
run; 
/*N=1383, 4 variables*/
/***/
/* Importing USDA_RUC */;
data USDA1;set c2.USDA_RUC;keep CountyFIPS USDA_RUC0;run; /*N=3143, 2 variables*/
/***/
/* Merging Zip_County and URCode; Weighting URCode by zip code population; Rounding URCode */;
proc sort data=Zip_County;by CountyFIPS;run;
proc sort data=USDA1     ;by CountyFIPS;run;
data USDA2;merge USDA1 Zip_County(IN=A);by CountyFIPS;if A;
USDA_RUC0w=USDA_RUC0*ZPOPPCT/100; /* Weighting URCode by zip code population */
run; 
/*N=1924*/
proc summary data=USDA2 nway;class ZipCode;var USDA_RUC0w;output out=USDA3 sum=;run;/*N=1383*/
data USDA4;set USDA3;
USDA_RUCFlag=1;
USDA_RUC0=round(USDA_RUC0w);
if USDA_RUC0=1   then USDA_RUC=1;
if 1<USDA_RUC0<4 then USDA_RUC=2;
if 3<USDA_RUC0   then USDA_RUC=3;
drop _TYPE_ _FREQ_ USDA_RUC0w;
label
USDA_RUC0="USDA 2013 RUC: 1-3=Metro;4-9=Nonmetro;(1)>=1M;(2)250K-1M;(3)<250K;(4)adjacent to metro(AM),>=20K;(5)not AM,>=20K;(6)AM,2.5K-19,999;(7)not AM,2.5K-19,999;(8)AM,<2.5K;(9)not AM,<2.5K"
USDA_RUC ="USDA 2013 RUC-collapsed: 1=large urban(USDA code1);2=small urban(USDA code2-3);3=rural(USDA code4-9)";
run; 
/*N=1383, 4 variables*/
/***/
proc sort data=NCHS4;by ZipCode;run;
proc sort data=USDA4;by ZipCode;run;
data RUC1;merge NCHS4 USDA4;by ZipCode;run;/*N=1383, 7 variables*/
/***/
/* Checking Consistency between NCHS and USDA codes*/
/* proc freq data=RUC1;tables NCHS_RUC*USDA_RUC/missing;run;
   Consistent:   99.64%
   Inconsistent:  0.36% */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* A02: Merging A01 and UR Code ****************************************************************************************************************/
/********************************* A02: Merging A01 and UR Code ****************************************************************************************************************/
/********************************* A02: Merging A01 and UR Code ****************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
proc sort data=A01 ;by ZipCode;run;     /*N=11064, 769 variables*/
proc sort data=RUC1;by ZipCode;run;     /*N= 1383,   7 variables*/
data A02;merge A01 RUC1;by ZipCode;run; /*N=11064, 775 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Spatial (latitude and longitude) data *******************************************************************************************************/
/********************************* Spatial (latitude and longitude) data *******************************************************************************************************/
/********************************* Spatial (latitude and longitude) data *******************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
data GAZ;retain GAZFlag;set d.GAZ;GAZFlag=1;keep GAZFlag ZipYear Latitude Longitude;run; /*N=265128, 4 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* A03: Merging A02 and Spatial Data ***********************************************************************************************************/
/********************************* A03: Merging A02 and Spatial Data ***********************************************************************************************************/
/********************************* A03: Merging A02 and Spatial Data ***********************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
proc sort data=A02;by ZipYear;run; /*N= 11064, 775 variables*/
proc sort data=GAZ;by ZipYear;run; /*N=265128,   4 variables*/
data A03;merge A02(IN=A) GAZ;by ZipYear;if A;run; /*N=11064, 778 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* IECAM Data **********************************************************************************************************************************/
/********************************* IECAM Data **********************************************************************************************************************************/
/********************************* IECAM Data **********************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
data ICM;
retain IECAMFlag CountyFIPS ZipYear ISBE_PFA ISBE_PFAE ISBE_PI HeadStart ElyHeadS HeadSAll PFA_HS1 PFA_HS2 LCCC LECCC LFCC LLECCC LCLFCC LCCCB1 LCCCB2 LCCB1 LCCB2 
LCCCS1 LCCCS2 LCCS1 LCCS2 LCCCG1 LCCCG2 LCCG1 LCCG2 ChildCare1 ChildCare2 ChildCare3 CCAP Homeless Homeless2 DHS_HFIr DHS_PTSr DHS_HVPr IDHS_EIr 
I_CPop0z I_CPop1z I_CPop2z I_CPop3z I_CPop4z;
set e.IECAM;
if 2010<Year<2019;
IECAMFlag=1;
ZipYear=ZipCode*10000+Year;
ISBE_PFA=ISBE_PFAc/(I_CPop3z+I_CPop4z)*100;
ISBE_PFAE=(ISBE_PFAc+ISBE_PFAEc)/(I_CPop3z+I_CPop4z)*100;
ISBE_PI=ISBE_PIc/(I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z)*100;
HeadStart=HeadStartc/I_CPopz*100;
ElyHeadS=ElyHeadSc/(I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z)*100;
HeadSAll=(HeadStartc+ElyHeadSc)/I_CPopz*100;
PFA_HS1=(ISBE_PFAc+HeadStartc+ElyHeadSc)/I_CPopz*100;
PFA_HS2=(ISBE_PFAc+ISBE_PFAEc+HeadStartc+ElyHeadSc)/I_CPopz*100;
LCCC=LCCCc/I_CPopz*100;
LECCC=LECCCc/I_CPopz*100;
LFCC=LFCCc/I_CPopz*100;
LLECCC=(LCCCc+LECCCc)/I_CPopz*100;
LCLFCC=(LCCCc+LFCCc)/I_CPopz*100;
LCCCB1=(LCCCBc+LCCCSc+LCCCGc)/I_CPopz*100;
LCCCB2=(LCCCBc+LCCCSc+LCCCGc)/LCCCc*100;
LCCB1=(LCCCBc+LCCCSc+LCCCGc+LFCCBc+LFCCSc+LFCCGc)/I_CPopz*100;
LCCB2=(LCCCBc+LCCCSc+LCCCGc+LFCCBc+LFCCSc+LFCCGc)/(LCCCc+LFCCc)*100;
LCCCS1=(LCCCSc+LCCCGc)/I_CPopz*100;
LCCCS2=(LCCCSc+LCCCGc)/LCCCc*100;
LCCS1=(LCCCSc+LCCCGc+LFCCSc+LFCCGc)/I_CPopz*100;
LCCS2=(LCCCSc+LCCCGc+LFCCSc+LFCCGc)/(LCCCc+LFCCc)*100;
LCCCG1=LCCCGc/I_CPopz*100;
LCCCG2=LCCCGc/LCCCc*100;
LCCG1=(LCCCGc+LFCCGc)/I_CPopz*100;
LCCG2=(LCCCGc+LFCCGc)/(LCCCc+LFCCc)*100;
ChildCare1=(LCCCc+LECCCc+LFCCc)/I_CPopz*100;
ChildCare2=(LCCCc+LECCCc+LFCCc+HeadStartc+ElyHeadSc+ISBE_PFAc)/I_CPopz*100;
ChildCare3=(LCCCc+LECCCc+LFCCc+HeadStartc+ElyHeadSc+ISBE_PFAc+ISBE_PFAEc)/I_CPopz*100;
CCAP=CCAPc/I_CPopz*100;
Homeless2=(HomelessC1+HomelessC2)/(HomelessD1+HomelessD2)*100;
label
ISBE_PFA="# proposed to be served (outside Chicago) or enrolled (in Chicago) in ISBE Preschool For All programs per 100 children age 3 to 4 years "
ISBE_PFAE="# proposed to be served (outside Chicago) or enrolled (in Chicago) in ISBE Preschool For All Original + Expansion programs per 100 children age 3 to 4 years "
ISBE_PI="# proposed to be served by ISBE Prevention Initiative programs per 100 children age 0 to 3 years"
HeadStart="# children (age 0-5) that a Head Start center is funded to enroll at any one time per 100 children age 0 to 5 years"
ElyHeadS="# children (age 0-3) that an Early Head Start center is funded to enroll at any one time per 100 children age 0 to 3 years"
HeadSAll="# children (age 0-5) that a Head Start or Early Head Start center is funded to enroll at any one time per 100 children age 0 to 5 years"
PFA_HS1="Early education capacity (PFA, HeadStart(HS), EarlyHS) per 100 children age 0 to 5 years"
PFA_HS2="Early education capacity (PFA, PFA expansion, HeadStart(HS), EarlyHS) per 100 children age 0 to 5 years"
LCCC="Licensed child care center capacity per 100 children age 0 to 5 years"
LECCC="License-exempt child care center capacity per 100 children age 0 to 5 years"
LFCC="Licensed family child care home capacity per 100 children age 0 to 5 years"
LLECCC="Licensed/License-exempt child care center capacity per 100 children age 0 to 5 years"
LCLFCC="Licensed center/family child care capacity per 100 children age 0 to 5 years"
LCCCB1="Licensed child care center with Bronze/Silver/Gold rating: capacity per 100 children age 0 to 5 years"
LCCCB2="% capacities with Bronze/Silver/Gold rating among licensed child care center capacities for children age 0 to 5 years"
LCCB1="Licensed center/family child care with Bronze/Silver/Gold rating: capacity per 100 children age 0 to 5 years"
LCCB2="% capacities with Bronze/Silver/Gold rating among licensed center/family child care capacities for children age 0 to 5 years"
LCCCS1="Licensed child care center with Silver/Gold rating: capacity per 100 children age 0 to 5 years"
LCCCS2="% capacities with Silver/Gold rating among licensed child care center capacities for children age 0 to 5 years"
LCCS1="Licensed center/family child care with Silver/Gold rating: capacity per 100 children age 0 to 5 years"
LCCS2="% capacities with Silver/Gold rating among licensed center/family child care capacities for children age 0 to 5 years"
LCCCG1="Licensed child care center with Gold rating: capacity per 100 children age 0 to 5 years"
LCCCG2="% capacities with Gold rating among licensed child care center capacities for children age 0 to 5 years"
LCCG1="Licensed center/family child care with Gold rating: capacity per 100 children age 0 to 5 years"
LCCG2="% capacities with Gold rating among licensed center/family child care capacities for children age 0 to 5 years"
ChildCare1="Child care capacity (licensed,license-exempt,family) per 100 children age 0 to 5 years"
ChildCare2="Child care capacity (licensed,license-exempt,family,HeadStart(HS),EarlyHS,PFA) per 100 children age 0 to 5 years"
ChildCare3="Child care capacity (licensed,license-exempt,family,HeadStart(HS),EarlyHS,PFA,PFA expansion) per 100 children age 0 to 5 years"
CCAP="# receiving Child Care Assistance Program per 100 children age 0 to 5 years"
Homeless2="# homeless PFA/K students per 100 children age 3-5 years in households,County";
keep IECAMFlag CountyFIPS ZipYear ISBE_PFA ISBE_PFAE ISBE_PI HeadStart ElyHeadS HeadSAll PFA_HS1 PFA_HS2 LCCC LECCC LFCC LLECCC LCLFCC LCCCB1 LCCCB2 LCCB1 LCCB2 
LCCCS1 LCCCS2 LCCS1 LCCS2 LCCCG1 LCCCG2 LCCG1 LCCG2 ChildCare1 ChildCare2 ChildCare3 CCAP Homeless Homeless2 DHS_HFIr DHS_PTSr DHS_HVPr IDHS_EIr 
I_CPop0z I_CPop1z I_CPop2z I_CPop3z I_CPop4z;
run;
/*N=11064, 43 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* A04: Merging A03 and IECAM Data ***********************************************************************************************************/
/********************************* A04: Merging A03 and IECAM Data ***********************************************************************************************************/
/********************************* A04: Merging A03 and IECAM Data ***********************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
proc sort data=A03;by ZipYear;run; /*N=11064, 778 variables*/
proc sort data=ICM;by ZipYear;run; /*N=11064,  43 variables*/
data A04;retain Year CountyFIPS ZipCode ZipYear;merge A03(IN=A) ICM;by ZipYear;if A;run; /*N=11064, 820 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* MHV Data ************************************************************************************************************************************/
/********************************* MHV Data ************************************************************************************************************************************/
/********************************* MHV Data ************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
/* Among 3439 children served by MIECHV in Illinois from 2015-2018, 95 children (2.76%) had no zip code and were deleted. 
   3344 children were aggregated by zip code from 2015-2018. --> "f.MHV"
   11 children had an invalid, PO box only, or outside-Illinois zip code. They were excluded. */
/***/;
data MHV;retain MHVFlag;set f.MHV;MHVFlag=1;keep MHVFlag ZipYear MHV_C MHV_P;run;/*N=382, 4 variables*/
proc sort data=A04;by ZipYear;run;/*N=11064, 820 variables*/
proc sort data=MHV;by ZipYear;run;/*N   382,   4 variables*/
data A05;merge A04(IN=A) MHV;by ZipYear;if A;
if 2014<Year & MHV_C=. then MHV_C=0;
if 2014<Year & MHV_P=. then MHV_P=0;
if I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z =0 then MHV_C4=0;
if I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z^=0 then MHV_C4=MHV_C/(I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z)*100;
if I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z =0 then MHV_P4=0;
if I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z^=0 then MHV_P4=MHV_P/(I_CPop0z+I_CPop1z+I_CPop2z+I_CPop3z+I_CPop4z)*1000;
if CPop1 =0 then MHV_C5=0;
if CPop1^=0 then MHV_C5=MHV_C/CPop1*100;
if CPop1 =0 then MHV_P5=0;
if CPop1^=0 then MHV_P5=MHV_P/CPop1*1000;
label
MHV_C4="% served by MIECHV among children aged 0-4 years"
MHV_P4="# MIECHV agencies serving the area per 1k children aged 0-4 years"
MHV_C5="% served by MIECHV among children aged 0-5 years"
MHV_P5="# MIECHV agencies serving the area per 1k children aged 0-5 years"
;
run;
/*N=11064, 827 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Food Data ***********************************************************************************************************************************/
/********************************* Food Data ***********************************************************************************************************************************/
/********************************* Food Data ***********************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
/***/;
data food;retain FoodFlag;set g.food;FoodFlag=1;keep FoodFlag ZipYear FoodInsP;run;/*N=11064*/
proc sort data=A05 ;by ZipYear;run;/*N=11064, 827 variables*/
proc sort data=food;by ZipYear;run;/*N=11064,   3 variables*/
data A06;merge A05 food;by ZipYear;run;/*N=11064, 829 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Saving Permanent Data ***********************************************************************************************************************/
/********************************* Saving Permanent Data ***********************************************************************************************************************/
/********************************* Saving Permanent Data ***********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/;
data z.CDCK01Zip;set A06;run;/*N=11064, 829 variables*/
proc contents data=z.CDCK01Zip varnum;run;





