
# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(spaMM)      # for spatial modeling
library(scales)     # for rescale
library(DHARMa)     # for simulateResiduals
library(doSNOW)
library(ggplot2)
library(e1071)      # for skewness
library(radiant.data) # for weighted.sd
library(Weighted.Desc.Stat) # for w.skewness (weighted skewness)


memory.limit(100000000000) # Increase memory limit

load("Z:/CDCK01/Analysis/ZipCode/Food/Food01_data_census2.RData")

zt<-zt[,.(Rpt  ,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopT ,RptTr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
z1<-z1[,.(Age1 ,CPop1,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPop1 ,Rpt1r,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPov1,CPov1c)]
z2<-z2[,.(Age2 ,CPop2,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPop2 ,Rpt2r,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPov2,CPov2c)]
z3<-z3[,.(Age3 ,CPop3,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPop3 ,Rpt3r,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPov3,CPov3c)]
zm<-zm[,.(SexM ,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTM,DisablTMc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopTM,RptMr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
zf<-zf[,.(SexF ,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTF,DisablTFc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopTF,RptFr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
zn<-zn[,.(RptNG,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopT ,NegTr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
zp<-zp[,.(RptPA,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopT ,PhyTr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
zs<-zs[,.(RptSA,CPopT,IncomeT1k,IncomeT1kc,UnempT,UnempTc,OwnerT,OwnerTc,DisablTC,DisablTCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopT ,SexTr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleT,SingleTc,NoHighT,NoHighTc,FBornT,FBornTc,ChildPT,ChildPTc,MalePT,MalePTc,ElderT,ElderTc,MoveT,MoveTc,CPovT,CPovTc)]
zw<-zw[,.(RacW ,CPopW,IncomeW1k,IncomeW1kc,UnempT,UnempTc,OwnerW,OwnerWc,DisablWC,DisablWCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopW ,RptWr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleW,SingleWc,NoHighW,NoHighWc,FBornW,FBornWc,ChildPW,ChildPWc,MalePW,MalePWc,ElderW,ElderWc,MoveW,MoveWc,CPovW,CPovWc)]
zb<-zb[,.(RacB ,CPopB,IncomeB1k,IncomeB1kc,UnempT,UnempTc,OwnerB,OwnerBc,DisablBC,DisablBCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopB ,RptBr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleB,SingleBc,NoHighB,NoHighBc,FBornB,FBornBc,ChildPB,ChildPBc,MalePB,MalePBc,ElderB,ElderBc,MoveB,MoveBc,CPovB,CPovBc)]
zh<-zh[,.(RacH ,CPopH,IncomeH1k,IncomeH1kc,UnempT,UnempTc,OwnerH,OwnerHc,DisablHC,DisablHCc,CPopBP,CPopBPc,CPopHP,CPopHPc,CPopH ,RptHr,ZipCode,Year,Yearf,FoodIS,FoodIS_within,FoodISc,FoodISc_within,FoodISc_between,USDA_RUC,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude,SingleH,SingleHc,NoHighH,NoHighHc,FBornH,FBornHc,ChildPH,ChildPHc,MalePH,MalePHc,ElderH,ElderHc,MoveH,MoveHc,CPovH,CPovHc)]

rm(z,zt1,z11,z21,z31,zm1,zf1,zn1,zp1,zs1,zw1,zb1,zh1,zt2,z12,z22,z32,zm2,zf2,zn2,zp2,zs2,zw2,zb2,zh2)

# Distribution of DVs

plot(density(zt$RptTr))
plot(density(z1$Rpt1r))
plot(density(z2$Rpt2r))
plot(density(z3$Rpt3r))
plot(density(zm$RptMr))
plot(density(zf$RptFr))
plot(density(zn$NegTr))
plot(density(zp$PhyTr))
plot(density(zs$SexTr))
plot(density(zw$RptWr))
plot(density(zb$RptBr))
plot(density(zh$RptHr))

w.skewness(zt$RptTr,zt$CPopT )
w.skewness(z1$Rpt1r,z1$CPop1 )
w.skewness(z2$Rpt2r,z2$CPop2 )
w.skewness(z3$Rpt3r,z3$CPop3 )
w.skewness(zm$RptMr,zm$CPopTM)
w.skewness(zf$RptFr,zf$CPopTF)
w.skewness(zn$NegTr,zn$CPopT )
w.skewness(zp$PhyTr,zp$CPopT )
w.skewness(zs$SexTr,zs$CPopT )
w.skewness(zw$RptWr,zw$CPopW )
w.skewness(zb$RptBr,zb$CPopB )
w.skewness(zh$RptHr,zh$CPopH )

weighted.mean(zt$RptTr,zt$CPopT )
weighted.mean(z1$Rpt1r,z1$CPop1 )
weighted.mean(z2$Rpt2r,z2$CPop2 )
weighted.mean(z3$Rpt3r,z3$CPop3 )
weighted.mean(zm$RptMr,zm$CPopTM)
weighted.mean(zf$RptFr,zf$CPopTF)
weighted.mean(zn$NegTr,zn$CPopT )
weighted.mean(zp$PhyTr,zp$CPopT )
weighted.mean(zs$SexTr,zs$CPopT )
weighted.mean(zw$RptWr,zw$CPopW )
weighted.mean(zb$RptBr,zb$CPopB )
weighted.mean(zh$RptHr,zh$CPopH )

weighted.sd(zt$RptTr,zt$CPopT )
weighted.sd(z1$Rpt1r,z1$CPop1 )
weighted.sd(z2$Rpt2r,z2$CPop2 )
weighted.sd(z3$Rpt3r,z3$CPop3 )
weighted.sd(zm$RptMr,zm$CPopTM)
weighted.sd(zf$RptFr,zf$CPopTF)
weighted.sd(zn$NegTr,zn$CPopT )
weighted.sd(zp$PhyTr,zp$CPopT )
weighted.sd(zs$SexTr,zs$CPopT )
weighted.sd(zw$RptWr,zw$CPopW )
weighted.sd(zb$RptBr,zb$CPopB )
weighted.sd(zh$RptHr,zh$CPopH )

zt$Year2012<-0;zt$Year2012[zt$Year==2012]<-1
zt$Year2013<-0;zt$Year2013[zt$Year==2013]<-1
zt$Year2014<-0;zt$Year2014[zt$Year==2014]<-1
zt$Year2015<-0;zt$Year2015[zt$Year==2015]<-1
zt$Year2016<-0;zt$Year2016[zt$Year==2016]<-1
zt$Year2017<-0;zt$Year2017[zt$Year==2017]<-1
zt$Year2018<-0;zt$Year2018[zt$Year==2018]<-1

z1$Year2012<-0;z1$Year2012[z1$Year==2012]<-1
z1$Year2013<-0;z1$Year2013[z1$Year==2013]<-1
z1$Year2014<-0;z1$Year2014[z1$Year==2014]<-1
z1$Year2015<-0;z1$Year2015[z1$Year==2015]<-1
z1$Year2016<-0;z1$Year2016[z1$Year==2016]<-1
z1$Year2017<-0;z1$Year2017[z1$Year==2017]<-1
z1$Year2018<-0;z1$Year2018[z1$Year==2018]<-1

z2$Year2012<-0;z2$Year2012[z2$Year==2012]<-1
z2$Year2013<-0;z2$Year2013[z2$Year==2013]<-1
z2$Year2014<-0;z2$Year2014[z2$Year==2014]<-1
z2$Year2015<-0;z2$Year2015[z2$Year==2015]<-1
z2$Year2016<-0;z2$Year2016[z2$Year==2016]<-1
z2$Year2017<-0;z2$Year2017[z2$Year==2017]<-1
z2$Year2018<-0;z2$Year2018[z2$Year==2018]<-1

z3$Year2012<-0;z3$Year2012[z3$Year==2012]<-1
z3$Year2013<-0;z3$Year2013[z3$Year==2013]<-1
z3$Year2014<-0;z3$Year2014[z3$Year==2014]<-1
z3$Year2015<-0;z3$Year2015[z3$Year==2015]<-1
z3$Year2016<-0;z3$Year2016[z3$Year==2016]<-1
z3$Year2017<-0;z3$Year2017[z3$Year==2017]<-1
z3$Year2018<-0;z3$Year2018[z3$Year==2018]<-1

zm$Year2012<-0;zm$Year2012[zm$Year==2012]<-1
zm$Year2013<-0;zm$Year2013[zm$Year==2013]<-1
zm$Year2014<-0;zm$Year2014[zm$Year==2014]<-1
zm$Year2015<-0;zm$Year2015[zm$Year==2015]<-1
zm$Year2016<-0;zm$Year2016[zm$Year==2016]<-1
zm$Year2017<-0;zm$Year2017[zm$Year==2017]<-1
zm$Year2018<-0;zm$Year2018[zm$Year==2018]<-1

zf$Year2012<-0;zf$Year2012[zf$Year==2012]<-1
zf$Year2013<-0;zf$Year2013[zf$Year==2013]<-1
zf$Year2014<-0;zf$Year2014[zf$Year==2014]<-1
zf$Year2015<-0;zf$Year2015[zf$Year==2015]<-1
zf$Year2016<-0;zf$Year2016[zf$Year==2016]<-1
zf$Year2017<-0;zf$Year2017[zf$Year==2017]<-1
zf$Year2018<-0;zf$Year2018[zf$Year==2018]<-1

zn$Year2012<-0;zn$Year2012[zn$Year==2012]<-1
zn$Year2013<-0;zn$Year2013[zn$Year==2013]<-1
zn$Year2014<-0;zn$Year2014[zn$Year==2014]<-1
zn$Year2015<-0;zn$Year2015[zn$Year==2015]<-1
zn$Year2016<-0;zn$Year2016[zn$Year==2016]<-1
zn$Year2017<-0;zn$Year2017[zn$Year==2017]<-1
zn$Year2018<-0;zn$Year2018[zn$Year==2018]<-1

zp$Year2012<-0;zp$Year2012[zp$Year==2012]<-1
zp$Year2013<-0;zp$Year2013[zp$Year==2013]<-1
zp$Year2014<-0;zp$Year2014[zp$Year==2014]<-1
zp$Year2015<-0;zp$Year2015[zp$Year==2015]<-1
zp$Year2016<-0;zp$Year2016[zp$Year==2016]<-1
zp$Year2017<-0;zp$Year2017[zp$Year==2017]<-1
zp$Year2018<-0;zp$Year2018[zp$Year==2018]<-1

zs$Year2012<-0;zs$Year2012[zs$Year==2012]<-1
zs$Year2013<-0;zs$Year2013[zs$Year==2013]<-1
zs$Year2014<-0;zs$Year2014[zs$Year==2014]<-1
zs$Year2015<-0;zs$Year2015[zs$Year==2015]<-1
zs$Year2016<-0;zs$Year2016[zs$Year==2016]<-1
zs$Year2017<-0;zs$Year2017[zs$Year==2017]<-1
zs$Year2018<-0;zs$Year2018[zs$Year==2018]<-1

zw$Year2012<-0;zw$Year2012[zw$Year==2012]<-1
zw$Year2013<-0;zw$Year2013[zw$Year==2013]<-1
zw$Year2014<-0;zw$Year2014[zw$Year==2014]<-1
zw$Year2015<-0;zw$Year2015[zw$Year==2015]<-1
zw$Year2016<-0;zw$Year2016[zw$Year==2016]<-1
zw$Year2017<-0;zw$Year2017[zw$Year==2017]<-1
zw$Year2018<-0;zw$Year2018[zw$Year==2018]<-1

zb$Year2012<-0;zb$Year2012[zb$Year==2012]<-1
zb$Year2013<-0;zb$Year2013[zb$Year==2013]<-1
zb$Year2014<-0;zb$Year2014[zb$Year==2014]<-1
zb$Year2015<-0;zb$Year2015[zb$Year==2015]<-1
zb$Year2016<-0;zb$Year2016[zb$Year==2016]<-1
zb$Year2017<-0;zb$Year2017[zb$Year==2017]<-1
zb$Year2018<-0;zb$Year2018[zb$Year==2018]<-1

zh$Year2012<-0;zh$Year2012[zh$Year==2012]<-1
zh$Year2013<-0;zh$Year2013[zh$Year==2013]<-1
zh$Year2014<-0;zh$Year2014[zh$Year==2014]<-1
zh$Year2015<-0;zh$Year2015[zh$Year==2015]<-1
zh$Year2016<-0;zh$Year2016[zh$Year==2016]<-1
zh$Year2017<-0;zh$Year2017[zh$Year==2017]<-1
zh$Year2018<-0;zh$Year2018[zh$Year==2018]<-1





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

library(raster) # To read shapefile
library(rgdal)  # To read shapefile
Shape <- shapefile("Z:/CDCK01/Data_Zip/Census2/ZipCodeShapeFile/gz_2010_us_860_00_500k.shp")

# Create Total and Subgroup Shape Files

Shape$ZipCode<-as.numeric(Shape$ZCTA5)
ShapeT<-Shape[Shape$ZipCode %in% zt$ZipCode,]
Shape1<-Shape[Shape$ZipCode %in% z1$ZipCode,]
Shape2<-Shape[Shape$ZipCode %in% z2$ZipCode,]
Shape3<-Shape[Shape$ZipCode %in% z3$ZipCode,]
ShapeM<-Shape[Shape$ZipCode %in% zm$ZipCode,]
ShapeF<-Shape[Shape$ZipCode %in% zf$ZipCode,]
ShapeN<-Shape[Shape$ZipCode %in% zn$ZipCode,]
ShapeP<-Shape[Shape$ZipCode %in% zp$ZipCode,]
ShapeS<-Shape[Shape$ZipCode %in% zs$ZipCode,]
ShapeW<-Shape[Shape$ZipCode %in% zw$ZipCode,]
ShapeB<-Shape[Shape$ZipCode %in% zb$ZipCode,]
ShapeH<-Shape[Shape$ZipCode %in% zh$ZipCode,]

# "poly2nb": construct neighbours list from polygon list (default = first order Queen contiguity)
library(spdep)
QueenT<-poly2nb(ShapeT)
Queen1<-poly2nb(Shape1)
Queen2<-poly2nb(Shape2)
Queen3<-poly2nb(Shape3)
QueenM<-poly2nb(ShapeM)
QueenF<-poly2nb(ShapeF)
QueenN<-poly2nb(ShapeN)
QueenP<-poly2nb(ShapeP)
QueenS<-poly2nb(ShapeS)
QueenW<-poly2nb(ShapeW)
QueenB<-poly2nb(ShapeB)
QueenH<-poly2nb(ShapeH)

# "nb2mat": Spatial weights matrices for neighbours lists
MatrixT<-nb2mat(QueenT,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix1<-nb2mat(Queen1,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix2<-nb2mat(Queen2,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix3<-nb2mat(Queen3,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixM<-nb2mat(QueenM,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixF<-nb2mat(QueenF,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixN<-nb2mat(QueenN,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixP<-nb2mat(QueenP,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixS<-nb2mat(QueenS,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixW<-nb2mat(QueenW,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixB<-nb2mat(QueenB,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixH<-nb2mat(QueenH,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights

# Set row and column Names
rownames(MatrixT)<-colnames(MatrixT)<-ShapeT$ZipCode
rownames(Matrix1)<-colnames(Matrix1)<-Shape1$ZipCode
rownames(Matrix2)<-colnames(Matrix2)<-Shape2$ZipCode
rownames(Matrix3)<-colnames(Matrix3)<-Shape3$ZipCode
rownames(MatrixM)<-colnames(MatrixM)<-ShapeM$ZipCode
rownames(MatrixF)<-colnames(MatrixF)<-ShapeF$ZipCode
rownames(MatrixN)<-colnames(MatrixN)<-ShapeN$ZipCode
rownames(MatrixP)<-colnames(MatrixP)<-ShapeP$ZipCode
rownames(MatrixS)<-colnames(MatrixS)<-ShapeS$ZipCode
rownames(MatrixW)<-colnames(MatrixW)<-ShapeW$ZipCode
rownames(MatrixB)<-colnames(MatrixB)<-ShapeB$ZipCode
rownames(MatrixH)<-colnames(MatrixH)<-ShapeH$ZipCode





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
# Queen Contiguity Spatial Weighting Modeling
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Total
mta0<-fitme(RptTr~1                                                                                                                                                                     +ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta1<-fitme(RptTr~FoodISc_within+FoodISc_between                                                                                                                                        +ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta2<-fitme(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc         +ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc         +ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta4<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

# Age 0-5
m1a0<-fitme(Rpt1r~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m1a1<-fitme(Rpt1r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m1a2<-fitme(Rpt1r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m1a3<-fitme(Rpt1r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m1a4<-fitme(Rpt1r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)

# Age 6-11
m2a0<-fitme(Rpt2r~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m2a1<-fitme(Rpt2r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m2a2<-fitme(Rpt2r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m2a3<-fitme(Rpt2r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m2a4<-fitme(Rpt2r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)

# Age 12-17
m3a0<-fitme(Rpt3r~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
m3a1<-fitme(Rpt3r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
m3a2<-fitme(Rpt3r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
m3a3<-fitme(Rpt3r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
m3a4<-fitme(Rpt3r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)

# Male Children
mma0<-fitme(RptMr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)
mma1<-fitme(RptMr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)
mma2<-fitme(RptMr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)
mma3<-fitme(RptMr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)
mma4<-fitme(RptMr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)

# Female Children
mfa0<-fitme(RptFr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)
mfa1<-fitme(RptFr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)
mfa2<-fitme(RptFr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)
mfa3<-fitme(RptFr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)
mfa4<-fitme(RptFr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)

# Neglect
mna0<-fitme(NegTr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)
mna1<-fitme(NegTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)
mna2<-fitme(NegTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)
mna3<-fitme(NegTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)
mna4<-fitme(NegTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)

# Physical Abuse
mpa0<-    fitme(PhyTr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)
mpa1<-    fitme(PhyTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)
mpa2<-    fitme(PhyTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)
mpa3<-corrHLfit(PhyTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)
mpa4<-    fitme(PhyTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)

# Sexual Abuse
msa0<-fitme(SexTr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)
msa1<-fitme(SexTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)
msa2<-fitme(SexTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)
msa3<-fitme(SexTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)
msa4<-fitme(SexTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)

# White
mwa0<-fitme(RptWr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mwa1<-fitme(RptWr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mwa2<-fitme(RptWr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mwa3<-fitme(RptWr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mwa4<-fitme(RptWr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)

# Black
mba0<-fitme(RptBr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mba1<-fitme(RptBr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mba2<-fitme(RptBr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mba3<-fitme(RptBr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mba4<-fitme(RptBr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)

# Hispanic
mha0<-fitme(RptHr~1+                                                                                                                                                                     ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)
mha1<-fitme(RptHr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)
mha2<-fitme(RptHr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)
mha3<-fitme(RptHr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)
mha4<-fitme(RptHr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)





# Sensitivity Analysis -- Autoregressive of orders 2 and 3
mta0p2<-fitme(RptTr~1+ARp(1|Year,p=2)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta1p2<-fitme(RptTr~FoodISc_within+FoodISc_between+ARp(1|Year,p=2)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta2p2<-fitme(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year,p=2)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3p2<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year,p=2)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta0p3<-fitme(RptTr~1+ARp(1|Year,p=3)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta1p3<-fitme(RptTr~FoodISc_within+FoodISc_between+ARp(1|Year,p=3)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta2p3<-fitme(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year,p=3)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3p3<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year,p=3)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

# Sensitivity Analysis -- (a) mta3 w/o FI measure variables; (b) mta3 + IncomeT1kc; (c) mta3 + UnempTc; (d) mta3 + OwnerTc
mta3a<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+SingleTc+NoHighTc+HValueT10kc+VacantTc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3b<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+IncomeT1kc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3c<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+UnempTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3d<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+OwnerTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3e<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc         +ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

AIC(mta3)
AIC(mta3a)
AIC(mta3b)
AIC(mta3c)
AIC(mta3d)

mta3x <-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3ax<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+SingleTc+NoHighTc+HValueT10kc+VacantTc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3bx<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+IncomeT1kc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3cx<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+UnempTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mta3dx<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+OwnerTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

AIC(mta3x)
AIC(mta3ax)
AIC(mta3bx)
AIC(mta3cx)
AIC(mta3dx)

# Skewness
skewness(residuals(mta3)) # 0.9071172
skewness(residuals(m1a3)) # 1.091949
skewness(residuals(m2a3)) # 1.19156
skewness(residuals(m3a3)) # 1.398302
skewness(residuals(mna3)) # 1.140119
skewness(residuals(mpa3)) # 1.765046
skewness(residuals(msa3)) # 2.640032

# Multicollinearity: VIF 
lm2 <-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zt,weights=CPopT)
lm2a<-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+SingleTc+NoHighTc+HValueT10kc+VacantTc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc,data=zt,weights=CPopT)
lm2b<-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+IncomeT1kc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zt,weights=CPopT)
lm2c<-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+UnempTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zt,weights=CPopT)
lm2d<-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+OwnerTc+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zt,weights=CPopT)
lm2e<-lm(RptTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zt,weights=CPopT)
check_collinearity(lm2)
check_collinearity(lm2a)
check_collinearity(lm2b)
check_collinearity(lm2c)
check_collinearity(lm2d)
check_collinearity(lm2e)
lm12<-lm(Rpt1r~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=z1,weights=CPop1)
lm22<-lm(Rpt2r~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=z2,weights=CPop2)
lm32<-lm(Rpt3r~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=z3,weights=CPop3)
lmn2<-lm(NegTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zn,weights=CPopT)
lmp2<-lm(PhyTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zp,weights=CPopT)
lms2<-lm(SexTr~Yearf+USDA_RUC+FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc,data=zs,weights=CPopT)
check_collinearity(lm12)
check_collinearity(lm22)
check_collinearity(lm32)
check_collinearity(lmn2)
check_collinearity(lmp2)
check_collinearity(lms2)
# Owner, Unemployment, Median income made VIF reach nearly or go over 10.
# Poverty, single parent (family structure), and education -- traditional measures of SES
# Economic conditions are highly correlated, especially at the community level, and are usually not entered together in the same model.
# It is conceptually redundant and introduces multicollinearity problems.
# While adjusting for key SES indicators and other controls, both within- and between-effects of food insecurity were significant.
# Yet, it could be still confounded by other variables.
# Given the importance of race/ethnicity, they are controlled for.

# For Prediction, I used year dummies instead of the year factor (results are identical)
mta3y<-    fitme(RptTr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
m1a3y<-    fitme(Rpt1r~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m2a3y<-    fitme(Rpt2r~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m3a3y<-    fitme(Rpt3r~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
mma3y<-    fitme(RptMr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixM,data=zm,family="gaussian",weights.form=~CPopTM)
mfa3y<-    fitme(RptFr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixF,data=zf,family="gaussian",weights.form=~CPopTF)
mna3y<-    fitme(NegTr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family="gaussian",weights.form=~CPopT)
mpa3y<-corrHLfit(PhyTr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family="gaussian",weights.form=~CPopT)
msa3y<-    fitme(SexTr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family="gaussian",weights.form=~CPopT)
mwa3y<-    fitme(RptWr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mba3y<-    fitme(RptBr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mha3y<-    fitme(RptHr~Year2012+Year2013+Year2014+Year2015+Year2016+Year2017+Year2018+USDA_RUC*FoodISc_within+FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)

save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food02_Model1_census2.RData")





# Negative Binomal Models
mta3nb<-fitme(Rpt  ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin())
m1a3nb<-fitme(Age1 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop1))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family=negbin())
m2a3nb<-fitme(Age2 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop2))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family=negbin())
m3a3nb<-fitme(Age3 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop3))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family=negbin())
mna3nb<-fitme(RptNG~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family=negbin())
mpa3nb<-fitme(RptPA~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family=negbin())
msa3nb<-fitme(RptSA~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family=negbin())

mta3nb
m1a3nb
m2a3nb
m3a3nb
mna3nb
mpa3nb
msa3nb

mta3nb2<-fitme(Rpt  ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin(),weights.form=~CPopT)
m1a3nb2<-fitme(Age1 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop1))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family=negbin(),weights.form=~CPop1)
m2a3nb2<-fitme(Age2 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop2))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family=negbin(),weights.form=~CPop2)
m3a3nb2<-fitme(Age3 ~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPop3))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family=negbin(),weights.form=~CPop3)
mna3nb2<-fitme(RptNG~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixN,data=zn,family=negbin(),weights.form=~CPopT)
mpa3nb2<-fitme(RptPA~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixP,data=zp,family=negbin(),weights.form=~CPopT)
msa3nb2<-fitme(RptSA~Yearf+USDA_RUC*FoodISc_within+FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+offset(log(CPopT))+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixS,data=zs,family=negbin(),weights.form=~CPopT)

mta3nb2
m1a3nb2
m2a3nb2
m3a3nb2
mna3nb2
mpa3nb2
msa3nb2

save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food02_Model1_census2.RData")




###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
# Distance-Based Spatial Weighting Modeling
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

mtb1<-fitme(RptTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zt,family="gaussian",weights.form=~CPopT)
mtb2<-fitme(RptTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zt,family="gaussian",weights.form=~CPopT)
mtb3<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zt,family="gaussian",weights.form=~CPopT)
mtb4<-fitme(RptTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zt,family="gaussian",weights.form=~CPopT)

m1b1<-fitme(Rpt1r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=z1,family="gaussian",weights.form=~CPop1)
m1b2<-fitme(Rpt1r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z1,family="gaussian",weights.form=~CPop1)
m1b3<-fitme(Rpt1r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z1,family="gaussian",weights.form=~CPop1)
m1b4<-fitme(Rpt1r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov1c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z1,family="gaussian",weights.form=~CPop1)

m2b1<-fitme(Rpt2r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=z2,family="gaussian",weights.form=~CPop2)
m2b2<-fitme(Rpt2r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z2,family="gaussian",weights.form=~CPop2)
m2b3<-fitme(Rpt2r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z2,family="gaussian",weights.form=~CPop2)
m2b4<-fitme(Rpt2r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov2c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z2,family="gaussian",weights.form=~CPop2)

m3b1<-fitme(Rpt3r~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=z3,family="gaussian",weights.form=~CPop3)
m3b2<-fitme(Rpt3r~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z3,family="gaussian",weights.form=~CPop3)
m3b3<-fitme(Rpt3r~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z3,family="gaussian",weights.form=~CPop3)
m3b4<-fitme(Rpt3r~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPov3c+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=z3,family="gaussian",weights.form=~CPop3)

mmb1<-fitme(RptMr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zm,family="gaussian",weights.form=~CPopTM)
mmb2<-fitme(RptMr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zm,family="gaussian",weights.form=~CPopTM)
mmb3<-fitme(RptMr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zm,family="gaussian",weights.form=~CPopTM)
mmb4<-fitme(RptMr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTMc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zm,family="gaussian",weights.form=~CPopTM)

mfb1<-fitme(RptFr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zf,family="gaussian",weights.form=~CPopTF)
mfb2<-fitme(RptFr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zf,family="gaussian",weights.form=~CPopTF)
mfb3<-fitme(RptFr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zf,family="gaussian",weights.form=~CPopTF)
mfb4<-fitme(RptFr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTFc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zf,family="gaussian",weights.form=~CPopTF)

mnb1<-fitme(NegTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zn,family="gaussian",weights.form=~CPopT)
mnb2<-fitme(NegTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zn,family="gaussian",weights.form=~CPopT)
mnb3<-fitme(NegTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zn,family="gaussian",weights.form=~CPopT)
mnb4<-fitme(NegTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zn,family="gaussian",weights.form=~CPopT)

mpb1<-fitme(PhyTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zp,family="gaussian",weights.form=~CPopT)
mpb2<-fitme(PhyTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zp,family="gaussian",weights.form=~CPopT)
mpb3<-fitme(PhyTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zp,family="gaussian",weights.form=~CPopT)
mpb4<-fitme(PhyTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zp,family="gaussian",weights.form=~CPopT)

msb1<-fitme(SexTr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zs,family="gaussian",weights.form=~CPopT)
msb2<-fitme(SexTr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zs,family="gaussian",weights.form=~CPopT)
msb3<-fitme(SexTr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zs,family="gaussian",weights.form=~CPopT)
msb4<-fitme(SexTr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovTc+SingleTc+NoHighTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+MoveTc+DisablTCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zs,family="gaussian",weights.form=~CPopT)

mwb1<-fitme(RptWr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zw,family="gaussian",weights.form=~CPopW)
mwb2<-fitme(RptWr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zw,family="gaussian",weights.form=~CPopW)
mwb3<-fitme(RptWr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zw,family="gaussian",weights.form=~CPopW)
mwb4<-fitme(RptWr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovWc+SingleWc+NoHighWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+MoveWc+DisablWCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zw,family="gaussian",weights.form=~CPopW)

mbb1<-fitme(RptBr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zb,family="gaussian",weights.form=~CPopB)
mbb2<-fitme(RptBr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zb,family="gaussian",weights.form=~CPopB)
mbb3<-fitme(RptBr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zb,family="gaussian",weights.form=~CPopB)
mbb4<-fitme(RptBr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovBc+SingleBc+NoHighBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+MoveBc+DisablBCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zb,family="gaussian",weights.form=~CPopB)

mhb1<-fitme(RptHr~               FoodISc_within+         FoodISc_between+                                                                                                                ARp(1|Year)+Matern(1|Longitude+Latitude),data=zh,family="gaussian",weights.form=~CPopH)
mhb2<-fitme(RptHr~Yearf+USDA_RUC+FoodISc_within+         FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zh,family="gaussian",weights.form=~CPopH)
mhb3<-fitme(RptHr~Yearf+USDA_RUC*FoodISc_within+         FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zh,family="gaussian",weights.form=~CPopH)
mhb4<-fitme(RptHr~Yearf+USDA_RUC*FoodISc_within+USDA_RUC*FoodISc_between+CPovHc+SingleHc+NoHighHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+MoveHc+DisablHCc+ARp(1|Year)+Matern(1|Longitude+Latitude),data=zh,family="gaussian",weights.form=~CPopH)

save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food02_Model2_census2.RData")







# Reporting
# Reporting
# Reporting
# Reporting
# Reporting
# Reporting
# Reporting
# Reporting
# Reporting

# Confidence Intervals
mta1CI<-confint(mta1,c("FoodISc_within","FoodISc_between"),level=0.95)
mta2CI<-confint(mta2,c("FoodISc_within","FoodISc_between"),level=0.95)
mta3CI<-confint(mta3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
m1a3CI<-confint(m1a3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
m2a3CI<-confint(m2a3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
m3a3CI<-confint(m3a3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mma3CI<-confint(mma3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mfa3CI<-confint(mfa3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mna3CI<-confint(mna3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mpa3CI<-confint(mpa3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
msa3CI<-confint(msa3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mwa3CI<-confint(mwa3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mba3CI<-confint(mba3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)
mha3CI<-confint(mha3,c("FoodISc_within","USDA_RUC2:FoodISc_within","USDA_RUC3:FoodISc_within","FoodISc_between"),level=0.95)

# Descriptive Tables
table1<-data.table(
	Var =c("Total CM","Young","Middle","Adolescent","Male","Female","Neglect","Physical Abuse","Sexual Abuse","Food Insecurity","% Child Poverty","% Single-Parent","% No High School","Median House Value","% Vacant","% Black","% Latino","% Foreign-Born","% Children","% Male","% Elderly","% Moved","% Child Disability","Large Urban","Small Urban","Rural","2011","2012","2013","2014","2015","2016","2017","2018"),
	N1  =c(nrow(zt),nrow(z1),nrow(z2),nrow(z3),nrow(zm),nrow(zf),nrow(zn),nrow(zp),nrow(zs),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	N2  =c(length(unique(zt$ZipCode)),length(unique(z1$ZipCode)),length(unique(z2$ZipCode)),length(unique(z3$ZipCode)),length(unique(zm$ZipCode)),length(unique(zf$ZipCode)),length(unique(zn$ZipCode)),length(unique(zp$ZipCode)),length(unique(zs$ZipCode)),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Mean=c(weighted.mean(zt$RptTr,zt$CPopT),weighted.mean(z1$Rpt1r,z1$CPop1),weighted.mean(z2$Rpt2r,z2$CPop2),weighted.mean(z3$Rpt3r,z3$CPop3),weighted.mean(zm$RptMr,zm$CPopTM),weighted.mean(zf$RptFr,zf$CPopTF),weighted.mean(zn$NegTr,zn$CPopT),weighted.mean(zp$PhyTr,zp$CPopT),weighted.mean(zs$SexTr,zs$CPopT),weighted.mean(zt$FoodIS,zt$CPopT),weighted.mean(zt$CPovT,zt$CPopT),weighted.mean(zt$SingleT,zt$CPopT),weighted.mean(zt$NoHighT,zt$CPopT),weighted.mean(zt$HValueT10k,zt$CPopT),weighted.mean(zt$VacantT,zt$CPopT),weighted.mean(zt$CPopBP,zt$CPopT),weighted.mean(zt$CPopHP,zt$CPopT),weighted.mean(zt$FBornT,zt$CPopT),weighted.mean(zt$ChildPT,zt$CPopT),weighted.mean(zt$MalePT,zt$CPopT),weighted.mean(zt$ElderT,zt$CPopT),weighted.mean(zt$MoveT,zt$CPopT),weighted.mean(zt$DisablTC,zt$CPopT),prop.table(table(zt$USDA_RUC))*100,prop.table(table(zt$Yearf))*100),
	SD  =c(  weighted.sd(zt$RptTr,zt$CPopT),  weighted.sd(z1$Rpt1r,z1$CPop1),  weighted.sd(z2$Rpt2r,z2$CPop2),  weighted.sd(z3$Rpt3r,z3$CPop3),  weighted.sd(zm$RptMr,zm$CPopTM),  weighted.sd(zf$RptFr,zf$CPopTF),  weighted.sd(zn$NegTr,zn$CPopT),  weighted.sd(zp$PhyTr,zp$CPopT),  weighted.sd(zs$SexTr,zs$CPopT),  weighted.sd(zt$FoodIS,zt$CPopT),  weighted.sd(zt$CPovT,zt$CPopT),  weighted.sd(zt$SingleT,zt$CPopT),  weighted.sd(zt$NoHighT,zt$CPopT),  weighted.sd(zt$HValueT10k,zt$CPopT),  weighted.sd(zt$VacantT,zt$CPopT),  weighted.sd(zt$CPopBP,zt$CPopT),  weighted.sd(zt$CPopHP,zt$CPopT),  weighted.sd(zt$FBornT,zt$CPopT),  weighted.sd(zt$ChildPT,zt$CPopT),  weighted.sd(zt$MalePT,zt$CPopT),  weighted.sd(zt$ElderT,zt$CPopT),  weighted.sd(zt$MoveT,zt$CPopT),  weighted.sd(zt$DisablTC,zt$CPopT),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA)
)
table1

# Total
table2<-data.table(
	name=c("FIW","FIB","FIWxSU","FIWxR","AIC","chi2_LR","df","p"),
	Model1C=c(fixef(mta1 )["FoodISc_within"]             ,fixef(mta1 )["FoodISc_between"]             ,NA                                                   ,NA                                                   ,extractAIC(mta1)[2],NA,NA,NA),
	Model1L=c(      mta1CI$"FoodISc_within"$interval[[1]],      mta1CI$"FoodISc_between"$interval[[1]],NA                                                   ,NA                                                   ,NA,NA,NA,NA),
	Model1U=c(      mta1CI$"FoodISc_within"$interval[[2]],      mta1CI$"FoodISc_between"$interval[[2]],NA                                                   ,NA                                                   ,NA,NA,NA,NA),
	Model2C=c(fixef(mta2 )["FoodISc_within"]             ,fixef(mta2 )["FoodISc_between"]             ,NA                                                   ,NA                                                   ,extractAIC(mta2)[2],anova(mta1,mta2)$basicLRT[[1]],anova(mta1,mta2)$basicLRT[[2]],anova(mta1,mta2)$basicLRT[[3]]),
	Model2L=c(      mta2CI$"FoodISc_within"$interval[[1]],      mta2CI$"FoodISc_between"$interval[[1]],NA                                                   ,NA                                                   ,NA,NA,NA,NA),
	Model2U=c(      mta2CI$"FoodISc_within"$interval[[2]],      mta2CI$"FoodISc_between"$interval[[2]],NA                                                   ,NA                                                   ,NA,NA,NA,NA),
	Model3C=c(fixef(mta3 )["FoodISc_within"]             ,fixef(mta3 )["FoodISc_between"]             ,fixef(mta3 )["USDA_RUC2:FoodISc_within"]             ,fixef(mta3 )["USDA_RUC3:FoodISc_within"]             ,extractAIC(mta3)[2],anova(mta2,mta3)$basicLRT[[1]],anova(mta2,mta3)$basicLRT[[2]],anova(mta2,mta3)$basicLRT[[3]]),
	Model3L=c(      mta3CI$"FoodISc_within"$interval[[1]],      mta3CI$"FoodISc_between"$interval[[1]],      mta3CI$"USDA_RUC2:FoodISc_within"$interval[[1]],      mta3CI$"USDA_RUC3:FoodISc_within"$interval[[1]],NA,NA,NA,NA),
	Model3U=c(      mta3CI$"FoodISc_within"$interval[[2]],      mta3CI$"FoodISc_between"$interval[[2]],      mta3CI$"USDA_RUC2:FoodISc_within"$interval[[2]],      mta3CI$"USDA_RUC3:FoodISc_within"$interval[[2]],NA,NA,NA,NA))
table2

# Child Age: Young, Middle, Older (1=raw coefficients;2=coefficients relative to mean Y)
table3.1<-data.table(
	name=c("N1","N2 or MeanY","FIW","FIB","FIWxSU","FIWxR"),
	Y1C=c(nrow(z1),length(unique(z1$ZipCode))      , fixef(m1a3 )["FoodISc_within"]                                                   , fixef(m1a3 )["FoodISc_between"]                                                   , fixef(m1a3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(m1a3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	Y1L=c(NA      ,NA                              ,       m1a3CI$"FoodISc_within"$interval[[1]]                                      ,       m1a3CI$"FoodISc_between"$interval[[1]]                                      ,       m1a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       m1a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	Y1U=c(NA      ,NA                              ,       m1a3CI$"FoodISc_within"$interval[[2]]                                      ,       m1a3CI$"FoodISc_between"$interval[[2]]                                      ,       m1a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       m1a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	M1C=c(nrow(z2),length(unique(z2$ZipCode))      , fixef(m2a3 )["FoodISc_within"]                                                   , fixef(m2a3 )["FoodISc_between"]                                                   , fixef(m2a3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(m2a3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	M1L=c(NA      ,NA                              ,       m2a3CI$"FoodISc_within"$interval[[1]]                                      ,       m2a3CI$"FoodISc_between"$interval[[1]]                                      ,       m2a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       m2a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	M1U=c(NA      ,NA                              ,       m2a3CI$"FoodISc_within"$interval[[2]]                                      ,       m2a3CI$"FoodISc_between"$interval[[2]]                                      ,       m2a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       m2a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	O1C=c(nrow(z3),length(unique(z3$ZipCode))      , fixef(m3a3 )["FoodISc_within"]                                                   , fixef(m3a3 )["FoodISc_between"]                                                   , fixef(m3a3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(m3a3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	O1L=c(NA      ,NA                              ,       m3a3CI$"FoodISc_within"$interval[[1]]                                      ,       m3a3CI$"FoodISc_between"$interval[[1]]                                      ,       m3a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       m3a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	O1U=c(NA      ,NA                              ,       m3a3CI$"FoodISc_within"$interval[[2]]                                      ,       m3a3CI$"FoodISc_between"$interval[[2]]                                      ,       m3a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       m3a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	Y2C=c(nrow(z1),weighted.mean(z1$Rpt1r,z1$CPop1),(fixef(m1a3 )["FoodISc_within"]             )/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(fixef(m1a3 )["FoodISc_between"]             )/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(fixef(m1a3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(fixef(m1a3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(z1$Rpt1r,z1$CPop1)*100),
	Y2L=c(NA      ,NA                              ,(      m1a3CI$"FoodISc_within"$interval[[1]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"FoodISc_between"$interval[[1]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100),
	Y2U=c(NA      ,NA                              ,(      m1a3CI$"FoodISc_within"$interval[[2]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"FoodISc_between"$interval[[2]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100,(      m1a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(z1$Rpt1r,z1$CPop1)*100),
	M2C=c(nrow(z2),weighted.mean(z2$Rpt2r,z2$CPop2),(fixef(m2a3 )["FoodISc_within"]             )/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(fixef(m2a3 )["FoodISc_between"]             )/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(fixef(m2a3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(fixef(m2a3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(z2$Rpt2r,z2$CPop2)*100),
	M2L=c(NA      ,NA                              ,(      m2a3CI$"FoodISc_within"$interval[[1]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"FoodISc_between"$interval[[1]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100),
	M2U=c(NA      ,NA                              ,(      m2a3CI$"FoodISc_within"$interval[[2]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"FoodISc_between"$interval[[2]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100,(      m2a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(z2$Rpt2r,z2$CPop2)*100),
	O2C=c(nrow(z3),weighted.mean(z3$Rpt3r,z3$CPop3),(fixef(m3a3 )["FoodISc_within"]             )/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(fixef(m3a3 )["FoodISc_between"]             )/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(fixef(m3a3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(fixef(m3a3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(z3$Rpt3r,z3$CPop3)*100),
	O2L=c(NA      ,NA                              ,(      m3a3CI$"FoodISc_within"$interval[[1]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"FoodISc_between"$interval[[1]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100),
	O2U=c(NA      ,NA                              ,(      m3a3CI$"FoodISc_within"$interval[[2]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"FoodISc_between"$interval[[2]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100,(      m3a3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(z3$Rpt3r,z3$CPop3)*100)
)
table3.1

# Child Gender: Male, Female (1=raw coefficients;2=coefficients relative to mean Y)
table3.2<-data.table(
	name=c("N1","N2 or MeanY","FIW","FIB","FIWxSU","FIWxR"),
	M1C=c(nrow(zm),length(unique(zm$ZipCode))       , fixef(mma3 )["FoodISc_within"]                                                    , fixef(mma3 )["FoodISc_between"]                                                    , fixef(mma3 )["USDA_RUC2:FoodISc_within"]                                                    , fixef(mma3 )["USDA_RUC3:FoodISc_within"]                                                    ),
	M1L=c(NA      ,NA                               ,       mma3CI$"FoodISc_within"$interval[[1]]                                       ,       mma3CI$"FoodISc_between"$interval[[1]]                                       ,       mma3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                       ,       mma3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                       ),
	M1U=c(NA      ,NA                               ,       mma3CI$"FoodISc_within"$interval[[2]]                                       ,       mma3CI$"FoodISc_between"$interval[[2]]                                       ,       mma3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                       ,       mma3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                       ),
	F1C=c(nrow(zf),length(unique(zf$ZipCode))       , fixef(mfa3 )["FoodISc_within"]                                                    , fixef(mfa3 )["FoodISc_between"]                                                    , fixef(mfa3 )["USDA_RUC2:FoodISc_within"]                                                    , fixef(mfa3 )["USDA_RUC3:FoodISc_within"]                                                    ),
	F1L=c(NA      ,NA                               ,       mfa3CI$"FoodISc_within"$interval[[1]]                                       ,       mfa3CI$"FoodISc_between"$interval[[1]]                                       ,       mfa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                       ,       mfa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                       ),
	F1U=c(NA      ,NA                               ,       mfa3CI$"FoodISc_within"$interval[[2]]                                       ,       mfa3CI$"FoodISc_between"$interval[[2]]                                       ,       mfa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                       ,       mfa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                       ),
	M2C=c(nrow(zm),weighted.mean(zm$RptMr,zm$CPopTM),(fixef(mma3 )["FoodISc_within"]             )/weighted.mean(zm$RptMr,zm$CPopTM)*100,(fixef(mma3 )["FoodISc_between"]             )/weighted.mean(zm$RptMr,zm$CPopTM)*100,(fixef(mma3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zm$RptMr,zm$CPopTM)*100,(fixef(mma3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zm$RptMr,zm$CPopTM)*100),
	M2L=c(NA      ,NA                               ,(      mma3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zm$RptMr,zm$CPopTM)*100),
	M2U=c(NA      ,NA                               ,(      mma3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zm$RptMr,zm$CPopTM)*100,(      mma3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zm$RptMr,zm$CPopTM)*100),
	F2C=c(nrow(zf),weighted.mean(zf$RptFr,zf$CPopTF),(fixef(mfa3 )["FoodISc_within"]             )/weighted.mean(zf$RptFr,zf$CPopTF)*100,(fixef(mfa3 )["FoodISc_between"]             )/weighted.mean(zf$RptFr,zf$CPopTF)*100,(fixef(mfa3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zf$RptFr,zf$CPopTF)*100,(fixef(mfa3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zf$RptFr,zf$CPopTF)*100),
	F2L=c(NA      ,NA                               ,(      mfa3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zf$RptFr,zf$CPopTF)*100),
	F2U=c(NA      ,NA                               ,(      mfa3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zf$RptFr,zf$CPopTF)*100,(      mfa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zf$RptFr,zf$CPopTF)*100)
)
table3.2

# Child Race/Ethnicity: White, Black, Latino (1=raw coefficients;2=coefficients relative to mean Y)
table3.3<-data.table(
	name=c("N1","N2 or MeanY","FIW","FIB","FIWxSU","FIWxR"),
	W1C=c(nrow(zw),length(unique(zw$ZipCode))      , fixef(mwa3 )["FoodISc_within"]                                                   , fixef(mwa3 )["FoodISc_between"]                                                   , fixef(mwa3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(mwa3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	W1L=c(NA      ,NA                              ,       mwa3CI$"FoodISc_within"$interval[[1]]                                      ,       mwa3CI$"FoodISc_between"$interval[[1]]                                      ,       mwa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       mwa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	W1U=c(NA      ,NA                              ,       mwa3CI$"FoodISc_within"$interval[[2]]                                      ,       mwa3CI$"FoodISc_between"$interval[[2]]                                      ,       mwa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       mwa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	B1C=c(nrow(zb),length(unique(zb$ZipCode))      , fixef(mba3 )["FoodISc_within"]                                                   , fixef(mba3 )["FoodISc_between"]                                                   , fixef(mba3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(mba3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	B1L=c(NA      ,NA                              ,       mba3CI$"FoodISc_within"$interval[[1]]                                      ,       mba3CI$"FoodISc_between"$interval[[1]]                                      ,       mba3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       mba3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	B1U=c(NA      ,NA                              ,       mba3CI$"FoodISc_within"$interval[[2]]                                      ,       mba3CI$"FoodISc_between"$interval[[2]]                                      ,       mba3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       mba3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	H1C=c(nrow(zh),length(unique(zh$ZipCode))      , fixef(mha3 )["FoodISc_within"]                                                   , fixef(mha3 )["FoodISc_between"]                                                   , fixef(mha3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(mha3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	H1L=c(NA      ,NA                              ,       mha3CI$"FoodISc_within"$interval[[1]]                                      ,       mha3CI$"FoodISc_between"$interval[[1]]                                      ,       mha3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       mha3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	H1U=c(NA      ,NA                              ,       mha3CI$"FoodISc_within"$interval[[2]]                                      ,       mha3CI$"FoodISc_between"$interval[[2]]                                      ,       mha3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       mha3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	W2C=c(nrow(zw),weighted.mean(zw$RptWr,zw$CPopW),(fixef(mwa3 )["FoodISc_within"]             )/weighted.mean(zw$RptWr,zw$CPopW)*100,(fixef(mwa3 )["FoodISc_between"]             )/weighted.mean(zw$RptWr,zw$CPopW)*100,(fixef(mwa3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zw$RptWr,zw$CPopW)*100,(fixef(mwa3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zw$RptWr,zw$CPopW)*100),
	W2L=c(NA      ,NA                              ,(      mwa3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zw$RptWr,zw$CPopW)*100),
	W2U=c(NA      ,NA                              ,(      mwa3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zw$RptWr,zw$CPopW)*100,(      mwa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zw$RptWr,zw$CPopW)*100),
	B2C=c(nrow(zb),weighted.mean(zb$RptBr,zb$CPopB),(fixef(mba3 )["FoodISc_within"]             )/weighted.mean(zb$RptBr,zb$CPopB)*100,(fixef(mba3 )["FoodISc_between"]             )/weighted.mean(zb$RptBr,zb$CPopB)*100,(fixef(mba3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zb$RptBr,zb$CPopB)*100,(fixef(mba3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zb$RptBr,zb$CPopB)*100),
	B2L=c(NA      ,NA                              ,(      mba3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zb$RptBr,zb$CPopB)*100),
	B2U=c(NA      ,NA                              ,(      mba3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zb$RptBr,zb$CPopB)*100,(      mba3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zb$RptBr,zb$CPopB)*100),
	H2C=c(nrow(zh),weighted.mean(zh$RptHr,zh$CPopH),(fixef(mha3 )["FoodISc_within"]             )/weighted.mean(zh$RptHr,zh$CPopH)*100,(fixef(mha3 )["FoodISc_between"]             )/weighted.mean(zh$RptHr,zh$CPopH)*100,(fixef(mha3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zh$RptHr,zh$CPopH)*100,(fixef(mha3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zh$RptHr,zh$CPopH)*100),
	H2L=c(NA      ,NA                              ,(      mha3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zh$RptHr,zh$CPopH)*100),
	H2U=c(NA      ,NA                              ,(      mha3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zh$RptHr,zh$CPopH)*100,(      mha3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zh$RptHr,zh$CPopH)*100)
)
table3.3

# Maltreatment Type: Neglect, Physical Abuse, Sexual Abuse (1=raw coefficients;2=coefficients relative to mean Y)
table3.4<-data.table(
	name=c("N1","N2 or MeanY","FIW","FIB","FIWxSU","FIWxR"),
	Neg1C=c(nrow(zn),length(unique(zn$ZipCode))      , fixef(mna3 )["FoodISc_within"]                                                   , fixef(mna3 )["FoodISc_between"]                                                   , fixef(mna3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(mna3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	Neg1L=c(NA      ,NA                              ,       mna3CI$"FoodISc_within"$interval[[1]]                                      ,       mna3CI$"FoodISc_between"$interval[[1]]                                      ,       mna3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       mna3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	Neg1U=c(NA      ,NA                              ,       mna3CI$"FoodISc_within"$interval[[2]]                                      ,       mna3CI$"FoodISc_between"$interval[[2]]                                      ,       mna3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       mna3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	Phy1C=c(nrow(zp),length(unique(zp$ZipCode))      , fixef(mpa3 )["FoodISc_within"]                                                   , fixef(mpa3 )["FoodISc_between"]                                                   , fixef(mpa3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(mpa3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	Phy1L=c(NA      ,NA                              ,       mpa3CI$"FoodISc_within"$interval[[1]]                                      ,       mpa3CI$"FoodISc_between"$interval[[1]]                                      ,       mpa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       mpa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	Phy1U=c(NA      ,NA                              ,       mpa3CI$"FoodISc_within"$interval[[2]]                                      ,       mpa3CI$"FoodISc_between"$interval[[2]]                                      ,       mpa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       mpa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	Sex1C=c(nrow(zs),length(unique(zs$ZipCode))      , fixef(msa3 )["FoodISc_within"]                                                   , fixef(msa3 )["FoodISc_between"]                                                   , fixef(msa3 )["USDA_RUC2:FoodISc_within"]                                                   , fixef(msa3 )["USDA_RUC3:FoodISc_within"]                                                   ),
	Sex1L=c(NA      ,NA                              ,       msa3CI$"FoodISc_within"$interval[[1]]                                      ,       msa3CI$"FoodISc_between"$interval[[1]]                                      ,       msa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]]                                      ,       msa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]]                                      ),
	Sex1U=c(NA      ,NA                              ,       msa3CI$"FoodISc_within"$interval[[2]]                                      ,       msa3CI$"FoodISc_between"$interval[[2]]                                      ,       msa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]]                                      ,       msa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]]                                      ),
	Neg2C=c(nrow(zn),weighted.mean(zn$NegTr,zn$CPopT),(fixef(mna3 )["FoodISc_within"]             )/weighted.mean(zn$NegTr,zn$CPopT)*100,(fixef(mna3 )["FoodISc_between"]             )/weighted.mean(zn$NegTr,zn$CPopT)*100,(fixef(mna3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zn$NegTr,zn$CPopT)*100,(fixef(mna3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zn$NegTr,zn$CPopT)*100),
	Neg2L=c(NA      ,NA                              ,(      mna3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zn$NegTr,zn$CPopT)*100),
	Neg2U=c(NA      ,NA                              ,(      mna3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zn$NegTr,zn$CPopT)*100,(      mna3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zn$NegTr,zn$CPopT)*100),
	Phy2C=c(nrow(zp),weighted.mean(zp$PhyTr,zp$CPopT),(fixef(mpa3 )["FoodISc_within"]             )/weighted.mean(zp$PhyTr,zp$CPopT)*100,(fixef(mpa3 )["FoodISc_between"]             )/weighted.mean(zp$PhyTr,zp$CPopT)*100,(fixef(mpa3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zp$PhyTr,zp$CPopT)*100,(fixef(mpa3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zp$PhyTr,zp$CPopT)*100),
	Phy2L=c(NA      ,NA                              ,(      mpa3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zp$PhyTr,zp$CPopT)*100),
	Phy2U=c(NA      ,NA                              ,(      mpa3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zp$PhyTr,zp$CPopT)*100,(      mpa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zp$PhyTr,zp$CPopT)*100),
	Sex2C=c(nrow(zs),weighted.mean(zs$SexTr,zs$CPopT),(fixef(msa3 )["FoodISc_within"]             )/weighted.mean(zs$SexTr,zs$CPopT)*100,(fixef(msa3 )["FoodISc_between"]             )/weighted.mean(zs$SexTr,zs$CPopT)*100,(fixef(msa3 )["USDA_RUC2:FoodISc_within"]             )/weighted.mean(zs$SexTr,zs$CPopT)*100,(fixef(msa3 )["USDA_RUC3:FoodISc_within"]             )/weighted.mean(zs$SexTr,zs$CPopT)*100),
	Sex2L=c(NA      ,NA                              ,(      msa3CI$"FoodISc_within"$interval[[1]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"FoodISc_between"$interval[[1]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"USDA_RUC2:FoodISc_within"$interval[[1]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"USDA_RUC3:FoodISc_within"$interval[[1]])/weighted.mean(zs$SexTr,zs$CPopT)*100),
	Sex2U=c(NA      ,NA                              ,(      msa3CI$"FoodISc_within"$interval[[2]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"FoodISc_between"$interval[[2]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"USDA_RUC2:FoodISc_within"$interval[[2]])/weighted.mean(zs$SexTr,zs$CPopT)*100,(      msa3CI$"USDA_RUC3:FoodISc_within"$interval[[2]])/weighted.mean(zs$SexTr,zs$CPopT)*100)
)
table3.4

# Raw Model Results
table.mta1<-data.table(names(fixef(mta1)),summary(mta1)$beta_table)
table.mta2<-data.table(names(fixef(mta2)),summary(mta2)$beta_table)
table.mta3<-data.table(names(fixef(mta3)),summary(mta3)$beta_table)
table.mta4<-data.table(names(fixef(mta4)),summary(mta4)$beta_table)
table.m1a3<-data.table(names(fixef(m1a3)),summary(m1a3)$beta_table)
table.m2a3<-data.table(names(fixef(m2a3)),summary(m2a3)$beta_table)
table.m3a3<-data.table(names(fixef(m3a3)),summary(m3a3)$beta_table)
table.mma3<-data.table(names(fixef(mma3)),summary(mma3)$beta_table)
table.mfa3<-data.table(names(fixef(mfa3)),summary(mfa3)$beta_table)
table.mwa3<-data.table(names(fixef(mwa3)),summary(mwa3)$beta_table)
table.mba3<-data.table(names(fixef(mba3)),summary(mba3)$beta_table)
table.mha3<-data.table(names(fixef(mha3)),summary(mha3)$beta_table)
table.mna3<-data.table(names(fixef(mna3)),summary(mna3)$beta_table)
table.mpa3<-data.table(names(fixef(mpa3)),summary(mpa3)$beta_table)
table.msa3<-data.table(names(fixef(msa3)),summary(msa3)$beta_table)

# Sensitivity Analysis
# ARp-2
table.mta1p2<-data.table(names(fixef(mta1p2)),summary(mta1p2)$beta_table)
table.mta2p2<-data.table(names(fixef(mta2p2)),summary(mta2p2)$beta_table)
table.mta3p2<-data.table(names(fixef(mta3p2)),summary(mta3p2)$beta_table)
# ARp-3
table.mta1p3<-data.table(names(fixef(mta1p3)),summary(mta1p3)$beta_table)
table.mta2p3<-data.table(names(fixef(mta2p3)),summary(mta2p3)$beta_table)
table.mta3p3<-data.table(names(fixef(mta3p3)),summary(mta3p3)$beta_table)
# Controls
table.mta3a<-data.table(names(fixef(mta3a)),summary(mta3a)$beta_table) # No FI measures in controls
table.mta3b<-data.table(names(fixef(mta3b)),summary(mta3b)$beta_table) # Median Income
table.mta3c<-data.table(names(fixef(mta3c)),summary(mta3c)$beta_table) # Unemployment
table.mta3d<-data.table(names(fixef(mta3d)),summary(mta3d)$beta_table) # Owner occupied households
# VIF
VIF2 <-data.table(check_collinearity(lm2 ))[,1:2]
VIF2a<-data.table(check_collinearity(lm2a))[,1:2]
VIF2b<-data.table(check_collinearity(lm2b))[,1:2]
VIF2c<-data.table(check_collinearity(lm2c))[,1:2]
VIF2d<-data.table(check_collinearity(lm2d))[,1:2]
setnames(VIF2 ,"VIF","VIF2" )
setnames(VIF2a,"VIF","VIF2a")
setnames(VIF2b,"VIF","VIF2b")
setnames(VIF2c,"VIF","VIF2c")
setnames(VIF2d,"VIF","VIF2d")
VIF2<-merge(VIF2,VIF2a,by="Term",all=T)
VIF2<-merge(VIF2,VIF2b,by="Term",all=T)
VIF2<-merge(VIF2,VIF2c,by="Term",all=T)
VIF2<-merge(VIF2,VIF2d,by="Term",all=T)
VIF2$VIFMax<-pmax(VIF2$VIF2,VIF2$VIF2a,VIF2$VIF2b,VIF2$VIF2c,VIF2$VIF2d,na.rm=T)
VIF2<-VIF2[order(-VIFMax)]
VIF2
# Total - ARp-2
table2p2<-data.table(
	name=c("FIW","FIB","FIWxSU","FIWxR","AIC","chi2_LR","df","p"),
	Model1C=c(fixef(mta1p2)["FoodISc_within"]                                                    ,fixef(mta1p2)["FoodISc_between"]                                                     ,NA                                                                                                              ,NA                                                                                                     ,extractAIC(mta1p2)[2],NA,NA,NA),
	Model1L=c(fixef(mta1p2)["FoodISc_within"]-1.96*summary(mta1p2)$beta_table["FoodISc_within",2],fixef(mta1p2)["FoodISc_between"]-1.96*summary(mta1p2)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model1U=c(fixef(mta1p2)["FoodISc_within"]+1.96*summary(mta1p2)$beta_table["FoodISc_within",2],fixef(mta1p2)["FoodISc_between"]+1.96*summary(mta1p2)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model2C=c(fixef(mta2p2)["FoodISc_within"]                                                    ,fixef(mta2p2)["FoodISc_between"]                                                     ,NA                                                                                                              ,NA                                                                                                     ,extractAIC(mta2p2)[2],anova(mta1p2,mta2p2)$basicLRT[[1]],anova(mta1p2,mta2p2)$basicLRT[[2]],anova(mta1p2,mta2p2)$basicLRT[[3]]),
	Model2L=c(fixef(mta2p2)["FoodISc_within"]-1.96*summary(mta2p2)$beta_table["FoodISc_within",2],fixef(mta2p2)["FoodISc_between"]-1.96*summary(mta2p2)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model2U=c(fixef(mta2p2)["FoodISc_within"]+1.96*summary(mta2p2)$beta_table["FoodISc_within",2],fixef(mta2p2)["FoodISc_between"]+1.96*summary(mta2p2)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model3C=c(fixef(mta3p2)["FoodISc_within"]                                                    ,fixef(mta3p2)["FoodISc_between"]                                                     ,round(fixef(mta3p2)["USDA_RUC2:FoodISc_within"]                                                              ,6),fixef(mta3p2)["USDA_RUC3:FoodISc_within"]                                                              ,extractAIC(mta3p2)[2],anova(mta2p2,mta3p2)$basicLRT[[1]],anova(mta2p2,mta3p2)$basicLRT[[2]],anova(mta2p2,mta3p2)$basicLRT[[3]]),
	Model3L=c(fixef(mta3p2)["FoodISc_within"]-1.96*summary(mta3p2)$beta_table["FoodISc_within",2],fixef(mta3p2)["FoodISc_between"]-1.96*summary(mta3p2)$beta_table["FoodISc_between",2],round(fixef(mta3p2)["USDA_RUC2:FoodISc_within"]-1.96*summary(mta3p2)$beta_table["USDA_RUC2:FoodISc_within",2],6),fixef(mta3p2)["USDA_RUC3:FoodISc_within"]-1.96*summary(mta3p2)$beta_table["USDA_RUC3:FoodISc_within",2],NA,NA,NA,NA),
	Model3U=c(fixef(mta3p2)["FoodISc_within"]+1.96*summary(mta3p2)$beta_table["FoodISc_within",2],fixef(mta3p2)["FoodISc_between"]+1.96*summary(mta3p2)$beta_table["FoodISc_between",2],round(fixef(mta3p2)["USDA_RUC2:FoodISc_within"]+1.96*summary(mta3p2)$beta_table["USDA_RUC2:FoodISc_within",2],6),fixef(mta3p2)["USDA_RUC3:FoodISc_within"]+1.96*summary(mta3p2)$beta_table["USDA_RUC3:FoodISc_within",2],NA,NA,NA,NA))
table2p2
# Total - ARp-3
table2p3<-data.table(
	name=c("FIW","FIB","FIWxSU","FIWxR","AIC","chi2_LR","df","p"),
	Model1C=c(fixef(mta1p3)["FoodISc_within"]                                                    ,fixef(mta1p3)["FoodISc_between"]                                                     ,NA                                                                                                              ,NA                                                                                                     ,extractAIC(mta1p3)[2],NA,NA,NA),
	Model1L=c(fixef(mta1p3)["FoodISc_within"]-1.96*summary(mta1p3)$beta_table["FoodISc_within",2],fixef(mta1p3)["FoodISc_between"]-1.96*summary(mta1p3)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model1U=c(fixef(mta1p3)["FoodISc_within"]+1.96*summary(mta1p3)$beta_table["FoodISc_within",2],fixef(mta1p3)["FoodISc_between"]+1.96*summary(mta1p3)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model2C=c(fixef(mta2p3)["FoodISc_within"]                                                    ,fixef(mta2p3)["FoodISc_between"]                                                     ,NA                                                                                                              ,NA                                                                                                     ,extractAIC(mta2p3)[2],anova(mta1p3,mta2p3)$basicLRT[[1]],anova(mta1p3,mta2p3)$basicLRT[[2]],anova(mta1p3,mta2p3)$basicLRT[[3]]),
	Model2L=c(fixef(mta2p3)["FoodISc_within"]-1.96*summary(mta2p3)$beta_table["FoodISc_within",2],fixef(mta2p3)["FoodISc_between"]-1.96*summary(mta2p3)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model2U=c(fixef(mta2p3)["FoodISc_within"]+1.96*summary(mta2p3)$beta_table["FoodISc_within",2],fixef(mta2p3)["FoodISc_between"]+1.96*summary(mta2p3)$beta_table["FoodISc_between",2],NA                                                                                                              ,NA                                                                                                     ,NA,NA,NA,NA),
	Model3C=c(fixef(mta3p3)["FoodISc_within"]                                                    ,fixef(mta3p3)["FoodISc_between"]                                                     ,round(fixef(mta3p3)["USDA_RUC2:FoodISc_within"]                                                              ,6),fixef(mta3p3)["USDA_RUC3:FoodISc_within"]                                                              ,extractAIC(mta3p3)[2],anova(mta2p3,mta3p3)$basicLRT[[1]],anova(mta2p3,mta3p3)$basicLRT[[2]],anova(mta2p3,mta3p3)$basicLRT[[3]]),
	Model3L=c(fixef(mta3p3)["FoodISc_within"]-1.96*summary(mta3p3)$beta_table["FoodISc_within",2],fixef(mta3p3)["FoodISc_between"]-1.96*summary(mta3p3)$beta_table["FoodISc_between",2],round(fixef(mta3p3)["USDA_RUC2:FoodISc_within"]-1.96*summary(mta3p3)$beta_table["USDA_RUC2:FoodISc_within",2],6),fixef(mta3p3)["USDA_RUC3:FoodISc_within"]-1.96*summary(mta3p3)$beta_table["USDA_RUC3:FoodISc_within",2],NA,NA,NA,NA),
	Model3U=c(fixef(mta3p3)["FoodISc_within"]+1.96*summary(mta3p3)$beta_table["FoodISc_within",2],fixef(mta3p3)["FoodISc_between"]+1.96*summary(mta3p3)$beta_table["FoodISc_between",2],round(fixef(mta3p3)["USDA_RUC2:FoodISc_within"]+1.96*summary(mta3p3)$beta_table["USDA_RUC2:FoodISc_within",2],6),fixef(mta3p3)["USDA_RUC3:FoodISc_within"]+1.96*summary(mta3p3)$beta_table["USDA_RUC3:FoodISc_within",2],NA,NA,NA,NA))
table2p3

write.csv(table1,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table1_census2.csv")
write.csv(table2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table2_census2.csv")
write.csv(table3.1,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table3.1_census2.csv")
write.csv(table3.2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table3.2_census2.csv")
write.csv(table3.3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table3.3_census2.csv")
write.csv(table3.4,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table3.4_census2.csv")
write.csv(table.mta1,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta1_census2.csv")
write.csv(table.mta2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta2_census2.csv")
write.csv(table.mta3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3_census2.csv")
write.csv(table.mta4,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta4_census2.csv")
write.csv(table.m1a3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.m1a3_census2.csv")
write.csv(table.m2a3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.m2a3_census2.csv")
write.csv(table.m3a3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.m3a3_census2.csv")
write.csv(table.mma3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mma3_census2.csv")
write.csv(table.mfa3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mfa3_census2.csv")
write.csv(table.mwa3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mwa3_census2.csv")
write.csv(table.mba3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mba3_census2.csv")
write.csv(table.mha3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mha3_census2.csv")
write.csv(table.mna3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mna3_census2.csv")
write.csv(table.mpa3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mpa3_census2.csv")
write.csv(table.msa3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.msa3_census2.csv")

write.csv(table2p2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table2p2_census2.csv")
write.csv(table2p3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table2p3_census2.csv")
write.csv(table.mta1p2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta1p2_census2.csv")
write.csv(table.mta2p2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta2p2_census2.csv")
write.csv(table.mta3p2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3p2_census2.csv")
write.csv(table.mta1p3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta1p3_census2.csv")
write.csv(table.mta2p3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta2p3_census2.csv")
write.csv(table.mta3p3,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3p3_census2.csv")
write.csv(table.mta3a,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3a_census2.csv")
write.csv(table.mta3b,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3b_census2.csv")
write.csv(table.mta3c,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3c_census2.csv")
write.csv(table.mta3d,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/table.mta3d_census2.csv")
write.csv(VIF2,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/VIF2_census2.csv")





# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs
# Prediction Graphs

quantile(zt$FoodISc_within-min(zt$FoodISc_within),c(0,0.95)) # 0 - 21.7
quantile(z1$FoodISc_within-min(z1$FoodISc_within),c(0,0.95)) # 0 - 21.6
quantile(z2$FoodISc_within-min(z2$FoodISc_within),c(0,0.95)) # 0 - 21.6
quantile(z3$FoodISc_within-min(z3$FoodISc_within),c(0,0.95)) # 0 - 21.6
quantile(zm$FoodISc_within-min(zm$FoodISc_within),c(0,0.95)) # 0 - 21.7
quantile(zf$FoodISc_within-min(zf$FoodISc_within),c(0,0.95)) # 0 - 21.7
quantile(zw$FoodISc_within-min(zw$FoodISc_within),c(0,0.95)) # 0 - 21.5
quantile(zb$FoodISc_within-min(zb$FoodISc_within),c(0,0.95)) # 0 - 20.7
quantile(zh$FoodISc_within-min(zh$FoodISc_within),c(0,0.95)) # 0 - 19.6
quantile(zn$FoodISc_within-min(zn$FoodISc_within),c(0,0.95)) # 0 - 21.7
quantile(zp$FoodISc_within-min(zp$FoodISc_within),c(0,0.95)) # 0 - 21.7
quantile(zs$FoodISc_within-min(zs$FoodISc_within),c(0,0.95)) # 0 - 21.7

quantile(zt$FoodISc_within,c(0.025,0.975)) # -7.2 - 11.5
quantile(z1$FoodISc_within,c(0.025,0.975)) # -7.1 - 11.4
quantile(z2$FoodISc_within,c(0.025,0.975)) # -7.1 - 11.4
quantile(z3$FoodISc_within,c(0.025,0.975)) # -7.1 - 11.5
quantile(zm$FoodISc_within,c(0.025,0.975)) # -7.2 - 11.5
quantile(zf$FoodISc_within,c(0.025,0.975)) # -7.1 - 11.5
quantile(zw$FoodISc_within,c(0.025,0.975)) # -7.0 - 11.4
quantile(zb$FoodISc_within,c(0.025,0.975)) # -7.5 - 12.5
quantile(zh$FoodISc_within,c(0.025,0.975)) # -7.0 - 11.1
quantile(zn$FoodISc_within,c(0.025,0.975)) # -7.2 - 11.5
quantile(zp$FoodISc_within,c(0.025,0.975)) # -7.2 - 11.5
quantile(zs$FoodISc_within,c(0.025,0.975)) # -7.2 - 11.5

# Prediction for Total
pt<-data.table(FoodISc_within=seq(-10,10,by=5))
pt$Year2012<-mean(zt$Year2012)
pt$Year2013<-mean(zt$Year2013)
pt$Year2014<-mean(zt$Year2014)
pt$Year2015<-mean(zt$Year2015)
pt$Year2016<-mean(zt$Year2016)
pt$Year2017<-mean(zt$Year2017)
pt$Year2018<-mean(zt$Year2018)
pt$FoodISc_between<-0
pt$CPovTc         <-0
pt$SingleTc       <-0
pt$NoHighTc       <-0
pt$HValueT10kc    <-0
pt$VacantTc       <-0
pt$CPopBPc        <-0
pt$CPopHPc        <-0
pt$FBornTc        <-0
pt$ChildPTc       <-0
pt$MalePTc        <-0
pt$ElderTc        <-0
pt$MoveTc         <-0
pt$DisablTCc      <-0
# Urban
pt$USDA_RUC<-"1"
ptu<-predict(mta3y,pt,re.form=NA)
# Small Urban
pt$USDA_RUC<-"2"
pts<-predict(mta3y,pt,re.form=NA)
# Rural
pt$USDA_RUC<-"3"
ptr<-predict(mta3y,pt,re.form=NA)

# Prediction for Age 1
p1<-data.table(FoodISc_within=seq(-10,10,by=5))
p1$Year2012<-mean(z1$Year2012)
p1$Year2013<-mean(z1$Year2013)
p1$Year2014<-mean(z1$Year2014)
p1$Year2015<-mean(z1$Year2015)
p1$Year2016<-mean(z1$Year2016)
p1$Year2017<-mean(z1$Year2017)
p1$Year2018<-mean(z1$Year2018)
p1$FoodISc_between<-0
p1$CPov1c         <-0
p1$SingleTc       <-0
p1$NoHighTc       <-0
p1$HValueT10kc    <-0
p1$VacantTc       <-0
p1$CPopBPc        <-0
p1$CPopHPc        <-0
p1$FBornTc        <-0
p1$ChildPTc       <-0
p1$MalePTc        <-0
p1$ElderTc        <-0
p1$MoveTc         <-0
p1$DisablTCc      <-0
# Urban
p1$USDA_RUC<-"1"
p1u<-predict(m1a3y,p1,re.form=NA)
# Small Urban
p1$USDA_RUC<-"2"
p1s<-predict(m1a3y,p1,re.form=NA)
# Rural
p1$USDA_RUC<-"3"
p1r<-predict(m1a3y,p1,re.form=NA)

# Prediction for Age 2
p2<-data.table(FoodISc_within=seq(-10,10,by=5))
p2$Year2012<-mean(z2$Year2012)
p2$Year2013<-mean(z2$Year2013)
p2$Year2014<-mean(z2$Year2014)
p2$Year2015<-mean(z2$Year2015)
p2$Year2016<-mean(z2$Year2016)
p2$Year2017<-mean(z2$Year2017)
p2$Year2018<-mean(z2$Year2018)
p2$FoodISc_between<-0
p2$CPov2c         <-0
p2$SingleTc       <-0
p2$NoHighTc       <-0
p2$HValueT10kc    <-0
p2$VacantTc       <-0
p2$CPopBPc        <-0
p2$CPopHPc        <-0
p2$FBornTc        <-0
p2$ChildPTc       <-0
p2$MalePTc        <-0
p2$ElderTc        <-0
p2$MoveTc         <-0
p2$DisablTCc      <-0
# Urban
p2$USDA_RUC<-"1"
p2u<-predict(m2a3y,p2,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
p2$USDA_RUC<-"2"
p2s<-predict(m2a3y,p2,re.form=NA,intervals="predVar",level=0.95)
# Rural
p2$USDA_RUC<-"3"
p2r<-predict(m2a3y,p2,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Age 3
p3<-data.table(FoodISc_within=seq(-10,10,by=5))
p3$Year2012<-mean(z3$Year2012)
p3$Year2013<-mean(z3$Year2013)
p3$Year2014<-mean(z3$Year2014)
p3$Year2015<-mean(z3$Year2015)
p3$Year2016<-mean(z3$Year2016)
p3$Year2017<-mean(z3$Year2017)
p3$Year2018<-mean(z3$Year2018)
p3$FoodISc_between<-0
p3$CPov3c         <-0
p3$SingleTc       <-0
p3$NoHighTc       <-0
p3$HValueT10kc    <-0
p3$VacantTc       <-0
p3$CPopBPc        <-0
p3$CPopHPc        <-0
p3$FBornTc        <-0
p3$ChildPTc       <-0
p3$MalePTc        <-0
p3$ElderTc        <-0
p3$MoveTc         <-0
p3$DisablTCc      <-0
# Urban
p3$USDA_RUC<-"1"
p3u<-predict(m3a3y,p3,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
p3$USDA_RUC<-"2"
p3s<-predict(m3a3y,p3,re.form=NA,intervals="predVar",level=0.95)
# Rural
p3$USDA_RUC<-"3"
p3r<-predict(m3a3y,p3,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Male
pm<-data.table(FoodISc_within=seq(-10,10,by=5))
pm$Year2012<-mean(zm$Year2012)
pm$Year2013<-mean(zm$Year2013)
pm$Year2014<-mean(zm$Year2014)
pm$Year2015<-mean(zm$Year2015)
pm$Year2016<-mean(zm$Year2016)
pm$Year2017<-mean(zm$Year2017)
pm$Year2018<-mean(zm$Year2018)
pm$FoodISc_between<-0
pm$CPovTc         <-0
pm$SingleTc       <-0
pm$NoHighTc       <-0
pm$HValueT10kc    <-0
pm$VacantTc       <-0
pm$CPopBPc        <-0
pm$CPopHPc        <-0
pm$FBornTc        <-0
pm$ChildPTc       <-0
pm$MalePTc        <-0
pm$ElderTc        <-0
pm$MoveTc         <-0
pm$DisablTMc      <-0
# Urban
pm$USDA_RUC<-"1"
pmu<-predict(mma3y,pm,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pm$USDA_RUC<-"2"
pms<-predict(mma3y,pm,re.form=NA,intervals="predVar",level=0.95)
# Rural
pm$USDA_RUC<-"3"
pmr<-predict(mma3y,pm,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Female
pf<-data.table(FoodISc_within=seq(-10,10,by=5))
pf$Year2012<-mean(zf$Year2012)
pf$Year2013<-mean(zf$Year2013)
pf$Year2014<-mean(zf$Year2014)
pf$Year2015<-mean(zf$Year2015)
pf$Year2016<-mean(zf$Year2016)
pf$Year2017<-mean(zf$Year2017)
pf$Year2018<-mean(zf$Year2018)
pf$FoodISc_between<-0
pf$CPovTc         <-0
pf$SingleTc       <-0
pf$NoHighTc       <-0
pf$HValueT10kc    <-0
pf$VacantTc       <-0
pf$CPopBPc        <-0
pf$CPopHPc        <-0
pf$FBornTc        <-0
pf$ChildPTc       <-0
pf$MalePTc        <-0
pf$ElderTc        <-0
pf$MoveTc         <-0
pf$DisablTFc      <-0
# Urban
pf$USDA_RUC<-"1"
pfu<-predict(mfa3y,pf,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pf$USDA_RUC<-"2"
pfs<-predict(mfa3y,pf,re.form=NA,intervals="predVar",level=0.95)
# Rural
pf$USDA_RUC<-"3"
pfr<-predict(mfa3y,pf,re.form=NA,intervals="predVar",level=0.95)

# Prediction for White
pw<-data.table(FoodISc_within=seq(-10,10,by=5))
pw$Year2012<-mean(zw$Year2012)
pw$Year2013<-mean(zw$Year2013)
pw$Year2014<-mean(zw$Year2014)
pw$Year2015<-mean(zw$Year2015)
pw$Year2016<-mean(zw$Year2016)
pw$Year2017<-mean(zw$Year2017)
pw$Year2018<-mean(zw$Year2018)
pw$FoodISc_between<-0
pw$CPovWc         <-0
pw$SingleWc       <-0
pw$NoHighWc       <-0
pw$HValueT10kc    <-0
pw$VacantTc       <-0
pw$CPopBPc        <-0
pw$CPopHPc        <-0
pw$FBornWc        <-0
pw$ChildPWc       <-0
pw$MalePWc        <-0
pw$ElderWc        <-0
pw$MoveWc         <-0
pw$DisablWCc      <-0
# Urban
pw$USDA_RUC<-"1"
pwu<-predict(mwa3y,pw,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pw$USDA_RUC<-"2"
pws<-predict(mwa3y,pw,re.form=NA,intervals="predVar",level=0.95)
# Rural
pw$USDA_RUC<-"3"
pwr<-predict(mwa3y,pw,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Black
pb<-data.table(FoodISc_within=seq(-10,10,by=5))
pb$Year2012<-mean(zb$Year2012)
pb$Year2013<-mean(zb$Year2013)
pb$Year2014<-mean(zb$Year2014)
pb$Year2015<-mean(zb$Year2015)
pb$Year2016<-mean(zb$Year2016)
pb$Year2017<-mean(zb$Year2017)
pb$Year2018<-mean(zb$Year2018)
pb$FoodISc_between<-0
pb$CPovBc         <-0
pb$SingleBc       <-0
pb$NoHighBc       <-0
pb$HValueT10kc    <-0
pb$VacantTc       <-0
pb$CPopBPc        <-0
pb$CPopHPc        <-0
pb$FBornBc        <-0
pb$ChildPBc       <-0
pb$MalePBc        <-0
pb$ElderBc        <-0
pb$MoveBc         <-0
pb$DisablBCc      <-0
# Urban
pb$USDA_RUC<-"1"
pbu<-predict(mba3y,pb,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pb$USDA_RUC<-"2"
pbs<-predict(mba3y,pb,re.form=NA,intervals="predVar",level=0.95)
# Rural
pb$USDA_RUC<-"3"
pbr<-predict(mba3y,pb,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Latino
ph<-data.table(FoodISc_within=seq(-10,10,by=5))
ph$Year2012<-mean(zh$Year2012)
ph$Year2013<-mean(zh$Year2013)
ph$Year2014<-mean(zh$Year2014)
ph$Year2015<-mean(zh$Year2015)
ph$Year2016<-mean(zh$Year2016)
ph$Year2017<-mean(zh$Year2017)
ph$Year2018<-mean(zh$Year2018)
ph$FoodISc_between<-0
ph$CPovHc         <-0
ph$SingleHc       <-0
ph$NoHighHc       <-0
ph$HValueT10kc    <-0
ph$VacantTc       <-0
ph$CPopBPc        <-0
ph$CPopHPc        <-0
ph$FBornHc        <-0
ph$ChildPHc       <-0
ph$MalePHc        <-0
ph$ElderHc        <-0
ph$MoveHc         <-0
ph$DisablHCc      <-0
# Urban
ph$USDA_RUC<-"1"
phu<-predict(mha3y,ph,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
ph$USDA_RUC<-"2"
phs<-predict(mha3y,ph,re.form=NA,intervals="predVar",level=0.95)
# Rural
ph$USDA_RUC<-"3"
phr<-predict(mha3y,ph,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Neglect
pn<-data.table(FoodISc_within=seq(-10,10,by=5))
pn$Year2012<-mean(zn$Year2012)
pn$Year2013<-mean(zn$Year2013)
pn$Year2014<-mean(zn$Year2014)
pn$Year2015<-mean(zn$Year2015)
pn$Year2016<-mean(zn$Year2016)
pn$Year2017<-mean(zn$Year2017)
pn$Year2018<-mean(zn$Year2018)
pn$FoodISc_between<-0
pn$CPovTc         <-0
pn$SingleTc       <-0
pn$NoHighTc       <-0
pn$HValueT10kc    <-0
pn$VacantTc       <-0
pn$CPopBPc        <-0
pn$CPopHPc        <-0
pn$FBornTc        <-0
pn$ChildPTc       <-0
pn$MalePTc        <-0
pn$ElderTc        <-0
pn$MoveTc         <-0
pn$DisablTCc      <-0
# Urban
pn$USDA_RUC<-"1"
pnu<-predict(mna3y,pn,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pn$USDA_RUC<-"2"
pns<-predict(mna3y,pn,re.form=NA,intervals="predVar",level=0.95)
# Rural
pn$USDA_RUC<-"3"
pnr<-predict(mna3y,pn,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Physical Abuse
pp<-data.table(FoodISc_within=seq(-10,10,by=5))
pp$Year2012<-mean(zp$Year2012)
pp$Year2013<-mean(zp$Year2013)
pp$Year2014<-mean(zp$Year2014)
pp$Year2015<-mean(zp$Year2015)
pp$Year2016<-mean(zp$Year2016)
pp$Year2017<-mean(zp$Year2017)
pp$Year2018<-mean(zp$Year2018)
pp$FoodISc_between<-0
pp$CPovTc         <-0
pp$SingleTc       <-0
pp$NoHighTc       <-0
pp$HValueT10kc    <-0
pp$VacantTc       <-0
pp$CPopBPc        <-0
pp$CPopHPc        <-0
pp$FBornTc        <-0
pp$ChildPTc       <-0
pp$MalePTc        <-0
pp$ElderTc        <-0
pp$MoveTc         <-0
pp$DisablTCc      <-0
# Urban
pp$USDA_RUC<-"1"
ppu<-predict(mpa3y,pp,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
pp$USDA_RUC<-"2"
pps<-predict(mpa3y,pp,re.form=NA,intervals="predVar",level=0.95)
# Rural
pp$USDA_RUC<-"3"
ppr<-predict(mpa3y,pp,re.form=NA,intervals="predVar",level=0.95)

# Prediction for Sexual Abuse
ps<-data.table(FoodISc_within=seq(-10,10,by=5))
ps$Year2012<-mean(zs$Year2012)
ps$Year2013<-mean(zs$Year2013)
ps$Year2014<-mean(zs$Year2014)
ps$Year2015<-mean(zs$Year2015)
ps$Year2016<-mean(zs$Year2016)
ps$Year2017<-mean(zs$Year2017)
ps$Year2018<-mean(zs$Year2018)
ps$FoodISc_between<-0
ps$CPovTc         <-0
ps$SingleTc       <-0
ps$NoHighTc       <-0
ps$HValueT10kc    <-0
ps$VacantTc       <-0
ps$CPopBPc        <-0
ps$CPopHPc        <-0
ps$FBornTc        <-0
ps$ChildPTc       <-0
ps$MalePTc        <-0
ps$ElderTc        <-0
ps$MoveTc         <-0
ps$DisablTCc      <-0
# Urban
ps$USDA_RUC<-"1"
psu<-predict(msa3y,ps,re.form=NA,intervals="predVar",level=0.95)
# Small Urban
ps$USDA_RUC<-"2"
pss<-predict(msa3y,ps,re.form=NA,intervals="predVar",level=0.95)
# Rural
ps$USDA_RUC<-"3"
psr<-predict(msa3y,ps,re.form=NA,intervals="predVar",level=0.95)

predict<-data.table(FoodISc_within=pt$FoodISc_within,
										Total.Urban=ptu,Total.SU=pts,Total.Rural=ptr,
										Age1.Urban=p1u,Age1.SU=p1s,Age1.Rural=p1r,
										Age2.Urban=p2u,Age2.SU=p2s,Age2.Rural=p2r,
										Age3.Urban=p3u,Age3.SU=p3s,Age3.Rural=p3r,
										Male.Urban=pmu,Male.SU=pms,Male.Rural=pmr,
										Female.Urban=pfu,Female.SU=pfs,Female.Rural=pfr,
										White.Urban=pwu,White.SU=pws,White.Rural=pwr,
										Black.Urban=pbu,Black.SU=pbs,Black.Rural=pbr,
										Latino.Urban=phu,Latino.SU=phs,Latino.Rural=phr,
										Neg.Urban=pnu,Neg.SU=pns,Neg.Rural=pnr,
										Phy.Urban=ppu,Phy.SU=pps,Phy.Rural=ppr,
										Sex.Urban=psu,Sex.SU=pss,Sex.Rural=psr)
predict

write.csv(predict,"Z:/CDCK01/Analysis/ZipCode/Food/Tables/predict_census2.csv")

save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food02_Model1_census2.RData")


# bootstrap CI -- takes days to run and somehow the results are not saved as an object (e.g., object 'mtd2CI' not found)
# So, do not run the below codes until figuring out how to save the results
# mtd2CI<-confint(mtd2,names(fixef(mtd2)),boot_args=list(nb_cores=15,nsim=1499))
# mtd4CI<-confint(mtd4,names(fixef(mtd4)),boot_args=list(nb_cores=15,nsim=1499))
# mtd5CI<-confint(mtd5,names(fixef(mtd5)),boot_args=list(nb_cores=15,nsim=1499))
# m1d4CI<-confint(m1d4,names(fixef(m1d4)),boot_args=list(nb_cores=15,nsim=1499))
# m2d4CI<-confint(m2d4,names(fixef(m2d4)),boot_args=list(nb_cores=15,nsim=1499))
# m3d4CI<-confint(m3d4,names(fixef(m3d4)),boot_args=list(nb_cores=15,nsim=1499))
# mmd4CI<-confint(mmd4,names(fixef(mmd4)),boot_args=list(nb_cores=15,nsim=1499))
# mfd4CI<-confint(mfd4,names(fixef(mfd4)),boot_args=list(nb_cores=15,nsim=1499))
# mwd4CI<-confint(mwd4,names(fixef(mwd4)),boot_args=list(nb_cores=15,nsim=1499))
# mbd4CI<-confint(mbd4,names(fixef(mbd4)),boot_args=list(nb_cores=15,nsim=1499))
# mhd4CI<-confint(mhd4,names(fixef(mhd4)),boot_args=list(nb_cores=15,nsim=1499))
# mnd4CI<-confint(mnd4,names(fixef(mnd4)),boot_args=list(nb_cores=15,nsim=1499))
# mpd4CI<-confint(mpd4,names(fixef(mpd4)),boot_args=list(nb_cores=15,nsim=1499))
# msd4CI<-confint(msd4,names(fixef(msd4)),boot_args=list(nb_cores=15,nsim=1499))

LongRpt<-zt[,list(mean=mean(RptTr)),by=.(Yearf,USDA_RUC)]
LongPov<-zt[,list(mean=mean(CPovT)),by=.(Yearf,USDA_RUC)]
LongFI <-zt[,list(mean=mean(FoodIS)),by=.(Yearf,USDA_RUC)]
ggplot(LongFI ,aes(x=Yearf,y=mean,group=USDA_RUC,color=USDA_RUC))+geom_line()+ylab("Food Insecurity, %")
ggplot(LongRpt,aes(x=Yearf,y=mean,group=USDA_RUC,color=USDA_RUC))+geom_line()+ylab("Child Maltreatment Report Rate per 1k")
ggplot(LongPov,aes(x=Yearf,y=mean,group=USDA_RUC,color=USDA_RUC))+geom_line()+ylab("Child Poverty, %")




figure.model<-lm(RptTr~FoodIS,data=zt)
cor.test(zt$FoodIS,zt$RptTr)
summary(figure.model)

figure<-ggplot(zt,aes(x=FoodIS,y=RptTr))+
	geom_point(shape=16,size=2,alpha=.5)+
	geom_smooth(method=lm,color="red",fill="red",se=F,size=1.2)+
	theme_bw()+
	annotate("text",x=35,y=250,label="r = 0.60; p < .0001")+
	ylab("Child maltreatment report rate per 1,000 children")+
	xlab("% Persons in a food insecure household")+
	theme(panel.grid.major=element_blank(),panel.grid.minor=element_blank(),panel.border=element_blank(),
				axis.line=element_line(),axis.text=element_text(color="black"))
figure
ggsave(filename="Z:/CDCK01/Analysis/ZipCode/Food/Figures/figure.pdf",plot=figure,width=6.5,height=4,device='pdf')
ggsave(filename="Z:/CDCK01/Analysis/ZipCode/Food/Figures/figure.jpg",plot=figure,width=6.5,height=4,dpi=1200,device='jpeg')




sims_mtd4<-simulateResiduals(mtd4)
testDispersion(mtd4)
testDispersion(sims_mtd4)
plot(residuals(sims_mtd4))
plot(density(residuals(sims_mtd4,quantileFunction=qnorm)))
skewness(residuals(sims_mtd4))

skewness(residuals(mtd1))
skewness(residuals(mtd2))
skewness(residuals(mtd4))
skewness(residuals(mtd5))
skewness(residuals(m1d4))
skewness(residuals(m2d4))
skewness(residuals(m3d4))
skewness(residuals(mmd4))
skewness(residuals(mfd4))
skewness(residuals(mwd4))
skewness(residuals(mbd4))
skewness(residuals(mhd4))
skewness(residuals(mnd4))
skewness(residuals(mpd4))
skewness(residuals(msd4))

plot(density(residuals(msd4)))

sims_msd4<-simulateResiduals(msd4)
testDispersion(sims_msd4)
plot(residuals(sims_msd4))
plot(density(residuals(sims_msd4,quantileFunction=qnorm)))
skewness(residuals(sims_msd4))
plot(sims_msd4)

save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food02_Model3.RData")





mta3.r3a<-fixef(mta3)["FoodISc_within"]+fixef(mta3)["USDA_RUC2:FoodISc_within"]
mta3.r3SEa<-(vcov(mta3)["FoodISc_within","FoodISc_within"]+vcov(mta3)["USDA_RUC2:FoodISc_within","USDA_RUC2:FoodISc_within"]+2*vcov(mta3)["FoodISc_within","USDA_RUC2:FoodISc_within"])^(1/2)
mta3.r3LLa<-mta3.r3a-1.96*mta3.r3SEa
mta3.r3ULa<-mta3.r3a+1.96*mta3.r3SEa
mta3.r3a*10
mta3.r3LLa*10
mta3.r3ULa*10

mta3.r3b<-fixef(mta3)["FoodISc_within"]+fixef(mta3)["USDA_RUC3:FoodISc_within"]
mta3.r3SEb<-(vcov(mta3)["FoodISc_within","FoodISc_within"]+vcov(mta3)["USDA_RUC3:FoodISc_within","USDA_RUC3:FoodISc_within"]+2*vcov(mta3)["FoodISc_within","USDA_RUC3:FoodISc_within"])^(1/2)
mta3.r3LLb<-mta3.r3b-1.96*mta3.r3SEb
mta3.r3ULb<-mta3.r3b+1.96*mta3.r3SEb
mta3.r3b*10
mta3.r3LLb*10
mta3.r3ULb*10


