
# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(parameters) # for demean
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(spaMM)      # for spatial modeling
library(radiant.data) # for weighted.sd
library(Weighted.Desc.Stat) # for w.skewness (weighted skewness)
library(raster) # To read shapefile
library(rgdal)  # To read shapefile
library(spdep)  # for poly2nb





memory.limit(300000000000) # Increase memory limit





# Loading Data
z<-read_sas("Z:/CDCK01/Data_Zip/cdck01zip_census2.sas7bdat")       # N=11064,  829 variables
z<-data.table(z)

# Replace NA with 0 (no child care provider)
z$ChildCare1[is.na(z$ChildCare1)]<-0
z$ChildCare2[is.na(z$ChildCare2)]<-0
z$ChildCare3[is.na(z$ChildCare3) & z$Year>2015]<-0

# making categorical variables as.factor & scaling (roughly 0-100) continuous variables
z$Yearf      <-as.factor(z$Year)
z$USDA_RUC   <-as.factor(z$USDA_RUC)
z$IncomeT1k  <-z$IncomeT /1000
z$IncomeW1k  <-z$IncomeW /1000
z$IncomeB1k  <-z$IncomeB /1000
z$IncomeH1k  <-z$IncomeH /1000
z$HValueT10k <-z$HValueT /10000
z$CARatioT100<-z$CARatioT*100
z$CARatioW100<-z$CARatioW*100
z$CARatioB100<-z$CARatioB*100
z$CARatioH100<-z$CARatioH*100
z$MFRatioT100<-z$MFRatioT*100
z$MFRatioW100<-z$MFRatioW*100
z$MFRatioB100<-z$MFRatioB*100
z$MFRatioH100<-z$MFRatioH*100
z$OwnerT     <-z$OwnNT/z$OHUnitT*100
z$OwnerW     <-z$OwnNW/z$OHUnitW*100
z$OwnerB     <-z$OwnNB/z$OHUnitB*100
z$OwnerH     <-z$OwnNH/z$OHUnitH*100





# Centering Variables
z$CPopBPc      <-z$CPopBP      -mean(z$CPopBP      ,na.rm=T)
z$CPopHPc      <-z$CPopHP      -mean(z$CPopHP      ,na.rm=T)
z$ChildPTc     <-z$ChildPT     -mean(z$ChildPT     ,na.rm=T)
z$ChildPWc     <-z$ChildPW     -mean(z$ChildPW     ,na.rm=T)
z$ChildPBc     <-z$ChildPB     -mean(z$ChildPB     ,na.rm=T)
z$ChildPHc     <-z$ChildPH     -mean(z$ChildPH     ,na.rm=T)
z$CARatioT100c <-z$CARatioT100 -mean(z$CARatioT100 ,na.rm=T)
z$CARatioW100c <-z$CARatioW100 -mean(z$CARatioW100 ,na.rm=T)
z$CARatioB100c <-z$CARatioB100 -mean(z$CARatioB100 ,na.rm=T)
z$CARatioH100c <-z$CARatioH100 -mean(z$CARatioH100 ,na.rm=T)
z$MalePTc      <-z$MalePT      -mean(z$MalePT      ,na.rm=T)
z$MalePWc      <-z$MalePW      -mean(z$MalePW      ,na.rm=T)
z$MalePBc      <-z$MalePB      -mean(z$MalePB      ,na.rm=T)
z$MalePHc      <-z$MalePH      -mean(z$MalePH      ,na.rm=T)
z$MFRatioT100c <-z$MFRatioT100 -mean(z$MFRatioT100 ,na.rm=T)
z$MFRatioW100c <-z$MFRatioW100 -mean(z$MFRatioW100 ,na.rm=T)
z$MFRatioB100c <-z$MFRatioB100 -mean(z$MFRatioB100 ,na.rm=T)
z$MFRatioH100c <-z$MFRatioH100 -mean(z$MFRatioH100 ,na.rm=T)
z$ElderTc      <-z$ElderT      -mean(z$ElderT      ,na.rm=T)
z$ElderWc      <-z$ElderW      -mean(z$ElderW      ,na.rm=T)
z$ElderBc      <-z$ElderB      -mean(z$ElderB      ,na.rm=T)
z$ElderHc      <-z$ElderH      -mean(z$ElderH      ,na.rm=T)
z$SingleTc     <-z$SingleT     -mean(z$SingleT     ,na.rm=T)
z$SingleWc     <-z$SingleW     -mean(z$SingleW     ,na.rm=T)
z$SingleBc     <-z$SingleB     -mean(z$SingleB     ,na.rm=T)
z$SingleHc     <-z$SingleH     -mean(z$SingleH     ,na.rm=T)
z$NoHighTc     <-z$NoHighT     -mean(z$NoHighT     ,na.rm=T)
z$NoHighWc     <-z$NoHighW     -mean(z$NoHighW     ,na.rm=T)
z$NoHighBc     <-z$NoHighB     -mean(z$NoHighB     ,na.rm=T)
z$NoHighHc     <-z$NoHighH     -mean(z$NoHighH     ,na.rm=T)
z$UnempTc      <-z$UnempT      -mean(z$UnempT      ,na.rm=T)
z$UnempWc      <-z$UnempW      -mean(z$UnempW      ,na.rm=T)
z$UnempBc      <-z$UnempB      -mean(z$UnempB      ,na.rm=T)
z$UnempHc      <-z$UnempH      -mean(z$UnempH      ,na.rm=T)
z$CPovTc       <-z$CPovT       -mean(z$CPovT       ,na.rm=T)
z$CPovWc       <-z$CPovW       -mean(z$CPovW       ,na.rm=T)
z$CPovBc       <-z$CPovB       -mean(z$CPovB       ,na.rm=T)
z$CPovHc       <-z$CPovH       -mean(z$CPovH       ,na.rm=T)
z$CPov1c       <-z$CPov1       -mean(z$CPov1       ,na.rm=T)
z$CPov2c       <-z$CPov2       -mean(z$CPov2       ,na.rm=T)
z$CPov3c       <-z$CPov3       -mean(z$CPov3       ,na.rm=T)
z$IncomeT1kc   <-z$IncomeT1k   -mean(z$IncomeT1k   ,na.rm=T)
z$IncomeW1kc   <-z$IncomeW1k   -mean(z$IncomeW1k   ,na.rm=T)
z$IncomeB1kc   <-z$IncomeB1k   -mean(z$IncomeB1k   ,na.rm=T)
z$IncomeH1kc   <-z$IncomeH1k   -mean(z$IncomeH1k   ,na.rm=T)
z$HValueT10kc  <-z$HValueT10k  -mean(z$HValueT10k  ,na.rm=T)
z$FBornTc      <-z$FBornT      -mean(z$FBornT      ,na.rm=T)
z$FBornWc      <-z$FBornW      -mean(z$FBornW      ,na.rm=T)
z$FBornBc      <-z$FBornB      -mean(z$FBornB      ,na.rm=T)
z$FBornHc      <-z$FBornH      -mean(z$FBornH      ,na.rm=T)
z$MoveTc       <-z$MoveT       -mean(z$MoveT       ,na.rm=T)
z$MoveWc       <-z$MoveW       -mean(z$MoveW       ,na.rm=T)
z$MoveBc       <-z$MoveB       -mean(z$MoveB       ,na.rm=T)
z$MoveHc       <-z$MoveH       -mean(z$MoveH       ,na.rm=T)
z$VacantTc     <-z$VacantT     -mean(z$VacantT     ,na.rm=T)
z$OwnerTc      <-z$OwnerT      -mean(z$OwnerT      ,na.rm=T)
z$OwnerWc      <-z$OwnerW      -mean(z$OwnerW      ,na.rm=T)
z$OwnerBc      <-z$OwnerB      -mean(z$OwnerB      ,na.rm=T)
z$OwnerHc      <-z$OwnerH      -mean(z$OwnerH      ,na.rm=T)
z$DisablTc     <-z$DisablT     -mean(z$DisablT     ,na.rm=T)
z$DisablWc     <-z$DisablW     -mean(z$DisablW     ,na.rm=T)
z$DisablBc     <-z$DisablB     -mean(z$DisablB     ,na.rm=T)
z$DisablHc     <-z$DisablH     -mean(z$DisablH     ,na.rm=T)
z$DisablTCc    <-z$DisablTC    -mean(z$DisablTC    ,na.rm=T)
z$DisablWCc    <-z$DisablWC    -mean(z$DisablWC    ,na.rm=T)
z$DisablBCc    <-z$DisablBC    -mean(z$DisablBC    ,na.rm=T)
z$DisablHCc    <-z$DisablHC    -mean(z$DisablHC    ,na.rm=T)
z$DisablTMc    <-z$DisablTM    -mean(z$DisablTM    ,na.rm=T)
z$DisablTFc    <-z$DisablTF    -mean(z$DisablTF    ,na.rm=T)
z$ChildCare1c  <-z$ChildCare1  -mean(z$ChildCare1  ,na.rm=T)
z$ChildCare2c  <-z$ChildCare2  -mean(z$ChildCare2  ,na.rm=T)
z$ChildCare3c  <-z$ChildCare3  -mean(z$ChildCare3  ,na.rm=T)
z$CCAPc        <-z$CCAP        -mean(z$CCAP        ,na.rm=T)





z<-z[,.(ZipCode,Year,Yearf,USDA_RUC,
				ChildCare1,ChildCare1c,ChildCare2,ChildCare2c,ChildCare3,ChildCare3c,CCAP,CCAPc,
				CPopT,CPop1,CPop2,CPop3,CPopW,CPopB,CPopH,
				Rpt  ,Age1 ,Age2 ,Age3 ,RptNG,RptPA,RptSA,RacW ,RacB ,RacH ,
				RptTr,Rpt1r,Rpt2r,Rpt3r,NegTr,PhyTr,SexTr,RptWr,RptBr,RptHr,
				CPovT,CPovTc,CPov1,CPov1c,CPov2,CPov2c,CPov3,CPov3c,CPovW,CPovWc,CPovB,CPovBc,CPovH,CPovHc,
				IncomeT1k,IncomeT1kc,IncomeW1k,IncomeW1kc,IncomeB1k,IncomeB1kc,IncomeH1k,IncomeH1kc,
				SingleT,SingleTc,SingleW,SingleWc,SingleB,SingleBc,SingleH,SingleHc,
				OwnerT,OwnerTc,OwnerW,OwnerWc,OwnerB,OwnerBc,OwnerH,OwnerHc,
				DisablTC,DisablTCc,DisablWC,DisablWCc,DisablBC,DisablBCc,DisablHC,DisablHCc,
				FBornT,FBornTc,FBornW,FBornWc,FBornB,FBornBc,FBornH,FBornHc,
				ChildPT,ChildPTc,ChildPW,ChildPWc,ChildPB,ChildPBc,ChildPH,ChildPHc,
				MalePT,MalePTc,MalePW,MalePWc,MalePB,MalePBc,MalePH,MalePHc,
				ElderT,ElderTc,ElderW,ElderWc,ElderB,ElderBc,ElderH,ElderHc,
				MoveT,MoveTc,MoveW,MoveWc,MoveB,MoveBc,MoveH,MoveHc,
				CPopBP,CPopBPc,CPopHP,CPopHPc,HValueT10k,HValueT10kc,VacantT,VacantTc,Longitude,Latitude)]





# "spaMM" does not allow an weighting variable has a zero value.
zt<-z[z$CPopT >0,] # N=11064 -> 10876 (no child= 188,  1.7% of 11064)
z1<-z[z$CPop1 >0,] # N=11064 -> 10640 (no child= 424,  3.8% of 11064)
z2<-z[z$CPop2 >0,] # N=11064 -> 10650 (no child= 414,  3.7% of 11064)
z3<-z[z$CPop3 >0,] # N=11064 -> 10695 (no child= 369,  3.3% of 11064)
zw<-z[z$CPopW >0,] # N=11064 -> 10807 (no child= 257,  2.3% of 11064)
zb<-z[z$CPopB >0,] # N=11064 ->  4997 (no child=6067, 54.8% of 11064)
zh<-z[z$CPopH >0,] # N=11064 ->  7445 (no child=3619, 32.7% of 11064)

sum(zt$CPopT )/sum(z$CPopT ) # 100% of Illinois children
sum(z1$CPop1 )/sum(z$CPop1 ) # 100% of Illinois age 0-5 children
sum(z2$CPop2 )/sum(z$CPop2 ) # 100% of Illinois age 6-11 children
sum(z3$CPop3 )/sum(z$CPop3 ) # 100% of Illinois age 12-17 children
sum(zw$CPopW )/sum(z$CPopW ) # 100% of Illinois White children
sum(zb$CPopB )/sum(z$CPopB ) # 100% of Illinois Black children
sum(zh$CPopH )/sum(z$CPopH ) # 100% of Illinois Latino children

# Analysis data covers 100% of Illinois zip codes with at least one child (or 98.3% of all Illinois zip codes), 
# in which 100% of Illinois children reside.

# Subgroup-specific analysis data covered all Illinois zip codes with at least one subgroup-specific child.


# Descriptive Statistics

Descriptive<-data.table(
	Name  =c("RptTr","ChildCare1","ChildCare2","CPovT","SingleT","VacantT","CPopBP","CPopHP","FBornT","ChildPT","MalePT","ElderT","DisablTC","MoveT","Large Urban","Small Urban","Rural","2011","2012","2013","2014","2015","2016","2017","2018"),
	TotalM=c(weighted.mean(zt$RptTr,zt$CPopT ),weighted.mean(zt$ChildCare1,zt$CPopT ),weighted.mean(zt$CPovT,zt$CPopT ),weighted.mean(zt$SingleT,zt$CPopT ),weighted.mean(zt$VacantT,zt$CPopT ),weighted.mean(zt$CPopBP,zt$CPopT ),weighted.mean(zt$CPopHP,zt$CPopT ),weighted.mean(zt$FBornT,zt$CPopT ),weighted.mean(zt$ChildPT,zt$CPopT ),weighted.mean(zt$MalePT,zt$CPopT ),weighted.mean(zt$ElderT,zt$CPopT ),weighted.mean(zt$DisablTC,zt$CPopT ),weighted.mean(zt$MoveT,zt$CPopT ),prop.table(table(zt$USDA_RUC)),prop.table(table(zt$Yearf))),
	Age1M =c(weighted.mean(z1$Rpt1r,z1$CPop1 ),weighted.mean(z1$ChildCare1,z1$CPop1 ),weighted.mean(z1$CPov1,z1$CPop1 ),weighted.mean(z1$SingleT,z1$CPop1 ),weighted.mean(z1$VacantT,z1$CPop1 ),weighted.mean(z1$CPopBP,z1$CPop1 ),weighted.mean(z1$CPopHP,z1$CPop1 ),weighted.mean(z1$FBornT,z1$CPop1 ),weighted.mean(z1$ChildPT,z1$CPop1 ),weighted.mean(z1$MalePT,z1$CPop1 ),weighted.mean(z1$ElderT,z1$CPop1 ),weighted.mean(z1$DisablTC,z1$CPop1 ),weighted.mean(z1$MoveT,z1$CPop1 ),prop.table(table(z1$USDA_RUC)),prop.table(table(z1$Yearf))),
	Age2M =c(weighted.mean(z2$Rpt2r,z2$CPop2 ),weighted.mean(z2$ChildCare1,z2$CPop2 ),weighted.mean(z2$CPov2,z2$CPop2 ),weighted.mean(z2$SingleT,z2$CPop2 ),weighted.mean(z2$VacantT,z2$CPop2 ),weighted.mean(z2$CPopBP,z2$CPop2 ),weighted.mean(z2$CPopHP,z2$CPop2 ),weighted.mean(z2$FBornT,z2$CPop2 ),weighted.mean(z2$ChildPT,z2$CPop2 ),weighted.mean(z2$MalePT,z2$CPop2 ),weighted.mean(z2$ElderT,z2$CPop2 ),weighted.mean(z2$DisablTC,z2$CPop2 ),weighted.mean(z2$MoveT,z2$CPop2 ),prop.table(table(z2$USDA_RUC)),prop.table(table(z2$Yearf))),
	Age3M =c(weighted.mean(z3$Rpt3r,z3$CPop3 ),weighted.mean(z3$ChildCare1,z3$CPop3 ),weighted.mean(z3$CPov3,z3$CPop3 ),weighted.mean(z3$SingleT,z3$CPop3 ),weighted.mean(z3$VacantT,z3$CPop3 ),weighted.mean(z3$CPopBP,z3$CPop3 ),weighted.mean(z3$CPopHP,z3$CPop3 ),weighted.mean(z3$FBornT,z3$CPop3 ),weighted.mean(z3$ChildPT,z3$CPop3 ),weighted.mean(z3$MalePT,z3$CPop3 ),weighted.mean(z3$ElderT,z3$CPop3 ),weighted.mean(z3$DisablTC,z3$CPop3 ),weighted.mean(z3$MoveT,z3$CPop3 ),prop.table(table(z3$USDA_RUC)),prop.table(table(z3$Yearf))),
	WhiteM=c(weighted.mean(zw$RptWr,zw$CPopW ),weighted.mean(zw$ChildCare1,zw$CPopW ),weighted.mean(zw$CPovW,zw$CPopW ),weighted.mean(zw$SingleW,zw$CPopW ),weighted.mean(zw$VacantT,zw$CPopW ),weighted.mean(zw$CPopBP,zw$CPopW ),weighted.mean(zw$CPopHP,zw$CPopW ),weighted.mean(zw$FBornW,zw$CPopW ),weighted.mean(zw$ChildPW,zw$CPopW ),weighted.mean(zw$MalePW,zw$CPopW ),weighted.mean(zw$ElderW,zw$CPopW ),weighted.mean(zw$DisablWC,zw$CPopW ),weighted.mean(zw$MoveW,zw$CPopW ),prop.table(table(zw$USDA_RUC)),prop.table(table(zw$Yearf))),
	BlackM=c(weighted.mean(zb$RptBr,zb$CPopB ),weighted.mean(zb$ChildCare1,zb$CPopB ),weighted.mean(zb$CPovB,zb$CPopB ),weighted.mean(zb$SingleB,zb$CPopB ),weighted.mean(zb$VacantT,zb$CPopB ),weighted.mean(zb$CPopBP,zb$CPopB ),weighted.mean(zb$CPopHP,zb$CPopB ),weighted.mean(zb$FBornB,zb$CPopB ),weighted.mean(zb$ChildPB,zb$CPopB ),weighted.mean(zb$MalePB,zb$CPopB ),weighted.mean(zb$ElderB,zb$CPopB ),weighted.mean(zb$DisablBC,zb$CPopB ),weighted.mean(zb$MoveB,zb$CPopB ),prop.table(table(zb$USDA_RUC)),prop.table(table(zb$Yearf))),
	LatinM=c(weighted.mean(zh$RptHr,zh$CPopH ),weighted.mean(zh$ChildCare1,zh$CPopH ),weighted.mean(zh$CPovH,zh$CPopH ),weighted.mean(zh$SingleH,zh$CPopH ),weighted.mean(zh$VacantT,zh$CPopH ),weighted.mean(zh$CPopBP,zh$CPopH ),weighted.mean(zh$CPopHP,zh$CPopH ),weighted.mean(zh$FBornH,zh$CPopH ),weighted.mean(zh$ChildPH,zh$CPopH ),weighted.mean(zh$MalePH,zh$CPopH ),weighted.mean(zh$ElderH,zh$CPopH ),weighted.mean(zh$DisablHC,zh$CPopH ),weighted.mean(zh$MoveH,zh$CPopH ),prop.table(table(zh$USDA_RUC)),prop.table(table(zh$Yearf))),
	NegM  =c(weighted.mean(zt$NegTr,zt$CPopT ),weighted.mean(zt$ChildCare1,zt$CPopT ),weighted.mean(zt$CPovT,zt$CPopT ),weighted.mean(zt$SingleT,zt$CPopT ),weighted.mean(zt$VacantT,zt$CPopT ),weighted.mean(zt$CPopBP,zt$CPopT ),weighted.mean(zt$CPopHP,zt$CPopT ),weighted.mean(zt$FBornT,zt$CPopT ),weighted.mean(zt$ChildPT,zt$CPopT ),weighted.mean(zt$MalePT,zt$CPopT ),weighted.mean(zt$ElderT,zt$CPopT ),weighted.mean(zt$DisablTC,zt$CPopT ),weighted.mean(zt$MoveT,zt$CPopT ),prop.table(table(zt$USDA_RUC)),prop.table(table(zt$Yearf))),
	PhyM  =c(weighted.mean(zt$PhyTr,zt$CPopT ),weighted.mean(zt$ChildCare1,zt$CPopT ),weighted.mean(zt$CPovT,zt$CPopT ),weighted.mean(zt$SingleT,zt$CPopT ),weighted.mean(zt$VacantT,zt$CPopT ),weighted.mean(zt$CPopBP,zt$CPopT ),weighted.mean(zt$CPopHP,zt$CPopT ),weighted.mean(zt$FBornT,zt$CPopT ),weighted.mean(zt$ChildPT,zt$CPopT ),weighted.mean(zt$MalePT,zt$CPopT ),weighted.mean(zt$ElderT,zt$CPopT ),weighted.mean(zt$DisablTC,zt$CPopT ),weighted.mean(zt$MoveT,zt$CPopT ),prop.table(table(zt$USDA_RUC)),prop.table(table(zt$Yearf))),
	SexM  =c(weighted.mean(zt$SexTr,zt$CPopT ),weighted.mean(zt$ChildCare1,zt$CPopT ),weighted.mean(zt$CPovT,zt$CPopT ),weighted.mean(zt$SingleT,zt$CPopT ),weighted.mean(zt$VacantT,zt$CPopT ),weighted.mean(zt$CPopBP,zt$CPopT ),weighted.mean(zt$CPopHP,zt$CPopT ),weighted.mean(zt$FBornT,zt$CPopT ),weighted.mean(zt$ChildPT,zt$CPopT ),weighted.mean(zt$MalePT,zt$CPopT ),weighted.mean(zt$ElderT,zt$CPopT ),weighted.mean(zt$DisablTC,zt$CPopT ),weighted.mean(zt$MoveT,zt$CPopT ),prop.table(table(zt$USDA_RUC)),prop.table(table(zt$Yearf))),
	TotalS=c(weighted.sd(zt$RptTr,zt$CPopT ),weighted.sd(zt$ChildCare1,zt$CPopT ),weighted.sd(zt$CPovT,zt$CPopT ),weighted.sd(zt$SingleT,zt$CPopT ),weighted.sd(zt$VacantT,zt$CPopT ),weighted.sd(zt$CPopBP,zt$CPopT ),weighted.sd(zt$CPopHP,zt$CPopT ),weighted.sd(zt$FBornT,zt$CPopT ),weighted.sd(zt$ChildPT,zt$CPopT ),weighted.sd(zt$MalePT,zt$CPopT ),weighted.sd(zt$ElderT,zt$CPopT ),weighted.sd(zt$DisablTC,zt$CPopT ),weighted.sd(zt$MoveT,zt$CPopT ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Age1S =c(weighted.sd(z1$Rpt1r,z1$CPop1 ),weighted.sd(z1$ChildCare1,z1$CPop1 ),weighted.sd(z1$CPov1,z1$CPop1 ),weighted.sd(z1$SingleT,z1$CPop1 ),weighted.sd(z1$VacantT,z1$CPop1 ),weighted.sd(z1$CPopBP,z1$CPop1 ),weighted.sd(z1$CPopHP,z1$CPop1 ),weighted.sd(z1$FBornT,z1$CPop1 ),weighted.sd(z1$ChildPT,z1$CPop1 ),weighted.sd(z1$MalePT,z1$CPop1 ),weighted.sd(z1$ElderT,z1$CPop1 ),weighted.sd(z1$DisablTC,z1$CPop1 ),weighted.sd(z1$MoveT,z1$CPop1 ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Age2S =c(weighted.sd(z2$Rpt2r,z2$CPop2 ),weighted.sd(z2$ChildCare1,z2$CPop2 ),weighted.sd(z2$CPov2,z2$CPop2 ),weighted.sd(z2$SingleT,z2$CPop2 ),weighted.sd(z2$VacantT,z2$CPop2 ),weighted.sd(z2$CPopBP,z2$CPop2 ),weighted.sd(z2$CPopHP,z2$CPop2 ),weighted.sd(z2$FBornT,z2$CPop2 ),weighted.sd(z2$ChildPT,z2$CPop2 ),weighted.sd(z2$MalePT,z2$CPop2 ),weighted.sd(z2$ElderT,z2$CPop2 ),weighted.sd(z2$DisablTC,z2$CPop2 ),weighted.sd(z2$MoveT,z2$CPop2 ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Age3S =c(weighted.sd(z3$Rpt3r,z3$CPop3 ),weighted.sd(z3$ChildCare1,z3$CPop3 ),weighted.sd(z3$CPov3,z3$CPop3 ),weighted.sd(z3$SingleT,z3$CPop3 ),weighted.sd(z3$VacantT,z3$CPop3 ),weighted.sd(z3$CPopBP,z3$CPop3 ),weighted.sd(z3$CPopHP,z3$CPop3 ),weighted.sd(z3$FBornT,z3$CPop3 ),weighted.sd(z3$ChildPT,z3$CPop3 ),weighted.sd(z3$MalePT,z3$CPop3 ),weighted.sd(z3$ElderT,z3$CPop3 ),weighted.sd(z3$DisablTC,z3$CPop3 ),weighted.sd(z3$MoveT,z3$CPop3 ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	WhiteS=c(weighted.sd(zw$RptWr,zw$CPopW ),weighted.sd(zw$ChildCare1,zw$CPopW ),weighted.sd(zw$CPovW,zw$CPopW ),weighted.sd(zw$SingleW,zw$CPopW ),weighted.sd(zw$VacantT,zw$CPopW ),weighted.sd(zw$CPopBP,zw$CPopW ),weighted.sd(zw$CPopHP,zw$CPopW ),weighted.sd(zw$FBornW,zw$CPopW ),weighted.sd(zw$ChildPW,zw$CPopW ),weighted.sd(zw$MalePW,zw$CPopW ),weighted.sd(zw$ElderW,zw$CPopW ),weighted.sd(zw$DisablWC,zw$CPopW ),weighted.sd(zw$MoveW,zw$CPopW ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	BlackS=c(weighted.sd(zb$RptBr,zb$CPopB ),weighted.sd(zb$ChildCare1,zb$CPopB ),weighted.sd(zb$CPovB,zb$CPopB ),weighted.sd(zb$SingleB,zb$CPopB ),weighted.sd(zb$VacantT,zb$CPopB ),weighted.sd(zb$CPopBP,zb$CPopB ),weighted.sd(zb$CPopHP,zb$CPopB ),weighted.sd(zb$FBornB,zb$CPopB ),weighted.sd(zb$ChildPB,zb$CPopB ),weighted.sd(zb$MalePB,zb$CPopB ),weighted.sd(zb$ElderB,zb$CPopB ),weighted.sd(zb$DisablBC,zb$CPopB ),weighted.sd(zb$MoveB,zb$CPopB ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	LatinS=c(weighted.sd(zh$RptHr,zh$CPopH ),weighted.sd(zh$ChildCare1,zh$CPopH ),weighted.sd(zh$CPovH,zh$CPopH ),weighted.sd(zh$SingleH,zh$CPopH ),weighted.sd(zh$VacantT,zh$CPopH ),weighted.sd(zh$CPopBP,zh$CPopH ),weighted.sd(zh$CPopHP,zh$CPopH ),weighted.sd(zh$FBornH,zh$CPopH ),weighted.sd(zh$ChildPH,zh$CPopH ),weighted.sd(zh$MalePH,zh$CPopH ),weighted.sd(zh$ElderH,zh$CPopH ),weighted.sd(zh$DisablHC,zh$CPopH ),weighted.sd(zh$MoveH,zh$CPopH ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	NegS  =c(weighted.sd(zt$NegTr,zt$CPopT ),weighted.sd(zt$ChildCare1,zt$CPopT ),weighted.sd(zt$CPovT,zt$CPopT ),weighted.sd(zt$SingleT,zt$CPopT ),weighted.sd(zt$VacantT,zt$CPopT ),weighted.sd(zt$CPopBP,zt$CPopT ),weighted.sd(zt$CPopHP,zt$CPopT ),weighted.sd(zt$FBornT,zt$CPopT ),weighted.sd(zt$ChildPT,zt$CPopT ),weighted.sd(zt$MalePT,zt$CPopT ),weighted.sd(zt$ElderT,zt$CPopT ),weighted.sd(zt$DisablTC,zt$CPopT ),weighted.sd(zt$MoveT,zt$CPopT ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	PhyS  =c(weighted.sd(zt$PhyTr,zt$CPopT ),weighted.sd(zt$ChildCare1,zt$CPopT ),weighted.sd(zt$CPovT,zt$CPopT ),weighted.sd(zt$SingleT,zt$CPopT ),weighted.sd(zt$VacantT,zt$CPopT ),weighted.sd(zt$CPopBP,zt$CPopT ),weighted.sd(zt$CPopHP,zt$CPopT ),weighted.sd(zt$FBornT,zt$CPopT ),weighted.sd(zt$ChildPT,zt$CPopT ),weighted.sd(zt$MalePT,zt$CPopT ),weighted.sd(zt$ElderT,zt$CPopT ),weighted.sd(zt$DisablTC,zt$CPopT ),weighted.sd(zt$MoveT,zt$CPopT ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	SexS  =c(weighted.sd(zt$SexTr,zt$CPopT ),weighted.sd(zt$ChildCare1,zt$CPopT ),weighted.sd(zt$CPovT,zt$CPopT ),weighted.sd(zt$SingleT,zt$CPopT ),weighted.sd(zt$VacantT,zt$CPopT ),weighted.sd(zt$CPopBP,zt$CPopT ),weighted.sd(zt$CPopHP,zt$CPopT ),weighted.sd(zt$FBornT,zt$CPopT ),weighted.sd(zt$ChildPT,zt$CPopT ),weighted.sd(zt$MalePT,zt$CPopT ),weighted.sd(zt$ElderT,zt$CPopT ),weighted.sd(zt$DisablTC,zt$CPopT ),weighted.sd(zt$MoveT,zt$CPopT ),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA)
)
Descriptive

write.csv(Descriptive,"Z:/CDCK01/Report/Service/Zip Code/table1_Descriptive.csv")


###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
# Create Queen Contiguity Matrix
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

Shape <- shapefile("Z:/CDCK01/Data_Zip/Census2/ZipCodeShapeFile/gz_2010_us_860_00_500k.shp")

# Create Total and Subgroup Shape Files
Shape$ZipCode<-as.numeric(Shape$ZCTA5)
ShapeT<-Shape[Shape$ZipCode %in% zt$ZipCode,]
Shape1<-Shape[Shape$ZipCode %in% z1$ZipCode,]
Shape2<-Shape[Shape$ZipCode %in% z2$ZipCode,]
Shape3<-Shape[Shape$ZipCode %in% z3$ZipCode,]
ShapeM<-Shape[Shape$ZipCode %in% zm$ZipCode,]
ShapeF<-Shape[Shape$ZipCode %in% zf$ZipCode,]
ShapeW<-Shape[Shape$ZipCode %in% zw$ZipCode,]
ShapeB<-Shape[Shape$ZipCode %in% zb$ZipCode,]
ShapeH<-Shape[Shape$ZipCode %in% zh$ZipCode,]

# "poly2nb": construct neighbours list from polygon list (default = first order Queen contiguity)
QueenT<-poly2nb(ShapeT)
Queen1<-poly2nb(Shape1)
Queen2<-poly2nb(Shape2)
Queen3<-poly2nb(Shape3)
QueenM<-poly2nb(ShapeM)
QueenF<-poly2nb(ShapeF)
QueenW<-poly2nb(ShapeW)
QueenB<-poly2nb(ShapeB)
QueenH<-poly2nb(ShapeH)



# "nb2mat": Spatial weights matrices for neighbours lists
MatrixT<-nb2mat(QueenT,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix1<-nb2mat(Queen1,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix2<-nb2mat(Queen2,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
Matrix3<-nb2mat(Queen3,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixM<-nb2mat(QueenM,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixF<-nb2mat(QueenF,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixW<-nb2mat(QueenW,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixB<-nb2mat(QueenB,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights
MatrixH<-nb2mat(QueenH,style="B",zero.policy=TRUE) # style='B' to use binary (TRUE/FALSE) distance weights

# Set row and column Names
rownames(MatrixT)<-colnames(MatrixT)<-ShapeT$ZipCode
rownames(Matrix1)<-colnames(Matrix1)<-Shape1$ZipCode
rownames(Matrix2)<-colnames(Matrix2)<-Shape2$ZipCode
rownames(Matrix3)<-colnames(Matrix3)<-Shape3$ZipCode
rownames(MatrixM)<-colnames(MatrixM)<-ShapeM$ZipCode
rownames(MatrixF)<-colnames(MatrixF)<-ShapeF$ZipCode
rownames(MatrixW)<-colnames(MatrixW)<-ShapeW$ZipCode
rownames(MatrixB)<-colnames(MatrixB)<-ShapeB$ZipCode
rownames(MatrixH)<-colnames(MatrixH)<-ShapeH$ZipCode





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################



# ChildCare1:	Child care capacity (licensed/license-exempt child care center, licensed family) per 100 children age 0 to 5 years

# Total
mt0<-fitme(RptTr~Yearf                       +adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mt1<-fitme(RptTr~Yearf+ChildCare1c           +adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mt2<-fitme(RptTr~Yearf+ChildCare1c+CPovTc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mt3<-fitme(RptTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mt4<-fitme(RptTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mt5<-fitme(RptTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+ARp(1|Year)+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

extractAIC(mt0)
extractAIC(mt1)
extractAIC(mt2)
extractAIC(mt3)
extractAIC(mt4)
extractAIC(mt5)

summary(mt0)
summary(mt1)
summary(mt2)
summary(mt3)
summary(mt4)
summary(mt5)



# By Age, Sex, Type, Race
m14<-fitme(Rpt1r~Yearf+ChildCare1c+CPov1c+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family="gaussian",weights.form=~CPop1)
m24<-fitme(Rpt2r~Yearf+ChildCare1c+CPov2c+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family="gaussian",weights.form=~CPop2)
m34<-fitme(Rpt3r~Yearf+ChildCare1c+CPov3c+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family="gaussian",weights.form=~CPop3)
mw4<-fitme(RptWr~Yearf+ChildCare1c+CPovWc+SingleWc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+DisablWCc+MoveWc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family="gaussian",weights.form=~CPopW)
mb4<-fitme(RptBr~Yearf+ChildCare1c+CPovBc+SingleBc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+DisablBCc+MoveBc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family="gaussian",weights.form=~CPopB)
mh4<-fitme(RptHr~Yearf+ChildCare1c+CPovHc+SingleHc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+DisablHCc+MoveHc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family="gaussian",weights.form=~CPopH)
mn4<-fitme(NegTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
mp4<-fitme(PhyTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)
ms4<-fitme(SexTr~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family="gaussian",weights.form=~CPopT)

summary(m14)
summary(m24)
summary(m34)
summary(mw4)
summary(mb4)
summary(mh4)
summary(mn4)
summary(mp4)
summary(ms4)








# Negative Binomial ############################################################
# Negative Binomial ############################################################
# Negative Binomial ############################################################
# Negative Binomial ############################################################
# Negative Binomial ############################################################

# Skewness
plot(density(zt$RptTr))
plot(density(z1$Rpt1r))
plot(density(z2$Rpt2r))
plot(density(z3$Rpt3r))
plot(density(zw$RptWr))
plot(density(zb$RptBr))
plot(density(zh$RptHr))
plot(density(zt$NegTr))
plot(density(zt$PhyTr))
plot(density(zt$SexTr))
w.skewness(zt$RptTr,zt$CPopT )
w.skewness(z1$Rpt1r,z1$CPop1 )
w.skewness(z2$Rpt2r,z2$CPop2 )
w.skewness(z3$Rpt3r,z3$CPop3 )
w.skewness(zw$RptWr,zw$CPopW )
w.skewness(zb$RptBr,zb$CPopB )
w.skewness(zh$RptHr,zh$CPopH )
w.skewness(zt$NegTr,zt$CPopT )
w.skewness(zt$PhyTr,zt$CPopT )
w.skewness(zt$SexTr,zt$CPopT )



# as.integer -- for negative binomial DV and offset
zt$CPopT <-as.integer(zt$CPopT )
z1$CPop1 <-as.integer(z1$CPop1 )
z2$CPop2 <-as.integer(z2$CPop2 )
z3$CPop3 <-as.integer(z3$CPop3 )
zw$CPopW <-as.integer(zw$CPopW )
zb$CPopB <-as.integer(zb$CPopB )
zh$CPopH <-as.integer(zh$CPopH )
zt$Rpt   <-as.integer(zt$Rpt   )
z1$Age1  <-as.integer(z1$Age1  )
z2$Age2  <-as.integer(z2$Age2  )
z3$Age3  <-as.integer(z3$Age3  )
zw$RacW  <-as.integer(zw$RacW  )
zb$RacB  <-as.integer(zb$RacB  )
zh$RacH  <-as.integer(zh$RacH  )
zt$RptNG <-as.integer(zt$RptNG )
zt$RptPA <-as.integer(zt$RptPA )
zt$RptSA <-as.integer(zt$RptSA )



# Negative Binomial Models
mt4nb<-fitme(Rpt  ~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPopT ))+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin(),weights.form=~CPopT )
m14nb<-fitme(Age1 ~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPop1 ))+adjacency(1|ZipCode),adjMatrix=Matrix1,data=z1,family=negbin(),weights.form=~CPop1 )
m24nb<-fitme(Age2 ~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPop2 ))+adjacency(1|ZipCode),adjMatrix=Matrix2,data=z2,family=negbin(),weights.form=~CPop2 )
m34nb<-fitme(Age3 ~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPop3 ))+adjacency(1|ZipCode),adjMatrix=Matrix3,data=z3,family=negbin(),weights.form=~CPop3 )
mw4nb<-fitme(RacW ~Yearf+ChildCare1c+CPovWc+SingleWc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+MalePWc+ElderWc+DisablWCc+MoveWc+USDA_RUC+offset(log(CPopW ))+adjacency(1|ZipCode),adjMatrix=MatrixW,data=zw,family=negbin(),weights.form=~CPopW )
mb4nb<-fitme(RacB ~Yearf+ChildCare1c+CPovBc+SingleBc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+MalePBc+ElderBc+DisablBCc+MoveBc+USDA_RUC+offset(log(CPopB ))+adjacency(1|ZipCode),adjMatrix=MatrixB,data=zb,family=negbin(),weights.form=~CPopB )
mh4nb<-fitme(RacH ~Yearf+ChildCare1c+CPovHc+SingleHc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+MalePHc+ElderHc+DisablHCc+MoveHc+USDA_RUC+offset(log(CPopH ))+adjacency(1|ZipCode),adjMatrix=MatrixH,data=zh,family=negbin(),weights.form=~CPopH )
mn4nb<-fitme(RptNG~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPopT ))+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin(),weights.form=~CPopT )
mp4nb<-fitme(RptPA~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPopT ))+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin(),weights.form=~CPopT )
ms4nb<-fitme(RptSA~Yearf+ChildCare1c+CPovTc+SingleTc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+MalePTc+ElderTc+DisablTCc+MoveTc+USDA_RUC+offset(log(CPopT ))+adjacency(1|ZipCode),adjMatrix=MatrixT,data=zt,family=negbin(),weights.form=~CPopT )

summary(mt4nb)
summary(m14nb)
summary(m24nb)
summary(m34nb)
summary(mw4nb)
summary(mb4nb)
summary(mh4nb)
summary(mn4nb)
summary(mp4nb)
summary(ms4nb)

save.image("Z:/CDCK01/Analysis/ZipCode/Service/Service_Model_New1.RData")



