


# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(lattice)
library(e1071)
memory.limit(100000000000) # Increase memory limit

# Loading Data
c<-read_sas("Z:/CDCK01/Data_County/cdck01county.sas7bdat") # N= 6153, 1011 variables
c<-data.table(c)
c<-c[Year>2015,]
sum(c$CPopT) # 220442066
sum(c$CPopT[c$CountyFIPS%%1000!=999]) # 166693756
sum(c$CPopT[c$CountyFIPS%%1000==999]) # 53748310
sum(c$CPopW) # 113013140
sum(c$CPopB) #  31114136
sum(c$CPopH) #  54438619
unique(c$StateFIPS) # 51
c<-c[c$CountyFIPS%%1000!=999,] # 592 counties, 1776 county-years
unique(c$StateFIPS) # 49 (50 Vermont and 56 Wyoming have no identified counties)
table(c$USDA_RUC)

table(c$USDA_RUC,c$Year)
# There are 592 identified counties in each of 2016, 2017, and 2018 (592*3=1776 county-years)
  # 208 large urban counties, 309 small urban counties, and 75 rural counties
# There are 3142 counties in each of 2016, 2017, and 2018 (3142*3=9426 county-years)
  # 432 large urban counties, 734 small urban counties, and 1976 rural counties

# County Coverage
592/3142 # 18.8% of US counties
208/432  # 48.1% of US large urban counties
309/734  # 42.1% of US small urban counties
75/1976  #  3.8% of US rural counties

# Child Population Coverage
sum(c$CPopT)/220442066 # 75.6%



# as.integer -- for negative binomial DV and offset
c$CPopT <-as.integer(c$CPopT )
c$CPopW <-as.integer(c$CPopW )
c$CPopB <-as.integer(c$CPopB )
c$CPopH <-as.integer(c$CPopH )
c$CPopTM<-as.integer(c$CPopTM)
c$CPopTF<-as.integer(c$CPopTF)
c$CPop1 <-as.integer(c$CPop1 )
c$CPop2 <-as.integer(c$CPop2 )
c$CPop3 <-as.integer(c$CPop3 )
c$RptT  <-as.integer(c$RptT  )
c$RptW  <-as.integer(c$RptW  )
c$RptB  <-as.integer(c$RptB  )
c$RptH  <-as.integer(c$RptH  )
c$RptM  <-as.integer(c$RptM  )
c$RptF  <-as.integer(c$RptF  )
c$Rpt1  <-as.integer(c$Rpt1  )
c$Rpt2  <-as.integer(c$Rpt2  )
c$Rpt3  <-as.integer(c$Rpt3  )
c$NegT  <-as.integer(c$NegT  )
c$PhyT  <-as.integer(c$PhyT  )
c$SexT  <-as.integer(c$SexT  )
c$EmoT  <-as.integer(c$EmoT  )



# making categorical variables as.factor & scaling (roughly 0-100) continuous variables
c$HomeV                             <-0 # No evidence-based home visiting provision
c$HomeV[c$MIECHV<0.5 & c$NHVRC>=0.5]<-1 # Evidence-based home visiting provision without MIECHV support
c$HomeV[c$MIECHV>=0.5              ]<-2 # Evidence-based home visiting provision with MIECHV support
c$HomeV2[c$MIECHV>=c$NHVRC]<-c$MIECHV[c$MIECHV>=c$NHVRC]
c$HomeV2[c$MIECHV<c$NHVRC]<-c$NHVRC[c$MIECHV<c$NHVRC]
c$HomeV      <-as.factor(c$HomeV)
c$Yearf      <-as.factor(c$Year)
c$NCHS_RUC   <-as.factor(c$NCHS_RUC)
c$USDA_RUC   <-as.factor(c$USDA_RUC)
c$IncomeT1k  <-c$IncomeT /1000
c$IncomeW1k  <-c$IncomeW /1000
c$IncomeB1k  <-c$IncomeB /1000
c$IncomeH1k  <-c$IncomeH /1000
c$HValueT10k <-c$HValueT /10000
c$MCostT100  <-c$MCostT  /100
c$OCostDT100 <-c$OCostDT /100
c$MRentDT100 <-c$MRentDT /100
c$CARatioT100<-c$CARatioT*100
c$CARatioW100<-c$CARatioW*100
c$CARatioB100<-c$CARatioB*100
c$CARatioH100<-c$CARatioH*100
c$MFRatioT100<-c$MFRatioT*100
c$MFRatioW100<-c$MFRatioW*100
c$MFRatioB100<-c$MFRatioB*100
c$MFRatioH100<-c$MFRatioH*100
c$OwnerT     <-c$OwnNT/c$OHUnitT*100
c$OwnerW     <-c$OwnNW/c$OHUnitW*100
c$OwnerB     <-c$OwnNB/c$OHUnitB*100
c$OwnerH     <-c$OwnNH/c$OHUnitH*100
c$GiniT100   <-c$GiniT*100

# Creating Outcome-Specific Data
ct<-c # total
cw<-c # White
cb<-c # Black
ch<-c # Hispanic
cm<-c # Male
cf<-c # Female
c1<-c # Age 0-5
c2<-c # Age 6-11
c3<-c # Age 12-17
cn<-c # Neglect
cp<-c # Physical abuse
cs<-c # Sexual abuse
ce<-c # Emotional abuse

# Excluding Counties with Low Child Population, Missing Outcome, or Outlier
ct<-ct[CPopT >=300,] # N=1776 -> 1776
cw<-cw[CPopW >=300,] # N=1776 -> 1776
cb<-cb[CPopB >=300,] # N=1776 -> 1626
ch<-ch[CPopH >=300,] # N=1776 -> 1762
cm<-cm[CPopTM>=300,] # N=1776 -> 1776
cf<-cf[CPopTF>=300,] # N=1776 -> 1776
c1<-c1[CPop1 >=300,] # N=1776 -> 1776
c2<-c2[CPop2 >=300,] # N=1776 -> 1776
c3<-c3[CPop3 >=300,] # N=1776 -> 1776
cn<-cn[CPopT >=300,] # N=1776 -> 1776
cp<-cp[CPopT >=300,] # N=1776 -> 1776
cs<-cs[CPopT >=300,] # N=1776 -> 1776
ce<-ce[CPopT >=300,] # N=1776 -> 1776

# Excluding Counties with Missing Median Income
cb<-cb[!is.na(cb$IncomeB),] # N=1626 -> 1611
ch<-ch[!is.na(ch$IncomeH),] # N=1762 -> 1742

ct<-ct[ct$RptTr<min(boxplot.stats(ct$RptTr,coef=4.5)$out),] # N=1776 -> 1776
cw<-cw[cw$RptWr<min(boxplot.stats(cw$RptWr,coef=4.5)$out),] # N=1776 -> 1776
cb<-cb[cb$RptBr<min(boxplot.stats(cb$RptBr,coef=4.5)$out),] # N=1611 -> 1608
ch<-ch[ch$RptHr<min(boxplot.stats(ch$RptHr,coef=4.5)$out),] # N=1742 -> 1734
cm<-cm[cm$RptMr<min(boxplot.stats(cm$RptMr,coef=4.5)$out),] # N=1776 -> 1776
cf<-cf[cf$RptFr<min(boxplot.stats(cf$RptFr,coef=4.5)$out),] # N=1776 -> 1776
c1<-c1[c1$Rpt1r<min(boxplot.stats(c1$Rpt1r,coef=4.5)$out),] # N=1776 -> 1776
c2<-c2[c2$Rpt2r<min(boxplot.stats(c2$Rpt2r,coef=4.5)$out),] # N=1776 -> 1776
c3<-c3[c3$Rpt3r<min(boxplot.stats(c3$Rpt3r,coef=4.5)$out),] # N=1776 -> 1776
cn<-cn[cn$NegTr<min(boxplot.stats(cn$NegTr,coef=4.5)$out),] # N=1776 -> 1776
cp<-cp[cp$PhyTr<min(boxplot.stats(cp$PhyTr,coef=4.5)$out),] # N=1776 -> 1757
cs<-cs[cs$SexTr<min(boxplot.stats(cs$SexTr,coef=4.5)$out),] # N=1776 -> 1773
ce<-ce[ce$EmoTr<min(boxplot.stats(ce$EmoTr,coef=4.5)$out),] # N=1776 -> 1742

# Race/Ethnicity-Specific Children Coverage
sum(c$CPopW)/113013140 # 66.7%
sum(c$CPopB)/31114136  # 82.9%
sum(c$CPopH)/54438619  # 87.6%

sum(ct$CPopT[ct$USDA_RUC==1]*ct$MIECHV[ct$USDA_RUC==1])/sum(ct$CPopT[ct$USDA_RUC==1])
sum(ct$CPopT[ct$USDA_RUC==2]*ct$MIECHV[ct$USDA_RUC==2])/sum(ct$CPopT[ct$USDA_RUC==2])
sum(ct$CPopT[ct$USDA_RUC==3]*ct$MIECHV[ct$USDA_RUC==3])/sum(ct$CPopT[ct$USDA_RUC==3])

sum(ct$CPopT[ct$USDA_RUC==1]*ct$NHVRC[ct$USDA_RUC==1])/sum(ct$CPopT[ct$USDA_RUC==1])
sum(ct$CPopT[ct$USDA_RUC==2]*ct$NHVRC[ct$USDA_RUC==2])/sum(ct$CPopT[ct$USDA_RUC==2])
sum(ct$CPopT[ct$USDA_RUC==3]*ct$NHVRC[ct$USDA_RUC==3])/sum(ct$CPopT[ct$USDA_RUC==3])

mean(ct$MIECHV)
mean(ct$MIECHV[ct$USDA_RUC==1])
mean(ct$MIECHV[ct$USDA_RUC==2])
mean(ct$MIECHV[ct$USDA_RUC==3])

mean(ct$NHVRC)
mean(ct$NHVRC[ct$USDA_RUC==1])
mean(ct$NHVRC[ct$USDA_RUC==2])
mean(ct$NHVRC[ct$USDA_RUC==3])

table(ct$MIECHV)
table(ct$NHVRC)

skewness(ct$RptTr)
skewness(c1$Rpt1r)
skewness(c2$Rpt2r)
skewness(c3$Rpt3r)
skewness(cm$RptMr)
skewness(cf$RptFr)
skewness(cw$RptWr)
skewness(cb$RptBr) # 1.439
skewness(ch$RptHr) # 1.277
skewness(cn$NegTr)
skewness(cp$PhyTr) # 1.412
skewness(cs$SexTr) # 1.211


###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Checking Sample Size
# length(ct1$CountyFIPS)
# length(ct4$CountyFIPS)
# length(unique(ct1$CountyFIPS))
# length(unique(ct4$CountyFIPS))
# sum(ct1$CPopT)
# sum(ct4$CPopT)

# Check DV Distribution
# boxplot(ct4$RptTr)
# skewness(ct4$RptTr)
# plot(density(ct4$RptTr))

# Check IV Distribution
# boxplot(ct4$CPovT)
# boxplot(ct4$IncomeT)
# boxplot(ct4$FoodInsecure)
# plot(density(ct4$CPovT))
# plot(density(ct4$IncomeT))
# plot(density(ct4$FoodInsecure))

ct[,list(mean=mean(NHVRC))]
ct[,list(mean=mean(NHVRC)),by=USDA_RUC]
ct[,list(mean=mean(NHVRC)),by=Year]
ct[,list(mean=mean(NHVRC)),by=.(Year,USDA_RUC)]
ct[,list(mean=mean(NHVRC_within)),by=USDA_RUC]
ct[,list(mean=mean(NHVRC_within)),by=Year]
ct[,list(mean=mean(NHVRC_within)),by=.(Year,USDA_RUC)]
ct[,list(mean=mean(NHVRC_between)),by=USDA_RUC]
ct[,list(mean=mean(NHVRC_between)),by=Year]
ct[,list(mean=mean(NHVRC_between)),by=.(Year,USDA_RUC)]

mean(ct$NHVRC)
mean(ct$NHVRC[ct$USDA_RUC==1])
mean(ct$NHVRC[ct$USDA_RUC==2])
mean(ct$NHVRC[ct$USDA_RUC==3])
plot(density(ct$NHVRC))
plot(density(ct$NHVRC[ct$USDA_RUC==1]))
plot(density(ct$NHVRC[ct$USDA_RUC==2]))
plot(density(ct$NHVRC[ct$USDA_RUC==3]))

mean(ct$NHVRC_within)
mean(ct$NHVRC_within[ct$USDA_RUC==1])
mean(ct$NHVRC_within[ct$USDA_RUC==2])
mean(ct$NHVRC_within[ct$USDA_RUC==3])
plot(density(ct$NHVRC_within))
plot(density(ct$NHVRC_within[ct$USDA_RUC==1]))
plot(density(ct$NHVRC_within[ct$USDA_RUC==2]))
plot(density(ct$NHVRC_within[ct$USDA_RUC==3]))

length(ct$NHVRC_within)
length(ct$NHVRC_within[ct$NHVRC_within==0])
length(ct$NHVRC_within[ct$NHVRC_within!=0])

mean(ct$NHVRC_between)
mean(ct$NHVRC_between[ct$USDA_RUC==1])
mean(ct$NHVRC_between[ct$USDA_RUC==2])
mean(ct$NHVRC_between[ct$USDA_RUC==3])
plot(density(ct$NHVRC_between))
plot(density(ct$NHVRC_between[ct$USDA_RUC==1]))
plot(density(ct$NHVRC_between[ct$USDA_RUC==2]))
plot(density(ct$NHVRC_between[ct$USDA_RUC==3]))



# Longitudinal Trend
# ct4[,list(mean=mean(RptTr)),by=Year]
# ct4[,list(mean=mean(CPovT)),by=Year]
# ct4[,list(mean=mean(IncomeT1k)),by=Year]
# ct4[,list(mean=mean(FoodInsecure)),by=Year]
# ggline(ct4, x="Year", y="FoodInsecure", add=c("mean_se"))
# ggline(ct4, x="Year", y="RptTr", add=c("mean_se"))
# ggline(ct4, x="Year", y="IncomeT1k", add=c("mean_se"))
# ggline(ct4, x="Year", y="CPovT", add=c("mean_se"))
# ggplot(ct4,aes(x=Year,y=FoodInsecure,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=RptTr       ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=IncomeT1k    ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=CPovT       ,group=CountyFIPS,color=StateFIPS))+geom_line()

# ggline(ct, x="Year", y="NHVRC", add=c("mean_se"))
# xyplot(NHVRC ~ Year | CountyFIPS,
  #     subset = ct$CountyFIPS %in% ct$CountyFIPS[ct$NHVRC_within!=0],
  #     data=ct, type=c("p","r"))

# Centering Variables
ct$CPopBPc      <-ct$CPopBP      -mean(ct$CPopBP      ,na.rm=T)
ct$CPopHPc      <-ct$CPopHP      -mean(ct$CPopHP      ,na.rm=T)
ct$ChildPTc     <-ct$ChildPT     -mean(ct$ChildPT     ,na.rm=T)
ct$ChildPWc     <-ct$ChildPW     -mean(ct$ChildPW     ,na.rm=T)
ct$ChildPBc     <-ct$ChildPB     -mean(ct$ChildPB     ,na.rm=T)
ct$ChildPHc     <-ct$ChildPH     -mean(ct$ChildPH     ,na.rm=T)
ct$CARatioT100c <-ct$CARatioT100 -mean(ct$CARatioT100 ,na.rm=T)
ct$CARatioW100c <-ct$CARatioW100 -mean(ct$CARatioW100 ,na.rm=T)
ct$CARatioB100c <-ct$CARatioB100 -mean(ct$CARatioB100 ,na.rm=T)
ct$CARatioH100c <-ct$CARatioH100 -mean(ct$CARatioH100 ,na.rm=T)
ct$MalePTc      <-ct$MalePT      -mean(ct$MalePT      ,na.rm=T)
ct$MalePWc      <-ct$MalePW      -mean(ct$MalePW      ,na.rm=T)
ct$MalePBc      <-ct$MalePB      -mean(ct$MalePB      ,na.rm=T)
ct$MalePHc      <-ct$MalePH      -mean(ct$MalePH      ,na.rm=T)
ct$MFRatioT100c <-ct$MFRatioT100 -mean(ct$MFRatioT100 ,na.rm=T)
ct$MFRatioW100c <-ct$MFRatioW100 -mean(ct$MFRatioW100 ,na.rm=T)
ct$MFRatioB100c <-ct$MFRatioB100 -mean(ct$MFRatioB100 ,na.rm=T)
ct$MFRatioH100c <-ct$MFRatioH100 -mean(ct$MFRatioH100 ,na.rm=T)
ct$ElderTc      <-ct$ElderT      -mean(ct$ElderT      ,na.rm=T)
ct$ElderWc      <-ct$ElderW      -mean(ct$ElderW      ,na.rm=T)
ct$ElderBc      <-ct$ElderB      -mean(ct$ElderB      ,na.rm=T)
ct$ElderHc      <-ct$ElderH      -mean(ct$ElderH      ,na.rm=T)
ct$SingleTc     <-ct$SingleT     -mean(ct$SingleT     ,na.rm=T)
ct$SingleWc     <-ct$SingleW     -mean(ct$SingleW     ,na.rm=T)
ct$SingleBc     <-ct$SingleB     -mean(ct$SingleB     ,na.rm=T)
ct$SingleHc     <-ct$SingleH     -mean(ct$SingleH     ,na.rm=T)
ct$FHeadTc      <-ct$FHeadT      -mean(ct$FHeadT      ,na.rm=T)
ct$FHeadWc      <-ct$FHeadW      -mean(ct$FHeadW      ,na.rm=T)
ct$FHeadBc      <-ct$FHeadB      -mean(ct$FHeadB      ,na.rm=T)
ct$FHeadHc      <-ct$FHeadH      -mean(ct$FHeadH      ,na.rm=T)
ct$NoHighTc     <-ct$NoHighT     -mean(ct$NoHighT     ,na.rm=T)
ct$NoHighWc     <-ct$NoHighW     -mean(ct$NoHighW     ,na.rm=T)
ct$NoHighBc     <-ct$NoHighB     -mean(ct$NoHighB     ,na.rm=T)
ct$NoHighHc     <-ct$NoHighH     -mean(ct$NoHighH     ,na.rm=T)
ct$UnempTc      <-ct$UnempT      -mean(ct$UnempT      ,na.rm=T)
ct$UnempWc      <-ct$UnempW      -mean(ct$UnempW      ,na.rm=T)
ct$UnempBc      <-ct$UnempB      -mean(ct$UnempB      ,na.rm=T)
ct$UnempHc      <-ct$UnempH      -mean(ct$UnempH      ,na.rm=T)
ct$PovTc        <-ct$PovT        -mean(ct$PovT        ,na.rm=T)
ct$CPovTc       <-ct$CPovT       -mean(ct$CPovT       ,na.rm=T)
ct$CPovWc       <-ct$CPovW       -mean(ct$CPovW       ,na.rm=T)
ct$CPovBc       <-ct$CPovB       -mean(ct$CPovB       ,na.rm=T)
ct$CPovHc       <-ct$CPovH       -mean(ct$CPovH       ,na.rm=T)
ct$CPov1c       <-ct$CPov1       -mean(ct$CPov1       ,na.rm=T)
ct$CPov2c       <-ct$CPov2       -mean(ct$CPov2       ,na.rm=T)
ct$CPov3c       <-ct$CPov3       -mean(ct$CPov3       ,na.rm=T)
ct$PubAsTc      <-ct$PubAsT      -mean(ct$PubAsT      ,na.rm=T)
ct$WelfarTc     <-ct$WelfarT     -mean(ct$WelfarT     ,na.rm=T)
ct$SnapTc       <-ct$SnapT       -mean(ct$SnapT       ,na.rm=T)
ct$SnapWc       <-ct$SnapW       -mean(ct$SnapW       ,na.rm=T)
ct$SnapBc       <-ct$SnapB       -mean(ct$SnapB       ,na.rm=T)
ct$SnapHc       <-ct$SnapH       -mean(ct$SnapH       ,na.rm=T)
ct$IncomeT1kc   <-ct$IncomeT1k   -mean(ct$IncomeT1k   ,na.rm=T)
ct$IncomeW1kc   <-ct$IncomeW1k   -mean(ct$IncomeW1k   ,na.rm=T)
ct$IncomeB1kc   <-ct$IncomeB1k   -mean(ct$IncomeB1k   ,na.rm=T)
ct$IncomeH1kc   <-ct$IncomeH1k   -mean(ct$IncomeH1k   ,na.rm=T)
ct$GiniT100c    <-ct$GiniT100    -mean(ct$GiniT100    ,na.rm=T)
ct$HValueT10kc  <-ct$HValueT10k  -mean(ct$HValueT10k  ,na.rm=T)
ct$MCostT100c   <-ct$MCostT100   -mean(ct$MCostT100   ,na.rm=T)
ct$OCostDT100c  <-ct$OCostDT100  -mean(ct$OCostDT100  ,na.rm=T)
ct$MRentDT100c  <-ct$MRentDT100  -mean(ct$MRentDT100  ,na.rm=T)
ct$OCostPTc     <-ct$OCostPT     -mean(ct$OCostPT     ,na.rm=T)
ct$MRentPTc     <-ct$MRentPT     -mean(ct$MRentPT     ,na.rm=T)
ct$MortgTc      <-ct$MortgT      -mean(ct$MortgT      ,na.rm=T)
ct$LangAPTc     <-ct$LangAPT     -mean(ct$LangAPT     ,na.rm=T)
ct$LangAPWc     <-ct$LangAPW     -mean(ct$LangAPW     ,na.rm=T)
ct$LangAPBc     <-ct$LangAPB     -mean(ct$LangAPB     ,na.rm=T)
ct$LangAPHc     <-ct$LangAPH     -mean(ct$LangAPH     ,na.rm=T)
ct$LangBPTc     <-ct$LangBPT     -mean(ct$LangBPT     ,na.rm=T)
ct$LangBPWc     <-ct$LangBPW     -mean(ct$LangBPW     ,na.rm=T)
ct$LangBPBc     <-ct$LangBPB     -mean(ct$LangBPB     ,na.rm=T)
ct$LangBPHc     <-ct$LangBPH     -mean(ct$LangBPH     ,na.rm=T)
ct$LangCPTc     <-ct$LangCPT     -mean(ct$LangCPT     ,na.rm=T)
ct$OutUsTc      <-ct$OutUsT      -mean(ct$OutUsT      ,na.rm=T)
ct$OutUsWc      <-ct$OutUsW      -mean(ct$OutUsW      ,na.rm=T)
ct$OutUsBc      <-ct$OutUsB      -mean(ct$OutUsB      ,na.rm=T)
ct$OutUsHc      <-ct$OutUsH      -mean(ct$OutUsH      ,na.rm=T)
ct$FBornTc      <-ct$FBornT      -mean(ct$FBornT      ,na.rm=T)
ct$FBornWc      <-ct$FBornW      -mean(ct$FBornW      ,na.rm=T)
ct$FBornBc      <-ct$FBornB      -mean(ct$FBornB      ,na.rm=T)
ct$FBornHc      <-ct$FBornH      -mean(ct$FBornH      ,na.rm=T)
ct$NotCtzTc     <-ct$NotCtzT     -mean(ct$NotCtzT     ,na.rm=T)
ct$NotCtzWc     <-ct$NotCtzW     -mean(ct$NotCtzW     ,na.rm=T)
ct$NotCtzBc     <-ct$NotCtzB     -mean(ct$NotCtzB     ,na.rm=T)
ct$NotCtzHc     <-ct$NotCtzH     -mean(ct$NotCtzH     ,na.rm=T)
ct$MoveTc       <-ct$MoveT       -mean(ct$MoveT       ,na.rm=T)
ct$MoveWc       <-ct$MoveW       -mean(ct$MoveW       ,na.rm=T)
ct$MoveBc       <-ct$MoveB       -mean(ct$MoveB       ,na.rm=T)
ct$MoveHc       <-ct$MoveH       -mean(ct$MoveH       ,na.rm=T)
ct$VacantTc     <-ct$VacantT     -mean(ct$VacantT     ,na.rm=T)
ct$OwnerTc      <-ct$OwnerT      -mean(ct$OwnerT      ,na.rm=T)
ct$OwnerWc      <-ct$OwnerW      -mean(ct$OwnerW      ,na.rm=T)
ct$OwnerBc      <-ct$OwnerB      -mean(ct$OwnerB      ,na.rm=T)
ct$OwnerHc      <-ct$OwnerH      -mean(ct$OwnerH      ,na.rm=T)
ct$CrowdTc      <-ct$CrowdT      -mean(ct$CrowdT      ,na.rm=T)
ct$CrowdWc      <-ct$CrowdW      -mean(ct$CrowdW      ,na.rm=T)
ct$CrowdBc      <-ct$CrowdB      -mean(ct$CrowdB      ,na.rm=T)
ct$CrowdHc      <-ct$CrowdH      -mean(ct$CrowdH      ,na.rm=T)
ct$MobileTc     <-ct$MobileT     -mean(ct$MobileT     ,na.rm=T)
ct$MobileWc     <-ct$MobileW     -mean(ct$MobileW     ,na.rm=T)
ct$MobileBc     <-ct$MobileB     -mean(ct$MobileB     ,na.rm=T)
ct$MobileHc     <-ct$MobileH     -mean(ct$MobileH     ,na.rm=T)
ct$DisablTc     <-ct$DisablT     -mean(ct$DisablT     ,na.rm=T)
ct$DisablWc     <-ct$DisablW     -mean(ct$DisablW     ,na.rm=T)
ct$DisablBc     <-ct$DisablB     -mean(ct$DisablB     ,na.rm=T)
ct$DisablHc     <-ct$DisablH     -mean(ct$DisablH     ,na.rm=T)
ct$DisablTCc    <-ct$DisablTC    -mean(ct$DisablTC    ,na.rm=T)
ct$DisablWCc    <-ct$DisablWC    -mean(ct$DisablWC    ,na.rm=T)
ct$DisablBCc    <-ct$DisablBC    -mean(ct$DisablBC    ,na.rm=T)
ct$DisablHCc    <-ct$DisablHC    -mean(ct$DisablHC    ,na.rm=T)
ct$DisablTMc    <-ct$DisablTM    -mean(ct$DisablTM    ,na.rm=T)
ct$DisablTFc    <-ct$DisablTF    -mean(ct$DisablTF    ,na.rm=T)
ct$Urban1c      <-ct$Urban1      -mean(ct$Urban1      ,na.rm=T)
ct$Urban2c      <-ct$Urban2      -mean(ct$Urban2      ,na.rm=T)
ct$LBWT1rc      <-ct$LBWT1r      -mean(ct$LBWT1r      ,na.rm=T)
ct$LBWM1rc      <-ct$LBWM1r      -mean(ct$LBWM1r      ,na.rm=T)
ct$LBWF1rc      <-ct$LBWF1r      -mean(ct$LBWF1r      ,na.rm=T)
ct$LBWW1rc      <-ct$LBWW1r      -mean(ct$LBWW1r      ,na.rm=T)
ct$LBWB1rc      <-ct$LBWB1r      -mean(ct$LBWB1r      ,na.rm=T)
ct$LBWH1rc      <-ct$LBWH1r      -mean(ct$LBWH1r      ,na.rm=T)
ct$PTBT1rc      <-ct$PTBT1r      -mean(ct$PTBT1r      ,na.rm=T)
ct$PTBM1rc      <-ct$PTBM1r      -mean(ct$PTBM1r      ,na.rm=T)
ct$PTBF1rc      <-ct$PTBF1r      -mean(ct$PTBF1r      ,na.rm=T)
ct$PTBW1rc      <-ct$PTBW1r      -mean(ct$PTBW1r      ,na.rm=T)
ct$PTBB1rc      <-ct$PTBB1r      -mean(ct$PTBB1r      ,na.rm=T)
ct$PTBH1rc      <-ct$PTBH1r      -mean(ct$PTBH1r      ,na.rm=T)
ct$PNCT1rc      <-ct$PNCT1r      -mean(ct$PNCT1r      ,na.rm=T)
ct$PNCM1rc      <-ct$PNCM1r      -mean(ct$PNCM1r      ,na.rm=T)
ct$PNCF1rc      <-ct$PNCF1r      -mean(ct$PNCF1r      ,na.rm=T)
ct$PNCW1rc      <-ct$PNCW1r      -mean(ct$PNCW1r      ,na.rm=T)
ct$PNCB1rc      <-ct$PNCB1r      -mean(ct$PNCB1r      ,na.rm=T)
ct$PNCH1rc      <-ct$PNCH1r      -mean(ct$PNCH1r      ,na.rm=T)
ct$TBBT1rc      <-ct$TBBT1r      -mean(ct$TBBT1r      ,na.rm=T)
ct$TBBM1rc      <-ct$TBBM1r      -mean(ct$TBBM1r      ,na.rm=T)
ct$TBBF1rc      <-ct$TBBF1r      -mean(ct$TBBF1r      ,na.rm=T)
ct$TBBW1rc      <-ct$TBBW1r      -mean(ct$TBBW1r      ,na.rm=T)
ct$TBBB1rc      <-ct$TBBB1r      -mean(ct$TBBB1r      ,na.rm=T)
ct$TBBH1rc      <-ct$TBBH1r      -mean(ct$TBBH1r      ,na.rm=T)
ct$TBTT1rc      <-ct$TBTT1r      -mean(ct$TBTT1r      ,na.rm=T)
ct$TBTM1rc      <-ct$TBTM1r      -mean(ct$TBTM1r      ,na.rm=T)
ct$TBTF1rc      <-ct$TBTF1r      -mean(ct$TBTF1r      ,na.rm=T)
ct$TBTW1rc      <-ct$TBTW1r      -mean(ct$TBTW1r      ,na.rm=T)
ct$TBTB1rc      <-ct$TBTB1r      -mean(ct$TBTB1r      ,na.rm=T)
ct$TBTH1rc      <-ct$TBTH1r      -mean(ct$TBTH1r      ,na.rm=T)
ct$LBWT5rc      <-ct$LBWT5r      -mean(ct$LBWT5r      ,na.rm=T)
ct$LBWM5rc      <-ct$LBWM5r      -mean(ct$LBWM5r      ,na.rm=T)
ct$LBWF5rc      <-ct$LBWF5r      -mean(ct$LBWF5r      ,na.rm=T)
ct$LBWW5rc      <-ct$LBWW5r      -mean(ct$LBWW5r      ,na.rm=T)
ct$LBWB5rc      <-ct$LBWB5r      -mean(ct$LBWB5r      ,na.rm=T)
ct$LBWH5rc      <-ct$LBWH5r      -mean(ct$LBWH5r      ,na.rm=T)
ct$PTBT5rc      <-ct$PTBT5r      -mean(ct$PTBT5r      ,na.rm=T)
ct$PTBM5rc      <-ct$PTBM5r      -mean(ct$PTBM5r      ,na.rm=T)
ct$PTBF5rc      <-ct$PTBF5r      -mean(ct$PTBF5r      ,na.rm=T)
ct$PTBW5rc      <-ct$PTBW5r      -mean(ct$PTBW5r      ,na.rm=T)
ct$PTBB5rc      <-ct$PTBB5r      -mean(ct$PTBB5r      ,na.rm=T)
ct$PTBH5rc      <-ct$PTBH5r      -mean(ct$PTBH5r      ,na.rm=T)
ct$PNCT5rc      <-ct$PNCT5r      -mean(ct$PNCT5r      ,na.rm=T)
ct$PNCM5rc      <-ct$PNCM5r      -mean(ct$PNCM5r      ,na.rm=T)
ct$PNCF5rc      <-ct$PNCF5r      -mean(ct$PNCF5r      ,na.rm=T)
ct$PNCW5rc      <-ct$PNCW5r      -mean(ct$PNCW5r      ,na.rm=T)
ct$PNCB5rc      <-ct$PNCB5r      -mean(ct$PNCB5r      ,na.rm=T)
ct$PNCH5rc      <-ct$PNCH5r      -mean(ct$PNCH5r      ,na.rm=T)
ct$TBBT5rc      <-ct$TBBT5r      -mean(ct$TBBT5r      ,na.rm=T)
ct$TBBM5rc      <-ct$TBBM5r      -mean(ct$TBBM5r      ,na.rm=T)
ct$TBBF5rc      <-ct$TBBF5r      -mean(ct$TBBF5r      ,na.rm=T)
ct$TBBW5rc      <-ct$TBBW5r      -mean(ct$TBBW5r      ,na.rm=T)
ct$TBBB5rc      <-ct$TBBB5r      -mean(ct$TBBB5r      ,na.rm=T)
ct$TBBH5rc      <-ct$TBBH5r      -mean(ct$TBBH5r      ,na.rm=T)
ct$TBTT5rc      <-ct$TBTT5r      -mean(ct$TBTT5r      ,na.rm=T)
ct$TBTM5rc      <-ct$TBTM5r      -mean(ct$TBTM5r      ,na.rm=T)
ct$TBTF5rc      <-ct$TBTF5r      -mean(ct$TBTF5r      ,na.rm=T)
ct$TBTW5rc      <-ct$TBTW5r      -mean(ct$TBTW5r      ,na.rm=T)
ct$TBTB5rc      <-ct$TBTB5r      -mean(ct$TBTB5r      ,na.rm=T)
ct$TBTH5rc      <-ct$TBTH5r      -mean(ct$TBTH5r      ,na.rm=T)
ct$Opioidc      <-ct$Opioid      -mean(ct$Opioid      ,na.rm=T)
ct$LifeExpc     <-ct$LifeExp     -mean(ct$LifeExp     ,na.rm=T)
ct$LifeExpBc    <-ct$LifeExpB    -mean(ct$LifeExpB    ,na.rm=T)
ct$LifeExpHc    <-ct$LifeExpH    -mean(ct$LifeExpH    ,na.rm=T)
ct$LifeExpWc    <-ct$LifeExpW    -mean(ct$LifeExpW    ,na.rm=T)
ct$ChdDeathc    <-ct$ChdDeath    -mean(ct$ChdDeath    ,na.rm=T)
ct$ChdDeathBc   <-ct$ChdDeathB   -mean(ct$ChdDeathB   ,na.rm=T)
ct$ChdDeathHc   <-ct$ChdDeathH   -mean(ct$ChdDeathH   ,na.rm=T)
ct$ChdDeathWc   <-ct$ChdDeathW   -mean(ct$ChdDeathW   ,na.rm=T)
ct$InfDeathc    <-ct$InfDeath    -mean(ct$InfDeath    ,na.rm=T)
ct$InfDeathBc   <-ct$InfDeathB   -mean(ct$InfDeathB   ,na.rm=T)
ct$InfDeathHc   <-ct$InfDeathH   -mean(ct$InfDeathH   ,na.rm=T)
ct$InfDeathWc   <-ct$InfDeathW   -mean(ct$InfDeathW   ,na.rm=T)
ct$Injuryc      <-ct$Injury      -mean(ct$Injury      ,na.rm=T)
ct$InjuryBc     <-ct$InjuryB     -mean(ct$InjuryB     ,na.rm=T)
ct$InjuryHc     <-ct$InjuryH     -mean(ct$InjuryH     ,na.rm=T)
ct$InjuryWc     <-ct$InjuryW     -mean(ct$InjuryW     ,na.rm=T)
ct$GunDeathc    <-ct$GunDeath    -mean(ct$GunDeath    ,na.rm=T)
ct$GunDeathBc   <-ct$GunDeathB   -mean(ct$GunDeathB   ,na.rm=T)
ct$GunDeathWc   <-ct$GunDeathW   -mean(ct$GunDeathW   ,na.rm=T)
ct$PrmDeath_c   <-ct$PrmDeath    -mean(ct$PrmDeath    ,na.rm=T)
ct$PrmDeathcc   <-ct$PrmDeathc   -mean(ct$PrmDeathc   ,na.rm=T)
ct$PrmDeathBc   <-ct$PrmDeathB   -mean(ct$PrmDeathB   ,na.rm=T)
ct$PrmDeathHc   <-ct$PrmDeathH   -mean(ct$PrmDeathH   ,na.rm=T)
ct$PrmDeathWc   <-ct$PrmDeathW   -mean(ct$PrmDeathW   ,na.rm=T)
ct$PrmDeath2_c  <-ct$PrmDeath2   -mean(ct$PrmDeath2   ,na.rm=T)
ct$PrmDeath2cc  <-ct$PrmDeath2c  -mean(ct$PrmDeath2c  ,na.rm=T)
ct$PrmDeath2Bc  <-ct$PrmDeath2B  -mean(ct$PrmDeath2B  ,na.rm=T)
ct$PrmDeath2Hc  <-ct$PrmDeath2H  -mean(ct$PrmDeath2H  ,na.rm=T)
ct$PrmDeath2Wc  <-ct$PrmDeath2W  -mean(ct$PrmDeath2W  ,na.rm=T)
ct$Suicidec     <-ct$Suicide     -mean(ct$Suicide     ,na.rm=T)
ct$Diabetc      <-ct$Diabet      -mean(ct$Diabet      ,na.rm=T)
ct$Obesityc     <-ct$Obesity     -mean(ct$Obesity     ,na.rm=T)
ct$Physicalc    <-ct$Physical    -mean(ct$Physical    ,na.rm=T)
ct$PoorHlthc    <-ct$PoorHlth    -mean(ct$PoorHlth    ,na.rm=T)
ct$PoorMHc      <-ct$PoorMH      -mean(ct$PoorMH      ,na.rm=T)
ct$PoorPhyc     <-ct$PoorPhy     -mean(ct$PoorPhy     ,na.rm=T)
ct$Sleepc       <-ct$Sleep       -mean(ct$Sleep       ,na.rm=T)
ct$DrugOdc      <-ct$DrugOd      -mean(ct$DrugOd      ,na.rm=T)
ct$DrugOdBc     <-ct$DrugOdB     -mean(ct$DrugOdB     ,na.rm=T)
ct$DrugOdHc     <-ct$DrugOdH     -mean(ct$DrugOdH     ,na.rm=T)
ct$DrugOdWc     <-ct$DrugOdW     -mean(ct$DrugOdW     ,na.rm=T)
ct$DWIDeathc    <-ct$DWIDeath    -mean(ct$DWIDeath    ,na.rm=T)
ct$EDrinkc      <-ct$EDrink      -mean(ct$EDrink      ,na.rm=T)
ct$Smokec       <-ct$Smoke       -mean(ct$Smoke       ,na.rm=T)
ct$FastFoodc    <-ct$FastFood    -mean(ct$FastFood    ,na.rm=T)
ct$FoodEnvc     <-ct$FoodEnv     -mean(ct$FoodEnv     ,na.rm=T)
ct$FoodInsc     <-ct$FoodIns     -mean(ct$FoodIns     ,na.rm=T)
ct$FrLunchc     <-ct$FrLunch     -mean(ct$FrLunch     ,na.rm=T)
ct$LAccFoodc    <-ct$LAccFood    -mean(ct$LAccFood    ,na.rm=T)
ct$Gymc         <-ct$Gym         -mean(ct$Gym         ,na.rm=T)
ct$Gym2c        <-ct$Gym2        -mean(ct$Gym2        ,na.rm=T)
ct$Inactivec    <-ct$Inactive    -mean(ct$Inactive    ,na.rm=T)
ct$HousCostc    <-ct$HousCost    -mean(ct$HousCost    ,na.rm=T)
ct$HousCostsc   <-ct$HousCosts   -mean(ct$HousCosts   ,na.rm=T)
ct$HousCrowdc   <-ct$HousCrowd   -mean(ct$HousCrowd   ,na.rm=T)
ct$Housingc     <-ct$Housing     -mean(ct$Housing     ,na.rm=T)
ct$HousPlumbc   <-ct$HousPlumb   -mean(ct$HousPlumb   ,na.rm=T)
ct$Insuredc     <-ct$Insured     -mean(ct$Insured     ,na.rm=T)
ct$InsuredAc    <-ct$InsuredA    -mean(ct$InsuredA    ,na.rm=T)
ct$InsuredCc    <-ct$InsuredC    -mean(ct$InsuredC    ,na.rm=T)
ct$JuvArrc      <-ct$JuvArr      -mean(ct$JuvArr      ,na.rm=T)
ct$Murderc      <-ct$Murder      -mean(ct$Murder      ,na.rm=T)
ct$Violentc     <-ct$Violent     -mean(ct$Violent     ,na.rm=T)
ct$LongCommc    <-ct$LongComm    -mean(ct$LongComm    ,na.rm=T)
ct$LowBWc       <-ct$LowBW       -mean(ct$LowBW       ,na.rm=T)
ct$LowBWBc      <-ct$LowBWB      -mean(ct$LowBWB      ,na.rm=T)
ct$LowBWHc      <-ct$LowBWH      -mean(ct$LowBWH      ,na.rm=T)
ct$LowBWWc      <-ct$LowBWW      -mean(ct$LowBWW      ,na.rm=T)
ct$TeenBthc     <-ct$TeenBth     -mean(ct$TeenBth     ,na.rm=T)
ct$TeenBthBc    <-ct$TeenBthB    -mean(ct$TeenBthB    ,na.rm=T)
ct$TeenBthHc    <-ct$TeenBthH    -mean(ct$TeenBthH    ,na.rm=T)
ct$TeenBthWc    <-ct$TeenBthW    -mean(ct$TeenBthW    ,na.rm=T)
ct$Mentalc      <-ct$Mental      -mean(ct$Mental      ,na.rm=T)
ct$MHPrvdc      <-ct$MHPrvd      -mean(ct$MHPrvd      ,na.rm=T)
ct$PCPc         <-ct$PCP         -mean(ct$PCP         ,na.rm=T)
ct$PCP2c        <-ct$PCP2        -mean(ct$PCP2        ,na.rm=T)
ct$Dentistc     <-ct$Dentist     -mean(ct$Dentist     ,na.rm=T)
ct$PrvtHospc    <-ct$PrvtHosp    -mean(ct$PrvtHosp    ,na.rm=T)
ct$PrvtHospBc   <-ct$PrvtHospB   -mean(ct$PrvtHospB   ,na.rm=T)
ct$PrvtHospHc   <-ct$PrvtHospH   -mean(ct$PrvtHospH   ,na.rm=T)
ct$PrvtHospWc   <-ct$PrvtHospW   -mean(ct$PrvtHospW   ,na.rm=T)
ct$SegBWc       <-ct$SegBW       -mean(ct$SegBW       ,na.rm=T)
ct$SegNWc       <-ct$SegNW       -mean(ct$SegNW       ,na.rm=T)
ct$SocAssoc     <-ct$SocAsso     -mean(ct$SocAsso     ,na.rm=T)
ct$SocSuppc     <-ct$SocSupp     -mean(ct$SocSupp     ,na.rm=T)
ct$MIECHVc      <-ct$MIECHV      -mean(ct$MIECHV      ,na.rm=T)
ct$NHVRCc       <-ct$NHVRC       -mean(ct$NHVRC       ,na.rm=T)
ct$HomeV2c      <-ct$HomeV2      -mean(ct$HomeV2      ,na.rm=T)
ct$FoodInsecurec<-ct$FoodInsecure-mean(ct$FoodInsecure,na.rm=T)

# demean - within and between variables
ct<-cbind(ct,demean(ct,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "PovT","PovTc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))



# Modeling Building - NHVRC
ctm01<-lmer(RptTr~Yearf+USDA_RUC+
            (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm02<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
            (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm03<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm04<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm05<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm06<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm07<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
# Interaction
ctm041<-lmer(RptTr~Yearf+USDA_RUC*NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm042<-lmer(RptTr~Yearf+USDA_RUC*NHVRCc_between+NHVRCc_within+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm043<-lmer(RptTr~Yearf+USDA_RUC*NHVRCc_within+USDA_RUC*NHVRCc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))

summary(ctm041)
anova(ctm04,ctm05)
anova(ctm04,ctm06)
anova(ctm04,ctm07)

ctz<-ct[!(ct$Year==2016 & ct$StateFIPS %in% c(17,19,24,37,40,41,55)) & !(ct$Year==2018 & ct$StateFIPS %in% c(12,21,26,32,42,48))]
ctm04z<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ctz,control=lmerControl(optimizer="Nelder_Mead"))
summary(ctm04z)

cty<-ct[ct$NHVRC==0|ct$NHVRC==1]
ctm04y<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=cty,control=lmerControl(optimizer="Nelder_Mead"))
summary(ctm04y)




tab_model(ctm01,ctm02,ctm03,ctm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04,ctm05,ctm06,ctm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04,ctm041,ctm042,ctm043,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04,ctm04z,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
ctm01CI<-confint(ctm01,method='boot',nsim=500,boot.type='perc')
ctm02CI<-confint(ctm02,method='boot',nsim=500,boot.type='perc')
ctm03CI<-confint(ctm03,method='boot',nsim=500,boot.type='perc')
ctm04CI<-confint(ctm04,method='boot',nsim=500,boot.type='perc')
ctm041CI<-confint(ctm041,method='boot',nsim=500,boot.type='perc')
ctm042CI<-confint(ctm042,method='boot',nsim=500,boot.type='perc')
ctm043CI<-confint(ctm043,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(ctm01)
check_collinearity(ctm02)
check_collinearity(ctm03)
check_collinearity(ctm04)
isSingular(ctm01)
isSingular(ctm02)
isSingular(ctm03)
isSingular(ctm04)



# Negative Binomial
ctg01<-glmmTMB(RptT~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom1)
ctg02<-glmmTMB(RptT~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2)
tab_model(ctg01,ctg02,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
AIC(ctg01,ctg02)
summary(ctg02)

# Modeling Building - MIECHV
ctm01a<-lmer(RptTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm02a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm03a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm04a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm05a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm06a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm07a<-lmer(RptTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
# Interaction
ctm041a<-lmer(RptTr~Yearf+USDA_RUC*MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm042a<-lmer(RptTr~Yearf+USDA_RUC*MIECHVc_between+MIECHVc_within+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm043a<-lmer(RptTr~Yearf+USDA_RUC*MIECHVc_within+USDA_RUC*MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
ctm08a<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))

anova(ctm04a,ctm041a)
anova(ctm04a,ctm042a)
summary(ctm041a)
summary(ctm042a)

anova(ctm04a,ctm05a)
anova(ctm04a,ctm06a)
anova(ctm04a,ctm07a)

anova(ctm04,ctm08a)
summary(ctm08a)


tab_model(ctm01a,ctm02a,ctm03a,ctm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04a,ctm05a,ctm06a,ctm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04a,ctm041a,ctm042a,ctm043a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04,ctm08a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
ctm01aCI<-confint(ctm01a,method='boot',nsim=500,boot.type='perc')
ctm02aCI<-confint(ctm02a,method='boot',nsim=500,boot.type='perc')
ctm03aCI<-confint(ctm03a,method='boot',nsim=500,boot.type='perc')
ctm04aCI<-confint(ctm04a,method='boot',nsim=500,boot.type='perc')
ctm041aCI<-confint(ctm041a,method='boot',nsim=500,boot.type='perc')
ctm042aCI<-confint(ctm042a,method='boot',nsim=500,boot.type='perc')
ctm042aCI<-confint(ctm042a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(ctm01a)
check_collinearity(ctm02a)
check_collinearity(ctm03a)
check_collinearity(ctm04a)
isSingular(ctm01a)
isSingular(ctm02a)
isSingular(ctm03a)
isSingular(ctm04a)



# Negative Binomial
ctg01a<-glmmTMB(RptT~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom1)
ctg02a<-glmmTMB(RptT~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2)
tab_model(ctg01a,ctg02a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)


summary(ctg02)
summary(ctg02a)


# prediction

ct$Year2017<-0
ct$Year2017[ct$Year==2017]<-1
ct$Year2018<-0
ct$Year2018[ct$Year==2018]<-1

ct$USDA_RUC2<-0
ct$USDA_RUC2[ct$USDA_RUC==2]<-1
ct$USDA_RUC3<-0
ct$USDA_RUC3[ct$USDA_RUC==3]<-1


ctm04p<-lmer(RptTr~Year2017+Year2018+USDA_RUC2+USDA_RUC3+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))

ctm04ap<-lmer(RptTr~Year2017+Year2018+USDA_RUC2+USDA_RUC3+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))




library(merTools)
z<-data.frame(Year2017=1,Year2018=1,USDA_RUC2=0.5219595,USDA_RUC3=0.1266892,NHVRCc_within=-0.03597122,
              NHVRCc_between=0,IncomeT1kc_within=0,IncomeT1kc_between=0,SingleTc_within=0,SingleTc_between=0,CPopBPc_within=0,CPopBPc_between=0,
              CPopHPc_within=0,CPopHPc_between=0,FBornTc_within=0,FBornTc_between=0,ChildPTc_within=0,ChildPTc_between=0,DisablTc_within=0,
              DisablTc_between=0,MoveTc_within=0,MoveTc_between=0)
z

b <- bootMer(ctm04p, nsim=5000, 
             FUN=function(x)predict(x, newdata=z, re.form=NA))
b
quantile(b$t, probs=c(0.025, 0.975))




summary(ctm02)
summary(ctm04)
icc(ctm02a,by_group=T)
icc(ctm04a,by_group=T)

summary(ctm02a)
summary(ctm04a)
icc(ctm02a,by_group=T)
icc(ctm04a,by_group=T)


ctm00<-lmer(RptTr~1+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
summary(ctm00)
icc(ctm00,by_group=T)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

c1$CPopBPc      <-c1$CPopBP      -mean(c1$CPopBP      ,na.rm=T)
c1$CPopHPc      <-c1$CPopHP      -mean(c1$CPopHP      ,na.rm=T)
c1$ChildPTc     <-c1$ChildPT     -mean(c1$ChildPT     ,na.rm=T)
c1$ChildPWc     <-c1$ChildPW     -mean(c1$ChildPW     ,na.rm=T)
c1$ChildPBc     <-c1$ChildPB     -mean(c1$ChildPB     ,na.rm=T)
c1$ChildPHc     <-c1$ChildPH     -mean(c1$ChildPH     ,na.rm=T)
c1$CARatioT100c <-c1$CARatioT100 -mean(c1$CARatioT100 ,na.rm=T)
c1$CARatioW100c <-c1$CARatioW100 -mean(c1$CARatioW100 ,na.rm=T)
c1$CARatioB100c <-c1$CARatioB100 -mean(c1$CARatioB100 ,na.rm=T)
c1$CARatioH100c <-c1$CARatioH100 -mean(c1$CARatioH100 ,na.rm=T)
c1$MalePTc      <-c1$MalePT      -mean(c1$MalePT      ,na.rm=T)
c1$MalePWc      <-c1$MalePW      -mean(c1$MalePW      ,na.rm=T)
c1$MalePBc      <-c1$MalePB      -mean(c1$MalePB      ,na.rm=T)
c1$MalePHc      <-c1$MalePH      -mean(c1$MalePH      ,na.rm=T)
c1$MFRatioT100c <-c1$MFRatioT100 -mean(c1$MFRatioT100 ,na.rm=T)
c1$MFRatioW100c <-c1$MFRatioW100 -mean(c1$MFRatioW100 ,na.rm=T)
c1$MFRatioB100c <-c1$MFRatioB100 -mean(c1$MFRatioB100 ,na.rm=T)
c1$MFRatioH100c <-c1$MFRatioH100 -mean(c1$MFRatioH100 ,na.rm=T)
c1$ElderTc      <-c1$ElderT      -mean(c1$ElderT      ,na.rm=T)
c1$ElderWc      <-c1$ElderW      -mean(c1$ElderW      ,na.rm=T)
c1$ElderBc      <-c1$ElderB      -mean(c1$ElderB      ,na.rm=T)
c1$ElderHc      <-c1$ElderH      -mean(c1$ElderH      ,na.rm=T)
c1$SingleTc     <-c1$SingleT     -mean(c1$SingleT     ,na.rm=T)
c1$SingleWc     <-c1$SingleW     -mean(c1$SingleW     ,na.rm=T)
c1$SingleBc     <-c1$SingleB     -mean(c1$SingleB     ,na.rm=T)
c1$SingleHc     <-c1$SingleH     -mean(c1$SingleH     ,na.rm=T)
c1$FHeadTc      <-c1$FHeadT      -mean(c1$FHeadT      ,na.rm=T)
c1$FHeadWc      <-c1$FHeadW      -mean(c1$FHeadW      ,na.rm=T)
c1$FHeadBc      <-c1$FHeadB      -mean(c1$FHeadB      ,na.rm=T)
c1$FHeadHc      <-c1$FHeadH      -mean(c1$FHeadH      ,na.rm=T)
c1$NoHighTc     <-c1$NoHighT     -mean(c1$NoHighT     ,na.rm=T)
c1$NoHighWc     <-c1$NoHighW     -mean(c1$NoHighW     ,na.rm=T)
c1$NoHighBc     <-c1$NoHighB     -mean(c1$NoHighB     ,na.rm=T)
c1$NoHighHc     <-c1$NoHighH     -mean(c1$NoHighH     ,na.rm=T)
c1$UnempTc      <-c1$UnempT      -mean(c1$UnempT      ,na.rm=T)
c1$UnempWc      <-c1$UnempW      -mean(c1$UnempW      ,na.rm=T)
c1$UnempBc      <-c1$UnempB      -mean(c1$UnempB      ,na.rm=T)
c1$UnempHc      <-c1$UnempH      -mean(c1$UnempH      ,na.rm=T)
c1$CPovTc       <-c1$CPovT       -mean(c1$CPovT       ,na.rm=T)
c1$CPovWc       <-c1$CPovW       -mean(c1$CPovW       ,na.rm=T)
c1$CPovBc       <-c1$CPovB       -mean(c1$CPovB       ,na.rm=T)
c1$CPovHc       <-c1$CPovH       -mean(c1$CPovH       ,na.rm=T)
c1$CPov1c       <-c1$CPov1       -mean(c1$CPov1       ,na.rm=T)
c1$CPov2c       <-c1$CPov2       -mean(c1$CPov2       ,na.rm=T)
c1$CPov3c       <-c1$CPov3       -mean(c1$CPov3       ,na.rm=T)
c1$PubAsTc      <-c1$PubAsT      -mean(c1$PubAsT      ,na.rm=T)
c1$WelfarTc     <-c1$WelfarT     -mean(c1$WelfarT     ,na.rm=T)
c1$SnapTc       <-c1$SnapT       -mean(c1$SnapT       ,na.rm=T)
c1$SnapWc       <-c1$SnapW       -mean(c1$SnapW       ,na.rm=T)
c1$SnapBc       <-c1$SnapB       -mean(c1$SnapB       ,na.rm=T)
c1$SnapHc       <-c1$SnapH       -mean(c1$SnapH       ,na.rm=T)
c1$IncomeT1kc   <-c1$IncomeT1k   -mean(c1$IncomeT1k   ,na.rm=T)
c1$IncomeW1kc   <-c1$IncomeW1k   -mean(c1$IncomeW1k   ,na.rm=T)
c1$IncomeB1kc   <-c1$IncomeB1k   -mean(c1$IncomeB1k   ,na.rm=T)
c1$IncomeH1kc   <-c1$IncomeH1k   -mean(c1$IncomeH1k   ,na.rm=T)
c1$GiniT100c    <-c1$GiniT100    -mean(c1$GiniT100    ,na.rm=T)
c1$HValueT10kc  <-c1$HValueT10k  -mean(c1$HValueT10k  ,na.rm=T)
c1$MCostT100c   <-c1$MCostT100   -mean(c1$MCostT100   ,na.rm=T)
c1$OCostDT100c  <-c1$OCostDT100  -mean(c1$OCostDT100  ,na.rm=T)
c1$MRentDT100c  <-c1$MRentDT100  -mean(c1$MRentDT100  ,na.rm=T)
c1$OCostPTc     <-c1$OCostPT     -mean(c1$OCostPT     ,na.rm=T)
c1$MRentPTc     <-c1$MRentPT     -mean(c1$MRentPT     ,na.rm=T)
c1$MortgTc      <-c1$MortgT      -mean(c1$MortgT      ,na.rm=T)
c1$LangAPTc     <-c1$LangAPT     -mean(c1$LangAPT     ,na.rm=T)
c1$LangAPWc     <-c1$LangAPW     -mean(c1$LangAPW     ,na.rm=T)
c1$LangAPBc     <-c1$LangAPB     -mean(c1$LangAPB     ,na.rm=T)
c1$LangAPHc     <-c1$LangAPH     -mean(c1$LangAPH     ,na.rm=T)
c1$LangBPTc     <-c1$LangBPT     -mean(c1$LangBPT     ,na.rm=T)
c1$LangBPWc     <-c1$LangBPW     -mean(c1$LangBPW     ,na.rm=T)
c1$LangBPBc     <-c1$LangBPB     -mean(c1$LangBPB     ,na.rm=T)
c1$LangBPHc     <-c1$LangBPH     -mean(c1$LangBPH     ,na.rm=T)
c1$LangCPTc     <-c1$LangCPT     -mean(c1$LangCPT     ,na.rm=T)
c1$OutUsTc      <-c1$OutUsT      -mean(c1$OutUsT      ,na.rm=T)
c1$OutUsWc      <-c1$OutUsW      -mean(c1$OutUsW      ,na.rm=T)
c1$OutUsBc      <-c1$OutUsB      -mean(c1$OutUsB      ,na.rm=T)
c1$OutUsHc      <-c1$OutUsH      -mean(c1$OutUsH      ,na.rm=T)
c1$FBornTc      <-c1$FBornT      -mean(c1$FBornT      ,na.rm=T)
c1$FBornWc      <-c1$FBornW      -mean(c1$FBornW      ,na.rm=T)
c1$FBornBc      <-c1$FBornB      -mean(c1$FBornB      ,na.rm=T)
c1$FBornHc      <-c1$FBornH      -mean(c1$FBornH      ,na.rm=T)
c1$NotCtzTc     <-c1$NotCtzT     -mean(c1$NotCtzT     ,na.rm=T)
c1$NotCtzWc     <-c1$NotCtzW     -mean(c1$NotCtzW     ,na.rm=T)
c1$NotCtzBc     <-c1$NotCtzB     -mean(c1$NotCtzB     ,na.rm=T)
c1$NotCtzHc     <-c1$NotCtzH     -mean(c1$NotCtzH     ,na.rm=T)
c1$MoveTc       <-c1$MoveT       -mean(c1$MoveT       ,na.rm=T)
c1$MoveWc       <-c1$MoveW       -mean(c1$MoveW       ,na.rm=T)
c1$MoveBc       <-c1$MoveB       -mean(c1$MoveB       ,na.rm=T)
c1$MoveHc       <-c1$MoveH       -mean(c1$MoveH       ,na.rm=T)
c1$VacantTc     <-c1$VacantT     -mean(c1$VacantT     ,na.rm=T)
c1$OwnerTc      <-c1$OwnerT      -mean(c1$OwnerT      ,na.rm=T)
c1$OwnerWc      <-c1$OwnerW      -mean(c1$OwnerW      ,na.rm=T)
c1$OwnerBc      <-c1$OwnerB      -mean(c1$OwnerB      ,na.rm=T)
c1$OwnerHc      <-c1$OwnerH      -mean(c1$OwnerH      ,na.rm=T)
c1$CrowdTc      <-c1$CrowdT      -mean(c1$CrowdT      ,na.rm=T)
c1$CrowdWc      <-c1$CrowdW      -mean(c1$CrowdW      ,na.rm=T)
c1$CrowdBc      <-c1$CrowdB      -mean(c1$CrowdB      ,na.rm=T)
c1$CrowdHc      <-c1$CrowdH      -mean(c1$CrowdH      ,na.rm=T)
c1$MobileTc     <-c1$MobileT     -mean(c1$MobileT     ,na.rm=T)
c1$MobileWc     <-c1$MobileW     -mean(c1$MobileW     ,na.rm=T)
c1$MobileBc     <-c1$MobileB     -mean(c1$MobileB     ,na.rm=T)
c1$MobileHc     <-c1$MobileH     -mean(c1$MobileH     ,na.rm=T)
c1$DisablTc     <-c1$DisablT     -mean(c1$DisablT     ,na.rm=T)
c1$DisablWc     <-c1$DisablW     -mean(c1$DisablW     ,na.rm=T)
c1$DisablBc     <-c1$DisablB     -mean(c1$DisablB     ,na.rm=T)
c1$DisablHc     <-c1$DisablH     -mean(c1$DisablH     ,na.rm=T)
c1$DisablTCc    <-c1$DisablTC    -mean(c1$DisablTC    ,na.rm=T)
c1$DisablWCc    <-c1$DisablWC    -mean(c1$DisablWC    ,na.rm=T)
c1$DisablBCc    <-c1$DisablBC    -mean(c1$DisablBC    ,na.rm=T)
c1$DisablHCc    <-c1$DisablHC    -mean(c1$DisablHC    ,na.rm=T)
c1$DisablTMc    <-c1$DisablTM    -mean(c1$DisablTM    ,na.rm=T)
c1$DisablTFc    <-c1$DisablTF    -mean(c1$DisablTF    ,na.rm=T)
c1$Urban1c      <-c1$Urban1      -mean(c1$Urban1      ,na.rm=T)
c1$Urban2c      <-c1$Urban2      -mean(c1$Urban2      ,na.rm=T)
c1$LBWT1rc      <-c1$LBWT1r      -mean(c1$LBWT1r      ,na.rm=T)
c1$LBWM1rc      <-c1$LBWM1r      -mean(c1$LBWM1r      ,na.rm=T)
c1$LBWF1rc      <-c1$LBWF1r      -mean(c1$LBWF1r      ,na.rm=T)
c1$LBWW1rc      <-c1$LBWW1r      -mean(c1$LBWW1r      ,na.rm=T)
c1$LBWB1rc      <-c1$LBWB1r      -mean(c1$LBWB1r      ,na.rm=T)
c1$LBWH1rc      <-c1$LBWH1r      -mean(c1$LBWH1r      ,na.rm=T)
c1$PTBT1rc      <-c1$PTBT1r      -mean(c1$PTBT1r      ,na.rm=T)
c1$PTBM1rc      <-c1$PTBM1r      -mean(c1$PTBM1r      ,na.rm=T)
c1$PTBF1rc      <-c1$PTBF1r      -mean(c1$PTBF1r      ,na.rm=T)
c1$PTBW1rc      <-c1$PTBW1r      -mean(c1$PTBW1r      ,na.rm=T)
c1$PTBB1rc      <-c1$PTBB1r      -mean(c1$PTBB1r      ,na.rm=T)
c1$PTBH1rc      <-c1$PTBH1r      -mean(c1$PTBH1r      ,na.rm=T)
c1$PNCT1rc      <-c1$PNCT1r      -mean(c1$PNCT1r      ,na.rm=T)
c1$PNCM1rc      <-c1$PNCM1r      -mean(c1$PNCM1r      ,na.rm=T)
c1$PNCF1rc      <-c1$PNCF1r      -mean(c1$PNCF1r      ,na.rm=T)
c1$PNCW1rc      <-c1$PNCW1r      -mean(c1$PNCW1r      ,na.rm=T)
c1$PNCB1rc      <-c1$PNCB1r      -mean(c1$PNCB1r      ,na.rm=T)
c1$PNCH1rc      <-c1$PNCH1r      -mean(c1$PNCH1r      ,na.rm=T)
c1$TBBT1rc      <-c1$TBBT1r      -mean(c1$TBBT1r      ,na.rm=T)
c1$TBBM1rc      <-c1$TBBM1r      -mean(c1$TBBM1r      ,na.rm=T)
c1$TBBF1rc      <-c1$TBBF1r      -mean(c1$TBBF1r      ,na.rm=T)
c1$TBBW1rc      <-c1$TBBW1r      -mean(c1$TBBW1r      ,na.rm=T)
c1$TBBB1rc      <-c1$TBBB1r      -mean(c1$TBBB1r      ,na.rm=T)
c1$TBBH1rc      <-c1$TBBH1r      -mean(c1$TBBH1r      ,na.rm=T)
c1$TBTT1rc      <-c1$TBTT1r      -mean(c1$TBTT1r      ,na.rm=T)
c1$TBTM1rc      <-c1$TBTM1r      -mean(c1$TBTM1r      ,na.rm=T)
c1$TBTF1rc      <-c1$TBTF1r      -mean(c1$TBTF1r      ,na.rm=T)
c1$TBTW1rc      <-c1$TBTW1r      -mean(c1$TBTW1r      ,na.rm=T)
c1$TBTB1rc      <-c1$TBTB1r      -mean(c1$TBTB1r      ,na.rm=T)
c1$TBTH1rc      <-c1$TBTH1r      -mean(c1$TBTH1r      ,na.rm=T)
c1$LBWT5rc      <-c1$LBWT5r      -mean(c1$LBWT5r      ,na.rm=T)
c1$LBWM5rc      <-c1$LBWM5r      -mean(c1$LBWM5r      ,na.rm=T)
c1$LBWF5rc      <-c1$LBWF5r      -mean(c1$LBWF5r      ,na.rm=T)
c1$LBWW5rc      <-c1$LBWW5r      -mean(c1$LBWW5r      ,na.rm=T)
c1$LBWB5rc      <-c1$LBWB5r      -mean(c1$LBWB5r      ,na.rm=T)
c1$LBWH5rc      <-c1$LBWH5r      -mean(c1$LBWH5r      ,na.rm=T)
c1$PTBT5rc      <-c1$PTBT5r      -mean(c1$PTBT5r      ,na.rm=T)
c1$PTBM5rc      <-c1$PTBM5r      -mean(c1$PTBM5r      ,na.rm=T)
c1$PTBF5rc      <-c1$PTBF5r      -mean(c1$PTBF5r      ,na.rm=T)
c1$PTBW5rc      <-c1$PTBW5r      -mean(c1$PTBW5r      ,na.rm=T)
c1$PTBB5rc      <-c1$PTBB5r      -mean(c1$PTBB5r      ,na.rm=T)
c1$PTBH5rc      <-c1$PTBH5r      -mean(c1$PTBH5r      ,na.rm=T)
c1$PNCT5rc      <-c1$PNCT5r      -mean(c1$PNCT5r      ,na.rm=T)
c1$PNCM5rc      <-c1$PNCM5r      -mean(c1$PNCM5r      ,na.rm=T)
c1$PNCF5rc      <-c1$PNCF5r      -mean(c1$PNCF5r      ,na.rm=T)
c1$PNCW5rc      <-c1$PNCW5r      -mean(c1$PNCW5r      ,na.rm=T)
c1$PNCB5rc      <-c1$PNCB5r      -mean(c1$PNCB5r      ,na.rm=T)
c1$PNCH5rc      <-c1$PNCH5r      -mean(c1$PNCH5r      ,na.rm=T)
c1$TBBT5rc      <-c1$TBBT5r      -mean(c1$TBBT5r      ,na.rm=T)
c1$TBBM5rc      <-c1$TBBM5r      -mean(c1$TBBM5r      ,na.rm=T)
c1$TBBF5rc      <-c1$TBBF5r      -mean(c1$TBBF5r      ,na.rm=T)
c1$TBBW5rc      <-c1$TBBW5r      -mean(c1$TBBW5r      ,na.rm=T)
c1$TBBB5rc      <-c1$TBBB5r      -mean(c1$TBBB5r      ,na.rm=T)
c1$TBBH5rc      <-c1$TBBH5r      -mean(c1$TBBH5r      ,na.rm=T)
c1$TBTT5rc      <-c1$TBTT5r      -mean(c1$TBTT5r      ,na.rm=T)
c1$TBTM5rc      <-c1$TBTM5r      -mean(c1$TBTM5r      ,na.rm=T)
c1$TBTF5rc      <-c1$TBTF5r      -mean(c1$TBTF5r      ,na.rm=T)
c1$TBTW5rc      <-c1$TBTW5r      -mean(c1$TBTW5r      ,na.rm=T)
c1$TBTB5rc      <-c1$TBTB5r      -mean(c1$TBTB5r      ,na.rm=T)
c1$TBTH5rc      <-c1$TBTH5r      -mean(c1$TBTH5r      ,na.rm=T)
c1$Opioidc      <-c1$Opioid      -mean(c1$Opioid      ,na.rm=T)
c1$LifeExpc     <-c1$LifeExp     -mean(c1$LifeExp     ,na.rm=T)
c1$LifeExpBc    <-c1$LifeExpB    -mean(c1$LifeExpB    ,na.rm=T)
c1$LifeExpHc    <-c1$LifeExpH    -mean(c1$LifeExpH    ,na.rm=T)
c1$LifeExpWc    <-c1$LifeExpW    -mean(c1$LifeExpW    ,na.rm=T)
c1$ChdDeathc    <-c1$ChdDeath    -mean(c1$ChdDeath    ,na.rm=T)
c1$ChdDeathBc   <-c1$ChdDeathB   -mean(c1$ChdDeathB   ,na.rm=T)
c1$ChdDeathHc   <-c1$ChdDeathH   -mean(c1$ChdDeathH   ,na.rm=T)
c1$ChdDeathWc   <-c1$ChdDeathW   -mean(c1$ChdDeathW   ,na.rm=T)
c1$InfDeathc    <-c1$InfDeath    -mean(c1$InfDeath    ,na.rm=T)
c1$InfDeathBc   <-c1$InfDeathB   -mean(c1$InfDeathB   ,na.rm=T)
c1$InfDeathHc   <-c1$InfDeathH   -mean(c1$InfDeathH   ,na.rm=T)
c1$InfDeathWc   <-c1$InfDeathW   -mean(c1$InfDeathW   ,na.rm=T)
c1$Injuryc      <-c1$Injury      -mean(c1$Injury      ,na.rm=T)
c1$InjuryBc     <-c1$InjuryB     -mean(c1$InjuryB     ,na.rm=T)
c1$InjuryHc     <-c1$InjuryH     -mean(c1$InjuryH     ,na.rm=T)
c1$InjuryWc     <-c1$InjuryW     -mean(c1$InjuryW     ,na.rm=T)
c1$GunDeathc    <-c1$GunDeath    -mean(c1$GunDeath    ,na.rm=T)
c1$GunDeathBc   <-c1$GunDeathB   -mean(c1$GunDeathB   ,na.rm=T)
c1$GunDeathWc   <-c1$GunDeathW   -mean(c1$GunDeathW   ,na.rm=T)
c1$PrmDeath_c   <-c1$PrmDeath    -mean(c1$PrmDeath    ,na.rm=T)
c1$PrmDeathcc   <-c1$PrmDeathc   -mean(c1$PrmDeathc   ,na.rm=T)
c1$PrmDeathBc   <-c1$PrmDeathB   -mean(c1$PrmDeathB   ,na.rm=T)
c1$PrmDeathHc   <-c1$PrmDeathH   -mean(c1$PrmDeathH   ,na.rm=T)
c1$PrmDeathWc   <-c1$PrmDeathW   -mean(c1$PrmDeathW   ,na.rm=T)
c1$PrmDeath2_c  <-c1$PrmDeath2   -mean(c1$PrmDeath2   ,na.rm=T)
c1$PrmDeath2cc  <-c1$PrmDeath2c  -mean(c1$PrmDeath2c  ,na.rm=T)
c1$PrmDeath2Bc  <-c1$PrmDeath2B  -mean(c1$PrmDeath2B  ,na.rm=T)
c1$PrmDeath2Hc  <-c1$PrmDeath2H  -mean(c1$PrmDeath2H  ,na.rm=T)
c1$PrmDeath2Wc  <-c1$PrmDeath2W  -mean(c1$PrmDeath2W  ,na.rm=T)
c1$Suicidec     <-c1$Suicide     -mean(c1$Suicide     ,na.rm=T)
c1$Diabetc      <-c1$Diabet      -mean(c1$Diabet      ,na.rm=T)
c1$Obesityc     <-c1$Obesity     -mean(c1$Obesity     ,na.rm=T)
c1$Physicalc    <-c1$Physical    -mean(c1$Physical    ,na.rm=T)
c1$PoorHlthc    <-c1$PoorHlth    -mean(c1$PoorHlth    ,na.rm=T)
c1$PoorMHc      <-c1$PoorMH      -mean(c1$PoorMH      ,na.rm=T)
c1$PoorPhyc     <-c1$PoorPhy     -mean(c1$PoorPhy     ,na.rm=T)
c1$Sleepc       <-c1$Sleep       -mean(c1$Sleep       ,na.rm=T)
c1$DrugOdc      <-c1$DrugOd      -mean(c1$DrugOd      ,na.rm=T)
c1$DrugOdBc     <-c1$DrugOdB     -mean(c1$DrugOdB     ,na.rm=T)
c1$DrugOdHc     <-c1$DrugOdH     -mean(c1$DrugOdH     ,na.rm=T)
c1$DrugOdWc     <-c1$DrugOdW     -mean(c1$DrugOdW     ,na.rm=T)
c1$DWIDeathc    <-c1$DWIDeath    -mean(c1$DWIDeath    ,na.rm=T)
c1$EDrinkc      <-c1$EDrink      -mean(c1$EDrink      ,na.rm=T)
c1$Smokec       <-c1$Smoke       -mean(c1$Smoke       ,na.rm=T)
c1$FastFoodc    <-c1$FastFood    -mean(c1$FastFood    ,na.rm=T)
c1$FoodEnvc     <-c1$FoodEnv     -mean(c1$FoodEnv     ,na.rm=T)
c1$FoodInsc     <-c1$FoodIns     -mean(c1$FoodIns     ,na.rm=T)
c1$FrLunchc     <-c1$FrLunch     -mean(c1$FrLunch     ,na.rm=T)
c1$LAccFoodc    <-c1$LAccFood    -mean(c1$LAccFood    ,na.rm=T)
c1$Gymc         <-c1$Gym         -mean(c1$Gym         ,na.rm=T)
c1$Gym2c        <-c1$Gym2        -mean(c1$Gym2        ,na.rm=T)
c1$Inactivec    <-c1$Inactive    -mean(c1$Inactive    ,na.rm=T)
c1$HousCostc    <-c1$HousCost    -mean(c1$HousCost    ,na.rm=T)
c1$HousCostsc   <-c1$HousCosts   -mean(c1$HousCosts   ,na.rm=T)
c1$HousCrowdc   <-c1$HousCrowd   -mean(c1$HousCrowd   ,na.rm=T)
c1$Housingc     <-c1$Housing     -mean(c1$Housing     ,na.rm=T)
c1$HousPlumbc   <-c1$HousPlumb   -mean(c1$HousPlumb   ,na.rm=T)
c1$Insuredc     <-c1$Insured     -mean(c1$Insured     ,na.rm=T)
c1$InsuredAc    <-c1$InsuredA    -mean(c1$InsuredA    ,na.rm=T)
c1$InsuredCc    <-c1$InsuredC    -mean(c1$InsuredC    ,na.rm=T)
c1$JuvArrc      <-c1$JuvArr      -mean(c1$JuvArr      ,na.rm=T)
c1$Murderc      <-c1$Murder      -mean(c1$Murder      ,na.rm=T)
c1$Violentc     <-c1$Violent     -mean(c1$Violent     ,na.rm=T)
c1$LongCommc    <-c1$LongComm    -mean(c1$LongComm    ,na.rm=T)
c1$LowBWc       <-c1$LowBW       -mean(c1$LowBW       ,na.rm=T)
c1$LowBWBc      <-c1$LowBWB      -mean(c1$LowBWB      ,na.rm=T)
c1$LowBWHc      <-c1$LowBWH      -mean(c1$LowBWH      ,na.rm=T)
c1$LowBWWc      <-c1$LowBWW      -mean(c1$LowBWW      ,na.rm=T)
c1$TeenBthc     <-c1$TeenBth     -mean(c1$TeenBth     ,na.rm=T)
c1$TeenBthBc    <-c1$TeenBthB    -mean(c1$TeenBthB    ,na.rm=T)
c1$TeenBthHc    <-c1$TeenBthH    -mean(c1$TeenBthH    ,na.rm=T)
c1$TeenBthWc    <-c1$TeenBthW    -mean(c1$TeenBthW    ,na.rm=T)
c1$Mentalc      <-c1$Mental      -mean(c1$Mental      ,na.rm=T)
c1$MHPrvdc      <-c1$MHPrvd      -mean(c1$MHPrvd      ,na.rm=T)
c1$PCPc         <-c1$PCP         -mean(c1$PCP         ,na.rm=T)
c1$PCP2c        <-c1$PCP2        -mean(c1$PCP2        ,na.rm=T)
c1$Dentistc     <-c1$Dentist     -mean(c1$Dentist     ,na.rm=T)
c1$PrvtHospc    <-c1$PrvtHosp    -mean(c1$PrvtHosp    ,na.rm=T)
c1$PrvtHospBc   <-c1$PrvtHospB   -mean(c1$PrvtHospB   ,na.rm=T)
c1$PrvtHospHc   <-c1$PrvtHospH   -mean(c1$PrvtHospH   ,na.rm=T)
c1$PrvtHospWc   <-c1$PrvtHospW   -mean(c1$PrvtHospW   ,na.rm=T)
c1$SegBWc       <-c1$SegBW       -mean(c1$SegBW       ,na.rm=T)
c1$SegNWc       <-c1$SegNW       -mean(c1$SegNW       ,na.rm=T)
c1$SocAssoc     <-c1$SocAsso     -mean(c1$SocAsso     ,na.rm=T)
c1$SocSuppc     <-c1$SocSupp     -mean(c1$SocSupp     ,na.rm=T)
c1$MIECHVc      <-c1$MIECHV      -mean(c1$MIECHV      ,na.rm=T)
c1$NHVRCc       <-c1$NHVRC       -mean(c1$NHVRC       ,na.rm=T)
c1$HomeV2c      <-c1$HomeV2      -mean(c1$HomeV2      ,na.rm=T)
c1$FoodInsecurec<-c1$FoodInsecure-mean(c1$FoodInsecure,na.rm=T)

c1<-cbind(c1,demean(c1,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))



# Model building - NHVRC
c1m01<-lmer(Rpt1r~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m02<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m03<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m04<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m05<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m06<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m07<-lmer(Rpt1r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
tab_model(c1m01,c1m02,c1m03,c1m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c1m04,c1m05,c1m06,c1m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c1m01CI<-confint(c1m01,method='boot',nsim=500,boot.type='perc')
c1m02CI<-confint(c1m02,method='boot',nsim=500,boot.type='perc')
c1m03CI<-confint(c1m03,method='boot',nsim=500,boot.type='perc')
c1m04CI<-confint(c1m04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c1m01)
check_collinearity(c1m02)
check_collinearity(c1m03)
check_collinearity(c1m04)
isSingular(c1m01)
isSingular(c1m02)
isSingular(c1m03)
isSingular(c1m04)



# Model building - MIECHV
c1m01a<-lmer(Rpt1r~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m02a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m03a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m04a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m05a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m06a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
c1m07a<-lmer(Rpt1r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=c1,control=lmerControl(optimizer="Nelder_Mead"))
tab_model(c1m01a,c1m02a,c1m03a,c1m04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c1m04a,c1m05a,c1m06a,c1m07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c1m01aCI<-confint(c1m01a,method='boot',nsim=500,boot.type='perc')
c1m02aCI<-confint(c1m02a,method='boot',nsim=500,boot.type='perc')
c1m03aCI<-confint(c1m03a,method='boot',nsim=500,boot.type='perc')
c1m04aCI<-confint(c1m04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c1m01a)
check_collinearity(c1m02a)
check_collinearity(c1m03a)
check_collinearity(c1m04a)
isSingular(c1m01a)
isSingular(c1m02a)
isSingular(c1m03a)
isSingular(c1m04a)


c1g02<-glmmTMB(Rpt1~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop1)),data=c1,family=nbinom2)
c1g02a<-glmmTMB(Rpt1~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop1)),data=c1,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

c2$CPopBPc      <-c2$CPopBP      -mean(c2$CPopBP      ,na.rm=T)
c2$CPopHPc      <-c2$CPopHP      -mean(c2$CPopHP      ,na.rm=T)
c2$ChildPTc     <-c2$ChildPT     -mean(c2$ChildPT     ,na.rm=T)
c2$ChildPWc     <-c2$ChildPW     -mean(c2$ChildPW     ,na.rm=T)
c2$ChildPBc     <-c2$ChildPB     -mean(c2$ChildPB     ,na.rm=T)
c2$ChildPHc     <-c2$ChildPH     -mean(c2$ChildPH     ,na.rm=T)
c2$CARatioT100c <-c2$CARatioT100 -mean(c2$CARatioT100 ,na.rm=T)
c2$CARatioW100c <-c2$CARatioW100 -mean(c2$CARatioW100 ,na.rm=T)
c2$CARatioB100c <-c2$CARatioB100 -mean(c2$CARatioB100 ,na.rm=T)
c2$CARatioH100c <-c2$CARatioH100 -mean(c2$CARatioH100 ,na.rm=T)
c2$MalePTc      <-c2$MalePT      -mean(c2$MalePT      ,na.rm=T)
c2$MalePWc      <-c2$MalePW      -mean(c2$MalePW      ,na.rm=T)
c2$MalePBc      <-c2$MalePB      -mean(c2$MalePB      ,na.rm=T)
c2$MalePHc      <-c2$MalePH      -mean(c2$MalePH      ,na.rm=T)
c2$MFRatioT100c <-c2$MFRatioT100 -mean(c2$MFRatioT100 ,na.rm=T)
c2$MFRatioW100c <-c2$MFRatioW100 -mean(c2$MFRatioW100 ,na.rm=T)
c2$MFRatioB100c <-c2$MFRatioB100 -mean(c2$MFRatioB100 ,na.rm=T)
c2$MFRatioH100c <-c2$MFRatioH100 -mean(c2$MFRatioH100 ,na.rm=T)
c2$ElderTc      <-c2$ElderT      -mean(c2$ElderT      ,na.rm=T)
c2$ElderWc      <-c2$ElderW      -mean(c2$ElderW      ,na.rm=T)
c2$ElderBc      <-c2$ElderB      -mean(c2$ElderB      ,na.rm=T)
c2$ElderHc      <-c2$ElderH      -mean(c2$ElderH      ,na.rm=T)
c2$SingleTc     <-c2$SingleT     -mean(c2$SingleT     ,na.rm=T)
c2$SingleWc     <-c2$SingleW     -mean(c2$SingleW     ,na.rm=T)
c2$SingleBc     <-c2$SingleB     -mean(c2$SingleB     ,na.rm=T)
c2$SingleHc     <-c2$SingleH     -mean(c2$SingleH     ,na.rm=T)
c2$FHeadTc      <-c2$FHeadT      -mean(c2$FHeadT      ,na.rm=T)
c2$FHeadWc      <-c2$FHeadW      -mean(c2$FHeadW      ,na.rm=T)
c2$FHeadBc      <-c2$FHeadB      -mean(c2$FHeadB      ,na.rm=T)
c2$FHeadHc      <-c2$FHeadH      -mean(c2$FHeadH      ,na.rm=T)
c2$NoHighTc     <-c2$NoHighT     -mean(c2$NoHighT     ,na.rm=T)
c2$NoHighWc     <-c2$NoHighW     -mean(c2$NoHighW     ,na.rm=T)
c2$NoHighBc     <-c2$NoHighB     -mean(c2$NoHighB     ,na.rm=T)
c2$NoHighHc     <-c2$NoHighH     -mean(c2$NoHighH     ,na.rm=T)
c2$UnempTc      <-c2$UnempT      -mean(c2$UnempT      ,na.rm=T)
c2$UnempWc      <-c2$UnempW      -mean(c2$UnempW      ,na.rm=T)
c2$UnempBc      <-c2$UnempB      -mean(c2$UnempB      ,na.rm=T)
c2$UnempHc      <-c2$UnempH      -mean(c2$UnempH      ,na.rm=T)
c2$CPovTc       <-c2$CPovT       -mean(c2$CPovT       ,na.rm=T)
c2$CPovWc       <-c2$CPovW       -mean(c2$CPovW       ,na.rm=T)
c2$CPovBc       <-c2$CPovB       -mean(c2$CPovB       ,na.rm=T)
c2$CPovHc       <-c2$CPovH       -mean(c2$CPovH       ,na.rm=T)
c2$CPov1c       <-c2$CPov1       -mean(c2$CPov1       ,na.rm=T)
c2$CPov2c       <-c2$CPov2       -mean(c2$CPov2       ,na.rm=T)
c2$CPov3c       <-c2$CPov3       -mean(c2$CPov3       ,na.rm=T)
c2$PubAsTc      <-c2$PubAsT      -mean(c2$PubAsT      ,na.rm=T)
c2$WelfarTc     <-c2$WelfarT     -mean(c2$WelfarT     ,na.rm=T)
c2$SnapTc       <-c2$SnapT       -mean(c2$SnapT       ,na.rm=T)
c2$SnapWc       <-c2$SnapW       -mean(c2$SnapW       ,na.rm=T)
c2$SnapBc       <-c2$SnapB       -mean(c2$SnapB       ,na.rm=T)
c2$SnapHc       <-c2$SnapH       -mean(c2$SnapH       ,na.rm=T)
c2$IncomeT1kc   <-c2$IncomeT1k   -mean(c2$IncomeT1k   ,na.rm=T)
c2$IncomeW1kc   <-c2$IncomeW1k   -mean(c2$IncomeW1k   ,na.rm=T)
c2$IncomeB1kc   <-c2$IncomeB1k   -mean(c2$IncomeB1k   ,na.rm=T)
c2$IncomeH1kc   <-c2$IncomeH1k   -mean(c2$IncomeH1k   ,na.rm=T)
c2$GiniT100c    <-c2$GiniT100    -mean(c2$GiniT100    ,na.rm=T)
c2$HValueT10kc  <-c2$HValueT10k  -mean(c2$HValueT10k  ,na.rm=T)
c2$MCostT100c   <-c2$MCostT100   -mean(c2$MCostT100   ,na.rm=T)
c2$OCostDT100c  <-c2$OCostDT100  -mean(c2$OCostDT100  ,na.rm=T)
c2$MRentDT100c  <-c2$MRentDT100  -mean(c2$MRentDT100  ,na.rm=T)
c2$OCostPTc     <-c2$OCostPT     -mean(c2$OCostPT     ,na.rm=T)
c2$MRentPTc     <-c2$MRentPT     -mean(c2$MRentPT     ,na.rm=T)
c2$MortgTc      <-c2$MortgT      -mean(c2$MortgT      ,na.rm=T)
c2$LangAPTc     <-c2$LangAPT     -mean(c2$LangAPT     ,na.rm=T)
c2$LangAPWc     <-c2$LangAPW     -mean(c2$LangAPW     ,na.rm=T)
c2$LangAPBc     <-c2$LangAPB     -mean(c2$LangAPB     ,na.rm=T)
c2$LangAPHc     <-c2$LangAPH     -mean(c2$LangAPH     ,na.rm=T)
c2$LangBPTc     <-c2$LangBPT     -mean(c2$LangBPT     ,na.rm=T)
c2$LangBPWc     <-c2$LangBPW     -mean(c2$LangBPW     ,na.rm=T)
c2$LangBPBc     <-c2$LangBPB     -mean(c2$LangBPB     ,na.rm=T)
c2$LangBPHc     <-c2$LangBPH     -mean(c2$LangBPH     ,na.rm=T)
c2$LangCPTc     <-c2$LangCPT     -mean(c2$LangCPT     ,na.rm=T)
c2$OutUsTc      <-c2$OutUsT      -mean(c2$OutUsT      ,na.rm=T)
c2$OutUsWc      <-c2$OutUsW      -mean(c2$OutUsW      ,na.rm=T)
c2$OutUsBc      <-c2$OutUsB      -mean(c2$OutUsB      ,na.rm=T)
c2$OutUsHc      <-c2$OutUsH      -mean(c2$OutUsH      ,na.rm=T)
c2$FBornTc      <-c2$FBornT      -mean(c2$FBornT      ,na.rm=T)
c2$FBornWc      <-c2$FBornW      -mean(c2$FBornW      ,na.rm=T)
c2$FBornBc      <-c2$FBornB      -mean(c2$FBornB      ,na.rm=T)
c2$FBornHc      <-c2$FBornH      -mean(c2$FBornH      ,na.rm=T)
c2$NotCtzTc     <-c2$NotCtzT     -mean(c2$NotCtzT     ,na.rm=T)
c2$NotCtzWc     <-c2$NotCtzW     -mean(c2$NotCtzW     ,na.rm=T)
c2$NotCtzBc     <-c2$NotCtzB     -mean(c2$NotCtzB     ,na.rm=T)
c2$NotCtzHc     <-c2$NotCtzH     -mean(c2$NotCtzH     ,na.rm=T)
c2$MoveTc       <-c2$MoveT       -mean(c2$MoveT       ,na.rm=T)
c2$MoveWc       <-c2$MoveW       -mean(c2$MoveW       ,na.rm=T)
c2$MoveBc       <-c2$MoveB       -mean(c2$MoveB       ,na.rm=T)
c2$MoveHc       <-c2$MoveH       -mean(c2$MoveH       ,na.rm=T)
c2$VacantTc     <-c2$VacantT     -mean(c2$VacantT     ,na.rm=T)
c2$OwnerTc      <-c2$OwnerT      -mean(c2$OwnerT      ,na.rm=T)
c2$OwnerWc      <-c2$OwnerW      -mean(c2$OwnerW      ,na.rm=T)
c2$OwnerBc      <-c2$OwnerB      -mean(c2$OwnerB      ,na.rm=T)
c2$OwnerHc      <-c2$OwnerH      -mean(c2$OwnerH      ,na.rm=T)
c2$CrowdTc      <-c2$CrowdT      -mean(c2$CrowdT      ,na.rm=T)
c2$CrowdWc      <-c2$CrowdW      -mean(c2$CrowdW      ,na.rm=T)
c2$CrowdBc      <-c2$CrowdB      -mean(c2$CrowdB      ,na.rm=T)
c2$CrowdHc      <-c2$CrowdH      -mean(c2$CrowdH      ,na.rm=T)
c2$MobileTc     <-c2$MobileT     -mean(c2$MobileT     ,na.rm=T)
c2$MobileWc     <-c2$MobileW     -mean(c2$MobileW     ,na.rm=T)
c2$MobileBc     <-c2$MobileB     -mean(c2$MobileB     ,na.rm=T)
c2$MobileHc     <-c2$MobileH     -mean(c2$MobileH     ,na.rm=T)
c2$DisablTc     <-c2$DisablT     -mean(c2$DisablT     ,na.rm=T)
c2$DisablWc     <-c2$DisablW     -mean(c2$DisablW     ,na.rm=T)
c2$DisablBc     <-c2$DisablB     -mean(c2$DisablB     ,na.rm=T)
c2$DisablHc     <-c2$DisablH     -mean(c2$DisablH     ,na.rm=T)
c2$DisablTCc    <-c2$DisablTC    -mean(c2$DisablTC    ,na.rm=T)
c2$DisablWCc    <-c2$DisablWC    -mean(c2$DisablWC    ,na.rm=T)
c2$DisablBCc    <-c2$DisablBC    -mean(c2$DisablBC    ,na.rm=T)
c2$DisablHCc    <-c2$DisablHC    -mean(c2$DisablHC    ,na.rm=T)
c2$DisablTMc    <-c2$DisablTM    -mean(c2$DisablTM    ,na.rm=T)
c2$DisablTFc    <-c2$DisablTF    -mean(c2$DisablTF    ,na.rm=T)
c2$Urban1c      <-c2$Urban1      -mean(c2$Urban1      ,na.rm=T)
c2$Urban2c      <-c2$Urban2      -mean(c2$Urban2      ,na.rm=T)
c2$LBWT1rc      <-c2$LBWT1r      -mean(c2$LBWT1r      ,na.rm=T)
c2$LBWM1rc      <-c2$LBWM1r      -mean(c2$LBWM1r      ,na.rm=T)
c2$LBWF1rc      <-c2$LBWF1r      -mean(c2$LBWF1r      ,na.rm=T)
c2$LBWW1rc      <-c2$LBWW1r      -mean(c2$LBWW1r      ,na.rm=T)
c2$LBWB1rc      <-c2$LBWB1r      -mean(c2$LBWB1r      ,na.rm=T)
c2$LBWH1rc      <-c2$LBWH1r      -mean(c2$LBWH1r      ,na.rm=T)
c2$PTBT1rc      <-c2$PTBT1r      -mean(c2$PTBT1r      ,na.rm=T)
c2$PTBM1rc      <-c2$PTBM1r      -mean(c2$PTBM1r      ,na.rm=T)
c2$PTBF1rc      <-c2$PTBF1r      -mean(c2$PTBF1r      ,na.rm=T)
c2$PTBW1rc      <-c2$PTBW1r      -mean(c2$PTBW1r      ,na.rm=T)
c2$PTBB1rc      <-c2$PTBB1r      -mean(c2$PTBB1r      ,na.rm=T)
c2$PTBH1rc      <-c2$PTBH1r      -mean(c2$PTBH1r      ,na.rm=T)
c2$PNCT1rc      <-c2$PNCT1r      -mean(c2$PNCT1r      ,na.rm=T)
c2$PNCM1rc      <-c2$PNCM1r      -mean(c2$PNCM1r      ,na.rm=T)
c2$PNCF1rc      <-c2$PNCF1r      -mean(c2$PNCF1r      ,na.rm=T)
c2$PNCW1rc      <-c2$PNCW1r      -mean(c2$PNCW1r      ,na.rm=T)
c2$PNCB1rc      <-c2$PNCB1r      -mean(c2$PNCB1r      ,na.rm=T)
c2$PNCH1rc      <-c2$PNCH1r      -mean(c2$PNCH1r      ,na.rm=T)
c2$TBBT1rc      <-c2$TBBT1r      -mean(c2$TBBT1r      ,na.rm=T)
c2$TBBM1rc      <-c2$TBBM1r      -mean(c2$TBBM1r      ,na.rm=T)
c2$TBBF1rc      <-c2$TBBF1r      -mean(c2$TBBF1r      ,na.rm=T)
c2$TBBW1rc      <-c2$TBBW1r      -mean(c2$TBBW1r      ,na.rm=T)
c2$TBBB1rc      <-c2$TBBB1r      -mean(c2$TBBB1r      ,na.rm=T)
c2$TBBH1rc      <-c2$TBBH1r      -mean(c2$TBBH1r      ,na.rm=T)
c2$TBTT1rc      <-c2$TBTT1r      -mean(c2$TBTT1r      ,na.rm=T)
c2$TBTM1rc      <-c2$TBTM1r      -mean(c2$TBTM1r      ,na.rm=T)
c2$TBTF1rc      <-c2$TBTF1r      -mean(c2$TBTF1r      ,na.rm=T)
c2$TBTW1rc      <-c2$TBTW1r      -mean(c2$TBTW1r      ,na.rm=T)
c2$TBTB1rc      <-c2$TBTB1r      -mean(c2$TBTB1r      ,na.rm=T)
c2$TBTH1rc      <-c2$TBTH1r      -mean(c2$TBTH1r      ,na.rm=T)
c2$LBWT5rc      <-c2$LBWT5r      -mean(c2$LBWT5r      ,na.rm=T)
c2$LBWM5rc      <-c2$LBWM5r      -mean(c2$LBWM5r      ,na.rm=T)
c2$LBWF5rc      <-c2$LBWF5r      -mean(c2$LBWF5r      ,na.rm=T)
c2$LBWW5rc      <-c2$LBWW5r      -mean(c2$LBWW5r      ,na.rm=T)
c2$LBWB5rc      <-c2$LBWB5r      -mean(c2$LBWB5r      ,na.rm=T)
c2$LBWH5rc      <-c2$LBWH5r      -mean(c2$LBWH5r      ,na.rm=T)
c2$PTBT5rc      <-c2$PTBT5r      -mean(c2$PTBT5r      ,na.rm=T)
c2$PTBM5rc      <-c2$PTBM5r      -mean(c2$PTBM5r      ,na.rm=T)
c2$PTBF5rc      <-c2$PTBF5r      -mean(c2$PTBF5r      ,na.rm=T)
c2$PTBW5rc      <-c2$PTBW5r      -mean(c2$PTBW5r      ,na.rm=T)
c2$PTBB5rc      <-c2$PTBB5r      -mean(c2$PTBB5r      ,na.rm=T)
c2$PTBH5rc      <-c2$PTBH5r      -mean(c2$PTBH5r      ,na.rm=T)
c2$PNCT5rc      <-c2$PNCT5r      -mean(c2$PNCT5r      ,na.rm=T)
c2$PNCM5rc      <-c2$PNCM5r      -mean(c2$PNCM5r      ,na.rm=T)
c2$PNCF5rc      <-c2$PNCF5r      -mean(c2$PNCF5r      ,na.rm=T)
c2$PNCW5rc      <-c2$PNCW5r      -mean(c2$PNCW5r      ,na.rm=T)
c2$PNCB5rc      <-c2$PNCB5r      -mean(c2$PNCB5r      ,na.rm=T)
c2$PNCH5rc      <-c2$PNCH5r      -mean(c2$PNCH5r      ,na.rm=T)
c2$TBBT5rc      <-c2$TBBT5r      -mean(c2$TBBT5r      ,na.rm=T)
c2$TBBM5rc      <-c2$TBBM5r      -mean(c2$TBBM5r      ,na.rm=T)
c2$TBBF5rc      <-c2$TBBF5r      -mean(c2$TBBF5r      ,na.rm=T)
c2$TBBW5rc      <-c2$TBBW5r      -mean(c2$TBBW5r      ,na.rm=T)
c2$TBBB5rc      <-c2$TBBB5r      -mean(c2$TBBB5r      ,na.rm=T)
c2$TBBH5rc      <-c2$TBBH5r      -mean(c2$TBBH5r      ,na.rm=T)
c2$TBTT5rc      <-c2$TBTT5r      -mean(c2$TBTT5r      ,na.rm=T)
c2$TBTM5rc      <-c2$TBTM5r      -mean(c2$TBTM5r      ,na.rm=T)
c2$TBTF5rc      <-c2$TBTF5r      -mean(c2$TBTF5r      ,na.rm=T)
c2$TBTW5rc      <-c2$TBTW5r      -mean(c2$TBTW5r      ,na.rm=T)
c2$TBTB5rc      <-c2$TBTB5r      -mean(c2$TBTB5r      ,na.rm=T)
c2$TBTH5rc      <-c2$TBTH5r      -mean(c2$TBTH5r      ,na.rm=T)
c2$Opioidc      <-c2$Opioid      -mean(c2$Opioid      ,na.rm=T)
c2$LifeExpc     <-c2$LifeExp     -mean(c2$LifeExp     ,na.rm=T)
c2$LifeExpBc    <-c2$LifeExpB    -mean(c2$LifeExpB    ,na.rm=T)
c2$LifeExpHc    <-c2$LifeExpH    -mean(c2$LifeExpH    ,na.rm=T)
c2$LifeExpWc    <-c2$LifeExpW    -mean(c2$LifeExpW    ,na.rm=T)
c2$ChdDeathc    <-c2$ChdDeath    -mean(c2$ChdDeath    ,na.rm=T)
c2$ChdDeathBc   <-c2$ChdDeathB   -mean(c2$ChdDeathB   ,na.rm=T)
c2$ChdDeathHc   <-c2$ChdDeathH   -mean(c2$ChdDeathH   ,na.rm=T)
c2$ChdDeathWc   <-c2$ChdDeathW   -mean(c2$ChdDeathW   ,na.rm=T)
c2$InfDeathc    <-c2$InfDeath    -mean(c2$InfDeath    ,na.rm=T)
c2$InfDeathBc   <-c2$InfDeathB   -mean(c2$InfDeathB   ,na.rm=T)
c2$InfDeathHc   <-c2$InfDeathH   -mean(c2$InfDeathH   ,na.rm=T)
c2$InfDeathWc   <-c2$InfDeathW   -mean(c2$InfDeathW   ,na.rm=T)
c2$Injuryc      <-c2$Injury      -mean(c2$Injury      ,na.rm=T)
c2$InjuryBc     <-c2$InjuryB     -mean(c2$InjuryB     ,na.rm=T)
c2$InjuryHc     <-c2$InjuryH     -mean(c2$InjuryH     ,na.rm=T)
c2$InjuryWc     <-c2$InjuryW     -mean(c2$InjuryW     ,na.rm=T)
c2$GunDeathc    <-c2$GunDeath    -mean(c2$GunDeath    ,na.rm=T)
c2$GunDeathBc   <-c2$GunDeathB   -mean(c2$GunDeathB   ,na.rm=T)
c2$GunDeathWc   <-c2$GunDeathW   -mean(c2$GunDeathW   ,na.rm=T)
c2$PrmDeath_c   <-c2$PrmDeath    -mean(c2$PrmDeath    ,na.rm=T)
c2$PrmDeathcc   <-c2$PrmDeathc   -mean(c2$PrmDeathc   ,na.rm=T)
c2$PrmDeathBc   <-c2$PrmDeathB   -mean(c2$PrmDeathB   ,na.rm=T)
c2$PrmDeathHc   <-c2$PrmDeathH   -mean(c2$PrmDeathH   ,na.rm=T)
c2$PrmDeathWc   <-c2$PrmDeathW   -mean(c2$PrmDeathW   ,na.rm=T)
c2$PrmDeath2_c  <-c2$PrmDeath2   -mean(c2$PrmDeath2   ,na.rm=T)
c2$PrmDeath2cc  <-c2$PrmDeath2c  -mean(c2$PrmDeath2c  ,na.rm=T)
c2$PrmDeath2Bc  <-c2$PrmDeath2B  -mean(c2$PrmDeath2B  ,na.rm=T)
c2$PrmDeath2Hc  <-c2$PrmDeath2H  -mean(c2$PrmDeath2H  ,na.rm=T)
c2$PrmDeath2Wc  <-c2$PrmDeath2W  -mean(c2$PrmDeath2W  ,na.rm=T)
c2$Suicidec     <-c2$Suicide     -mean(c2$Suicide     ,na.rm=T)
c2$Diabetc      <-c2$Diabet      -mean(c2$Diabet      ,na.rm=T)
c2$Obesityc     <-c2$Obesity     -mean(c2$Obesity     ,na.rm=T)
c2$Physicalc    <-c2$Physical    -mean(c2$Physical    ,na.rm=T)
c2$PoorHlthc    <-c2$PoorHlth    -mean(c2$PoorHlth    ,na.rm=T)
c2$PoorMHc      <-c2$PoorMH      -mean(c2$PoorMH      ,na.rm=T)
c2$PoorPhyc     <-c2$PoorPhy     -mean(c2$PoorPhy     ,na.rm=T)
c2$Sleepc       <-c2$Sleep       -mean(c2$Sleep       ,na.rm=T)
c2$DrugOdc      <-c2$DrugOd      -mean(c2$DrugOd      ,na.rm=T)
c2$DrugOdBc     <-c2$DrugOdB     -mean(c2$DrugOdB     ,na.rm=T)
c2$DrugOdHc     <-c2$DrugOdH     -mean(c2$DrugOdH     ,na.rm=T)
c2$DrugOdWc     <-c2$DrugOdW     -mean(c2$DrugOdW     ,na.rm=T)
c2$DWIDeathc    <-c2$DWIDeath    -mean(c2$DWIDeath    ,na.rm=T)
c2$EDrinkc      <-c2$EDrink      -mean(c2$EDrink      ,na.rm=T)
c2$Smokec       <-c2$Smoke       -mean(c2$Smoke       ,na.rm=T)
c2$FastFoodc    <-c2$FastFood    -mean(c2$FastFood    ,na.rm=T)
c2$FoodEnvc     <-c2$FoodEnv     -mean(c2$FoodEnv     ,na.rm=T)
c2$FoodInsc     <-c2$FoodIns     -mean(c2$FoodIns     ,na.rm=T)
c2$FrLunchc     <-c2$FrLunch     -mean(c2$FrLunch     ,na.rm=T)
c2$LAccFoodc    <-c2$LAccFood    -mean(c2$LAccFood    ,na.rm=T)
c2$Gymc         <-c2$Gym         -mean(c2$Gym         ,na.rm=T)
c2$Gym2c        <-c2$Gym2        -mean(c2$Gym2        ,na.rm=T)
c2$Inactivec    <-c2$Inactive    -mean(c2$Inactive    ,na.rm=T)
c2$HousCostc    <-c2$HousCost    -mean(c2$HousCost    ,na.rm=T)
c2$HousCostsc   <-c2$HousCosts   -mean(c2$HousCosts   ,na.rm=T)
c2$HousCrowdc   <-c2$HousCrowd   -mean(c2$HousCrowd   ,na.rm=T)
c2$Housingc     <-c2$Housing     -mean(c2$Housing     ,na.rm=T)
c2$HousPlumbc   <-c2$HousPlumb   -mean(c2$HousPlumb   ,na.rm=T)
c2$Insuredc     <-c2$Insured     -mean(c2$Insured     ,na.rm=T)
c2$InsuredAc    <-c2$InsuredA    -mean(c2$InsuredA    ,na.rm=T)
c2$InsuredCc    <-c2$InsuredC    -mean(c2$InsuredC    ,na.rm=T)
c2$JuvArrc      <-c2$JuvArr      -mean(c2$JuvArr      ,na.rm=T)
c2$Murderc      <-c2$Murder      -mean(c2$Murder      ,na.rm=T)
c2$Violentc     <-c2$Violent     -mean(c2$Violent     ,na.rm=T)
c2$LongCommc    <-c2$LongComm    -mean(c2$LongComm    ,na.rm=T)
c2$LowBWc       <-c2$LowBW       -mean(c2$LowBW       ,na.rm=T)
c2$LowBWBc      <-c2$LowBWB      -mean(c2$LowBWB      ,na.rm=T)
c2$LowBWHc      <-c2$LowBWH      -mean(c2$LowBWH      ,na.rm=T)
c2$LowBWWc      <-c2$LowBWW      -mean(c2$LowBWW      ,na.rm=T)
c2$TeenBthc     <-c2$TeenBth     -mean(c2$TeenBth     ,na.rm=T)
c2$TeenBthBc    <-c2$TeenBthB    -mean(c2$TeenBthB    ,na.rm=T)
c2$TeenBthHc    <-c2$TeenBthH    -mean(c2$TeenBthH    ,na.rm=T)
c2$TeenBthWc    <-c2$TeenBthW    -mean(c2$TeenBthW    ,na.rm=T)
c2$Mentalc      <-c2$Mental      -mean(c2$Mental      ,na.rm=T)
c2$MHPrvdc      <-c2$MHPrvd      -mean(c2$MHPrvd      ,na.rm=T)
c2$PCPc         <-c2$PCP         -mean(c2$PCP         ,na.rm=T)
c2$PCP2c        <-c2$PCP2        -mean(c2$PCP2        ,na.rm=T)
c2$Dentistc     <-c2$Dentist     -mean(c2$Dentist     ,na.rm=T)
c2$PrvtHospc    <-c2$PrvtHosp    -mean(c2$PrvtHosp    ,na.rm=T)
c2$PrvtHospBc   <-c2$PrvtHospB   -mean(c2$PrvtHospB   ,na.rm=T)
c2$PrvtHospHc   <-c2$PrvtHospH   -mean(c2$PrvtHospH   ,na.rm=T)
c2$PrvtHospWc   <-c2$PrvtHospW   -mean(c2$PrvtHospW   ,na.rm=T)
c2$SegBWc       <-c2$SegBW       -mean(c2$SegBW       ,na.rm=T)
c2$SegNWc       <-c2$SegNW       -mean(c2$SegNW       ,na.rm=T)
c2$SocAssoc     <-c2$SocAsso     -mean(c2$SocAsso     ,na.rm=T)
c2$SocSuppc     <-c2$SocSupp     -mean(c2$SocSupp     ,na.rm=T)
c2$MIECHVc      <-c2$MIECHV      -mean(c2$MIECHV      ,na.rm=T)
c2$NHVRCc       <-c2$NHVRC       -mean(c2$NHVRC       ,na.rm=T)
c2$HomeV2c      <-c2$HomeV2      -mean(c2$HomeV2      ,na.rm=T)
c2$FoodInsecurec<-c2$FoodInsecure-mean(c2$FoodInsecure,na.rm=T)

c2<-cbind(c2,demean(c2,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
c2m01<-lmer(Rpt2r~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m02<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m03<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m04<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m05<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m06<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m07<-lmer(Rpt2r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(c2m01,c2m02,c2m03,c2m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c2m04,c2m05,c2m06,c2m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c2m01CI<-confint(c2m01,method='boot',nsim=500,boot.type='perc')
c2m02CI<-confint(c2m02,method='boot',nsim=500,boot.type='perc')
c2m03CI<-confint(c2m03,method='boot',nsim=500,boot.type='perc')
c2m04CI<-confint(c2m04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c2m01)
check_collinearity(c2m02)
check_collinearity(c2m03)
check_collinearity(c2m04)
isSingular(c2m01)
isSingular(c2m02)
isSingular(c2m03)
isSingular(c2m04)




# Model building - MIECHV
c2m01a<-lmer(Rpt2r~Yearf+USDA_RUC+
               (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m02a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m03a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m04a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m05a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m06a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
c2m07a<-lmer(Rpt2r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
               IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
               CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
               ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
               (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=c2,control=lmerControl(optimizer="Nelder_Mead"))
tab_model(c2m01a,c2m02a,c2m03a,c2m04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c2m04a,c2m05a,c2m06a,c2m07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c2m01aCI<-confint(c2m01a,method='boot',nsim=500,boot.type='perc')
c2m02aCI<-confint(c2m02a,method='boot',nsim=500,boot.type='perc')
c2m03aCI<-confint(c2m03a,method='boot',nsim=500,boot.type='perc')
c2m04aCI<-confint(c2m04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c2m01a)
check_collinearity(c2m02a)
check_collinearity(c2m03a)
check_collinearity(c2m04a)
isSingular(c2m01a)
isSingular(c2m02a)
isSingular(c2m03a)
isSingular(c2m04a)



c2g02<-glmmTMB(Rpt2~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop2)),data=c2,family=nbinom2)
c2g02a<-glmmTMB(Rpt2~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop2)),data=c2,family=nbinom2)








###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

c3$CPopBPc      <-c3$CPopBP      -mean(c3$CPopBP      ,na.rm=T)
c3$CPopHPc      <-c3$CPopHP      -mean(c3$CPopHP      ,na.rm=T)
c3$ChildPTc     <-c3$ChildPT     -mean(c3$ChildPT     ,na.rm=T)
c3$ChildPWc     <-c3$ChildPW     -mean(c3$ChildPW     ,na.rm=T)
c3$ChildPBc     <-c3$ChildPB     -mean(c3$ChildPB     ,na.rm=T)
c3$ChildPHc     <-c3$ChildPH     -mean(c3$ChildPH     ,na.rm=T)
c3$CARatioT100c <-c3$CARatioT100 -mean(c3$CARatioT100 ,na.rm=T)
c3$CARatioW100c <-c3$CARatioW100 -mean(c3$CARatioW100 ,na.rm=T)
c3$CARatioB100c <-c3$CARatioB100 -mean(c3$CARatioB100 ,na.rm=T)
c3$CARatioH100c <-c3$CARatioH100 -mean(c3$CARatioH100 ,na.rm=T)
c3$MalePTc      <-c3$MalePT      -mean(c3$MalePT      ,na.rm=T)
c3$MalePWc      <-c3$MalePW      -mean(c3$MalePW      ,na.rm=T)
c3$MalePBc      <-c3$MalePB      -mean(c3$MalePB      ,na.rm=T)
c3$MalePHc      <-c3$MalePH      -mean(c3$MalePH      ,na.rm=T)
c3$MFRatioT100c <-c3$MFRatioT100 -mean(c3$MFRatioT100 ,na.rm=T)
c3$MFRatioW100c <-c3$MFRatioW100 -mean(c3$MFRatioW100 ,na.rm=T)
c3$MFRatioB100c <-c3$MFRatioB100 -mean(c3$MFRatioB100 ,na.rm=T)
c3$MFRatioH100c <-c3$MFRatioH100 -mean(c3$MFRatioH100 ,na.rm=T)
c3$ElderTc      <-c3$ElderT      -mean(c3$ElderT      ,na.rm=T)
c3$ElderWc      <-c3$ElderW      -mean(c3$ElderW      ,na.rm=T)
c3$ElderBc      <-c3$ElderB      -mean(c3$ElderB      ,na.rm=T)
c3$ElderHc      <-c3$ElderH      -mean(c3$ElderH      ,na.rm=T)
c3$SingleTc     <-c3$SingleT     -mean(c3$SingleT     ,na.rm=T)
c3$SingleWc     <-c3$SingleW     -mean(c3$SingleW     ,na.rm=T)
c3$SingleBc     <-c3$SingleB     -mean(c3$SingleB     ,na.rm=T)
c3$SingleHc     <-c3$SingleH     -mean(c3$SingleH     ,na.rm=T)
c3$FHeadTc      <-c3$FHeadT      -mean(c3$FHeadT      ,na.rm=T)
c3$FHeadWc      <-c3$FHeadW      -mean(c3$FHeadW      ,na.rm=T)
c3$FHeadBc      <-c3$FHeadB      -mean(c3$FHeadB      ,na.rm=T)
c3$FHeadHc      <-c3$FHeadH      -mean(c3$FHeadH      ,na.rm=T)
c3$NoHighTc     <-c3$NoHighT     -mean(c3$NoHighT     ,na.rm=T)
c3$NoHighWc     <-c3$NoHighW     -mean(c3$NoHighW     ,na.rm=T)
c3$NoHighBc     <-c3$NoHighB     -mean(c3$NoHighB     ,na.rm=T)
c3$NoHighHc     <-c3$NoHighH     -mean(c3$NoHighH     ,na.rm=T)
c3$UnempTc      <-c3$UnempT      -mean(c3$UnempT      ,na.rm=T)
c3$UnempWc      <-c3$UnempW      -mean(c3$UnempW      ,na.rm=T)
c3$UnempBc      <-c3$UnempB      -mean(c3$UnempB      ,na.rm=T)
c3$UnempHc      <-c3$UnempH      -mean(c3$UnempH      ,na.rm=T)
c3$CPovTc       <-c3$CPovT       -mean(c3$CPovT       ,na.rm=T)
c3$CPovWc       <-c3$CPovW       -mean(c3$CPovW       ,na.rm=T)
c3$CPovBc       <-c3$CPovB       -mean(c3$CPovB       ,na.rm=T)
c3$CPovHc       <-c3$CPovH       -mean(c3$CPovH       ,na.rm=T)
c3$CPov1c       <-c3$CPov1       -mean(c3$CPov1       ,na.rm=T)
c3$CPov2c       <-c3$CPov2       -mean(c3$CPov2       ,na.rm=T)
c3$CPov3c       <-c3$CPov3       -mean(c3$CPov3       ,na.rm=T)
c3$PubAsTc      <-c3$PubAsT      -mean(c3$PubAsT      ,na.rm=T)
c3$WelfarTc     <-c3$WelfarT     -mean(c3$WelfarT     ,na.rm=T)
c3$SnapTc       <-c3$SnapT       -mean(c3$SnapT       ,na.rm=T)
c3$SnapWc       <-c3$SnapW       -mean(c3$SnapW       ,na.rm=T)
c3$SnapBc       <-c3$SnapB       -mean(c3$SnapB       ,na.rm=T)
c3$SnapHc       <-c3$SnapH       -mean(c3$SnapH       ,na.rm=T)
c3$IncomeT1kc   <-c3$IncomeT1k   -mean(c3$IncomeT1k   ,na.rm=T)
c3$IncomeW1kc   <-c3$IncomeW1k   -mean(c3$IncomeW1k   ,na.rm=T)
c3$IncomeB1kc   <-c3$IncomeB1k   -mean(c3$IncomeB1k   ,na.rm=T)
c3$IncomeH1kc   <-c3$IncomeH1k   -mean(c3$IncomeH1k   ,na.rm=T)
c3$GiniT100c    <-c3$GiniT100    -mean(c3$GiniT100    ,na.rm=T)
c3$HValueT10kc  <-c3$HValueT10k  -mean(c3$HValueT10k  ,na.rm=T)
c3$MCostT100c   <-c3$MCostT100   -mean(c3$MCostT100   ,na.rm=T)
c3$OCostDT100c  <-c3$OCostDT100  -mean(c3$OCostDT100  ,na.rm=T)
c3$MRentDT100c  <-c3$MRentDT100  -mean(c3$MRentDT100  ,na.rm=T)
c3$OCostPTc     <-c3$OCostPT     -mean(c3$OCostPT     ,na.rm=T)
c3$MRentPTc     <-c3$MRentPT     -mean(c3$MRentPT     ,na.rm=T)
c3$MortgTc      <-c3$MortgT      -mean(c3$MortgT      ,na.rm=T)
c3$LangAPTc     <-c3$LangAPT     -mean(c3$LangAPT     ,na.rm=T)
c3$LangAPWc     <-c3$LangAPW     -mean(c3$LangAPW     ,na.rm=T)
c3$LangAPBc     <-c3$LangAPB     -mean(c3$LangAPB     ,na.rm=T)
c3$LangAPHc     <-c3$LangAPH     -mean(c3$LangAPH     ,na.rm=T)
c3$LangBPTc     <-c3$LangBPT     -mean(c3$LangBPT     ,na.rm=T)
c3$LangBPWc     <-c3$LangBPW     -mean(c3$LangBPW     ,na.rm=T)
c3$LangBPBc     <-c3$LangBPB     -mean(c3$LangBPB     ,na.rm=T)
c3$LangBPHc     <-c3$LangBPH     -mean(c3$LangBPH     ,na.rm=T)
c3$LangCPTc     <-c3$LangCPT     -mean(c3$LangCPT     ,na.rm=T)
c3$OutUsTc      <-c3$OutUsT      -mean(c3$OutUsT      ,na.rm=T)
c3$OutUsWc      <-c3$OutUsW      -mean(c3$OutUsW      ,na.rm=T)
c3$OutUsBc      <-c3$OutUsB      -mean(c3$OutUsB      ,na.rm=T)
c3$OutUsHc      <-c3$OutUsH      -mean(c3$OutUsH      ,na.rm=T)
c3$FBornTc      <-c3$FBornT      -mean(c3$FBornT      ,na.rm=T)
c3$FBornWc      <-c3$FBornW      -mean(c3$FBornW      ,na.rm=T)
c3$FBornBc      <-c3$FBornB      -mean(c3$FBornB      ,na.rm=T)
c3$FBornHc      <-c3$FBornH      -mean(c3$FBornH      ,na.rm=T)
c3$NotCtzTc     <-c3$NotCtzT     -mean(c3$NotCtzT     ,na.rm=T)
c3$NotCtzWc     <-c3$NotCtzW     -mean(c3$NotCtzW     ,na.rm=T)
c3$NotCtzBc     <-c3$NotCtzB     -mean(c3$NotCtzB     ,na.rm=T)
c3$NotCtzHc     <-c3$NotCtzH     -mean(c3$NotCtzH     ,na.rm=T)
c3$MoveTc       <-c3$MoveT       -mean(c3$MoveT       ,na.rm=T)
c3$MoveWc       <-c3$MoveW       -mean(c3$MoveW       ,na.rm=T)
c3$MoveBc       <-c3$MoveB       -mean(c3$MoveB       ,na.rm=T)
c3$MoveHc       <-c3$MoveH       -mean(c3$MoveH       ,na.rm=T)
c3$VacantTc     <-c3$VacantT     -mean(c3$VacantT     ,na.rm=T)
c3$OwnerTc      <-c3$OwnerT      -mean(c3$OwnerT      ,na.rm=T)
c3$OwnerWc      <-c3$OwnerW      -mean(c3$OwnerW      ,na.rm=T)
c3$OwnerBc      <-c3$OwnerB      -mean(c3$OwnerB      ,na.rm=T)
c3$OwnerHc      <-c3$OwnerH      -mean(c3$OwnerH      ,na.rm=T)
c3$CrowdTc      <-c3$CrowdT      -mean(c3$CrowdT      ,na.rm=T)
c3$CrowdWc      <-c3$CrowdW      -mean(c3$CrowdW      ,na.rm=T)
c3$CrowdBc      <-c3$CrowdB      -mean(c3$CrowdB      ,na.rm=T)
c3$CrowdHc      <-c3$CrowdH      -mean(c3$CrowdH      ,na.rm=T)
c3$MobileTc     <-c3$MobileT     -mean(c3$MobileT     ,na.rm=T)
c3$MobileWc     <-c3$MobileW     -mean(c3$MobileW     ,na.rm=T)
c3$MobileBc     <-c3$MobileB     -mean(c3$MobileB     ,na.rm=T)
c3$MobileHc     <-c3$MobileH     -mean(c3$MobileH     ,na.rm=T)
c3$DisablTc     <-c3$DisablT     -mean(c3$DisablT     ,na.rm=T)
c3$DisablWc     <-c3$DisablW     -mean(c3$DisablW     ,na.rm=T)
c3$DisablBc     <-c3$DisablB     -mean(c3$DisablB     ,na.rm=T)
c3$DisablHc     <-c3$DisablH     -mean(c3$DisablH     ,na.rm=T)
c3$DisablTCc    <-c3$DisablTC    -mean(c3$DisablTC    ,na.rm=T)
c3$DisablWCc    <-c3$DisablWC    -mean(c3$DisablWC    ,na.rm=T)
c3$DisablBCc    <-c3$DisablBC    -mean(c3$DisablBC    ,na.rm=T)
c3$DisablHCc    <-c3$DisablHC    -mean(c3$DisablHC    ,na.rm=T)
c3$DisablTMc    <-c3$DisablTM    -mean(c3$DisablTM    ,na.rm=T)
c3$DisablTFc    <-c3$DisablTF    -mean(c3$DisablTF    ,na.rm=T)
c3$Urban1c      <-c3$Urban1      -mean(c3$Urban1      ,na.rm=T)
c3$Urban2c      <-c3$Urban2      -mean(c3$Urban2      ,na.rm=T)
c3$LBWT1rc      <-c3$LBWT1r      -mean(c3$LBWT1r      ,na.rm=T)
c3$LBWM1rc      <-c3$LBWM1r      -mean(c3$LBWM1r      ,na.rm=T)
c3$LBWF1rc      <-c3$LBWF1r      -mean(c3$LBWF1r      ,na.rm=T)
c3$LBWW1rc      <-c3$LBWW1r      -mean(c3$LBWW1r      ,na.rm=T)
c3$LBWB1rc      <-c3$LBWB1r      -mean(c3$LBWB1r      ,na.rm=T)
c3$LBWH1rc      <-c3$LBWH1r      -mean(c3$LBWH1r      ,na.rm=T)
c3$PTBT1rc      <-c3$PTBT1r      -mean(c3$PTBT1r      ,na.rm=T)
c3$PTBM1rc      <-c3$PTBM1r      -mean(c3$PTBM1r      ,na.rm=T)
c3$PTBF1rc      <-c3$PTBF1r      -mean(c3$PTBF1r      ,na.rm=T)
c3$PTBW1rc      <-c3$PTBW1r      -mean(c3$PTBW1r      ,na.rm=T)
c3$PTBB1rc      <-c3$PTBB1r      -mean(c3$PTBB1r      ,na.rm=T)
c3$PTBH1rc      <-c3$PTBH1r      -mean(c3$PTBH1r      ,na.rm=T)
c3$PNCT1rc      <-c3$PNCT1r      -mean(c3$PNCT1r      ,na.rm=T)
c3$PNCM1rc      <-c3$PNCM1r      -mean(c3$PNCM1r      ,na.rm=T)
c3$PNCF1rc      <-c3$PNCF1r      -mean(c3$PNCF1r      ,na.rm=T)
c3$PNCW1rc      <-c3$PNCW1r      -mean(c3$PNCW1r      ,na.rm=T)
c3$PNCB1rc      <-c3$PNCB1r      -mean(c3$PNCB1r      ,na.rm=T)
c3$PNCH1rc      <-c3$PNCH1r      -mean(c3$PNCH1r      ,na.rm=T)
c3$TBBT1rc      <-c3$TBBT1r      -mean(c3$TBBT1r      ,na.rm=T)
c3$TBBM1rc      <-c3$TBBM1r      -mean(c3$TBBM1r      ,na.rm=T)
c3$TBBF1rc      <-c3$TBBF1r      -mean(c3$TBBF1r      ,na.rm=T)
c3$TBBW1rc      <-c3$TBBW1r      -mean(c3$TBBW1r      ,na.rm=T)
c3$TBBB1rc      <-c3$TBBB1r      -mean(c3$TBBB1r      ,na.rm=T)
c3$TBBH1rc      <-c3$TBBH1r      -mean(c3$TBBH1r      ,na.rm=T)
c3$TBTT1rc      <-c3$TBTT1r      -mean(c3$TBTT1r      ,na.rm=T)
c3$TBTM1rc      <-c3$TBTM1r      -mean(c3$TBTM1r      ,na.rm=T)
c3$TBTF1rc      <-c3$TBTF1r      -mean(c3$TBTF1r      ,na.rm=T)
c3$TBTW1rc      <-c3$TBTW1r      -mean(c3$TBTW1r      ,na.rm=T)
c3$TBTB1rc      <-c3$TBTB1r      -mean(c3$TBTB1r      ,na.rm=T)
c3$TBTH1rc      <-c3$TBTH1r      -mean(c3$TBTH1r      ,na.rm=T)
c3$LBWT5rc      <-c3$LBWT5r      -mean(c3$LBWT5r      ,na.rm=T)
c3$LBWM5rc      <-c3$LBWM5r      -mean(c3$LBWM5r      ,na.rm=T)
c3$LBWF5rc      <-c3$LBWF5r      -mean(c3$LBWF5r      ,na.rm=T)
c3$LBWW5rc      <-c3$LBWW5r      -mean(c3$LBWW5r      ,na.rm=T)
c3$LBWB5rc      <-c3$LBWB5r      -mean(c3$LBWB5r      ,na.rm=T)
c3$LBWH5rc      <-c3$LBWH5r      -mean(c3$LBWH5r      ,na.rm=T)
c3$PTBT5rc      <-c3$PTBT5r      -mean(c3$PTBT5r      ,na.rm=T)
c3$PTBM5rc      <-c3$PTBM5r      -mean(c3$PTBM5r      ,na.rm=T)
c3$PTBF5rc      <-c3$PTBF5r      -mean(c3$PTBF5r      ,na.rm=T)
c3$PTBW5rc      <-c3$PTBW5r      -mean(c3$PTBW5r      ,na.rm=T)
c3$PTBB5rc      <-c3$PTBB5r      -mean(c3$PTBB5r      ,na.rm=T)
c3$PTBH5rc      <-c3$PTBH5r      -mean(c3$PTBH5r      ,na.rm=T)
c3$PNCT5rc      <-c3$PNCT5r      -mean(c3$PNCT5r      ,na.rm=T)
c3$PNCM5rc      <-c3$PNCM5r      -mean(c3$PNCM5r      ,na.rm=T)
c3$PNCF5rc      <-c3$PNCF5r      -mean(c3$PNCF5r      ,na.rm=T)
c3$PNCW5rc      <-c3$PNCW5r      -mean(c3$PNCW5r      ,na.rm=T)
c3$PNCB5rc      <-c3$PNCB5r      -mean(c3$PNCB5r      ,na.rm=T)
c3$PNCH5rc      <-c3$PNCH5r      -mean(c3$PNCH5r      ,na.rm=T)
c3$TBBT5rc      <-c3$TBBT5r      -mean(c3$TBBT5r      ,na.rm=T)
c3$TBBM5rc      <-c3$TBBM5r      -mean(c3$TBBM5r      ,na.rm=T)
c3$TBBF5rc      <-c3$TBBF5r      -mean(c3$TBBF5r      ,na.rm=T)
c3$TBBW5rc      <-c3$TBBW5r      -mean(c3$TBBW5r      ,na.rm=T)
c3$TBBB5rc      <-c3$TBBB5r      -mean(c3$TBBB5r      ,na.rm=T)
c3$TBBH5rc      <-c3$TBBH5r      -mean(c3$TBBH5r      ,na.rm=T)
c3$TBTT5rc      <-c3$TBTT5r      -mean(c3$TBTT5r      ,na.rm=T)
c3$TBTM5rc      <-c3$TBTM5r      -mean(c3$TBTM5r      ,na.rm=T)
c3$TBTF5rc      <-c3$TBTF5r      -mean(c3$TBTF5r      ,na.rm=T)
c3$TBTW5rc      <-c3$TBTW5r      -mean(c3$TBTW5r      ,na.rm=T)
c3$TBTB5rc      <-c3$TBTB5r      -mean(c3$TBTB5r      ,na.rm=T)
c3$TBTH5rc      <-c3$TBTH5r      -mean(c3$TBTH5r      ,na.rm=T)
c3$Opioidc      <-c3$Opioid      -mean(c3$Opioid      ,na.rm=T)
c3$LifeExpc     <-c3$LifeExp     -mean(c3$LifeExp     ,na.rm=T)
c3$LifeExpBc    <-c3$LifeExpB    -mean(c3$LifeExpB    ,na.rm=T)
c3$LifeExpHc    <-c3$LifeExpH    -mean(c3$LifeExpH    ,na.rm=T)
c3$LifeExpWc    <-c3$LifeExpW    -mean(c3$LifeExpW    ,na.rm=T)
c3$ChdDeathc    <-c3$ChdDeath    -mean(c3$ChdDeath    ,na.rm=T)
c3$ChdDeathBc   <-c3$ChdDeathB   -mean(c3$ChdDeathB   ,na.rm=T)
c3$ChdDeathHc   <-c3$ChdDeathH   -mean(c3$ChdDeathH   ,na.rm=T)
c3$ChdDeathWc   <-c3$ChdDeathW   -mean(c3$ChdDeathW   ,na.rm=T)
c3$InfDeathc    <-c3$InfDeath    -mean(c3$InfDeath    ,na.rm=T)
c3$InfDeathBc   <-c3$InfDeathB   -mean(c3$InfDeathB   ,na.rm=T)
c3$InfDeathHc   <-c3$InfDeathH   -mean(c3$InfDeathH   ,na.rm=T)
c3$InfDeathWc   <-c3$InfDeathW   -mean(c3$InfDeathW   ,na.rm=T)
c3$Injuryc      <-c3$Injury      -mean(c3$Injury      ,na.rm=T)
c3$InjuryBc     <-c3$InjuryB     -mean(c3$InjuryB     ,na.rm=T)
c3$InjuryHc     <-c3$InjuryH     -mean(c3$InjuryH     ,na.rm=T)
c3$InjuryWc     <-c3$InjuryW     -mean(c3$InjuryW     ,na.rm=T)
c3$GunDeathc    <-c3$GunDeath    -mean(c3$GunDeath    ,na.rm=T)
c3$GunDeathBc   <-c3$GunDeathB   -mean(c3$GunDeathB   ,na.rm=T)
c3$GunDeathWc   <-c3$GunDeathW   -mean(c3$GunDeathW   ,na.rm=T)
c3$PrmDeath_c   <-c3$PrmDeath    -mean(c3$PrmDeath    ,na.rm=T)
c3$PrmDeathcc   <-c3$PrmDeathc   -mean(c3$PrmDeathc   ,na.rm=T)
c3$PrmDeathBc   <-c3$PrmDeathB   -mean(c3$PrmDeathB   ,na.rm=T)
c3$PrmDeathHc   <-c3$PrmDeathH   -mean(c3$PrmDeathH   ,na.rm=T)
c3$PrmDeathWc   <-c3$PrmDeathW   -mean(c3$PrmDeathW   ,na.rm=T)
c3$PrmDeath2_c  <-c3$PrmDeath2   -mean(c3$PrmDeath2   ,na.rm=T)
c3$PrmDeath2cc  <-c3$PrmDeath2c  -mean(c3$PrmDeath2c  ,na.rm=T)
c3$PrmDeath2Bc  <-c3$PrmDeath2B  -mean(c3$PrmDeath2B  ,na.rm=T)
c3$PrmDeath2Hc  <-c3$PrmDeath2H  -mean(c3$PrmDeath2H  ,na.rm=T)
c3$PrmDeath2Wc  <-c3$PrmDeath2W  -mean(c3$PrmDeath2W  ,na.rm=T)
c3$Suicidec     <-c3$Suicide     -mean(c3$Suicide     ,na.rm=T)
c3$Diabetc      <-c3$Diabet      -mean(c3$Diabet      ,na.rm=T)
c3$Obesityc     <-c3$Obesity     -mean(c3$Obesity     ,na.rm=T)
c3$Physicalc    <-c3$Physical    -mean(c3$Physical    ,na.rm=T)
c3$PoorHlthc    <-c3$PoorHlth    -mean(c3$PoorHlth    ,na.rm=T)
c3$PoorMHc      <-c3$PoorMH      -mean(c3$PoorMH      ,na.rm=T)
c3$PoorPhyc     <-c3$PoorPhy     -mean(c3$PoorPhy     ,na.rm=T)
c3$Sleepc       <-c3$Sleep       -mean(c3$Sleep       ,na.rm=T)
c3$DrugOdc      <-c3$DrugOd      -mean(c3$DrugOd      ,na.rm=T)
c3$DrugOdBc     <-c3$DrugOdB     -mean(c3$DrugOdB     ,na.rm=T)
c3$DrugOdHc     <-c3$DrugOdH     -mean(c3$DrugOdH     ,na.rm=T)
c3$DrugOdWc     <-c3$DrugOdW     -mean(c3$DrugOdW     ,na.rm=T)
c3$DWIDeathc    <-c3$DWIDeath    -mean(c3$DWIDeath    ,na.rm=T)
c3$EDrinkc      <-c3$EDrink      -mean(c3$EDrink      ,na.rm=T)
c3$Smokec       <-c3$Smoke       -mean(c3$Smoke       ,na.rm=T)
c3$FastFoodc    <-c3$FastFood    -mean(c3$FastFood    ,na.rm=T)
c3$FoodEnvc     <-c3$FoodEnv     -mean(c3$FoodEnv     ,na.rm=T)
c3$FoodInsc     <-c3$FoodIns     -mean(c3$FoodIns     ,na.rm=T)
c3$FrLunchc     <-c3$FrLunch     -mean(c3$FrLunch     ,na.rm=T)
c3$LAccFoodc    <-c3$LAccFood    -mean(c3$LAccFood    ,na.rm=T)
c3$Gymc         <-c3$Gym         -mean(c3$Gym         ,na.rm=T)
c3$Gym2c        <-c3$Gym2        -mean(c3$Gym2        ,na.rm=T)
c3$Inactivec    <-c3$Inactive    -mean(c3$Inactive    ,na.rm=T)
c3$HousCostc    <-c3$HousCost    -mean(c3$HousCost    ,na.rm=T)
c3$HousCostsc   <-c3$HousCosts   -mean(c3$HousCosts   ,na.rm=T)
c3$HousCrowdc   <-c3$HousCrowd   -mean(c3$HousCrowd   ,na.rm=T)
c3$Housingc     <-c3$Housing     -mean(c3$Housing     ,na.rm=T)
c3$HousPlumbc   <-c3$HousPlumb   -mean(c3$HousPlumb   ,na.rm=T)
c3$Insuredc     <-c3$Insured     -mean(c3$Insured     ,na.rm=T)
c3$InsuredAc    <-c3$InsuredA    -mean(c3$InsuredA    ,na.rm=T)
c3$InsuredCc    <-c3$InsuredC    -mean(c3$InsuredC    ,na.rm=T)
c3$JuvArrc      <-c3$JuvArr      -mean(c3$JuvArr      ,na.rm=T)
c3$Murderc      <-c3$Murder      -mean(c3$Murder      ,na.rm=T)
c3$Violentc     <-c3$Violent     -mean(c3$Violent     ,na.rm=T)
c3$LongCommc    <-c3$LongComm    -mean(c3$LongComm    ,na.rm=T)
c3$LowBWc       <-c3$LowBW       -mean(c3$LowBW       ,na.rm=T)
c3$LowBWBc      <-c3$LowBWB      -mean(c3$LowBWB      ,na.rm=T)
c3$LowBWHc      <-c3$LowBWH      -mean(c3$LowBWH      ,na.rm=T)
c3$LowBWWc      <-c3$LowBWW      -mean(c3$LowBWW      ,na.rm=T)
c3$TeenBthc     <-c3$TeenBth     -mean(c3$TeenBth     ,na.rm=T)
c3$TeenBthBc    <-c3$TeenBthB    -mean(c3$TeenBthB    ,na.rm=T)
c3$TeenBthHc    <-c3$TeenBthH    -mean(c3$TeenBthH    ,na.rm=T)
c3$TeenBthWc    <-c3$TeenBthW    -mean(c3$TeenBthW    ,na.rm=T)
c3$Mentalc      <-c3$Mental      -mean(c3$Mental      ,na.rm=T)
c3$MHPrvdc      <-c3$MHPrvd      -mean(c3$MHPrvd      ,na.rm=T)
c3$PCPc         <-c3$PCP         -mean(c3$PCP         ,na.rm=T)
c3$PCP2c        <-c3$PCP2        -mean(c3$PCP2        ,na.rm=T)
c3$Dentistc     <-c3$Dentist     -mean(c3$Dentist     ,na.rm=T)
c3$PrvtHospc    <-c3$PrvtHosp    -mean(c3$PrvtHosp    ,na.rm=T)
c3$PrvtHospBc   <-c3$PrvtHospB   -mean(c3$PrvtHospB   ,na.rm=T)
c3$PrvtHospHc   <-c3$PrvtHospH   -mean(c3$PrvtHospH   ,na.rm=T)
c3$PrvtHospWc   <-c3$PrvtHospW   -mean(c3$PrvtHospW   ,na.rm=T)
c3$SegBWc       <-c3$SegBW       -mean(c3$SegBW       ,na.rm=T)
c3$SegNWc       <-c3$SegNW       -mean(c3$SegNW       ,na.rm=T)
c3$SocAssoc     <-c3$SocAsso     -mean(c3$SocAsso     ,na.rm=T)
c3$SocSuppc     <-c3$SocSupp     -mean(c3$SocSupp     ,na.rm=T)
c3$MIECHVc      <-c3$MIECHV      -mean(c3$MIECHV      ,na.rm=T)
c3$NHVRCc       <-c3$NHVRC       -mean(c3$NHVRC       ,na.rm=T)
c3$HomeV2c      <-c3$HomeV2      -mean(c3$HomeV2      ,na.rm=T)
c3$FoodInsecurec<-c3$FoodInsecure-mean(c3$FoodInsecure,na.rm=T)

c3<-cbind(c3,demean(c3,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))



# Model building
c3m01<-lmer(Rpt3r~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m02<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m03<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m04<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m05<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m06<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m07<-lmer(Rpt3r~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(c3m01,c3m02,c3m03,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c3m04,c3m05,c3m06,c3m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c3m01CI<-confint(c3m01,method='boot',nsim=500,boot.type='perc')
c3m02CI<-confint(c3m02,method='boot',nsim=500,boot.type='perc')
c3m03CI<-confint(c3m03,method='boot',nsim=500,boot.type='perc')
c3m04CI<-confint(c3m04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c3m01)
check_collinearity(c3m02)
check_collinearity(c3m03)
check_collinearity(c3m04)
isSingular(c3m01)
isSingular(c3m02)
isSingular(c3m03)
isSingular(c3m04)




# Model building
c3m01a<-lmer(Rpt3r~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m02a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m03a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m04a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m05a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m06a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))
c3m07a<-lmer(Rpt3r~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=c3,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(c3m01a,c3m02a,c3m03a,c3m04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c3m04a,c3m05a,c3m06a,c3m07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
c3m01aCI<-confint(c3m01a,method='boot',nsim=500,boot.type='perc')
c3m02aCI<-confint(c3m02a,method='boot',nsim=500,boot.type='perc')
c3m03aCI<-confint(c3m03a,method='boot',nsim=500,boot.type='perc')
c3m04aCI<-confint(c3m04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c3m01a)
check_collinearity(c3m02a)
check_collinearity(c3m03a)
check_collinearity(c3m04a)
isSingular(c3m01a)
isSingular(c3m02a)
isSingular(c3m03a)
isSingular(c3m04a)



tab_model(c1m04,c2m04,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c1m04a,c2m04a,c3m04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)



c3g02<-glmmTMB(Rpt3~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop3)),data=c3,family=nbinom2)
c3g02a<-glmmTMB(Rpt3~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPop3)),data=c3,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cm$CPopBPc      <-cm$CPopBP      -mean(cm$CPopBP      ,na.rm=T)
cm$CPopHPc      <-cm$CPopHP      -mean(cm$CPopHP      ,na.rm=T)
cm$ChildPTc     <-cm$ChildPT     -mean(cm$ChildPT     ,na.rm=T)
cm$ChildPWc     <-cm$ChildPW     -mean(cm$ChildPW     ,na.rm=T)
cm$ChildPBc     <-cm$ChildPB     -mean(cm$ChildPB     ,na.rm=T)
cm$ChildPHc     <-cm$ChildPH     -mean(cm$ChildPH     ,na.rm=T)
cm$CARatioT100c <-cm$CARatioT100 -mean(cm$CARatioT100 ,na.rm=T)
cm$CARatioW100c <-cm$CARatioW100 -mean(cm$CARatioW100 ,na.rm=T)
cm$CARatioB100c <-cm$CARatioB100 -mean(cm$CARatioB100 ,na.rm=T)
cm$CARatioH100c <-cm$CARatioH100 -mean(cm$CARatioH100 ,na.rm=T)
cm$MalePTc      <-cm$MalePT      -mean(cm$MalePT      ,na.rm=T)
cm$MalePWc      <-cm$MalePW      -mean(cm$MalePW      ,na.rm=T)
cm$MalePBc      <-cm$MalePB      -mean(cm$MalePB      ,na.rm=T)
cm$MalePHc      <-cm$MalePH      -mean(cm$MalePH      ,na.rm=T)
cm$MFRatioT100c <-cm$MFRatioT100 -mean(cm$MFRatioT100 ,na.rm=T)
cm$MFRatioW100c <-cm$MFRatioW100 -mean(cm$MFRatioW100 ,na.rm=T)
cm$MFRatioB100c <-cm$MFRatioB100 -mean(cm$MFRatioB100 ,na.rm=T)
cm$MFRatioH100c <-cm$MFRatioH100 -mean(cm$MFRatioH100 ,na.rm=T)
cm$ElderTc      <-cm$ElderT      -mean(cm$ElderT      ,na.rm=T)
cm$ElderWc      <-cm$ElderW      -mean(cm$ElderW      ,na.rm=T)
cm$ElderBc      <-cm$ElderB      -mean(cm$ElderB      ,na.rm=T)
cm$ElderHc      <-cm$ElderH      -mean(cm$ElderH      ,na.rm=T)
cm$SingleTc     <-cm$SingleT     -mean(cm$SingleT     ,na.rm=T)
cm$SingleWc     <-cm$SingleW     -mean(cm$SingleW     ,na.rm=T)
cm$SingleBc     <-cm$SingleB     -mean(cm$SingleB     ,na.rm=T)
cm$SingleHc     <-cm$SingleH     -mean(cm$SingleH     ,na.rm=T)
cm$FHeadTc      <-cm$FHeadT      -mean(cm$FHeadT      ,na.rm=T)
cm$FHeadWc      <-cm$FHeadW      -mean(cm$FHeadW      ,na.rm=T)
cm$FHeadBc      <-cm$FHeadB      -mean(cm$FHeadB      ,na.rm=T)
cm$FHeadHc      <-cm$FHeadH      -mean(cm$FHeadH      ,na.rm=T)
cm$NoHighTc     <-cm$NoHighT     -mean(cm$NoHighT     ,na.rm=T)
cm$NoHighWc     <-cm$NoHighW     -mean(cm$NoHighW     ,na.rm=T)
cm$NoHighBc     <-cm$NoHighB     -mean(cm$NoHighB     ,na.rm=T)
cm$NoHighHc     <-cm$NoHighH     -mean(cm$NoHighH     ,na.rm=T)
cm$UnempTc      <-cm$UnempT      -mean(cm$UnempT      ,na.rm=T)
cm$UnempWc      <-cm$UnempW      -mean(cm$UnempW      ,na.rm=T)
cm$UnempBc      <-cm$UnempB      -mean(cm$UnempB      ,na.rm=T)
cm$UnempHc      <-cm$UnempH      -mean(cm$UnempH      ,na.rm=T)
cm$CPovTc       <-cm$CPovT       -mean(cm$CPovT       ,na.rm=T)
cm$CPovWc       <-cm$CPovW       -mean(cm$CPovW       ,na.rm=T)
cm$CPovBc       <-cm$CPovB       -mean(cm$CPovB       ,na.rm=T)
cm$CPovHc       <-cm$CPovH       -mean(cm$CPovH       ,na.rm=T)
cm$CPov1c       <-cm$CPov1       -mean(cm$CPov1       ,na.rm=T)
cm$CPov2c       <-cm$CPov2       -mean(cm$CPov2       ,na.rm=T)
cm$CPov3c       <-cm$CPov3       -mean(cm$CPov3       ,na.rm=T)
cm$PubAsTc      <-cm$PubAsT      -mean(cm$PubAsT      ,na.rm=T)
cm$WelfarTc     <-cm$WelfarT     -mean(cm$WelfarT     ,na.rm=T)
cm$SnapTc       <-cm$SnapT       -mean(cm$SnapT       ,na.rm=T)
cm$SnapWc       <-cm$SnapW       -mean(cm$SnapW       ,na.rm=T)
cm$SnapBc       <-cm$SnapB       -mean(cm$SnapB       ,na.rm=T)
cm$SnapHc       <-cm$SnapH       -mean(cm$SnapH       ,na.rm=T)
cm$IncomeT1kc   <-cm$IncomeT1k   -mean(cm$IncomeT1k   ,na.rm=T)
cm$IncomeW1kc   <-cm$IncomeW1k   -mean(cm$IncomeW1k   ,na.rm=T)
cm$IncomeB1kc   <-cm$IncomeB1k   -mean(cm$IncomeB1k   ,na.rm=T)
cm$IncomeH1kc   <-cm$IncomeH1k   -mean(cm$IncomeH1k   ,na.rm=T)
cm$GiniT100c    <-cm$GiniT100    -mean(cm$GiniT100    ,na.rm=T)
cm$HValueT10kc  <-cm$HValueT10k  -mean(cm$HValueT10k  ,na.rm=T)
cm$MCostT100c   <-cm$MCostT100   -mean(cm$MCostT100   ,na.rm=T)
cm$OCostDT100c  <-cm$OCostDT100  -mean(cm$OCostDT100  ,na.rm=T)
cm$MRentDT100c  <-cm$MRentDT100  -mean(cm$MRentDT100  ,na.rm=T)
cm$OCostPTc     <-cm$OCostPT     -mean(cm$OCostPT     ,na.rm=T)
cm$MRentPTc     <-cm$MRentPT     -mean(cm$MRentPT     ,na.rm=T)
cm$MortgTc      <-cm$MortgT      -mean(cm$MortgT      ,na.rm=T)
cm$LangAPTc     <-cm$LangAPT     -mean(cm$LangAPT     ,na.rm=T)
cm$LangAPWc     <-cm$LangAPW     -mean(cm$LangAPW     ,na.rm=T)
cm$LangAPBc     <-cm$LangAPB     -mean(cm$LangAPB     ,na.rm=T)
cm$LangAPHc     <-cm$LangAPH     -mean(cm$LangAPH     ,na.rm=T)
cm$LangBPTc     <-cm$LangBPT     -mean(cm$LangBPT     ,na.rm=T)
cm$LangBPWc     <-cm$LangBPW     -mean(cm$LangBPW     ,na.rm=T)
cm$LangBPBc     <-cm$LangBPB     -mean(cm$LangBPB     ,na.rm=T)
cm$LangBPHc     <-cm$LangBPH     -mean(cm$LangBPH     ,na.rm=T)
cm$LangCPTc     <-cm$LangCPT     -mean(cm$LangCPT     ,na.rm=T)
cm$OutUsTc      <-cm$OutUsT      -mean(cm$OutUsT      ,na.rm=T)
cm$OutUsWc      <-cm$OutUsW      -mean(cm$OutUsW      ,na.rm=T)
cm$OutUsBc      <-cm$OutUsB      -mean(cm$OutUsB      ,na.rm=T)
cm$OutUsHc      <-cm$OutUsH      -mean(cm$OutUsH      ,na.rm=T)
cm$FBornTc      <-cm$FBornT      -mean(cm$FBornT      ,na.rm=T)
cm$FBornWc      <-cm$FBornW      -mean(cm$FBornW      ,na.rm=T)
cm$FBornBc      <-cm$FBornB      -mean(cm$FBornB      ,na.rm=T)
cm$FBornHc      <-cm$FBornH      -mean(cm$FBornH      ,na.rm=T)
cm$NotCtzTc     <-cm$NotCtzT     -mean(cm$NotCtzT     ,na.rm=T)
cm$NotCtzWc     <-cm$NotCtzW     -mean(cm$NotCtzW     ,na.rm=T)
cm$NotCtzBc     <-cm$NotCtzB     -mean(cm$NotCtzB     ,na.rm=T)
cm$NotCtzHc     <-cm$NotCtzH     -mean(cm$NotCtzH     ,na.rm=T)
cm$MoveTc       <-cm$MoveT       -mean(cm$MoveT       ,na.rm=T)
cm$MoveWc       <-cm$MoveW       -mean(cm$MoveW       ,na.rm=T)
cm$MoveBc       <-cm$MoveB       -mean(cm$MoveB       ,na.rm=T)
cm$MoveHc       <-cm$MoveH       -mean(cm$MoveH       ,na.rm=T)
cm$VacantTc     <-cm$VacantT     -mean(cm$VacantT     ,na.rm=T)
cm$OwnerTc      <-cm$OwnerT      -mean(cm$OwnerT      ,na.rm=T)
cm$OwnerWc      <-cm$OwnerW      -mean(cm$OwnerW      ,na.rm=T)
cm$OwnerBc      <-cm$OwnerB      -mean(cm$OwnerB      ,na.rm=T)
cm$OwnerHc      <-cm$OwnerH      -mean(cm$OwnerH      ,na.rm=T)
cm$CrowdTc      <-cm$CrowdT      -mean(cm$CrowdT      ,na.rm=T)
cm$CrowdWc      <-cm$CrowdW      -mean(cm$CrowdW      ,na.rm=T)
cm$CrowdBc      <-cm$CrowdB      -mean(cm$CrowdB      ,na.rm=T)
cm$CrowdHc      <-cm$CrowdH      -mean(cm$CrowdH      ,na.rm=T)
cm$MobileTc     <-cm$MobileT     -mean(cm$MobileT     ,na.rm=T)
cm$MobileWc     <-cm$MobileW     -mean(cm$MobileW     ,na.rm=T)
cm$MobileBc     <-cm$MobileB     -mean(cm$MobileB     ,na.rm=T)
cm$MobileHc     <-cm$MobileH     -mean(cm$MobileH     ,na.rm=T)
cm$DisablTc     <-cm$DisablT     -mean(cm$DisablT     ,na.rm=T)
cm$DisablWc     <-cm$DisablW     -mean(cm$DisablW     ,na.rm=T)
cm$DisablBc     <-cm$DisablB     -mean(cm$DisablB     ,na.rm=T)
cm$DisablHc     <-cm$DisablH     -mean(cm$DisablH     ,na.rm=T)
cm$DisablTCc    <-cm$DisablTC    -mean(cm$DisablTC    ,na.rm=T)
cm$DisablWCc    <-cm$DisablWC    -mean(cm$DisablWC    ,na.rm=T)
cm$DisablBCc    <-cm$DisablBC    -mean(cm$DisablBC    ,na.rm=T)
cm$DisablHCc    <-cm$DisablHC    -mean(cm$DisablHC    ,na.rm=T)
cm$DisablTMc    <-cm$DisablTM    -mean(cm$DisablTM    ,na.rm=T)
cm$DisablTFc    <-cm$DisablTF    -mean(cm$DisablTF    ,na.rm=T)
cm$Urban1c      <-cm$Urban1      -mean(cm$Urban1      ,na.rm=T)
cm$Urban2c      <-cm$Urban2      -mean(cm$Urban2      ,na.rm=T)
cm$LBWT1rc      <-cm$LBWT1r      -mean(cm$LBWT1r      ,na.rm=T)
cm$LBWM1rc      <-cm$LBWM1r      -mean(cm$LBWM1r      ,na.rm=T)
cm$LBWF1rc      <-cm$LBWF1r      -mean(cm$LBWF1r      ,na.rm=T)
cm$LBWW1rc      <-cm$LBWW1r      -mean(cm$LBWW1r      ,na.rm=T)
cm$LBWB1rc      <-cm$LBWB1r      -mean(cm$LBWB1r      ,na.rm=T)
cm$LBWH1rc      <-cm$LBWH1r      -mean(cm$LBWH1r      ,na.rm=T)
cm$PTBT1rc      <-cm$PTBT1r      -mean(cm$PTBT1r      ,na.rm=T)
cm$PTBM1rc      <-cm$PTBM1r      -mean(cm$PTBM1r      ,na.rm=T)
cm$PTBF1rc      <-cm$PTBF1r      -mean(cm$PTBF1r      ,na.rm=T)
cm$PTBW1rc      <-cm$PTBW1r      -mean(cm$PTBW1r      ,na.rm=T)
cm$PTBB1rc      <-cm$PTBB1r      -mean(cm$PTBB1r      ,na.rm=T)
cm$PTBH1rc      <-cm$PTBH1r      -mean(cm$PTBH1r      ,na.rm=T)
cm$PNCT1rc      <-cm$PNCT1r      -mean(cm$PNCT1r      ,na.rm=T)
cm$PNCM1rc      <-cm$PNCM1r      -mean(cm$PNCM1r      ,na.rm=T)
cm$PNCF1rc      <-cm$PNCF1r      -mean(cm$PNCF1r      ,na.rm=T)
cm$PNCW1rc      <-cm$PNCW1r      -mean(cm$PNCW1r      ,na.rm=T)
cm$PNCB1rc      <-cm$PNCB1r      -mean(cm$PNCB1r      ,na.rm=T)
cm$PNCH1rc      <-cm$PNCH1r      -mean(cm$PNCH1r      ,na.rm=T)
cm$TBBT1rc      <-cm$TBBT1r      -mean(cm$TBBT1r      ,na.rm=T)
cm$TBBM1rc      <-cm$TBBM1r      -mean(cm$TBBM1r      ,na.rm=T)
cm$TBBF1rc      <-cm$TBBF1r      -mean(cm$TBBF1r      ,na.rm=T)
cm$TBBW1rc      <-cm$TBBW1r      -mean(cm$TBBW1r      ,na.rm=T)
cm$TBBB1rc      <-cm$TBBB1r      -mean(cm$TBBB1r      ,na.rm=T)
cm$TBBH1rc      <-cm$TBBH1r      -mean(cm$TBBH1r      ,na.rm=T)
cm$TBTT1rc      <-cm$TBTT1r      -mean(cm$TBTT1r      ,na.rm=T)
cm$TBTM1rc      <-cm$TBTM1r      -mean(cm$TBTM1r      ,na.rm=T)
cm$TBTF1rc      <-cm$TBTF1r      -mean(cm$TBTF1r      ,na.rm=T)
cm$TBTW1rc      <-cm$TBTW1r      -mean(cm$TBTW1r      ,na.rm=T)
cm$TBTB1rc      <-cm$TBTB1r      -mean(cm$TBTB1r      ,na.rm=T)
cm$TBTH1rc      <-cm$TBTH1r      -mean(cm$TBTH1r      ,na.rm=T)
cm$LBWT5rc      <-cm$LBWT5r      -mean(cm$LBWT5r      ,na.rm=T)
cm$LBWM5rc      <-cm$LBWM5r      -mean(cm$LBWM5r      ,na.rm=T)
cm$LBWF5rc      <-cm$LBWF5r      -mean(cm$LBWF5r      ,na.rm=T)
cm$LBWW5rc      <-cm$LBWW5r      -mean(cm$LBWW5r      ,na.rm=T)
cm$LBWB5rc      <-cm$LBWB5r      -mean(cm$LBWB5r      ,na.rm=T)
cm$LBWH5rc      <-cm$LBWH5r      -mean(cm$LBWH5r      ,na.rm=T)
cm$PTBT5rc      <-cm$PTBT5r      -mean(cm$PTBT5r      ,na.rm=T)
cm$PTBM5rc      <-cm$PTBM5r      -mean(cm$PTBM5r      ,na.rm=T)
cm$PTBF5rc      <-cm$PTBF5r      -mean(cm$PTBF5r      ,na.rm=T)
cm$PTBW5rc      <-cm$PTBW5r      -mean(cm$PTBW5r      ,na.rm=T)
cm$PTBB5rc      <-cm$PTBB5r      -mean(cm$PTBB5r      ,na.rm=T)
cm$PTBH5rc      <-cm$PTBH5r      -mean(cm$PTBH5r      ,na.rm=T)
cm$PNCT5rc      <-cm$PNCT5r      -mean(cm$PNCT5r      ,na.rm=T)
cm$PNCM5rc      <-cm$PNCM5r      -mean(cm$PNCM5r      ,na.rm=T)
cm$PNCF5rc      <-cm$PNCF5r      -mean(cm$PNCF5r      ,na.rm=T)
cm$PNCW5rc      <-cm$PNCW5r      -mean(cm$PNCW5r      ,na.rm=T)
cm$PNCB5rc      <-cm$PNCB5r      -mean(cm$PNCB5r      ,na.rm=T)
cm$PNCH5rc      <-cm$PNCH5r      -mean(cm$PNCH5r      ,na.rm=T)
cm$TBBT5rc      <-cm$TBBT5r      -mean(cm$TBBT5r      ,na.rm=T)
cm$TBBM5rc      <-cm$TBBM5r      -mean(cm$TBBM5r      ,na.rm=T)
cm$TBBF5rc      <-cm$TBBF5r      -mean(cm$TBBF5r      ,na.rm=T)
cm$TBBW5rc      <-cm$TBBW5r      -mean(cm$TBBW5r      ,na.rm=T)
cm$TBBB5rc      <-cm$TBBB5r      -mean(cm$TBBB5r      ,na.rm=T)
cm$TBBH5rc      <-cm$TBBH5r      -mean(cm$TBBH5r      ,na.rm=T)
cm$TBTT5rc      <-cm$TBTT5r      -mean(cm$TBTT5r      ,na.rm=T)
cm$TBTM5rc      <-cm$TBTM5r      -mean(cm$TBTM5r      ,na.rm=T)
cm$TBTF5rc      <-cm$TBTF5r      -mean(cm$TBTF5r      ,na.rm=T)
cm$TBTW5rc      <-cm$TBTW5r      -mean(cm$TBTW5r      ,na.rm=T)
cm$TBTB5rc      <-cm$TBTB5r      -mean(cm$TBTB5r      ,na.rm=T)
cm$TBTH5rc      <-cm$TBTH5r      -mean(cm$TBTH5r      ,na.rm=T)
cm$Opioidc      <-cm$Opioid      -mean(cm$Opioid      ,na.rm=T)
cm$LifeExpc     <-cm$LifeExp     -mean(cm$LifeExp     ,na.rm=T)
cm$LifeExpBc    <-cm$LifeExpB    -mean(cm$LifeExpB    ,na.rm=T)
cm$LifeExpHc    <-cm$LifeExpH    -mean(cm$LifeExpH    ,na.rm=T)
cm$LifeExpWc    <-cm$LifeExpW    -mean(cm$LifeExpW    ,na.rm=T)
cm$ChdDeathc    <-cm$ChdDeath    -mean(cm$ChdDeath    ,na.rm=T)
cm$ChdDeathBc   <-cm$ChdDeathB   -mean(cm$ChdDeathB   ,na.rm=T)
cm$ChdDeathHc   <-cm$ChdDeathH   -mean(cm$ChdDeathH   ,na.rm=T)
cm$ChdDeathWc   <-cm$ChdDeathW   -mean(cm$ChdDeathW   ,na.rm=T)
cm$InfDeathc    <-cm$InfDeath    -mean(cm$InfDeath    ,na.rm=T)
cm$InfDeathBc   <-cm$InfDeathB   -mean(cm$InfDeathB   ,na.rm=T)
cm$InfDeathHc   <-cm$InfDeathH   -mean(cm$InfDeathH   ,na.rm=T)
cm$InfDeathWc   <-cm$InfDeathW   -mean(cm$InfDeathW   ,na.rm=T)
cm$Injuryc      <-cm$Injury      -mean(cm$Injury      ,na.rm=T)
cm$InjuryBc     <-cm$InjuryB     -mean(cm$InjuryB     ,na.rm=T)
cm$InjuryHc     <-cm$InjuryH     -mean(cm$InjuryH     ,na.rm=T)
cm$InjuryWc     <-cm$InjuryW     -mean(cm$InjuryW     ,na.rm=T)
cm$GunDeathc    <-cm$GunDeath    -mean(cm$GunDeath    ,na.rm=T)
cm$GunDeathBc   <-cm$GunDeathB   -mean(cm$GunDeathB   ,na.rm=T)
cm$GunDeathWc   <-cm$GunDeathW   -mean(cm$GunDeathW   ,na.rm=T)
cm$PrmDeath_c   <-cm$PrmDeath    -mean(cm$PrmDeath    ,na.rm=T)
cm$PrmDeathcc   <-cm$PrmDeathc   -mean(cm$PrmDeathc   ,na.rm=T)
cm$PrmDeathBc   <-cm$PrmDeathB   -mean(cm$PrmDeathB   ,na.rm=T)
cm$PrmDeathHc   <-cm$PrmDeathH   -mean(cm$PrmDeathH   ,na.rm=T)
cm$PrmDeathWc   <-cm$PrmDeathW   -mean(cm$PrmDeathW   ,na.rm=T)
cm$PrmDeath2_c  <-cm$PrmDeath2   -mean(cm$PrmDeath2   ,na.rm=T)
cm$PrmDeath2cc  <-cm$PrmDeath2c  -mean(cm$PrmDeath2c  ,na.rm=T)
cm$PrmDeath2Bc  <-cm$PrmDeath2B  -mean(cm$PrmDeath2B  ,na.rm=T)
cm$PrmDeath2Hc  <-cm$PrmDeath2H  -mean(cm$PrmDeath2H  ,na.rm=T)
cm$PrmDeath2Wc  <-cm$PrmDeath2W  -mean(cm$PrmDeath2W  ,na.rm=T)
cm$Suicidec     <-cm$Suicide     -mean(cm$Suicide     ,na.rm=T)
cm$Diabetc      <-cm$Diabet      -mean(cm$Diabet      ,na.rm=T)
cm$Obesityc     <-cm$Obesity     -mean(cm$Obesity     ,na.rm=T)
cm$Physicalc    <-cm$Physical    -mean(cm$Physical    ,na.rm=T)
cm$PoorHlthc    <-cm$PoorHlth    -mean(cm$PoorHlth    ,na.rm=T)
cm$PoorMHc      <-cm$PoorMH      -mean(cm$PoorMH      ,na.rm=T)
cm$PoorPhyc     <-cm$PoorPhy     -mean(cm$PoorPhy     ,na.rm=T)
cm$Sleepc       <-cm$Sleep       -mean(cm$Sleep       ,na.rm=T)
cm$DrugOdc      <-cm$DrugOd      -mean(cm$DrugOd      ,na.rm=T)
cm$DrugOdBc     <-cm$DrugOdB     -mean(cm$DrugOdB     ,na.rm=T)
cm$DrugOdHc     <-cm$DrugOdH     -mean(cm$DrugOdH     ,na.rm=T)
cm$DrugOdWc     <-cm$DrugOdW     -mean(cm$DrugOdW     ,na.rm=T)
cm$DWIDeathc    <-cm$DWIDeath    -mean(cm$DWIDeath    ,na.rm=T)
cm$EDrinkc      <-cm$EDrink      -mean(cm$EDrink      ,na.rm=T)
cm$Smokec       <-cm$Smoke       -mean(cm$Smoke       ,na.rm=T)
cm$FastFoodc    <-cm$FastFood    -mean(cm$FastFood    ,na.rm=T)
cm$FoodEnvc     <-cm$FoodEnv     -mean(cm$FoodEnv     ,na.rm=T)
cm$FoodInsc     <-cm$FoodIns     -mean(cm$FoodIns     ,na.rm=T)
cm$FrLunchc     <-cm$FrLunch     -mean(cm$FrLunch     ,na.rm=T)
cm$LAccFoodc    <-cm$LAccFood    -mean(cm$LAccFood    ,na.rm=T)
cm$Gymc         <-cm$Gym         -mean(cm$Gym         ,na.rm=T)
cm$Gym2c        <-cm$Gym2        -mean(cm$Gym2        ,na.rm=T)
cm$Inactivec    <-cm$Inactive    -mean(cm$Inactive    ,na.rm=T)
cm$HousCostc    <-cm$HousCost    -mean(cm$HousCost    ,na.rm=T)
cm$HousCostsc   <-cm$HousCosts   -mean(cm$HousCosts   ,na.rm=T)
cm$HousCrowdc   <-cm$HousCrowd   -mean(cm$HousCrowd   ,na.rm=T)
cm$Housingc     <-cm$Housing     -mean(cm$Housing     ,na.rm=T)
cm$HousPlumbc   <-cm$HousPlumb   -mean(cm$HousPlumb   ,na.rm=T)
cm$Insuredc     <-cm$Insured     -mean(cm$Insured     ,na.rm=T)
cm$InsuredAc    <-cm$InsuredA    -mean(cm$InsuredA    ,na.rm=T)
cm$InsuredCc    <-cm$InsuredC    -mean(cm$InsuredC    ,na.rm=T)
cm$JuvArrc      <-cm$JuvArr      -mean(cm$JuvArr      ,na.rm=T)
cm$Murderc      <-cm$Murder      -mean(cm$Murder      ,na.rm=T)
cm$Violentc     <-cm$Violent     -mean(cm$Violent     ,na.rm=T)
cm$LongCommc    <-cm$LongComm    -mean(cm$LongComm    ,na.rm=T)
cm$LowBWc       <-cm$LowBW       -mean(cm$LowBW       ,na.rm=T)
cm$LowBWBc      <-cm$LowBWB      -mean(cm$LowBWB      ,na.rm=T)
cm$LowBWHc      <-cm$LowBWH      -mean(cm$LowBWH      ,na.rm=T)
cm$LowBWWc      <-cm$LowBWW      -mean(cm$LowBWW      ,na.rm=T)
cm$TeenBthc     <-cm$TeenBth     -mean(cm$TeenBth     ,na.rm=T)
cm$TeenBthBc    <-cm$TeenBthB    -mean(cm$TeenBthB    ,na.rm=T)
cm$TeenBthHc    <-cm$TeenBthH    -mean(cm$TeenBthH    ,na.rm=T)
cm$TeenBthWc    <-cm$TeenBthW    -mean(cm$TeenBthW    ,na.rm=T)
cm$Mentalc      <-cm$Mental      -mean(cm$Mental      ,na.rm=T)
cm$MHPrvdc      <-cm$MHPrvd      -mean(cm$MHPrvd      ,na.rm=T)
cm$PCPc         <-cm$PCP         -mean(cm$PCP         ,na.rm=T)
cm$PCP2c        <-cm$PCP2        -mean(cm$PCP2        ,na.rm=T)
cm$Dentistc     <-cm$Dentist     -mean(cm$Dentist     ,na.rm=T)
cm$PrvtHospc    <-cm$PrvtHosp    -mean(cm$PrvtHosp    ,na.rm=T)
cm$PrvtHospBc   <-cm$PrvtHospB   -mean(cm$PrvtHospB   ,na.rm=T)
cm$PrvtHospHc   <-cm$PrvtHospH   -mean(cm$PrvtHospH   ,na.rm=T)
cm$PrvtHospWc   <-cm$PrvtHospW   -mean(cm$PrvtHospW   ,na.rm=T)
cm$SegBWc       <-cm$SegBW       -mean(cm$SegBW       ,na.rm=T)
cm$SegNWc       <-cm$SegNW       -mean(cm$SegNW       ,na.rm=T)
cm$SocAssoc     <-cm$SocAsso     -mean(cm$SocAsso     ,na.rm=T)
cm$SocSuppc     <-cm$SocSupp     -mean(cm$SocSupp     ,na.rm=T)
cm$MIECHVc      <-cm$MIECHV      -mean(cm$MIECHV      ,na.rm=T)
cm$NHVRCc       <-cm$NHVRC       -mean(cm$NHVRC       ,na.rm=T)
cm$HomeV2c      <-cm$HomeV2      -mean(cm$HomeV2      ,na.rm=T)
cm$FoodInsecurec<-cm$FoodInsecure-mean(cm$FoodInsecure,na.rm=T)

cm<-cbind(cm,demean(cm,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cmm01<-lmer(RptMr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm02<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm03<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm04<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm05<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm06<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm07<-lmer(RptMr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cmm01,cmm02,cmm03,cmm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cmm04,cmm05,cmm06,cmm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cmm01CI<-confint(cmm01,method='boot',nsim=500,boot.type='perc')
cmm02CI<-confint(cmm02,method='boot',nsim=500,boot.type='perc')
cmm03CI<-confint(cmm03,method='boot',nsim=500,boot.type='perc')
cmm04CI<-confint(cmm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cmm01)
check_collinearity(cmm02)
check_collinearity(cmm03)
check_collinearity(cmm04)
isSingular(cmm01)
isSingular(cmm02)
isSingular(cmm03)
isSingular(cmm04)




# Model building
cmm01a<-lmer(RptMr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm02a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm03a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm04a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm05a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm06a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))
cmm07a<-lmer(RptMr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cm,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cmm01a,cmm02a,cmm03a,cmm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cmm04a,cmm05a,cmm06a,cmm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cmm01aCI<-confint(cmm01a,method='boot',nsim=500,boot.type='perc')
cmm02aCI<-confint(cmm02a,method='boot',nsim=500,boot.type='perc')
cmm03aCI<-confint(cmm03a,method='boot',nsim=500,boot.type='perc')
cmm04aCI<-confint(cmm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cmm01a)
check_collinearity(cmm02a)
check_collinearity(cmm03a)
check_collinearity(cmm04a)
isSingular(cmm01a)
isSingular(cmm02a)
isSingular(cmm03a)
isSingular(cmm04a)


cmg02<-glmmTMB(RptM~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopTM)),data=cm,family=nbinom2)
cmg02a<-glmmTMB(RptM~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopTM)),data=cm,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cf$CPopBPc      <-cf$CPopBP      -mean(cf$CPopBP      ,na.rm=T)
cf$CPopHPc      <-cf$CPopHP      -mean(cf$CPopHP      ,na.rm=T)
cf$ChildPTc     <-cf$ChildPT     -mean(cf$ChildPT     ,na.rm=T)
cf$ChildPWc     <-cf$ChildPW     -mean(cf$ChildPW     ,na.rm=T)
cf$ChildPBc     <-cf$ChildPB     -mean(cf$ChildPB     ,na.rm=T)
cf$ChildPHc     <-cf$ChildPH     -mean(cf$ChildPH     ,na.rm=T)
cf$CARatioT100c <-cf$CARatioT100 -mean(cf$CARatioT100 ,na.rm=T)
cf$CARatioW100c <-cf$CARatioW100 -mean(cf$CARatioW100 ,na.rm=T)
cf$CARatioB100c <-cf$CARatioB100 -mean(cf$CARatioB100 ,na.rm=T)
cf$CARatioH100c <-cf$CARatioH100 -mean(cf$CARatioH100 ,na.rm=T)
cf$MalePTc      <-cf$MalePT      -mean(cf$MalePT      ,na.rm=T)
cf$MalePWc      <-cf$MalePW      -mean(cf$MalePW      ,na.rm=T)
cf$MalePBc      <-cf$MalePB      -mean(cf$MalePB      ,na.rm=T)
cf$MalePHc      <-cf$MalePH      -mean(cf$MalePH      ,na.rm=T)
cf$MFRatioT100c <-cf$MFRatioT100 -mean(cf$MFRatioT100 ,na.rm=T)
cf$MFRatioW100c <-cf$MFRatioW100 -mean(cf$MFRatioW100 ,na.rm=T)
cf$MFRatioB100c <-cf$MFRatioB100 -mean(cf$MFRatioB100 ,na.rm=T)
cf$MFRatioH100c <-cf$MFRatioH100 -mean(cf$MFRatioH100 ,na.rm=T)
cf$ElderTc      <-cf$ElderT      -mean(cf$ElderT      ,na.rm=T)
cf$ElderWc      <-cf$ElderW      -mean(cf$ElderW      ,na.rm=T)
cf$ElderBc      <-cf$ElderB      -mean(cf$ElderB      ,na.rm=T)
cf$ElderHc      <-cf$ElderH      -mean(cf$ElderH      ,na.rm=T)
cf$SingleTc     <-cf$SingleT     -mean(cf$SingleT     ,na.rm=T)
cf$SingleWc     <-cf$SingleW     -mean(cf$SingleW     ,na.rm=T)
cf$SingleBc     <-cf$SingleB     -mean(cf$SingleB     ,na.rm=T)
cf$SingleHc     <-cf$SingleH     -mean(cf$SingleH     ,na.rm=T)
cf$FHeadTc      <-cf$FHeadT      -mean(cf$FHeadT      ,na.rm=T)
cf$FHeadWc      <-cf$FHeadW      -mean(cf$FHeadW      ,na.rm=T)
cf$FHeadBc      <-cf$FHeadB      -mean(cf$FHeadB      ,na.rm=T)
cf$FHeadHc      <-cf$FHeadH      -mean(cf$FHeadH      ,na.rm=T)
cf$NoHighTc     <-cf$NoHighT     -mean(cf$NoHighT     ,na.rm=T)
cf$NoHighWc     <-cf$NoHighW     -mean(cf$NoHighW     ,na.rm=T)
cf$NoHighBc     <-cf$NoHighB     -mean(cf$NoHighB     ,na.rm=T)
cf$NoHighHc     <-cf$NoHighH     -mean(cf$NoHighH     ,na.rm=T)
cf$UnempTc      <-cf$UnempT      -mean(cf$UnempT      ,na.rm=T)
cf$UnempWc      <-cf$UnempW      -mean(cf$UnempW      ,na.rm=T)
cf$UnempBc      <-cf$UnempB      -mean(cf$UnempB      ,na.rm=T)
cf$UnempHc      <-cf$UnempH      -mean(cf$UnempH      ,na.rm=T)
cf$CPovTc       <-cf$CPovT       -mean(cf$CPovT       ,na.rm=T)
cf$CPovWc       <-cf$CPovW       -mean(cf$CPovW       ,na.rm=T)
cf$CPovBc       <-cf$CPovB       -mean(cf$CPovB       ,na.rm=T)
cf$CPovHc       <-cf$CPovH       -mean(cf$CPovH       ,na.rm=T)
cf$CPov1c       <-cf$CPov1       -mean(cf$CPov1       ,na.rm=T)
cf$CPov2c       <-cf$CPov2       -mean(cf$CPov2       ,na.rm=T)
cf$CPov3c       <-cf$CPov3       -mean(cf$CPov3       ,na.rm=T)
cf$PubAsTc      <-cf$PubAsT      -mean(cf$PubAsT      ,na.rm=T)
cf$WelfarTc     <-cf$WelfarT     -mean(cf$WelfarT     ,na.rm=T)
cf$SnapTc       <-cf$SnapT       -mean(cf$SnapT       ,na.rm=T)
cf$SnapWc       <-cf$SnapW       -mean(cf$SnapW       ,na.rm=T)
cf$SnapBc       <-cf$SnapB       -mean(cf$SnapB       ,na.rm=T)
cf$SnapHc       <-cf$SnapH       -mean(cf$SnapH       ,na.rm=T)
cf$IncomeT1kc   <-cf$IncomeT1k   -mean(cf$IncomeT1k   ,na.rm=T)
cf$IncomeW1kc   <-cf$IncomeW1k   -mean(cf$IncomeW1k   ,na.rm=T)
cf$IncomeB1kc   <-cf$IncomeB1k   -mean(cf$IncomeB1k   ,na.rm=T)
cf$IncomeH1kc   <-cf$IncomeH1k   -mean(cf$IncomeH1k   ,na.rm=T)
cf$GiniT100c    <-cf$GiniT100    -mean(cf$GiniT100    ,na.rm=T)
cf$HValueT10kc  <-cf$HValueT10k  -mean(cf$HValueT10k  ,na.rm=T)
cf$MCostT100c   <-cf$MCostT100   -mean(cf$MCostT100   ,na.rm=T)
cf$OCostDT100c  <-cf$OCostDT100  -mean(cf$OCostDT100  ,na.rm=T)
cf$MRentDT100c  <-cf$MRentDT100  -mean(cf$MRentDT100  ,na.rm=T)
cf$OCostPTc     <-cf$OCostPT     -mean(cf$OCostPT     ,na.rm=T)
cf$MRentPTc     <-cf$MRentPT     -mean(cf$MRentPT     ,na.rm=T)
cf$MortgTc      <-cf$MortgT      -mean(cf$MortgT      ,na.rm=T)
cf$LangAPTc     <-cf$LangAPT     -mean(cf$LangAPT     ,na.rm=T)
cf$LangAPWc     <-cf$LangAPW     -mean(cf$LangAPW     ,na.rm=T)
cf$LangAPBc     <-cf$LangAPB     -mean(cf$LangAPB     ,na.rm=T)
cf$LangAPHc     <-cf$LangAPH     -mean(cf$LangAPH     ,na.rm=T)
cf$LangBPTc     <-cf$LangBPT     -mean(cf$LangBPT     ,na.rm=T)
cf$LangBPWc     <-cf$LangBPW     -mean(cf$LangBPW     ,na.rm=T)
cf$LangBPBc     <-cf$LangBPB     -mean(cf$LangBPB     ,na.rm=T)
cf$LangBPHc     <-cf$LangBPH     -mean(cf$LangBPH     ,na.rm=T)
cf$LangCPTc     <-cf$LangCPT     -mean(cf$LangCPT     ,na.rm=T)
cf$OutUsTc      <-cf$OutUsT      -mean(cf$OutUsT      ,na.rm=T)
cf$OutUsWc      <-cf$OutUsW      -mean(cf$OutUsW      ,na.rm=T)
cf$OutUsBc      <-cf$OutUsB      -mean(cf$OutUsB      ,na.rm=T)
cf$OutUsHc      <-cf$OutUsH      -mean(cf$OutUsH      ,na.rm=T)
cf$FBornTc      <-cf$FBornT      -mean(cf$FBornT      ,na.rm=T)
cf$FBornWc      <-cf$FBornW      -mean(cf$FBornW      ,na.rm=T)
cf$FBornBc      <-cf$FBornB      -mean(cf$FBornB      ,na.rm=T)
cf$FBornHc      <-cf$FBornH      -mean(cf$FBornH      ,na.rm=T)
cf$NotCtzTc     <-cf$NotCtzT     -mean(cf$NotCtzT     ,na.rm=T)
cf$NotCtzWc     <-cf$NotCtzW     -mean(cf$NotCtzW     ,na.rm=T)
cf$NotCtzBc     <-cf$NotCtzB     -mean(cf$NotCtzB     ,na.rm=T)
cf$NotCtzHc     <-cf$NotCtzH     -mean(cf$NotCtzH     ,na.rm=T)
cf$MoveTc       <-cf$MoveT       -mean(cf$MoveT       ,na.rm=T)
cf$MoveWc       <-cf$MoveW       -mean(cf$MoveW       ,na.rm=T)
cf$MoveBc       <-cf$MoveB       -mean(cf$MoveB       ,na.rm=T)
cf$MoveHc       <-cf$MoveH       -mean(cf$MoveH       ,na.rm=T)
cf$VacantTc     <-cf$VacantT     -mean(cf$VacantT     ,na.rm=T)
cf$OwnerTc      <-cf$OwnerT      -mean(cf$OwnerT      ,na.rm=T)
cf$OwnerWc      <-cf$OwnerW      -mean(cf$OwnerW      ,na.rm=T)
cf$OwnerBc      <-cf$OwnerB      -mean(cf$OwnerB      ,na.rm=T)
cf$OwnerHc      <-cf$OwnerH      -mean(cf$OwnerH      ,na.rm=T)
cf$CrowdTc      <-cf$CrowdT      -mean(cf$CrowdT      ,na.rm=T)
cf$CrowdWc      <-cf$CrowdW      -mean(cf$CrowdW      ,na.rm=T)
cf$CrowdBc      <-cf$CrowdB      -mean(cf$CrowdB      ,na.rm=T)
cf$CrowdHc      <-cf$CrowdH      -mean(cf$CrowdH      ,na.rm=T)
cf$MobileTc     <-cf$MobileT     -mean(cf$MobileT     ,na.rm=T)
cf$MobileWc     <-cf$MobileW     -mean(cf$MobileW     ,na.rm=T)
cf$MobileBc     <-cf$MobileB     -mean(cf$MobileB     ,na.rm=T)
cf$MobileHc     <-cf$MobileH     -mean(cf$MobileH     ,na.rm=T)
cf$DisablTc     <-cf$DisablT     -mean(cf$DisablT     ,na.rm=T)
cf$DisablWc     <-cf$DisablW     -mean(cf$DisablW     ,na.rm=T)
cf$DisablBc     <-cf$DisablB     -mean(cf$DisablB     ,na.rm=T)
cf$DisablHc     <-cf$DisablH     -mean(cf$DisablH     ,na.rm=T)
cf$DisablTCc    <-cf$DisablTC    -mean(cf$DisablTC    ,na.rm=T)
cf$DisablWCc    <-cf$DisablWC    -mean(cf$DisablWC    ,na.rm=T)
cf$DisablBCc    <-cf$DisablBC    -mean(cf$DisablBC    ,na.rm=T)
cf$DisablHCc    <-cf$DisablHC    -mean(cf$DisablHC    ,na.rm=T)
cf$DisablTMc    <-cf$DisablTM    -mean(cf$DisablTM    ,na.rm=T)
cf$DisablTFc    <-cf$DisablTF    -mean(cf$DisablTF    ,na.rm=T)
cf$Urban1c      <-cf$Urban1      -mean(cf$Urban1      ,na.rm=T)
cf$Urban2c      <-cf$Urban2      -mean(cf$Urban2      ,na.rm=T)
cf$LBWT1rc      <-cf$LBWT1r      -mean(cf$LBWT1r      ,na.rm=T)
cf$LBWM1rc      <-cf$LBWM1r      -mean(cf$LBWM1r      ,na.rm=T)
cf$LBWF1rc      <-cf$LBWF1r      -mean(cf$LBWF1r      ,na.rm=T)
cf$LBWW1rc      <-cf$LBWW1r      -mean(cf$LBWW1r      ,na.rm=T)
cf$LBWB1rc      <-cf$LBWB1r      -mean(cf$LBWB1r      ,na.rm=T)
cf$LBWH1rc      <-cf$LBWH1r      -mean(cf$LBWH1r      ,na.rm=T)
cf$PTBT1rc      <-cf$PTBT1r      -mean(cf$PTBT1r      ,na.rm=T)
cf$PTBM1rc      <-cf$PTBM1r      -mean(cf$PTBM1r      ,na.rm=T)
cf$PTBF1rc      <-cf$PTBF1r      -mean(cf$PTBF1r      ,na.rm=T)
cf$PTBW1rc      <-cf$PTBW1r      -mean(cf$PTBW1r      ,na.rm=T)
cf$PTBB1rc      <-cf$PTBB1r      -mean(cf$PTBB1r      ,na.rm=T)
cf$PTBH1rc      <-cf$PTBH1r      -mean(cf$PTBH1r      ,na.rm=T)
cf$PNCT1rc      <-cf$PNCT1r      -mean(cf$PNCT1r      ,na.rm=T)
cf$PNCM1rc      <-cf$PNCM1r      -mean(cf$PNCM1r      ,na.rm=T)
cf$PNCF1rc      <-cf$PNCF1r      -mean(cf$PNCF1r      ,na.rm=T)
cf$PNCW1rc      <-cf$PNCW1r      -mean(cf$PNCW1r      ,na.rm=T)
cf$PNCB1rc      <-cf$PNCB1r      -mean(cf$PNCB1r      ,na.rm=T)
cf$PNCH1rc      <-cf$PNCH1r      -mean(cf$PNCH1r      ,na.rm=T)
cf$TBBT1rc      <-cf$TBBT1r      -mean(cf$TBBT1r      ,na.rm=T)
cf$TBBM1rc      <-cf$TBBM1r      -mean(cf$TBBM1r      ,na.rm=T)
cf$TBBF1rc      <-cf$TBBF1r      -mean(cf$TBBF1r      ,na.rm=T)
cf$TBBW1rc      <-cf$TBBW1r      -mean(cf$TBBW1r      ,na.rm=T)
cf$TBBB1rc      <-cf$TBBB1r      -mean(cf$TBBB1r      ,na.rm=T)
cf$TBBH1rc      <-cf$TBBH1r      -mean(cf$TBBH1r      ,na.rm=T)
cf$TBTT1rc      <-cf$TBTT1r      -mean(cf$TBTT1r      ,na.rm=T)
cf$TBTM1rc      <-cf$TBTM1r      -mean(cf$TBTM1r      ,na.rm=T)
cf$TBTF1rc      <-cf$TBTF1r      -mean(cf$TBTF1r      ,na.rm=T)
cf$TBTW1rc      <-cf$TBTW1r      -mean(cf$TBTW1r      ,na.rm=T)
cf$TBTB1rc      <-cf$TBTB1r      -mean(cf$TBTB1r      ,na.rm=T)
cf$TBTH1rc      <-cf$TBTH1r      -mean(cf$TBTH1r      ,na.rm=T)
cf$LBWT5rc      <-cf$LBWT5r      -mean(cf$LBWT5r      ,na.rm=T)
cf$LBWM5rc      <-cf$LBWM5r      -mean(cf$LBWM5r      ,na.rm=T)
cf$LBWF5rc      <-cf$LBWF5r      -mean(cf$LBWF5r      ,na.rm=T)
cf$LBWW5rc      <-cf$LBWW5r      -mean(cf$LBWW5r      ,na.rm=T)
cf$LBWB5rc      <-cf$LBWB5r      -mean(cf$LBWB5r      ,na.rm=T)
cf$LBWH5rc      <-cf$LBWH5r      -mean(cf$LBWH5r      ,na.rm=T)
cf$PTBT5rc      <-cf$PTBT5r      -mean(cf$PTBT5r      ,na.rm=T)
cf$PTBM5rc      <-cf$PTBM5r      -mean(cf$PTBM5r      ,na.rm=T)
cf$PTBF5rc      <-cf$PTBF5r      -mean(cf$PTBF5r      ,na.rm=T)
cf$PTBW5rc      <-cf$PTBW5r      -mean(cf$PTBW5r      ,na.rm=T)
cf$PTBB5rc      <-cf$PTBB5r      -mean(cf$PTBB5r      ,na.rm=T)
cf$PTBH5rc      <-cf$PTBH5r      -mean(cf$PTBH5r      ,na.rm=T)
cf$PNCT5rc      <-cf$PNCT5r      -mean(cf$PNCT5r      ,na.rm=T)
cf$PNCM5rc      <-cf$PNCM5r      -mean(cf$PNCM5r      ,na.rm=T)
cf$PNCF5rc      <-cf$PNCF5r      -mean(cf$PNCF5r      ,na.rm=T)
cf$PNCW5rc      <-cf$PNCW5r      -mean(cf$PNCW5r      ,na.rm=T)
cf$PNCB5rc      <-cf$PNCB5r      -mean(cf$PNCB5r      ,na.rm=T)
cf$PNCH5rc      <-cf$PNCH5r      -mean(cf$PNCH5r      ,na.rm=T)
cf$TBBT5rc      <-cf$TBBT5r      -mean(cf$TBBT5r      ,na.rm=T)
cf$TBBM5rc      <-cf$TBBM5r      -mean(cf$TBBM5r      ,na.rm=T)
cf$TBBF5rc      <-cf$TBBF5r      -mean(cf$TBBF5r      ,na.rm=T)
cf$TBBW5rc      <-cf$TBBW5r      -mean(cf$TBBW5r      ,na.rm=T)
cf$TBBB5rc      <-cf$TBBB5r      -mean(cf$TBBB5r      ,na.rm=T)
cf$TBBH5rc      <-cf$TBBH5r      -mean(cf$TBBH5r      ,na.rm=T)
cf$TBTT5rc      <-cf$TBTT5r      -mean(cf$TBTT5r      ,na.rm=T)
cf$TBTM5rc      <-cf$TBTM5r      -mean(cf$TBTM5r      ,na.rm=T)
cf$TBTF5rc      <-cf$TBTF5r      -mean(cf$TBTF5r      ,na.rm=T)
cf$TBTW5rc      <-cf$TBTW5r      -mean(cf$TBTW5r      ,na.rm=T)
cf$TBTB5rc      <-cf$TBTB5r      -mean(cf$TBTB5r      ,na.rm=T)
cf$TBTH5rc      <-cf$TBTH5r      -mean(cf$TBTH5r      ,na.rm=T)
cf$Opioidc      <-cf$Opioid      -mean(cf$Opioid      ,na.rm=T)
cf$LifeExpc     <-cf$LifeExp     -mean(cf$LifeExp     ,na.rm=T)
cf$LifeExpBc    <-cf$LifeExpB    -mean(cf$LifeExpB    ,na.rm=T)
cf$LifeExpHc    <-cf$LifeExpH    -mean(cf$LifeExpH    ,na.rm=T)
cf$LifeExpWc    <-cf$LifeExpW    -mean(cf$LifeExpW    ,na.rm=T)
cf$ChdDeathc    <-cf$ChdDeath    -mean(cf$ChdDeath    ,na.rm=T)
cf$ChdDeathBc   <-cf$ChdDeathB   -mean(cf$ChdDeathB   ,na.rm=T)
cf$ChdDeathHc   <-cf$ChdDeathH   -mean(cf$ChdDeathH   ,na.rm=T)
cf$ChdDeathWc   <-cf$ChdDeathW   -mean(cf$ChdDeathW   ,na.rm=T)
cf$InfDeathc    <-cf$InfDeath    -mean(cf$InfDeath    ,na.rm=T)
cf$InfDeathBc   <-cf$InfDeathB   -mean(cf$InfDeathB   ,na.rm=T)
cf$InfDeathHc   <-cf$InfDeathH   -mean(cf$InfDeathH   ,na.rm=T)
cf$InfDeathWc   <-cf$InfDeathW   -mean(cf$InfDeathW   ,na.rm=T)
cf$Injuryc      <-cf$Injury      -mean(cf$Injury      ,na.rm=T)
cf$InjuryBc     <-cf$InjuryB     -mean(cf$InjuryB     ,na.rm=T)
cf$InjuryHc     <-cf$InjuryH     -mean(cf$InjuryH     ,na.rm=T)
cf$InjuryWc     <-cf$InjuryW     -mean(cf$InjuryW     ,na.rm=T)
cf$GunDeathc    <-cf$GunDeath    -mean(cf$GunDeath    ,na.rm=T)
cf$GunDeathBc   <-cf$GunDeathB   -mean(cf$GunDeathB   ,na.rm=T)
cf$GunDeathWc   <-cf$GunDeathW   -mean(cf$GunDeathW   ,na.rm=T)
cf$PrmDeath_c   <-cf$PrmDeath    -mean(cf$PrmDeath    ,na.rm=T)
cf$PrmDeathcc   <-cf$PrmDeathc   -mean(cf$PrmDeathc   ,na.rm=T)
cf$PrmDeathBc   <-cf$PrmDeathB   -mean(cf$PrmDeathB   ,na.rm=T)
cf$PrmDeathHc   <-cf$PrmDeathH   -mean(cf$PrmDeathH   ,na.rm=T)
cf$PrmDeathWc   <-cf$PrmDeathW   -mean(cf$PrmDeathW   ,na.rm=T)
cf$PrmDeath2_c  <-cf$PrmDeath2   -mean(cf$PrmDeath2   ,na.rm=T)
cf$PrmDeath2cc  <-cf$PrmDeath2c  -mean(cf$PrmDeath2c  ,na.rm=T)
cf$PrmDeath2Bc  <-cf$PrmDeath2B  -mean(cf$PrmDeath2B  ,na.rm=T)
cf$PrmDeath2Hc  <-cf$PrmDeath2H  -mean(cf$PrmDeath2H  ,na.rm=T)
cf$PrmDeath2Wc  <-cf$PrmDeath2W  -mean(cf$PrmDeath2W  ,na.rm=T)
cf$Suicidec     <-cf$Suicide     -mean(cf$Suicide     ,na.rm=T)
cf$Diabetc      <-cf$Diabet      -mean(cf$Diabet      ,na.rm=T)
cf$Obesityc     <-cf$Obesity     -mean(cf$Obesity     ,na.rm=T)
cf$Physicalc    <-cf$Physical    -mean(cf$Physical    ,na.rm=T)
cf$PoorHlthc    <-cf$PoorHlth    -mean(cf$PoorHlth    ,na.rm=T)
cf$PoorMHc      <-cf$PoorMH      -mean(cf$PoorMH      ,na.rm=T)
cf$PoorPhyc     <-cf$PoorPhy     -mean(cf$PoorPhy     ,na.rm=T)
cf$Sleepc       <-cf$Sleep       -mean(cf$Sleep       ,na.rm=T)
cf$DrugOdc      <-cf$DrugOd      -mean(cf$DrugOd      ,na.rm=T)
cf$DrugOdBc     <-cf$DrugOdB     -mean(cf$DrugOdB     ,na.rm=T)
cf$DrugOdHc     <-cf$DrugOdH     -mean(cf$DrugOdH     ,na.rm=T)
cf$DrugOdWc     <-cf$DrugOdW     -mean(cf$DrugOdW     ,na.rm=T)
cf$DWIDeathc    <-cf$DWIDeath    -mean(cf$DWIDeath    ,na.rm=T)
cf$EDrinkc      <-cf$EDrink      -mean(cf$EDrink      ,na.rm=T)
cf$Smokec       <-cf$Smoke       -mean(cf$Smoke       ,na.rm=T)
cf$FastFoodc    <-cf$FastFood    -mean(cf$FastFood    ,na.rm=T)
cf$FoodEnvc     <-cf$FoodEnv     -mean(cf$FoodEnv     ,na.rm=T)
cf$FoodInsc     <-cf$FoodIns     -mean(cf$FoodIns     ,na.rm=T)
cf$FrLunchc     <-cf$FrLunch     -mean(cf$FrLunch     ,na.rm=T)
cf$LAccFoodc    <-cf$LAccFood    -mean(cf$LAccFood    ,na.rm=T)
cf$Gymc         <-cf$Gym         -mean(cf$Gym         ,na.rm=T)
cf$Gym2c        <-cf$Gym2        -mean(cf$Gym2        ,na.rm=T)
cf$Inactivec    <-cf$Inactive    -mean(cf$Inactive    ,na.rm=T)
cf$HousCostc    <-cf$HousCost    -mean(cf$HousCost    ,na.rm=T)
cf$HousCostsc   <-cf$HousCosts   -mean(cf$HousCosts   ,na.rm=T)
cf$HousCrowdc   <-cf$HousCrowd   -mean(cf$HousCrowd   ,na.rm=T)
cf$Housingc     <-cf$Housing     -mean(cf$Housing     ,na.rm=T)
cf$HousPlumbc   <-cf$HousPlumb   -mean(cf$HousPlumb   ,na.rm=T)
cf$Insuredc     <-cf$Insured     -mean(cf$Insured     ,na.rm=T)
cf$InsuredAc    <-cf$InsuredA    -mean(cf$InsuredA    ,na.rm=T)
cf$InsuredCc    <-cf$InsuredC    -mean(cf$InsuredC    ,na.rm=T)
cf$JuvArrc      <-cf$JuvArr      -mean(cf$JuvArr      ,na.rm=T)
cf$Murderc      <-cf$Murder      -mean(cf$Murder      ,na.rm=T)
cf$Violentc     <-cf$Violent     -mean(cf$Violent     ,na.rm=T)
cf$LongCommc    <-cf$LongComm    -mean(cf$LongComm    ,na.rm=T)
cf$LowBWc       <-cf$LowBW       -mean(cf$LowBW       ,na.rm=T)
cf$LowBWBc      <-cf$LowBWB      -mean(cf$LowBWB      ,na.rm=T)
cf$LowBWHc      <-cf$LowBWH      -mean(cf$LowBWH      ,na.rm=T)
cf$LowBWWc      <-cf$LowBWW      -mean(cf$LowBWW      ,na.rm=T)
cf$TeenBthc     <-cf$TeenBth     -mean(cf$TeenBth     ,na.rm=T)
cf$TeenBthBc    <-cf$TeenBthB    -mean(cf$TeenBthB    ,na.rm=T)
cf$TeenBthHc    <-cf$TeenBthH    -mean(cf$TeenBthH    ,na.rm=T)
cf$TeenBthWc    <-cf$TeenBthW    -mean(cf$TeenBthW    ,na.rm=T)
cf$Mentalc      <-cf$Mental      -mean(cf$Mental      ,na.rm=T)
cf$MHPrvdc      <-cf$MHPrvd      -mean(cf$MHPrvd      ,na.rm=T)
cf$PCPc         <-cf$PCP         -mean(cf$PCP         ,na.rm=T)
cf$PCP2c        <-cf$PCP2        -mean(cf$PCP2        ,na.rm=T)
cf$Dentistc     <-cf$Dentist     -mean(cf$Dentist     ,na.rm=T)
cf$PrvtHospc    <-cf$PrvtHosp    -mean(cf$PrvtHosp    ,na.rm=T)
cf$PrvtHospBc   <-cf$PrvtHospB   -mean(cf$PrvtHospB   ,na.rm=T)
cf$PrvtHospHc   <-cf$PrvtHospH   -mean(cf$PrvtHospH   ,na.rm=T)
cf$PrvtHospWc   <-cf$PrvtHospW   -mean(cf$PrvtHospW   ,na.rm=T)
cf$SegBWc       <-cf$SegBW       -mean(cf$SegBW       ,na.rm=T)
cf$SegNWc       <-cf$SegNW       -mean(cf$SegNW       ,na.rm=T)
cf$SocAssoc     <-cf$SocAsso     -mean(cf$SocAsso     ,na.rm=T)
cf$SocSuppc     <-cf$SocSupp     -mean(cf$SocSupp     ,na.rm=T)
cf$MIECHVc      <-cf$MIECHV      -mean(cf$MIECHV      ,na.rm=T)
cf$NHVRCc       <-cf$NHVRC       -mean(cf$NHVRC       ,na.rm=T)
cf$HomeV2c      <-cf$HomeV2      -mean(cf$HomeV2      ,na.rm=T)
cf$FoodInsecurec<-cf$FoodInsecure-mean(cf$FoodInsecure,na.rm=T)

cf<-cbind(cf,demean(cf,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cfm01<-lmer(RptFr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm02<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm03<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm04<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm05<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm06<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm07<-lmer(RptFr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cfm01,cfm02,cfm03,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cfm04,cfm05,cfm06,cfm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cfm01CI<-confint(cfm01,method='boot',nsim=500,boot.type='perc')
cfm02CI<-confint(cfm02,method='boot',nsim=500,boot.type='perc')
cfm03CI<-confint(cfm03,method='boot',nsim=500,boot.type='perc')
cfm04CI<-confint(cfm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cfm01)
check_collinearity(cfm02)
check_collinearity(cfm03)
check_collinearity(cfm04)
isSingular(cfm01)
isSingular(cfm02)
isSingular(cfm03)
isSingular(cfm04)




# Model building
cfm01a<-lmer(RptFr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm02a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm03a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm04a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm05a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm06a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))
cfm07a<-lmer(RptFr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cf,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cfm01a,cfm02a,cfm03a,cfm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cfm04a,cfm05a,cfm06a,cfm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cfm01aCI<-confint(cfm01a,method='boot',nsim=500,boot.type='perc')
cfm02aCI<-confint(cfm02a,method='boot',nsim=500,boot.type='perc')
cfm03aCI<-confint(cfm03a,method='boot',nsim=500,boot.type='perc')
cfm04aCI<-confint(cfm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cfm01a)
check_collinearity(cfm02a)
check_collinearity(cfm03a)
check_collinearity(cfm04a)
isSingular(cfm01a)
isSingular(cfm02a)
isSingular(cfm03a)
isSingular(cfm04a)



tab_model(cmm04,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cmm04a,cfm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)




cfg02<-glmmTMB(RptF~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopTF)),data=cf,family=nbinom2)
cfg02a<-glmmTMB(RptM~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopTF)),data=cf,family=nbinom2)


###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cn$CPopBPc      <-cn$CPopBP      -mean(cn$CPopBP      ,na.rm=T)
cn$CPopHPc      <-cn$CPopHP      -mean(cn$CPopHP      ,na.rm=T)
cn$ChildPTc     <-cn$ChildPT     -mean(cn$ChildPT     ,na.rm=T)
cn$ChildPWc     <-cn$ChildPW     -mean(cn$ChildPW     ,na.rm=T)
cn$ChildPBc     <-cn$ChildPB     -mean(cn$ChildPB     ,na.rm=T)
cn$ChildPHc     <-cn$ChildPH     -mean(cn$ChildPH     ,na.rm=T)
cn$CARatioT100c <-cn$CARatioT100 -mean(cn$CARatioT100 ,na.rm=T)
cn$CARatioW100c <-cn$CARatioW100 -mean(cn$CARatioW100 ,na.rm=T)
cn$CARatioB100c <-cn$CARatioB100 -mean(cn$CARatioB100 ,na.rm=T)
cn$CARatioH100c <-cn$CARatioH100 -mean(cn$CARatioH100 ,na.rm=T)
cn$MalePTc      <-cn$MalePT      -mean(cn$MalePT      ,na.rm=T)
cn$MalePWc      <-cn$MalePW      -mean(cn$MalePW      ,na.rm=T)
cn$MalePBc      <-cn$MalePB      -mean(cn$MalePB      ,na.rm=T)
cn$MalePHc      <-cn$MalePH      -mean(cn$MalePH      ,na.rm=T)
cn$MFRatioT100c <-cn$MFRatioT100 -mean(cn$MFRatioT100 ,na.rm=T)
cn$MFRatioW100c <-cn$MFRatioW100 -mean(cn$MFRatioW100 ,na.rm=T)
cn$MFRatioB100c <-cn$MFRatioB100 -mean(cn$MFRatioB100 ,na.rm=T)
cn$MFRatioH100c <-cn$MFRatioH100 -mean(cn$MFRatioH100 ,na.rm=T)
cn$ElderTc      <-cn$ElderT      -mean(cn$ElderT      ,na.rm=T)
cn$ElderWc      <-cn$ElderW      -mean(cn$ElderW      ,na.rm=T)
cn$ElderBc      <-cn$ElderB      -mean(cn$ElderB      ,na.rm=T)
cn$ElderHc      <-cn$ElderH      -mean(cn$ElderH      ,na.rm=T)
cn$SingleTc     <-cn$SingleT     -mean(cn$SingleT     ,na.rm=T)
cn$SingleWc     <-cn$SingleW     -mean(cn$SingleW     ,na.rm=T)
cn$SingleBc     <-cn$SingleB     -mean(cn$SingleB     ,na.rm=T)
cn$SingleHc     <-cn$SingleH     -mean(cn$SingleH     ,na.rm=T)
cn$FHeadTc      <-cn$FHeadT      -mean(cn$FHeadT      ,na.rm=T)
cn$FHeadWc      <-cn$FHeadW      -mean(cn$FHeadW      ,na.rm=T)
cn$FHeadBc      <-cn$FHeadB      -mean(cn$FHeadB      ,na.rm=T)
cn$FHeadHc      <-cn$FHeadH      -mean(cn$FHeadH      ,na.rm=T)
cn$NoHighTc     <-cn$NoHighT     -mean(cn$NoHighT     ,na.rm=T)
cn$NoHighWc     <-cn$NoHighW     -mean(cn$NoHighW     ,na.rm=T)
cn$NoHighBc     <-cn$NoHighB     -mean(cn$NoHighB     ,na.rm=T)
cn$NoHighHc     <-cn$NoHighH     -mean(cn$NoHighH     ,na.rm=T)
cn$UnempTc      <-cn$UnempT      -mean(cn$UnempT      ,na.rm=T)
cn$UnempWc      <-cn$UnempW      -mean(cn$UnempW      ,na.rm=T)
cn$UnempBc      <-cn$UnempB      -mean(cn$UnempB      ,na.rm=T)
cn$UnempHc      <-cn$UnempH      -mean(cn$UnempH      ,na.rm=T)
cn$CPovTc       <-cn$CPovT       -mean(cn$CPovT       ,na.rm=T)
cn$CPovWc       <-cn$CPovW       -mean(cn$CPovW       ,na.rm=T)
cn$CPovBc       <-cn$CPovB       -mean(cn$CPovB       ,na.rm=T)
cn$CPovHc       <-cn$CPovH       -mean(cn$CPovH       ,na.rm=T)
cn$CPov1c       <-cn$CPov1       -mean(cn$CPov1       ,na.rm=T)
cn$CPov2c       <-cn$CPov2       -mean(cn$CPov2       ,na.rm=T)
cn$CPov3c       <-cn$CPov3       -mean(cn$CPov3       ,na.rm=T)
cn$PubAsTc      <-cn$PubAsT      -mean(cn$PubAsT      ,na.rm=T)
cn$WelfarTc     <-cn$WelfarT     -mean(cn$WelfarT     ,na.rm=T)
cn$SnapTc       <-cn$SnapT       -mean(cn$SnapT       ,na.rm=T)
cn$SnapWc       <-cn$SnapW       -mean(cn$SnapW       ,na.rm=T)
cn$SnapBc       <-cn$SnapB       -mean(cn$SnapB       ,na.rm=T)
cn$SnapHc       <-cn$SnapH       -mean(cn$SnapH       ,na.rm=T)
cn$IncomeT1kc   <-cn$IncomeT1k   -mean(cn$IncomeT1k   ,na.rm=T)
cn$IncomeW1kc   <-cn$IncomeW1k   -mean(cn$IncomeW1k   ,na.rm=T)
cn$IncomeB1kc   <-cn$IncomeB1k   -mean(cn$IncomeB1k   ,na.rm=T)
cn$IncomeH1kc   <-cn$IncomeH1k   -mean(cn$IncomeH1k   ,na.rm=T)
cn$GiniT100c    <-cn$GiniT100    -mean(cn$GiniT100    ,na.rm=T)
cn$HValueT10kc  <-cn$HValueT10k  -mean(cn$HValueT10k  ,na.rm=T)
cn$MCostT100c   <-cn$MCostT100   -mean(cn$MCostT100   ,na.rm=T)
cn$OCostDT100c  <-cn$OCostDT100  -mean(cn$OCostDT100  ,na.rm=T)
cn$MRentDT100c  <-cn$MRentDT100  -mean(cn$MRentDT100  ,na.rm=T)
cn$OCostPTc     <-cn$OCostPT     -mean(cn$OCostPT     ,na.rm=T)
cn$MRentPTc     <-cn$MRentPT     -mean(cn$MRentPT     ,na.rm=T)
cn$MortgTc      <-cn$MortgT      -mean(cn$MortgT      ,na.rm=T)
cn$LangAPTc     <-cn$LangAPT     -mean(cn$LangAPT     ,na.rm=T)
cn$LangAPWc     <-cn$LangAPW     -mean(cn$LangAPW     ,na.rm=T)
cn$LangAPBc     <-cn$LangAPB     -mean(cn$LangAPB     ,na.rm=T)
cn$LangAPHc     <-cn$LangAPH     -mean(cn$LangAPH     ,na.rm=T)
cn$LangBPTc     <-cn$LangBPT     -mean(cn$LangBPT     ,na.rm=T)
cn$LangBPWc     <-cn$LangBPW     -mean(cn$LangBPW     ,na.rm=T)
cn$LangBPBc     <-cn$LangBPB     -mean(cn$LangBPB     ,na.rm=T)
cn$LangBPHc     <-cn$LangBPH     -mean(cn$LangBPH     ,na.rm=T)
cn$LangCPTc     <-cn$LangCPT     -mean(cn$LangCPT     ,na.rm=T)
cn$OutUsTc      <-cn$OutUsT      -mean(cn$OutUsT      ,na.rm=T)
cn$OutUsWc      <-cn$OutUsW      -mean(cn$OutUsW      ,na.rm=T)
cn$OutUsBc      <-cn$OutUsB      -mean(cn$OutUsB      ,na.rm=T)
cn$OutUsHc      <-cn$OutUsH      -mean(cn$OutUsH      ,na.rm=T)
cn$FBornTc      <-cn$FBornT      -mean(cn$FBornT      ,na.rm=T)
cn$FBornWc      <-cn$FBornW      -mean(cn$FBornW      ,na.rm=T)
cn$FBornBc      <-cn$FBornB      -mean(cn$FBornB      ,na.rm=T)
cn$FBornHc      <-cn$FBornH      -mean(cn$FBornH      ,na.rm=T)
cn$NotCtzTc     <-cn$NotCtzT     -mean(cn$NotCtzT     ,na.rm=T)
cn$NotCtzWc     <-cn$NotCtzW     -mean(cn$NotCtzW     ,na.rm=T)
cn$NotCtzBc     <-cn$NotCtzB     -mean(cn$NotCtzB     ,na.rm=T)
cn$NotCtzHc     <-cn$NotCtzH     -mean(cn$NotCtzH     ,na.rm=T)
cn$MoveTc       <-cn$MoveT       -mean(cn$MoveT       ,na.rm=T)
cn$MoveWc       <-cn$MoveW       -mean(cn$MoveW       ,na.rm=T)
cn$MoveBc       <-cn$MoveB       -mean(cn$MoveB       ,na.rm=T)
cn$MoveHc       <-cn$MoveH       -mean(cn$MoveH       ,na.rm=T)
cn$VacantTc     <-cn$VacantT     -mean(cn$VacantT     ,na.rm=T)
cn$OwnerTc      <-cn$OwnerT      -mean(cn$OwnerT      ,na.rm=T)
cn$OwnerWc      <-cn$OwnerW      -mean(cn$OwnerW      ,na.rm=T)
cn$OwnerBc      <-cn$OwnerB      -mean(cn$OwnerB      ,na.rm=T)
cn$OwnerHc      <-cn$OwnerH      -mean(cn$OwnerH      ,na.rm=T)
cn$CrowdTc      <-cn$CrowdT      -mean(cn$CrowdT      ,na.rm=T)
cn$CrowdWc      <-cn$CrowdW      -mean(cn$CrowdW      ,na.rm=T)
cn$CrowdBc      <-cn$CrowdB      -mean(cn$CrowdB      ,na.rm=T)
cn$CrowdHc      <-cn$CrowdH      -mean(cn$CrowdH      ,na.rm=T)
cn$MobileTc     <-cn$MobileT     -mean(cn$MobileT     ,na.rm=T)
cn$MobileWc     <-cn$MobileW     -mean(cn$MobileW     ,na.rm=T)
cn$MobileBc     <-cn$MobileB     -mean(cn$MobileB     ,na.rm=T)
cn$MobileHc     <-cn$MobileH     -mean(cn$MobileH     ,na.rm=T)
cn$DisablTc     <-cn$DisablT     -mean(cn$DisablT     ,na.rm=T)
cn$DisablWc     <-cn$DisablW     -mean(cn$DisablW     ,na.rm=T)
cn$DisablBc     <-cn$DisablB     -mean(cn$DisablB     ,na.rm=T)
cn$DisablHc     <-cn$DisablH     -mean(cn$DisablH     ,na.rm=T)
cn$DisablTCc    <-cn$DisablTC    -mean(cn$DisablTC    ,na.rm=T)
cn$DisablWCc    <-cn$DisablWC    -mean(cn$DisablWC    ,na.rm=T)
cn$DisablBCc    <-cn$DisablBC    -mean(cn$DisablBC    ,na.rm=T)
cn$DisablHCc    <-cn$DisablHC    -mean(cn$DisablHC    ,na.rm=T)
cn$DisablTMc    <-cn$DisablTM    -mean(cn$DisablTM    ,na.rm=T)
cn$DisablTFc    <-cn$DisablTF    -mean(cn$DisablTF    ,na.rm=T)
cn$Urban1c      <-cn$Urban1      -mean(cn$Urban1      ,na.rm=T)
cn$Urban2c      <-cn$Urban2      -mean(cn$Urban2      ,na.rm=T)
cn$LBWT1rc      <-cn$LBWT1r      -mean(cn$LBWT1r      ,na.rm=T)
cn$LBWM1rc      <-cn$LBWM1r      -mean(cn$LBWM1r      ,na.rm=T)
cn$LBWF1rc      <-cn$LBWF1r      -mean(cn$LBWF1r      ,na.rm=T)
cn$LBWW1rc      <-cn$LBWW1r      -mean(cn$LBWW1r      ,na.rm=T)
cn$LBWB1rc      <-cn$LBWB1r      -mean(cn$LBWB1r      ,na.rm=T)
cn$LBWH1rc      <-cn$LBWH1r      -mean(cn$LBWH1r      ,na.rm=T)
cn$PTBT1rc      <-cn$PTBT1r      -mean(cn$PTBT1r      ,na.rm=T)
cn$PTBM1rc      <-cn$PTBM1r      -mean(cn$PTBM1r      ,na.rm=T)
cn$PTBF1rc      <-cn$PTBF1r      -mean(cn$PTBF1r      ,na.rm=T)
cn$PTBW1rc      <-cn$PTBW1r      -mean(cn$PTBW1r      ,na.rm=T)
cn$PTBB1rc      <-cn$PTBB1r      -mean(cn$PTBB1r      ,na.rm=T)
cn$PTBH1rc      <-cn$PTBH1r      -mean(cn$PTBH1r      ,na.rm=T)
cn$PNCT1rc      <-cn$PNCT1r      -mean(cn$PNCT1r      ,na.rm=T)
cn$PNCM1rc      <-cn$PNCM1r      -mean(cn$PNCM1r      ,na.rm=T)
cn$PNCF1rc      <-cn$PNCF1r      -mean(cn$PNCF1r      ,na.rm=T)
cn$PNCW1rc      <-cn$PNCW1r      -mean(cn$PNCW1r      ,na.rm=T)
cn$PNCB1rc      <-cn$PNCB1r      -mean(cn$PNCB1r      ,na.rm=T)
cn$PNCH1rc      <-cn$PNCH1r      -mean(cn$PNCH1r      ,na.rm=T)
cn$TBBT1rc      <-cn$TBBT1r      -mean(cn$TBBT1r      ,na.rm=T)
cn$TBBM1rc      <-cn$TBBM1r      -mean(cn$TBBM1r      ,na.rm=T)
cn$TBBF1rc      <-cn$TBBF1r      -mean(cn$TBBF1r      ,na.rm=T)
cn$TBBW1rc      <-cn$TBBW1r      -mean(cn$TBBW1r      ,na.rm=T)
cn$TBBB1rc      <-cn$TBBB1r      -mean(cn$TBBB1r      ,na.rm=T)
cn$TBBH1rc      <-cn$TBBH1r      -mean(cn$TBBH1r      ,na.rm=T)
cn$TBTT1rc      <-cn$TBTT1r      -mean(cn$TBTT1r      ,na.rm=T)
cn$TBTM1rc      <-cn$TBTM1r      -mean(cn$TBTM1r      ,na.rm=T)
cn$TBTF1rc      <-cn$TBTF1r      -mean(cn$TBTF1r      ,na.rm=T)
cn$TBTW1rc      <-cn$TBTW1r      -mean(cn$TBTW1r      ,na.rm=T)
cn$TBTB1rc      <-cn$TBTB1r      -mean(cn$TBTB1r      ,na.rm=T)
cn$TBTH1rc      <-cn$TBTH1r      -mean(cn$TBTH1r      ,na.rm=T)
cn$LBWT5rc      <-cn$LBWT5r      -mean(cn$LBWT5r      ,na.rm=T)
cn$LBWM5rc      <-cn$LBWM5r      -mean(cn$LBWM5r      ,na.rm=T)
cn$LBWF5rc      <-cn$LBWF5r      -mean(cn$LBWF5r      ,na.rm=T)
cn$LBWW5rc      <-cn$LBWW5r      -mean(cn$LBWW5r      ,na.rm=T)
cn$LBWB5rc      <-cn$LBWB5r      -mean(cn$LBWB5r      ,na.rm=T)
cn$LBWH5rc      <-cn$LBWH5r      -mean(cn$LBWH5r      ,na.rm=T)
cn$PTBT5rc      <-cn$PTBT5r      -mean(cn$PTBT5r      ,na.rm=T)
cn$PTBM5rc      <-cn$PTBM5r      -mean(cn$PTBM5r      ,na.rm=T)
cn$PTBF5rc      <-cn$PTBF5r      -mean(cn$PTBF5r      ,na.rm=T)
cn$PTBW5rc      <-cn$PTBW5r      -mean(cn$PTBW5r      ,na.rm=T)
cn$PTBB5rc      <-cn$PTBB5r      -mean(cn$PTBB5r      ,na.rm=T)
cn$PTBH5rc      <-cn$PTBH5r      -mean(cn$PTBH5r      ,na.rm=T)
cn$PNCT5rc      <-cn$PNCT5r      -mean(cn$PNCT5r      ,na.rm=T)
cn$PNCM5rc      <-cn$PNCM5r      -mean(cn$PNCM5r      ,na.rm=T)
cn$PNCF5rc      <-cn$PNCF5r      -mean(cn$PNCF5r      ,na.rm=T)
cn$PNCW5rc      <-cn$PNCW5r      -mean(cn$PNCW5r      ,na.rm=T)
cn$PNCB5rc      <-cn$PNCB5r      -mean(cn$PNCB5r      ,na.rm=T)
cn$PNCH5rc      <-cn$PNCH5r      -mean(cn$PNCH5r      ,na.rm=T)
cn$TBBT5rc      <-cn$TBBT5r      -mean(cn$TBBT5r      ,na.rm=T)
cn$TBBM5rc      <-cn$TBBM5r      -mean(cn$TBBM5r      ,na.rm=T)
cn$TBBF5rc      <-cn$TBBF5r      -mean(cn$TBBF5r      ,na.rm=T)
cn$TBBW5rc      <-cn$TBBW5r      -mean(cn$TBBW5r      ,na.rm=T)
cn$TBBB5rc      <-cn$TBBB5r      -mean(cn$TBBB5r      ,na.rm=T)
cn$TBBH5rc      <-cn$TBBH5r      -mean(cn$TBBH5r      ,na.rm=T)
cn$TBTT5rc      <-cn$TBTT5r      -mean(cn$TBTT5r      ,na.rm=T)
cn$TBTM5rc      <-cn$TBTM5r      -mean(cn$TBTM5r      ,na.rm=T)
cn$TBTF5rc      <-cn$TBTF5r      -mean(cn$TBTF5r      ,na.rm=T)
cn$TBTW5rc      <-cn$TBTW5r      -mean(cn$TBTW5r      ,na.rm=T)
cn$TBTB5rc      <-cn$TBTB5r      -mean(cn$TBTB5r      ,na.rm=T)
cn$TBTH5rc      <-cn$TBTH5r      -mean(cn$TBTH5r      ,na.rm=T)
cn$Opioidc      <-cn$Opioid      -mean(cn$Opioid      ,na.rm=T)
cn$LifeExpc     <-cn$LifeExp     -mean(cn$LifeExp     ,na.rm=T)
cn$LifeExpBc    <-cn$LifeExpB    -mean(cn$LifeExpB    ,na.rm=T)
cn$LifeExpHc    <-cn$LifeExpH    -mean(cn$LifeExpH    ,na.rm=T)
cn$LifeExpWc    <-cn$LifeExpW    -mean(cn$LifeExpW    ,na.rm=T)
cn$ChdDeathc    <-cn$ChdDeath    -mean(cn$ChdDeath    ,na.rm=T)
cn$ChdDeathBc   <-cn$ChdDeathB   -mean(cn$ChdDeathB   ,na.rm=T)
cn$ChdDeathHc   <-cn$ChdDeathH   -mean(cn$ChdDeathH   ,na.rm=T)
cn$ChdDeathWc   <-cn$ChdDeathW   -mean(cn$ChdDeathW   ,na.rm=T)
cn$InfDeathc    <-cn$InfDeath    -mean(cn$InfDeath    ,na.rm=T)
cn$InfDeathBc   <-cn$InfDeathB   -mean(cn$InfDeathB   ,na.rm=T)
cn$InfDeathHc   <-cn$InfDeathH   -mean(cn$InfDeathH   ,na.rm=T)
cn$InfDeathWc   <-cn$InfDeathW   -mean(cn$InfDeathW   ,na.rm=T)
cn$Injuryc      <-cn$Injury      -mean(cn$Injury      ,na.rm=T)
cn$InjuryBc     <-cn$InjuryB     -mean(cn$InjuryB     ,na.rm=T)
cn$InjuryHc     <-cn$InjuryH     -mean(cn$InjuryH     ,na.rm=T)
cn$InjuryWc     <-cn$InjuryW     -mean(cn$InjuryW     ,na.rm=T)
cn$GunDeathc    <-cn$GunDeath    -mean(cn$GunDeath    ,na.rm=T)
cn$GunDeathBc   <-cn$GunDeathB   -mean(cn$GunDeathB   ,na.rm=T)
cn$GunDeathWc   <-cn$GunDeathW   -mean(cn$GunDeathW   ,na.rm=T)
cn$PrmDeath_c   <-cn$PrmDeath    -mean(cn$PrmDeath    ,na.rm=T)
cn$PrmDeathcc   <-cn$PrmDeathc   -mean(cn$PrmDeathc   ,na.rm=T)
cn$PrmDeathBc   <-cn$PrmDeathB   -mean(cn$PrmDeathB   ,na.rm=T)
cn$PrmDeathHc   <-cn$PrmDeathH   -mean(cn$PrmDeathH   ,na.rm=T)
cn$PrmDeathWc   <-cn$PrmDeathW   -mean(cn$PrmDeathW   ,na.rm=T)
cn$PrmDeath2_c  <-cn$PrmDeath2   -mean(cn$PrmDeath2   ,na.rm=T)
cn$PrmDeath2cc  <-cn$PrmDeath2c  -mean(cn$PrmDeath2c  ,na.rm=T)
cn$PrmDeath2Bc  <-cn$PrmDeath2B  -mean(cn$PrmDeath2B  ,na.rm=T)
cn$PrmDeath2Hc  <-cn$PrmDeath2H  -mean(cn$PrmDeath2H  ,na.rm=T)
cn$PrmDeath2Wc  <-cn$PrmDeath2W  -mean(cn$PrmDeath2W  ,na.rm=T)
cn$Suicidec     <-cn$Suicide     -mean(cn$Suicide     ,na.rm=T)
cn$Diabetc      <-cn$Diabet      -mean(cn$Diabet      ,na.rm=T)
cn$Obesityc     <-cn$Obesity     -mean(cn$Obesity     ,na.rm=T)
cn$Physicalc    <-cn$Physical    -mean(cn$Physical    ,na.rm=T)
cn$PoorHlthc    <-cn$PoorHlth    -mean(cn$PoorHlth    ,na.rm=T)
cn$PoorMHc      <-cn$PoorMH      -mean(cn$PoorMH      ,na.rm=T)
cn$PoorPhyc     <-cn$PoorPhy     -mean(cn$PoorPhy     ,na.rm=T)
cn$Sleepc       <-cn$Sleep       -mean(cn$Sleep       ,na.rm=T)
cn$DrugOdc      <-cn$DrugOd      -mean(cn$DrugOd      ,na.rm=T)
cn$DrugOdBc     <-cn$DrugOdB     -mean(cn$DrugOdB     ,na.rm=T)
cn$DrugOdHc     <-cn$DrugOdH     -mean(cn$DrugOdH     ,na.rm=T)
cn$DrugOdWc     <-cn$DrugOdW     -mean(cn$DrugOdW     ,na.rm=T)
cn$DWIDeathc    <-cn$DWIDeath    -mean(cn$DWIDeath    ,na.rm=T)
cn$EDrinkc      <-cn$EDrink      -mean(cn$EDrink      ,na.rm=T)
cn$Smokec       <-cn$Smoke       -mean(cn$Smoke       ,na.rm=T)
cn$FastFoodc    <-cn$FastFood    -mean(cn$FastFood    ,na.rm=T)
cn$FoodEnvc     <-cn$FoodEnv     -mean(cn$FoodEnv     ,na.rm=T)
cn$FoodInsc     <-cn$FoodIns     -mean(cn$FoodIns     ,na.rm=T)
cn$FrLunchc     <-cn$FrLunch     -mean(cn$FrLunch     ,na.rm=T)
cn$LAccFoodc    <-cn$LAccFood    -mean(cn$LAccFood    ,na.rm=T)
cn$Gymc         <-cn$Gym         -mean(cn$Gym         ,na.rm=T)
cn$Gym2c        <-cn$Gym2        -mean(cn$Gym2        ,na.rm=T)
cn$Inactivec    <-cn$Inactive    -mean(cn$Inactive    ,na.rm=T)
cn$HousCostc    <-cn$HousCost    -mean(cn$HousCost    ,na.rm=T)
cn$HousCostsc   <-cn$HousCosts   -mean(cn$HousCosts   ,na.rm=T)
cn$HousCrowdc   <-cn$HousCrowd   -mean(cn$HousCrowd   ,na.rm=T)
cn$Housingc     <-cn$Housing     -mean(cn$Housing     ,na.rm=T)
cn$HousPlumbc   <-cn$HousPlumb   -mean(cn$HousPlumb   ,na.rm=T)
cn$Insuredc     <-cn$Insured     -mean(cn$Insured     ,na.rm=T)
cn$InsuredAc    <-cn$InsuredA    -mean(cn$InsuredA    ,na.rm=T)
cn$InsuredCc    <-cn$InsuredC    -mean(cn$InsuredC    ,na.rm=T)
cn$JuvArrc      <-cn$JuvArr      -mean(cn$JuvArr      ,na.rm=T)
cn$Murderc      <-cn$Murder      -mean(cn$Murder      ,na.rm=T)
cn$Violentc     <-cn$Violent     -mean(cn$Violent     ,na.rm=T)
cn$LongCommc    <-cn$LongComm    -mean(cn$LongComm    ,na.rm=T)
cn$LowBWc       <-cn$LowBW       -mean(cn$LowBW       ,na.rm=T)
cn$LowBWBc      <-cn$LowBWB      -mean(cn$LowBWB      ,na.rm=T)
cn$LowBWHc      <-cn$LowBWH      -mean(cn$LowBWH      ,na.rm=T)
cn$LowBWWc      <-cn$LowBWW      -mean(cn$LowBWW      ,na.rm=T)
cn$TeenBthc     <-cn$TeenBth     -mean(cn$TeenBth     ,na.rm=T)
cn$TeenBthBc    <-cn$TeenBthB    -mean(cn$TeenBthB    ,na.rm=T)
cn$TeenBthHc    <-cn$TeenBthH    -mean(cn$TeenBthH    ,na.rm=T)
cn$TeenBthWc    <-cn$TeenBthW    -mean(cn$TeenBthW    ,na.rm=T)
cn$Mentalc      <-cn$Mental      -mean(cn$Mental      ,na.rm=T)
cn$MHPrvdc      <-cn$MHPrvd      -mean(cn$MHPrvd      ,na.rm=T)
cn$PCPc         <-cn$PCP         -mean(cn$PCP         ,na.rm=T)
cn$PCP2c        <-cn$PCP2        -mean(cn$PCP2        ,na.rm=T)
cn$Dentistc     <-cn$Dentist     -mean(cn$Dentist     ,na.rm=T)
cn$PrvtHospc    <-cn$PrvtHosp    -mean(cn$PrvtHosp    ,na.rm=T)
cn$PrvtHospBc   <-cn$PrvtHospB   -mean(cn$PrvtHospB   ,na.rm=T)
cn$PrvtHospHc   <-cn$PrvtHospH   -mean(cn$PrvtHospH   ,na.rm=T)
cn$PrvtHospWc   <-cn$PrvtHospW   -mean(cn$PrvtHospW   ,na.rm=T)
cn$SegBWc       <-cn$SegBW       -mean(cn$SegBW       ,na.rm=T)
cn$SegNWc       <-cn$SegNW       -mean(cn$SegNW       ,na.rm=T)
cn$SocAssoc     <-cn$SocAsso     -mean(cn$SocAsso     ,na.rm=T)
cn$SocSuppc     <-cn$SocSupp     -mean(cn$SocSupp     ,na.rm=T)
cn$MIECHVc      <-cn$MIECHV      -mean(cn$MIECHV      ,na.rm=T)
cn$NHVRCc       <-cn$NHVRC       -mean(cn$NHVRC       ,na.rm=T)
cn$HomeV2c      <-cn$HomeV2      -mean(cn$HomeV2      ,na.rm=T)
cn$FoodInsecurec<-cn$FoodInsecure-mean(cn$FoodInsecure,na.rm=T)

cn<-cbind(cn,demean(cn,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cnm01<-lmer(NegTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm02<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm03<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm04<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm05<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm06<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm07<-lmer(NegTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cnm01,cnm02,cnm03,cnm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cnm04,cnm05,cnm06,cnm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cnm01CI<-confint(cnm01,method='boot',nsim=500,boot.type='perc')
cnm02CI<-confint(cnm02,method='boot',nsim=500,boot.type='perc')
cnm03CI<-confint(cnm03,method='boot',nsim=500,boot.type='perc')
cnm04CI<-confint(cnm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cnm01)
check_collinearity(cnm02)
check_collinearity(cnm03)
check_collinearity(cnm04)
isSingular(cnm01)
isSingular(cnm02)
isSingular(cnm03)
isSingular(cnm04)




# Model building
cnm01a<-lmer(NegTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm02a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm03a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm04a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm05a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm06a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))
cnm07a<-lmer(NegTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cn,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cnm01a,cnm02a,cnm03a,cnm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cnm04a,cnm05a,cnm06a,cnm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cnm01aCI<-confint(cnm01a,method='boot',nsim=500,boot.type='perc')
cnm02aCI<-confint(cnm02a,method='boot',nsim=500,boot.type='perc')
cnm03aCI<-confint(cnm03a,method='boot',nsim=500,boot.type='perc')
cnm04aCI<-confint(cnm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cnm01a)
check_collinearity(cnm02a)
check_collinearity(cnm03a)
check_collinearity(cnm04a)
isSingular(cnm01a)
isSingular(cnm02a)
isSingular(cnm03a)
isSingular(cnm04a)



cng02<-glmmTMB(NegT~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cn,family=nbinom2)
cng02a<-glmmTMB(NegT~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cn,family=nbinom2)




###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cp$CPopBPc      <-cp$CPopBP      -mean(cp$CPopBP      ,na.rm=T)
cp$CPopHPc      <-cp$CPopHP      -mean(cp$CPopHP      ,na.rm=T)
cp$ChildPTc     <-cp$ChildPT     -mean(cp$ChildPT     ,na.rm=T)
cp$ChildPWc     <-cp$ChildPW     -mean(cp$ChildPW     ,na.rm=T)
cp$ChildPBc     <-cp$ChildPB     -mean(cp$ChildPB     ,na.rm=T)
cp$ChildPHc     <-cp$ChildPH     -mean(cp$ChildPH     ,na.rm=T)
cp$CARatioT100c <-cp$CARatioT100 -mean(cp$CARatioT100 ,na.rm=T)
cp$CARatioW100c <-cp$CARatioW100 -mean(cp$CARatioW100 ,na.rm=T)
cp$CARatioB100c <-cp$CARatioB100 -mean(cp$CARatioB100 ,na.rm=T)
cp$CARatioH100c <-cp$CARatioH100 -mean(cp$CARatioH100 ,na.rm=T)
cp$MalePTc      <-cp$MalePT      -mean(cp$MalePT      ,na.rm=T)
cp$MalePWc      <-cp$MalePW      -mean(cp$MalePW      ,na.rm=T)
cp$MalePBc      <-cp$MalePB      -mean(cp$MalePB      ,na.rm=T)
cp$MalePHc      <-cp$MalePH      -mean(cp$MalePH      ,na.rm=T)
cp$MFRatioT100c <-cp$MFRatioT100 -mean(cp$MFRatioT100 ,na.rm=T)
cp$MFRatioW100c <-cp$MFRatioW100 -mean(cp$MFRatioW100 ,na.rm=T)
cp$MFRatioB100c <-cp$MFRatioB100 -mean(cp$MFRatioB100 ,na.rm=T)
cp$MFRatioH100c <-cp$MFRatioH100 -mean(cp$MFRatioH100 ,na.rm=T)
cp$ElderTc      <-cp$ElderT      -mean(cp$ElderT      ,na.rm=T)
cp$ElderWc      <-cp$ElderW      -mean(cp$ElderW      ,na.rm=T)
cp$ElderBc      <-cp$ElderB      -mean(cp$ElderB      ,na.rm=T)
cp$ElderHc      <-cp$ElderH      -mean(cp$ElderH      ,na.rm=T)
cp$SingleTc     <-cp$SingleT     -mean(cp$SingleT     ,na.rm=T)
cp$SingleWc     <-cp$SingleW     -mean(cp$SingleW     ,na.rm=T)
cp$SingleBc     <-cp$SingleB     -mean(cp$SingleB     ,na.rm=T)
cp$SingleHc     <-cp$SingleH     -mean(cp$SingleH     ,na.rm=T)
cp$FHeadTc      <-cp$FHeadT      -mean(cp$FHeadT      ,na.rm=T)
cp$FHeadWc      <-cp$FHeadW      -mean(cp$FHeadW      ,na.rm=T)
cp$FHeadBc      <-cp$FHeadB      -mean(cp$FHeadB      ,na.rm=T)
cp$FHeadHc      <-cp$FHeadH      -mean(cp$FHeadH      ,na.rm=T)
cp$NoHighTc     <-cp$NoHighT     -mean(cp$NoHighT     ,na.rm=T)
cp$NoHighWc     <-cp$NoHighW     -mean(cp$NoHighW     ,na.rm=T)
cp$NoHighBc     <-cp$NoHighB     -mean(cp$NoHighB     ,na.rm=T)
cp$NoHighHc     <-cp$NoHighH     -mean(cp$NoHighH     ,na.rm=T)
cp$UnempTc      <-cp$UnempT      -mean(cp$UnempT      ,na.rm=T)
cp$UnempWc      <-cp$UnempW      -mean(cp$UnempW      ,na.rm=T)
cp$UnempBc      <-cp$UnempB      -mean(cp$UnempB      ,na.rm=T)
cp$UnempHc      <-cp$UnempH      -mean(cp$UnempH      ,na.rm=T)
cp$CPovTc       <-cp$CPovT       -mean(cp$CPovT       ,na.rm=T)
cp$CPovWc       <-cp$CPovW       -mean(cp$CPovW       ,na.rm=T)
cp$CPovBc       <-cp$CPovB       -mean(cp$CPovB       ,na.rm=T)
cp$CPovHc       <-cp$CPovH       -mean(cp$CPovH       ,na.rm=T)
cp$CPov1c       <-cp$CPov1       -mean(cp$CPov1       ,na.rm=T)
cp$CPov2c       <-cp$CPov2       -mean(cp$CPov2       ,na.rm=T)
cp$CPov3c       <-cp$CPov3       -mean(cp$CPov3       ,na.rm=T)
cp$PubAsTc      <-cp$PubAsT      -mean(cp$PubAsT      ,na.rm=T)
cp$WelfarTc     <-cp$WelfarT     -mean(cp$WelfarT     ,na.rm=T)
cp$SnapTc       <-cp$SnapT       -mean(cp$SnapT       ,na.rm=T)
cp$SnapWc       <-cp$SnapW       -mean(cp$SnapW       ,na.rm=T)
cp$SnapBc       <-cp$SnapB       -mean(cp$SnapB       ,na.rm=T)
cp$SnapHc       <-cp$SnapH       -mean(cp$SnapH       ,na.rm=T)
cp$IncomeT1kc   <-cp$IncomeT1k   -mean(cp$IncomeT1k   ,na.rm=T)
cp$IncomeW1kc   <-cp$IncomeW1k   -mean(cp$IncomeW1k   ,na.rm=T)
cp$IncomeB1kc   <-cp$IncomeB1k   -mean(cp$IncomeB1k   ,na.rm=T)
cp$IncomeH1kc   <-cp$IncomeH1k   -mean(cp$IncomeH1k   ,na.rm=T)
cp$GiniT100c    <-cp$GiniT100    -mean(cp$GiniT100    ,na.rm=T)
cp$HValueT10kc  <-cp$HValueT10k  -mean(cp$HValueT10k  ,na.rm=T)
cp$MCostT100c   <-cp$MCostT100   -mean(cp$MCostT100   ,na.rm=T)
cp$OCostDT100c  <-cp$OCostDT100  -mean(cp$OCostDT100  ,na.rm=T)
cp$MRentDT100c  <-cp$MRentDT100  -mean(cp$MRentDT100  ,na.rm=T)
cp$OCostPTc     <-cp$OCostPT     -mean(cp$OCostPT     ,na.rm=T)
cp$MRentPTc     <-cp$MRentPT     -mean(cp$MRentPT     ,na.rm=T)
cp$MortgTc      <-cp$MortgT      -mean(cp$MortgT      ,na.rm=T)
cp$LangAPTc     <-cp$LangAPT     -mean(cp$LangAPT     ,na.rm=T)
cp$LangAPWc     <-cp$LangAPW     -mean(cp$LangAPW     ,na.rm=T)
cp$LangAPBc     <-cp$LangAPB     -mean(cp$LangAPB     ,na.rm=T)
cp$LangAPHc     <-cp$LangAPH     -mean(cp$LangAPH     ,na.rm=T)
cp$LangBPTc     <-cp$LangBPT     -mean(cp$LangBPT     ,na.rm=T)
cp$LangBPWc     <-cp$LangBPW     -mean(cp$LangBPW     ,na.rm=T)
cp$LangBPBc     <-cp$LangBPB     -mean(cp$LangBPB     ,na.rm=T)
cp$LangBPHc     <-cp$LangBPH     -mean(cp$LangBPH     ,na.rm=T)
cp$LangCPTc     <-cp$LangCPT     -mean(cp$LangCPT     ,na.rm=T)
cp$OutUsTc      <-cp$OutUsT      -mean(cp$OutUsT      ,na.rm=T)
cp$OutUsWc      <-cp$OutUsW      -mean(cp$OutUsW      ,na.rm=T)
cp$OutUsBc      <-cp$OutUsB      -mean(cp$OutUsB      ,na.rm=T)
cp$OutUsHc      <-cp$OutUsH      -mean(cp$OutUsH      ,na.rm=T)
cp$FBornTc      <-cp$FBornT      -mean(cp$FBornT      ,na.rm=T)
cp$FBornWc      <-cp$FBornW      -mean(cp$FBornW      ,na.rm=T)
cp$FBornBc      <-cp$FBornB      -mean(cp$FBornB      ,na.rm=T)
cp$FBornHc      <-cp$FBornH      -mean(cp$FBornH      ,na.rm=T)
cp$NotCtzTc     <-cp$NotCtzT     -mean(cp$NotCtzT     ,na.rm=T)
cp$NotCtzWc     <-cp$NotCtzW     -mean(cp$NotCtzW     ,na.rm=T)
cp$NotCtzBc     <-cp$NotCtzB     -mean(cp$NotCtzB     ,na.rm=T)
cp$NotCtzHc     <-cp$NotCtzH     -mean(cp$NotCtzH     ,na.rm=T)
cp$MoveTc       <-cp$MoveT       -mean(cp$MoveT       ,na.rm=T)
cp$MoveWc       <-cp$MoveW       -mean(cp$MoveW       ,na.rm=T)
cp$MoveBc       <-cp$MoveB       -mean(cp$MoveB       ,na.rm=T)
cp$MoveHc       <-cp$MoveH       -mean(cp$MoveH       ,na.rm=T)
cp$VacantTc     <-cp$VacantT     -mean(cp$VacantT     ,na.rm=T)
cp$OwnerTc      <-cp$OwnerT      -mean(cp$OwnerT      ,na.rm=T)
cp$OwnerWc      <-cp$OwnerW      -mean(cp$OwnerW      ,na.rm=T)
cp$OwnerBc      <-cp$OwnerB      -mean(cp$OwnerB      ,na.rm=T)
cp$OwnerHc      <-cp$OwnerH      -mean(cp$OwnerH      ,na.rm=T)
cp$CrowdTc      <-cp$CrowdT      -mean(cp$CrowdT      ,na.rm=T)
cp$CrowdWc      <-cp$CrowdW      -mean(cp$CrowdW      ,na.rm=T)
cp$CrowdBc      <-cp$CrowdB      -mean(cp$CrowdB      ,na.rm=T)
cp$CrowdHc      <-cp$CrowdH      -mean(cp$CrowdH      ,na.rm=T)
cp$MobileTc     <-cp$MobileT     -mean(cp$MobileT     ,na.rm=T)
cp$MobileWc     <-cp$MobileW     -mean(cp$MobileW     ,na.rm=T)
cp$MobileBc     <-cp$MobileB     -mean(cp$MobileB     ,na.rm=T)
cp$MobileHc     <-cp$MobileH     -mean(cp$MobileH     ,na.rm=T)
cp$DisablTc     <-cp$DisablT     -mean(cp$DisablT     ,na.rm=T)
cp$DisablWc     <-cp$DisablW     -mean(cp$DisablW     ,na.rm=T)
cp$DisablBc     <-cp$DisablB     -mean(cp$DisablB     ,na.rm=T)
cp$DisablHc     <-cp$DisablH     -mean(cp$DisablH     ,na.rm=T)
cp$DisablTCc    <-cp$DisablTC    -mean(cp$DisablTC    ,na.rm=T)
cp$DisablWCc    <-cp$DisablWC    -mean(cp$DisablWC    ,na.rm=T)
cp$DisablBCc    <-cp$DisablBC    -mean(cp$DisablBC    ,na.rm=T)
cp$DisablHCc    <-cp$DisablHC    -mean(cp$DisablHC    ,na.rm=T)
cp$DisablTMc    <-cp$DisablTM    -mean(cp$DisablTM    ,na.rm=T)
cp$DisablTFc    <-cp$DisablTF    -mean(cp$DisablTF    ,na.rm=T)
cp$Urban1c      <-cp$Urban1      -mean(cp$Urban1      ,na.rm=T)
cp$Urban2c      <-cp$Urban2      -mean(cp$Urban2      ,na.rm=T)
cp$LBWT1rc      <-cp$LBWT1r      -mean(cp$LBWT1r      ,na.rm=T)
cp$LBWM1rc      <-cp$LBWM1r      -mean(cp$LBWM1r      ,na.rm=T)
cp$LBWF1rc      <-cp$LBWF1r      -mean(cp$LBWF1r      ,na.rm=T)
cp$LBWW1rc      <-cp$LBWW1r      -mean(cp$LBWW1r      ,na.rm=T)
cp$LBWB1rc      <-cp$LBWB1r      -mean(cp$LBWB1r      ,na.rm=T)
cp$LBWH1rc      <-cp$LBWH1r      -mean(cp$LBWH1r      ,na.rm=T)
cp$PTBT1rc      <-cp$PTBT1r      -mean(cp$PTBT1r      ,na.rm=T)
cp$PTBM1rc      <-cp$PTBM1r      -mean(cp$PTBM1r      ,na.rm=T)
cp$PTBF1rc      <-cp$PTBF1r      -mean(cp$PTBF1r      ,na.rm=T)
cp$PTBW1rc      <-cp$PTBW1r      -mean(cp$PTBW1r      ,na.rm=T)
cp$PTBB1rc      <-cp$PTBB1r      -mean(cp$PTBB1r      ,na.rm=T)
cp$PTBH1rc      <-cp$PTBH1r      -mean(cp$PTBH1r      ,na.rm=T)
cp$PNCT1rc      <-cp$PNCT1r      -mean(cp$PNCT1r      ,na.rm=T)
cp$PNCM1rc      <-cp$PNCM1r      -mean(cp$PNCM1r      ,na.rm=T)
cp$PNCF1rc      <-cp$PNCF1r      -mean(cp$PNCF1r      ,na.rm=T)
cp$PNCW1rc      <-cp$PNCW1r      -mean(cp$PNCW1r      ,na.rm=T)
cp$PNCB1rc      <-cp$PNCB1r      -mean(cp$PNCB1r      ,na.rm=T)
cp$PNCH1rc      <-cp$PNCH1r      -mean(cp$PNCH1r      ,na.rm=T)
cp$TBBT1rc      <-cp$TBBT1r      -mean(cp$TBBT1r      ,na.rm=T)
cp$TBBM1rc      <-cp$TBBM1r      -mean(cp$TBBM1r      ,na.rm=T)
cp$TBBF1rc      <-cp$TBBF1r      -mean(cp$TBBF1r      ,na.rm=T)
cp$TBBW1rc      <-cp$TBBW1r      -mean(cp$TBBW1r      ,na.rm=T)
cp$TBBB1rc      <-cp$TBBB1r      -mean(cp$TBBB1r      ,na.rm=T)
cp$TBBH1rc      <-cp$TBBH1r      -mean(cp$TBBH1r      ,na.rm=T)
cp$TBTT1rc      <-cp$TBTT1r      -mean(cp$TBTT1r      ,na.rm=T)
cp$TBTM1rc      <-cp$TBTM1r      -mean(cp$TBTM1r      ,na.rm=T)
cp$TBTF1rc      <-cp$TBTF1r      -mean(cp$TBTF1r      ,na.rm=T)
cp$TBTW1rc      <-cp$TBTW1r      -mean(cp$TBTW1r      ,na.rm=T)
cp$TBTB1rc      <-cp$TBTB1r      -mean(cp$TBTB1r      ,na.rm=T)
cp$TBTH1rc      <-cp$TBTH1r      -mean(cp$TBTH1r      ,na.rm=T)
cp$LBWT5rc      <-cp$LBWT5r      -mean(cp$LBWT5r      ,na.rm=T)
cp$LBWM5rc      <-cp$LBWM5r      -mean(cp$LBWM5r      ,na.rm=T)
cp$LBWF5rc      <-cp$LBWF5r      -mean(cp$LBWF5r      ,na.rm=T)
cp$LBWW5rc      <-cp$LBWW5r      -mean(cp$LBWW5r      ,na.rm=T)
cp$LBWB5rc      <-cp$LBWB5r      -mean(cp$LBWB5r      ,na.rm=T)
cp$LBWH5rc      <-cp$LBWH5r      -mean(cp$LBWH5r      ,na.rm=T)
cp$PTBT5rc      <-cp$PTBT5r      -mean(cp$PTBT5r      ,na.rm=T)
cp$PTBM5rc      <-cp$PTBM5r      -mean(cp$PTBM5r      ,na.rm=T)
cp$PTBF5rc      <-cp$PTBF5r      -mean(cp$PTBF5r      ,na.rm=T)
cp$PTBW5rc      <-cp$PTBW5r      -mean(cp$PTBW5r      ,na.rm=T)
cp$PTBB5rc      <-cp$PTBB5r      -mean(cp$PTBB5r      ,na.rm=T)
cp$PTBH5rc      <-cp$PTBH5r      -mean(cp$PTBH5r      ,na.rm=T)
cp$PNCT5rc      <-cp$PNCT5r      -mean(cp$PNCT5r      ,na.rm=T)
cp$PNCM5rc      <-cp$PNCM5r      -mean(cp$PNCM5r      ,na.rm=T)
cp$PNCF5rc      <-cp$PNCF5r      -mean(cp$PNCF5r      ,na.rm=T)
cp$PNCW5rc      <-cp$PNCW5r      -mean(cp$PNCW5r      ,na.rm=T)
cp$PNCB5rc      <-cp$PNCB5r      -mean(cp$PNCB5r      ,na.rm=T)
cp$PNCH5rc      <-cp$PNCH5r      -mean(cp$PNCH5r      ,na.rm=T)
cp$TBBT5rc      <-cp$TBBT5r      -mean(cp$TBBT5r      ,na.rm=T)
cp$TBBM5rc      <-cp$TBBM5r      -mean(cp$TBBM5r      ,na.rm=T)
cp$TBBF5rc      <-cp$TBBF5r      -mean(cp$TBBF5r      ,na.rm=T)
cp$TBBW5rc      <-cp$TBBW5r      -mean(cp$TBBW5r      ,na.rm=T)
cp$TBBB5rc      <-cp$TBBB5r      -mean(cp$TBBB5r      ,na.rm=T)
cp$TBBH5rc      <-cp$TBBH5r      -mean(cp$TBBH5r      ,na.rm=T)
cp$TBTT5rc      <-cp$TBTT5r      -mean(cp$TBTT5r      ,na.rm=T)
cp$TBTM5rc      <-cp$TBTM5r      -mean(cp$TBTM5r      ,na.rm=T)
cp$TBTF5rc      <-cp$TBTF5r      -mean(cp$TBTF5r      ,na.rm=T)
cp$TBTW5rc      <-cp$TBTW5r      -mean(cp$TBTW5r      ,na.rm=T)
cp$TBTB5rc      <-cp$TBTB5r      -mean(cp$TBTB5r      ,na.rm=T)
cp$TBTH5rc      <-cp$TBTH5r      -mean(cp$TBTH5r      ,na.rm=T)
cp$Opioidc      <-cp$Opioid      -mean(cp$Opioid      ,na.rm=T)
cp$LifeExpc     <-cp$LifeExp     -mean(cp$LifeExp     ,na.rm=T)
cp$LifeExpBc    <-cp$LifeExpB    -mean(cp$LifeExpB    ,na.rm=T)
cp$LifeExpHc    <-cp$LifeExpH    -mean(cp$LifeExpH    ,na.rm=T)
cp$LifeExpWc    <-cp$LifeExpW    -mean(cp$LifeExpW    ,na.rm=T)
cp$ChdDeathc    <-cp$ChdDeath    -mean(cp$ChdDeath    ,na.rm=T)
cp$ChdDeathBc   <-cp$ChdDeathB   -mean(cp$ChdDeathB   ,na.rm=T)
cp$ChdDeathHc   <-cp$ChdDeathH   -mean(cp$ChdDeathH   ,na.rm=T)
cp$ChdDeathWc   <-cp$ChdDeathW   -mean(cp$ChdDeathW   ,na.rm=T)
cp$InfDeathc    <-cp$InfDeath    -mean(cp$InfDeath    ,na.rm=T)
cp$InfDeathBc   <-cp$InfDeathB   -mean(cp$InfDeathB   ,na.rm=T)
cp$InfDeathHc   <-cp$InfDeathH   -mean(cp$InfDeathH   ,na.rm=T)
cp$InfDeathWc   <-cp$InfDeathW   -mean(cp$InfDeathW   ,na.rm=T)
cp$Injuryc      <-cp$Injury      -mean(cp$Injury      ,na.rm=T)
cp$InjuryBc     <-cp$InjuryB     -mean(cp$InjuryB     ,na.rm=T)
cp$InjuryHc     <-cp$InjuryH     -mean(cp$InjuryH     ,na.rm=T)
cp$InjuryWc     <-cp$InjuryW     -mean(cp$InjuryW     ,na.rm=T)
cp$GunDeathc    <-cp$GunDeath    -mean(cp$GunDeath    ,na.rm=T)
cp$GunDeathBc   <-cp$GunDeathB   -mean(cp$GunDeathB   ,na.rm=T)
cp$GunDeathWc   <-cp$GunDeathW   -mean(cp$GunDeathW   ,na.rm=T)
cp$PrmDeath_c   <-cp$PrmDeath    -mean(cp$PrmDeath    ,na.rm=T)
cp$PrmDeathcc   <-cp$PrmDeathc   -mean(cp$PrmDeathc   ,na.rm=T)
cp$PrmDeathBc   <-cp$PrmDeathB   -mean(cp$PrmDeathB   ,na.rm=T)
cp$PrmDeathHc   <-cp$PrmDeathH   -mean(cp$PrmDeathH   ,na.rm=T)
cp$PrmDeathWc   <-cp$PrmDeathW   -mean(cp$PrmDeathW   ,na.rm=T)
cp$PrmDeath2_c  <-cp$PrmDeath2   -mean(cp$PrmDeath2   ,na.rm=T)
cp$PrmDeath2cc  <-cp$PrmDeath2c  -mean(cp$PrmDeath2c  ,na.rm=T)
cp$PrmDeath2Bc  <-cp$PrmDeath2B  -mean(cp$PrmDeath2B  ,na.rm=T)
cp$PrmDeath2Hc  <-cp$PrmDeath2H  -mean(cp$PrmDeath2H  ,na.rm=T)
cp$PrmDeath2Wc  <-cp$PrmDeath2W  -mean(cp$PrmDeath2W  ,na.rm=T)
cp$Suicidec     <-cp$Suicide     -mean(cp$Suicide     ,na.rm=T)
cp$Diabetc      <-cp$Diabet      -mean(cp$Diabet      ,na.rm=T)
cp$Obesityc     <-cp$Obesity     -mean(cp$Obesity     ,na.rm=T)
cp$Physicalc    <-cp$Physical    -mean(cp$Physical    ,na.rm=T)
cp$PoorHlthc    <-cp$PoorHlth    -mean(cp$PoorHlth    ,na.rm=T)
cp$PoorMHc      <-cp$PoorMH      -mean(cp$PoorMH      ,na.rm=T)
cp$PoorPhyc     <-cp$PoorPhy     -mean(cp$PoorPhy     ,na.rm=T)
cp$Sleepc       <-cp$Sleep       -mean(cp$Sleep       ,na.rm=T)
cp$DrugOdc      <-cp$DrugOd      -mean(cp$DrugOd      ,na.rm=T)
cp$DrugOdBc     <-cp$DrugOdB     -mean(cp$DrugOdB     ,na.rm=T)
cp$DrugOdHc     <-cp$DrugOdH     -mean(cp$DrugOdH     ,na.rm=T)
cp$DrugOdWc     <-cp$DrugOdW     -mean(cp$DrugOdW     ,na.rm=T)
cp$DWIDeathc    <-cp$DWIDeath    -mean(cp$DWIDeath    ,na.rm=T)
cp$EDrinkc      <-cp$EDrink      -mean(cp$EDrink      ,na.rm=T)
cp$Smokec       <-cp$Smoke       -mean(cp$Smoke       ,na.rm=T)
cp$FastFoodc    <-cp$FastFood    -mean(cp$FastFood    ,na.rm=T)
cp$FoodEnvc     <-cp$FoodEnv     -mean(cp$FoodEnv     ,na.rm=T)
cp$FoodInsc     <-cp$FoodIns     -mean(cp$FoodIns     ,na.rm=T)
cp$FrLunchc     <-cp$FrLunch     -mean(cp$FrLunch     ,na.rm=T)
cp$LAccFoodc    <-cp$LAccFood    -mean(cp$LAccFood    ,na.rm=T)
cp$Gymc         <-cp$Gym         -mean(cp$Gym         ,na.rm=T)
cp$Gym2c        <-cp$Gym2        -mean(cp$Gym2        ,na.rm=T)
cp$Inactivec    <-cp$Inactive    -mean(cp$Inactive    ,na.rm=T)
cp$HousCostc    <-cp$HousCost    -mean(cp$HousCost    ,na.rm=T)
cp$HousCostsc   <-cp$HousCosts   -mean(cp$HousCosts   ,na.rm=T)
cp$HousCrowdc   <-cp$HousCrowd   -mean(cp$HousCrowd   ,na.rm=T)
cp$Housingc     <-cp$Housing     -mean(cp$Housing     ,na.rm=T)
cp$HousPlumbc   <-cp$HousPlumb   -mean(cp$HousPlumb   ,na.rm=T)
cp$Insuredc     <-cp$Insured     -mean(cp$Insured     ,na.rm=T)
cp$InsuredAc    <-cp$InsuredA    -mean(cp$InsuredA    ,na.rm=T)
cp$InsuredCc    <-cp$InsuredC    -mean(cp$InsuredC    ,na.rm=T)
cp$JuvArrc      <-cp$JuvArr      -mean(cp$JuvArr      ,na.rm=T)
cp$Murderc      <-cp$Murder      -mean(cp$Murder      ,na.rm=T)
cp$Violentc     <-cp$Violent     -mean(cp$Violent     ,na.rm=T)
cp$LongCommc    <-cp$LongComm    -mean(cp$LongComm    ,na.rm=T)
cp$LowBWc       <-cp$LowBW       -mean(cp$LowBW       ,na.rm=T)
cp$LowBWBc      <-cp$LowBWB      -mean(cp$LowBWB      ,na.rm=T)
cp$LowBWHc      <-cp$LowBWH      -mean(cp$LowBWH      ,na.rm=T)
cp$LowBWWc      <-cp$LowBWW      -mean(cp$LowBWW      ,na.rm=T)
cp$TeenBthc     <-cp$TeenBth     -mean(cp$TeenBth     ,na.rm=T)
cp$TeenBthBc    <-cp$TeenBthB    -mean(cp$TeenBthB    ,na.rm=T)
cp$TeenBthHc    <-cp$TeenBthH    -mean(cp$TeenBthH    ,na.rm=T)
cp$TeenBthWc    <-cp$TeenBthW    -mean(cp$TeenBthW    ,na.rm=T)
cp$Mentalc      <-cp$Mental      -mean(cp$Mental      ,na.rm=T)
cp$MHPrvdc      <-cp$MHPrvd      -mean(cp$MHPrvd      ,na.rm=T)
cp$PCPc         <-cp$PCP         -mean(cp$PCP         ,na.rm=T)
cp$PCP2c        <-cp$PCP2        -mean(cp$PCP2        ,na.rm=T)
cp$Dentistc     <-cp$Dentist     -mean(cp$Dentist     ,na.rm=T)
cp$PrvtHospc    <-cp$PrvtHosp    -mean(cp$PrvtHosp    ,na.rm=T)
cp$PrvtHospBc   <-cp$PrvtHospB   -mean(cp$PrvtHospB   ,na.rm=T)
cp$PrvtHospHc   <-cp$PrvtHospH   -mean(cp$PrvtHospH   ,na.rm=T)
cp$PrvtHospWc   <-cp$PrvtHospW   -mean(cp$PrvtHospW   ,na.rm=T)
cp$SegBWc       <-cp$SegBW       -mean(cp$SegBW       ,na.rm=T)
cp$SegNWc       <-cp$SegNW       -mean(cp$SegNW       ,na.rm=T)
cp$SocAssoc     <-cp$SocAsso     -mean(cp$SocAsso     ,na.rm=T)
cp$SocSuppc     <-cp$SocSupp     -mean(cp$SocSupp     ,na.rm=T)
cp$MIECHVc      <-cp$MIECHV      -mean(cp$MIECHV      ,na.rm=T)
cp$NHVRCc       <-cp$NHVRC       -mean(cp$NHVRC       ,na.rm=T)
cp$HomeV2c      <-cp$HomeV2      -mean(cp$HomeV2      ,na.rm=T)
cp$FoodInsecurec<-cp$FoodInsecure-mean(cp$FoodInsecure,na.rm=T)

cp<-cbind(cp,demean(cp,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))



# Model building
cpm01<-lmer(PhyTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm02<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm03<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm04<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm05<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm06<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm07<-lmer(PhyTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cpm01,cpm02,cpm03,cpm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cpm04,cpm05,cpm06,cpm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cpm01CI<-confint(cpm01,method='boot',nsim=500,boot.type='perc')
cpm02CI<-confint(cpm02,method='boot',nsim=500,boot.type='perc')
cpm03CI<-confint(cpm03,method='boot',nsim=500,boot.type='perc')
cpm04CI<-confint(cpm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cpm01)
check_collinearity(cpm02)
check_collinearity(cpm03)
check_collinearity(cpm04)
isSingular(cpm01)
isSingular(cpm02)
isSingular(cpm03)
isSingular(cpm04)





# Model building
cpm01a<-lmer(PhyTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm02a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm03a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm04a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm05a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm06a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))
cpm07a<-lmer(PhyTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cp,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cpm01a,cpm02a,cpm03a,cpm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cpm04a,cpm05a,cpm06a,cpm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cpm01aCI<-confint(cpm01a,method='boot',nsim=500,boot.type='perc')
cpm02aCI<-confint(cpm02a,method='boot',nsim=500,boot.type='perc')
cpm03aCI<-confint(cpm03a,method='boot',nsim=500,boot.type='perc')
cpm04aCI<-confint(cpm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cpm01a)
check_collinearity(cpm02a)
check_collinearity(cpm03a)
check_collinearity(cpm04a)
isSingular(cpm01a)
isSingular(cpm02a)
isSingular(cpm03a)
isSingular(cpm04a)


cpg02<-glmmTMB(PhyT~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cp,family=nbinom2)
cpg02a<-glmmTMB(PhyT~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cp,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cs$CPopBPc      <-cs$CPopBP      -mean(cs$CPopBP      ,na.rm=T)
cs$CPopHPc      <-cs$CPopHP      -mean(cs$CPopHP      ,na.rm=T)
cs$ChildPTc     <-cs$ChildPT     -mean(cs$ChildPT     ,na.rm=T)
cs$ChildPWc     <-cs$ChildPW     -mean(cs$ChildPW     ,na.rm=T)
cs$ChildPBc     <-cs$ChildPB     -mean(cs$ChildPB     ,na.rm=T)
cs$ChildPHc     <-cs$ChildPH     -mean(cs$ChildPH     ,na.rm=T)
cs$CARatioT100c <-cs$CARatioT100 -mean(cs$CARatioT100 ,na.rm=T)
cs$CARatioW100c <-cs$CARatioW100 -mean(cs$CARatioW100 ,na.rm=T)
cs$CARatioB100c <-cs$CARatioB100 -mean(cs$CARatioB100 ,na.rm=T)
cs$CARatioH100c <-cs$CARatioH100 -mean(cs$CARatioH100 ,na.rm=T)
cs$MalePTc      <-cs$MalePT      -mean(cs$MalePT      ,na.rm=T)
cs$MalePWc      <-cs$MalePW      -mean(cs$MalePW      ,na.rm=T)
cs$MalePBc      <-cs$MalePB      -mean(cs$MalePB      ,na.rm=T)
cs$MalePHc      <-cs$MalePH      -mean(cs$MalePH      ,na.rm=T)
cs$MFRatioT100c <-cs$MFRatioT100 -mean(cs$MFRatioT100 ,na.rm=T)
cs$MFRatioW100c <-cs$MFRatioW100 -mean(cs$MFRatioW100 ,na.rm=T)
cs$MFRatioB100c <-cs$MFRatioB100 -mean(cs$MFRatioB100 ,na.rm=T)
cs$MFRatioH100c <-cs$MFRatioH100 -mean(cs$MFRatioH100 ,na.rm=T)
cs$ElderTc      <-cs$ElderT      -mean(cs$ElderT      ,na.rm=T)
cs$ElderWc      <-cs$ElderW      -mean(cs$ElderW      ,na.rm=T)
cs$ElderBc      <-cs$ElderB      -mean(cs$ElderB      ,na.rm=T)
cs$ElderHc      <-cs$ElderH      -mean(cs$ElderH      ,na.rm=T)
cs$SingleTc     <-cs$SingleT     -mean(cs$SingleT     ,na.rm=T)
cs$SingleWc     <-cs$SingleW     -mean(cs$SingleW     ,na.rm=T)
cs$SingleBc     <-cs$SingleB     -mean(cs$SingleB     ,na.rm=T)
cs$SingleHc     <-cs$SingleH     -mean(cs$SingleH     ,na.rm=T)
cs$FHeadTc      <-cs$FHeadT      -mean(cs$FHeadT      ,na.rm=T)
cs$FHeadWc      <-cs$FHeadW      -mean(cs$FHeadW      ,na.rm=T)
cs$FHeadBc      <-cs$FHeadB      -mean(cs$FHeadB      ,na.rm=T)
cs$FHeadHc      <-cs$FHeadH      -mean(cs$FHeadH      ,na.rm=T)
cs$NoHighTc     <-cs$NoHighT     -mean(cs$NoHighT     ,na.rm=T)
cs$NoHighWc     <-cs$NoHighW     -mean(cs$NoHighW     ,na.rm=T)
cs$NoHighBc     <-cs$NoHighB     -mean(cs$NoHighB     ,na.rm=T)
cs$NoHighHc     <-cs$NoHighH     -mean(cs$NoHighH     ,na.rm=T)
cs$UnempTc      <-cs$UnempT      -mean(cs$UnempT      ,na.rm=T)
cs$UnempWc      <-cs$UnempW      -mean(cs$UnempW      ,na.rm=T)
cs$UnempBc      <-cs$UnempB      -mean(cs$UnempB      ,na.rm=T)
cs$UnempHc      <-cs$UnempH      -mean(cs$UnempH      ,na.rm=T)
cs$CPovTc       <-cs$CPovT       -mean(cs$CPovT       ,na.rm=T)
cs$CPovWc       <-cs$CPovW       -mean(cs$CPovW       ,na.rm=T)
cs$CPovBc       <-cs$CPovB       -mean(cs$CPovB       ,na.rm=T)
cs$CPovHc       <-cs$CPovH       -mean(cs$CPovH       ,na.rm=T)
cs$CPov1c       <-cs$CPov1       -mean(cs$CPov1       ,na.rm=T)
cs$CPov2c       <-cs$CPov2       -mean(cs$CPov2       ,na.rm=T)
cs$CPov3c       <-cs$CPov3       -mean(cs$CPov3       ,na.rm=T)
cs$PubAsTc      <-cs$PubAsT      -mean(cs$PubAsT      ,na.rm=T)
cs$WelfarTc     <-cs$WelfarT     -mean(cs$WelfarT     ,na.rm=T)
cs$SnapTc       <-cs$SnapT       -mean(cs$SnapT       ,na.rm=T)
cs$SnapWc       <-cs$SnapW       -mean(cs$SnapW       ,na.rm=T)
cs$SnapBc       <-cs$SnapB       -mean(cs$SnapB       ,na.rm=T)
cs$SnapHc       <-cs$SnapH       -mean(cs$SnapH       ,na.rm=T)
cs$IncomeT1kc   <-cs$IncomeT1k   -mean(cs$IncomeT1k   ,na.rm=T)
cs$IncomeW1kc   <-cs$IncomeW1k   -mean(cs$IncomeW1k   ,na.rm=T)
cs$IncomeB1kc   <-cs$IncomeB1k   -mean(cs$IncomeB1k   ,na.rm=T)
cs$IncomeH1kc   <-cs$IncomeH1k   -mean(cs$IncomeH1k   ,na.rm=T)
cs$GiniT100c    <-cs$GiniT100    -mean(cs$GiniT100    ,na.rm=T)
cs$HValueT10kc  <-cs$HValueT10k  -mean(cs$HValueT10k  ,na.rm=T)
cs$MCostT100c   <-cs$MCostT100   -mean(cs$MCostT100   ,na.rm=T)
cs$OCostDT100c  <-cs$OCostDT100  -mean(cs$OCostDT100  ,na.rm=T)
cs$MRentDT100c  <-cs$MRentDT100  -mean(cs$MRentDT100  ,na.rm=T)
cs$OCostPTc     <-cs$OCostPT     -mean(cs$OCostPT     ,na.rm=T)
cs$MRentPTc     <-cs$MRentPT     -mean(cs$MRentPT     ,na.rm=T)
cs$MortgTc      <-cs$MortgT      -mean(cs$MortgT      ,na.rm=T)
cs$LangAPTc     <-cs$LangAPT     -mean(cs$LangAPT     ,na.rm=T)
cs$LangAPWc     <-cs$LangAPW     -mean(cs$LangAPW     ,na.rm=T)
cs$LangAPBc     <-cs$LangAPB     -mean(cs$LangAPB     ,na.rm=T)
cs$LangAPHc     <-cs$LangAPH     -mean(cs$LangAPH     ,na.rm=T)
cs$LangBPTc     <-cs$LangBPT     -mean(cs$LangBPT     ,na.rm=T)
cs$LangBPWc     <-cs$LangBPW     -mean(cs$LangBPW     ,na.rm=T)
cs$LangBPBc     <-cs$LangBPB     -mean(cs$LangBPB     ,na.rm=T)
cs$LangBPHc     <-cs$LangBPH     -mean(cs$LangBPH     ,na.rm=T)
cs$LangCPTc     <-cs$LangCPT     -mean(cs$LangCPT     ,na.rm=T)
cs$OutUsTc      <-cs$OutUsT      -mean(cs$OutUsT      ,na.rm=T)
cs$OutUsWc      <-cs$OutUsW      -mean(cs$OutUsW      ,na.rm=T)
cs$OutUsBc      <-cs$OutUsB      -mean(cs$OutUsB      ,na.rm=T)
cs$OutUsHc      <-cs$OutUsH      -mean(cs$OutUsH      ,na.rm=T)
cs$FBornTc      <-cs$FBornT      -mean(cs$FBornT      ,na.rm=T)
cs$FBornWc      <-cs$FBornW      -mean(cs$FBornW      ,na.rm=T)
cs$FBornBc      <-cs$FBornB      -mean(cs$FBornB      ,na.rm=T)
cs$FBornHc      <-cs$FBornH      -mean(cs$FBornH      ,na.rm=T)
cs$NotCtzTc     <-cs$NotCtzT     -mean(cs$NotCtzT     ,na.rm=T)
cs$NotCtzWc     <-cs$NotCtzW     -mean(cs$NotCtzW     ,na.rm=T)
cs$NotCtzBc     <-cs$NotCtzB     -mean(cs$NotCtzB     ,na.rm=T)
cs$NotCtzHc     <-cs$NotCtzH     -mean(cs$NotCtzH     ,na.rm=T)
cs$MoveTc       <-cs$MoveT       -mean(cs$MoveT       ,na.rm=T)
cs$MoveWc       <-cs$MoveW       -mean(cs$MoveW       ,na.rm=T)
cs$MoveBc       <-cs$MoveB       -mean(cs$MoveB       ,na.rm=T)
cs$MoveHc       <-cs$MoveH       -mean(cs$MoveH       ,na.rm=T)
cs$VacantTc     <-cs$VacantT     -mean(cs$VacantT     ,na.rm=T)
cs$OwnerTc      <-cs$OwnerT      -mean(cs$OwnerT      ,na.rm=T)
cs$OwnerWc      <-cs$OwnerW      -mean(cs$OwnerW      ,na.rm=T)
cs$OwnerBc      <-cs$OwnerB      -mean(cs$OwnerB      ,na.rm=T)
cs$OwnerHc      <-cs$OwnerH      -mean(cs$OwnerH      ,na.rm=T)
cs$CrowdTc      <-cs$CrowdT      -mean(cs$CrowdT      ,na.rm=T)
cs$CrowdWc      <-cs$CrowdW      -mean(cs$CrowdW      ,na.rm=T)
cs$CrowdBc      <-cs$CrowdB      -mean(cs$CrowdB      ,na.rm=T)
cs$CrowdHc      <-cs$CrowdH      -mean(cs$CrowdH      ,na.rm=T)
cs$MobileTc     <-cs$MobileT     -mean(cs$MobileT     ,na.rm=T)
cs$MobileWc     <-cs$MobileW     -mean(cs$MobileW     ,na.rm=T)
cs$MobileBc     <-cs$MobileB     -mean(cs$MobileB     ,na.rm=T)
cs$MobileHc     <-cs$MobileH     -mean(cs$MobileH     ,na.rm=T)
cs$DisablTc     <-cs$DisablT     -mean(cs$DisablT     ,na.rm=T)
cs$DisablWc     <-cs$DisablW     -mean(cs$DisablW     ,na.rm=T)
cs$DisablBc     <-cs$DisablB     -mean(cs$DisablB     ,na.rm=T)
cs$DisablHc     <-cs$DisablH     -mean(cs$DisablH     ,na.rm=T)
cs$DisablTCc    <-cs$DisablTC    -mean(cs$DisablTC    ,na.rm=T)
cs$DisablWCc    <-cs$DisablWC    -mean(cs$DisablWC    ,na.rm=T)
cs$DisablBCc    <-cs$DisablBC    -mean(cs$DisablBC    ,na.rm=T)
cs$DisablHCc    <-cs$DisablHC    -mean(cs$DisablHC    ,na.rm=T)
cs$DisablTMc    <-cs$DisablTM    -mean(cs$DisablTM    ,na.rm=T)
cs$DisablTFc    <-cs$DisablTF    -mean(cs$DisablTF    ,na.rm=T)
cs$Urban1c      <-cs$Urban1      -mean(cs$Urban1      ,na.rm=T)
cs$Urban2c      <-cs$Urban2      -mean(cs$Urban2      ,na.rm=T)
cs$LBWT1rc      <-cs$LBWT1r      -mean(cs$LBWT1r      ,na.rm=T)
cs$LBWM1rc      <-cs$LBWM1r      -mean(cs$LBWM1r      ,na.rm=T)
cs$LBWF1rc      <-cs$LBWF1r      -mean(cs$LBWF1r      ,na.rm=T)
cs$LBWW1rc      <-cs$LBWW1r      -mean(cs$LBWW1r      ,na.rm=T)
cs$LBWB1rc      <-cs$LBWB1r      -mean(cs$LBWB1r      ,na.rm=T)
cs$LBWH1rc      <-cs$LBWH1r      -mean(cs$LBWH1r      ,na.rm=T)
cs$PTBT1rc      <-cs$PTBT1r      -mean(cs$PTBT1r      ,na.rm=T)
cs$PTBM1rc      <-cs$PTBM1r      -mean(cs$PTBM1r      ,na.rm=T)
cs$PTBF1rc      <-cs$PTBF1r      -mean(cs$PTBF1r      ,na.rm=T)
cs$PTBW1rc      <-cs$PTBW1r      -mean(cs$PTBW1r      ,na.rm=T)
cs$PTBB1rc      <-cs$PTBB1r      -mean(cs$PTBB1r      ,na.rm=T)
cs$PTBH1rc      <-cs$PTBH1r      -mean(cs$PTBH1r      ,na.rm=T)
cs$PNCT1rc      <-cs$PNCT1r      -mean(cs$PNCT1r      ,na.rm=T)
cs$PNCM1rc      <-cs$PNCM1r      -mean(cs$PNCM1r      ,na.rm=T)
cs$PNCF1rc      <-cs$PNCF1r      -mean(cs$PNCF1r      ,na.rm=T)
cs$PNCW1rc      <-cs$PNCW1r      -mean(cs$PNCW1r      ,na.rm=T)
cs$PNCB1rc      <-cs$PNCB1r      -mean(cs$PNCB1r      ,na.rm=T)
cs$PNCH1rc      <-cs$PNCH1r      -mean(cs$PNCH1r      ,na.rm=T)
cs$TBBT1rc      <-cs$TBBT1r      -mean(cs$TBBT1r      ,na.rm=T)
cs$TBBM1rc      <-cs$TBBM1r      -mean(cs$TBBM1r      ,na.rm=T)
cs$TBBF1rc      <-cs$TBBF1r      -mean(cs$TBBF1r      ,na.rm=T)
cs$TBBW1rc      <-cs$TBBW1r      -mean(cs$TBBW1r      ,na.rm=T)
cs$TBBB1rc      <-cs$TBBB1r      -mean(cs$TBBB1r      ,na.rm=T)
cs$TBBH1rc      <-cs$TBBH1r      -mean(cs$TBBH1r      ,na.rm=T)
cs$TBTT1rc      <-cs$TBTT1r      -mean(cs$TBTT1r      ,na.rm=T)
cs$TBTM1rc      <-cs$TBTM1r      -mean(cs$TBTM1r      ,na.rm=T)
cs$TBTF1rc      <-cs$TBTF1r      -mean(cs$TBTF1r      ,na.rm=T)
cs$TBTW1rc      <-cs$TBTW1r      -mean(cs$TBTW1r      ,na.rm=T)
cs$TBTB1rc      <-cs$TBTB1r      -mean(cs$TBTB1r      ,na.rm=T)
cs$TBTH1rc      <-cs$TBTH1r      -mean(cs$TBTH1r      ,na.rm=T)
cs$LBWT5rc      <-cs$LBWT5r      -mean(cs$LBWT5r      ,na.rm=T)
cs$LBWM5rc      <-cs$LBWM5r      -mean(cs$LBWM5r      ,na.rm=T)
cs$LBWF5rc      <-cs$LBWF5r      -mean(cs$LBWF5r      ,na.rm=T)
cs$LBWW5rc      <-cs$LBWW5r      -mean(cs$LBWW5r      ,na.rm=T)
cs$LBWB5rc      <-cs$LBWB5r      -mean(cs$LBWB5r      ,na.rm=T)
cs$LBWH5rc      <-cs$LBWH5r      -mean(cs$LBWH5r      ,na.rm=T)
cs$PTBT5rc      <-cs$PTBT5r      -mean(cs$PTBT5r      ,na.rm=T)
cs$PTBM5rc      <-cs$PTBM5r      -mean(cs$PTBM5r      ,na.rm=T)
cs$PTBF5rc      <-cs$PTBF5r      -mean(cs$PTBF5r      ,na.rm=T)
cs$PTBW5rc      <-cs$PTBW5r      -mean(cs$PTBW5r      ,na.rm=T)
cs$PTBB5rc      <-cs$PTBB5r      -mean(cs$PTBB5r      ,na.rm=T)
cs$PTBH5rc      <-cs$PTBH5r      -mean(cs$PTBH5r      ,na.rm=T)
cs$PNCT5rc      <-cs$PNCT5r      -mean(cs$PNCT5r      ,na.rm=T)
cs$PNCM5rc      <-cs$PNCM5r      -mean(cs$PNCM5r      ,na.rm=T)
cs$PNCF5rc      <-cs$PNCF5r      -mean(cs$PNCF5r      ,na.rm=T)
cs$PNCW5rc      <-cs$PNCW5r      -mean(cs$PNCW5r      ,na.rm=T)
cs$PNCB5rc      <-cs$PNCB5r      -mean(cs$PNCB5r      ,na.rm=T)
cs$PNCH5rc      <-cs$PNCH5r      -mean(cs$PNCH5r      ,na.rm=T)
cs$TBBT5rc      <-cs$TBBT5r      -mean(cs$TBBT5r      ,na.rm=T)
cs$TBBM5rc      <-cs$TBBM5r      -mean(cs$TBBM5r      ,na.rm=T)
cs$TBBF5rc      <-cs$TBBF5r      -mean(cs$TBBF5r      ,na.rm=T)
cs$TBBW5rc      <-cs$TBBW5r      -mean(cs$TBBW5r      ,na.rm=T)
cs$TBBB5rc      <-cs$TBBB5r      -mean(cs$TBBB5r      ,na.rm=T)
cs$TBBH5rc      <-cs$TBBH5r      -mean(cs$TBBH5r      ,na.rm=T)
cs$TBTT5rc      <-cs$TBTT5r      -mean(cs$TBTT5r      ,na.rm=T)
cs$TBTM5rc      <-cs$TBTM5r      -mean(cs$TBTM5r      ,na.rm=T)
cs$TBTF5rc      <-cs$TBTF5r      -mean(cs$TBTF5r      ,na.rm=T)
cs$TBTW5rc      <-cs$TBTW5r      -mean(cs$TBTW5r      ,na.rm=T)
cs$TBTB5rc      <-cs$TBTB5r      -mean(cs$TBTB5r      ,na.rm=T)
cs$TBTH5rc      <-cs$TBTH5r      -mean(cs$TBTH5r      ,na.rm=T)
cs$Opioidc      <-cs$Opioid      -mean(cs$Opioid      ,na.rm=T)
cs$LifeExpc     <-cs$LifeExp     -mean(cs$LifeExp     ,na.rm=T)
cs$LifeExpBc    <-cs$LifeExpB    -mean(cs$LifeExpB    ,na.rm=T)
cs$LifeExpHc    <-cs$LifeExpH    -mean(cs$LifeExpH    ,na.rm=T)
cs$LifeExpWc    <-cs$LifeExpW    -mean(cs$LifeExpW    ,na.rm=T)
cs$ChdDeathc    <-cs$ChdDeath    -mean(cs$ChdDeath    ,na.rm=T)
cs$ChdDeathBc   <-cs$ChdDeathB   -mean(cs$ChdDeathB   ,na.rm=T)
cs$ChdDeathHc   <-cs$ChdDeathH   -mean(cs$ChdDeathH   ,na.rm=T)
cs$ChdDeathWc   <-cs$ChdDeathW   -mean(cs$ChdDeathW   ,na.rm=T)
cs$InfDeathc    <-cs$InfDeath    -mean(cs$InfDeath    ,na.rm=T)
cs$InfDeathBc   <-cs$InfDeathB   -mean(cs$InfDeathB   ,na.rm=T)
cs$InfDeathHc   <-cs$InfDeathH   -mean(cs$InfDeathH   ,na.rm=T)
cs$InfDeathWc   <-cs$InfDeathW   -mean(cs$InfDeathW   ,na.rm=T)
cs$Injuryc      <-cs$Injury      -mean(cs$Injury      ,na.rm=T)
cs$InjuryBc     <-cs$InjuryB     -mean(cs$InjuryB     ,na.rm=T)
cs$InjuryHc     <-cs$InjuryH     -mean(cs$InjuryH     ,na.rm=T)
cs$InjuryWc     <-cs$InjuryW     -mean(cs$InjuryW     ,na.rm=T)
cs$GunDeathc    <-cs$GunDeath    -mean(cs$GunDeath    ,na.rm=T)
cs$GunDeathBc   <-cs$GunDeathB   -mean(cs$GunDeathB   ,na.rm=T)
cs$GunDeathWc   <-cs$GunDeathW   -mean(cs$GunDeathW   ,na.rm=T)
cs$PrmDeath_c   <-cs$PrmDeath    -mean(cs$PrmDeath    ,na.rm=T)
cs$PrmDeathcc   <-cs$PrmDeathc   -mean(cs$PrmDeathc   ,na.rm=T)
cs$PrmDeathBc   <-cs$PrmDeathB   -mean(cs$PrmDeathB   ,na.rm=T)
cs$PrmDeathHc   <-cs$PrmDeathH   -mean(cs$PrmDeathH   ,na.rm=T)
cs$PrmDeathWc   <-cs$PrmDeathW   -mean(cs$PrmDeathW   ,na.rm=T)
cs$PrmDeath2_c  <-cs$PrmDeath2   -mean(cs$PrmDeath2   ,na.rm=T)
cs$PrmDeath2cc  <-cs$PrmDeath2c  -mean(cs$PrmDeath2c  ,na.rm=T)
cs$PrmDeath2Bc  <-cs$PrmDeath2B  -mean(cs$PrmDeath2B  ,na.rm=T)
cs$PrmDeath2Hc  <-cs$PrmDeath2H  -mean(cs$PrmDeath2H  ,na.rm=T)
cs$PrmDeath2Wc  <-cs$PrmDeath2W  -mean(cs$PrmDeath2W  ,na.rm=T)
cs$Suicidec     <-cs$Suicide     -mean(cs$Suicide     ,na.rm=T)
cs$Diabetc      <-cs$Diabet      -mean(cs$Diabet      ,na.rm=T)
cs$Obesityc     <-cs$Obesity     -mean(cs$Obesity     ,na.rm=T)
cs$Physicalc    <-cs$Physical    -mean(cs$Physical    ,na.rm=T)
cs$PoorHlthc    <-cs$PoorHlth    -mean(cs$PoorHlth    ,na.rm=T)
cs$PoorMHc      <-cs$PoorMH      -mean(cs$PoorMH      ,na.rm=T)
cs$PoorPhyc     <-cs$PoorPhy     -mean(cs$PoorPhy     ,na.rm=T)
cs$Sleepc       <-cs$Sleep       -mean(cs$Sleep       ,na.rm=T)
cs$DrugOdc      <-cs$DrugOd      -mean(cs$DrugOd      ,na.rm=T)
cs$DrugOdBc     <-cs$DrugOdB     -mean(cs$DrugOdB     ,na.rm=T)
cs$DrugOdHc     <-cs$DrugOdH     -mean(cs$DrugOdH     ,na.rm=T)
cs$DrugOdWc     <-cs$DrugOdW     -mean(cs$DrugOdW     ,na.rm=T)
cs$DWIDeathc    <-cs$DWIDeath    -mean(cs$DWIDeath    ,na.rm=T)
cs$EDrinkc      <-cs$EDrink      -mean(cs$EDrink      ,na.rm=T)
cs$Smokec       <-cs$Smoke       -mean(cs$Smoke       ,na.rm=T)
cs$FastFoodc    <-cs$FastFood    -mean(cs$FastFood    ,na.rm=T)
cs$FoodEnvc     <-cs$FoodEnv     -mean(cs$FoodEnv     ,na.rm=T)
cs$FoodInsc     <-cs$FoodIns     -mean(cs$FoodIns     ,na.rm=T)
cs$FrLunchc     <-cs$FrLunch     -mean(cs$FrLunch     ,na.rm=T)
cs$LAccFoodc    <-cs$LAccFood    -mean(cs$LAccFood    ,na.rm=T)
cs$Gymc         <-cs$Gym         -mean(cs$Gym         ,na.rm=T)
cs$Gym2c        <-cs$Gym2        -mean(cs$Gym2        ,na.rm=T)
cs$Inactivec    <-cs$Inactive    -mean(cs$Inactive    ,na.rm=T)
cs$HousCostc    <-cs$HousCost    -mean(cs$HousCost    ,na.rm=T)
cs$HousCostsc   <-cs$HousCosts   -mean(cs$HousCosts   ,na.rm=T)
cs$HousCrowdc   <-cs$HousCrowd   -mean(cs$HousCrowd   ,na.rm=T)
cs$Housingc     <-cs$Housing     -mean(cs$Housing     ,na.rm=T)
cs$HousPlumbc   <-cs$HousPlumb   -mean(cs$HousPlumb   ,na.rm=T)
cs$Insuredc     <-cs$Insured     -mean(cs$Insured     ,na.rm=T)
cs$InsuredAc    <-cs$InsuredA    -mean(cs$InsuredA    ,na.rm=T)
cs$InsuredCc    <-cs$InsuredC    -mean(cs$InsuredC    ,na.rm=T)
cs$JuvArrc      <-cs$JuvArr      -mean(cs$JuvArr      ,na.rm=T)
cs$Murderc      <-cs$Murder      -mean(cs$Murder      ,na.rm=T)
cs$Violentc     <-cs$Violent     -mean(cs$Violent     ,na.rm=T)
cs$LongCommc    <-cs$LongComm    -mean(cs$LongComm    ,na.rm=T)
cs$LowBWc       <-cs$LowBW       -mean(cs$LowBW       ,na.rm=T)
cs$LowBWBc      <-cs$LowBWB      -mean(cs$LowBWB      ,na.rm=T)
cs$LowBWHc      <-cs$LowBWH      -mean(cs$LowBWH      ,na.rm=T)
cs$LowBWWc      <-cs$LowBWW      -mean(cs$LowBWW      ,na.rm=T)
cs$TeenBthc     <-cs$TeenBth     -mean(cs$TeenBth     ,na.rm=T)
cs$TeenBthBc    <-cs$TeenBthB    -mean(cs$TeenBthB    ,na.rm=T)
cs$TeenBthHc    <-cs$TeenBthH    -mean(cs$TeenBthH    ,na.rm=T)
cs$TeenBthWc    <-cs$TeenBthW    -mean(cs$TeenBthW    ,na.rm=T)
cs$Mentalc      <-cs$Mental      -mean(cs$Mental      ,na.rm=T)
cs$MHPrvdc      <-cs$MHPrvd      -mean(cs$MHPrvd      ,na.rm=T)
cs$PCPc         <-cs$PCP         -mean(cs$PCP         ,na.rm=T)
cs$PCP2c        <-cs$PCP2        -mean(cs$PCP2        ,na.rm=T)
cs$Dentistc     <-cs$Dentist     -mean(cs$Dentist     ,na.rm=T)
cs$PrvtHospc    <-cs$PrvtHosp    -mean(cs$PrvtHosp    ,na.rm=T)
cs$PrvtHospBc   <-cs$PrvtHospB   -mean(cs$PrvtHospB   ,na.rm=T)
cs$PrvtHospHc   <-cs$PrvtHospH   -mean(cs$PrvtHospH   ,na.rm=T)
cs$PrvtHospWc   <-cs$PrvtHospW   -mean(cs$PrvtHospW   ,na.rm=T)
cs$SegBWc       <-cs$SegBW       -mean(cs$SegBW       ,na.rm=T)
cs$SegNWc       <-cs$SegNW       -mean(cs$SegNW       ,na.rm=T)
cs$SocAssoc     <-cs$SocAsso     -mean(cs$SocAsso     ,na.rm=T)
cs$SocSuppc     <-cs$SocSupp     -mean(cs$SocSupp     ,na.rm=T)
cs$MIECHVc      <-cs$MIECHV      -mean(cs$MIECHV      ,na.rm=T)
cs$NHVRCc       <-cs$NHVRC       -mean(cs$NHVRC       ,na.rm=T)
cs$HomeV2c      <-cs$HomeV2      -mean(cs$HomeV2      ,na.rm=T)
cs$FoodInsecurec<-cs$FoodInsecure-mean(cs$FoodInsecure,na.rm=T)

cs<-cbind(cs,demean(cs,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Model building
csm01<-lmer(SexTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm02<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm03<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm04<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm05<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm06<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm07<-lmer(SexTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(csm01,csm02,csm03,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(csm04,csm05,csm06,csm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
csm01CI<-confint(csm01,method='boot',nsim=500,boot.type='perc')
csm02CI<-confint(csm02,method='boot',nsim=500,boot.type='perc')
csm03CI<-confint(csm03,method='boot',nsim=500,boot.type='perc')
csm04CI<-confint(csm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(csm01)
check_collinearity(csm02)
check_collinearity(csm03)
check_collinearity(csm04)
isSingular(csm01)
isSingular(csm02)
isSingular(csm03)
isSingular(csm04)




# Model building
csm01a<-lmer(SexTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm02a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm03a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm04a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm05a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm06a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))
csm07a<-lmer(SexTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cs,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(csm01a,csm02a,csm03a,csm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(csm04a,csm05a,csm06a,csm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
csm01aCI<-confint(csm01a,method='boot',nsim=500,boot.type='perc')
csm02aCI<-confint(csm02a,method='boot',nsim=500,boot.type='perc')
csm03aCI<-confint(csm03a,method='boot',nsim=500,boot.type='perc')
csm04aCI<-confint(csm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(csm01a)
check_collinearity(csm02a)
check_collinearity(csm03a)
check_collinearity(csm04a)
isSingular(csm01a)
isSingular(csm02a)
isSingular(csm03a)
isSingular(csm04a)




tab_model(cnm04,cpm04,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cnm04a,cpm04a,csm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)



csg02<-glmmTMB(SexT~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                 ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cs,family=nbinom2)
csg02a<-glmmTMB(SexT~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
                  ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=cs,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
# Food Insecurity - Emotional Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

ce$CPopBPc      <-ce$CPopBP      -mean(ce$CPopBP      ,na.rm=T)
ce$CPopHPc      <-ce$CPopHP      -mean(ce$CPopHP      ,na.rm=T)
ce$ChildPTc     <-ce$ChildPT     -mean(ce$ChildPT     ,na.rm=T)
ce$ChildPWc     <-ce$ChildPW     -mean(ce$ChildPW     ,na.rm=T)
ce$ChildPBc     <-ce$ChildPB     -mean(ce$ChildPB     ,na.rm=T)
ce$ChildPHc     <-ce$ChildPH     -mean(ce$ChildPH     ,na.rm=T)
ce$CARatioT100c <-ce$CARatioT100 -mean(ce$CARatioT100 ,na.rm=T)
ce$CARatioW100c <-ce$CARatioW100 -mean(ce$CARatioW100 ,na.rm=T)
ce$CARatioB100c <-ce$CARatioB100 -mean(ce$CARatioB100 ,na.rm=T)
ce$CARatioH100c <-ce$CARatioH100 -mean(ce$CARatioH100 ,na.rm=T)
ce$MalePTc      <-ce$MalePT      -mean(ce$MalePT      ,na.rm=T)
ce$MalePWc      <-ce$MalePW      -mean(ce$MalePW      ,na.rm=T)
ce$MalePBc      <-ce$MalePB      -mean(ce$MalePB      ,na.rm=T)
ce$MalePHc      <-ce$MalePH      -mean(ce$MalePH      ,na.rm=T)
ce$MFRatioT100c <-ce$MFRatioT100 -mean(ce$MFRatioT100 ,na.rm=T)
ce$MFRatioW100c <-ce$MFRatioW100 -mean(ce$MFRatioW100 ,na.rm=T)
ce$MFRatioB100c <-ce$MFRatioB100 -mean(ce$MFRatioB100 ,na.rm=T)
ce$MFRatioH100c <-ce$MFRatioH100 -mean(ce$MFRatioH100 ,na.rm=T)
ce$ElderTc      <-ce$ElderT      -mean(ce$ElderT      ,na.rm=T)
ce$ElderWc      <-ce$ElderW      -mean(ce$ElderW      ,na.rm=T)
ce$ElderBc      <-ce$ElderB      -mean(ce$ElderB      ,na.rm=T)
ce$ElderHc      <-ce$ElderH      -mean(ce$ElderH      ,na.rm=T)
ce$SingleTc     <-ce$SingleT     -mean(ce$SingleT     ,na.rm=T)
ce$SingleWc     <-ce$SingleW     -mean(ce$SingleW     ,na.rm=T)
ce$SingleBc     <-ce$SingleB     -mean(ce$SingleB     ,na.rm=T)
ce$SingleHc     <-ce$SingleH     -mean(ce$SingleH     ,na.rm=T)
ce$FHeadTc      <-ce$FHeadT      -mean(ce$FHeadT      ,na.rm=T)
ce$FHeadWc      <-ce$FHeadW      -mean(ce$FHeadW      ,na.rm=T)
ce$FHeadBc      <-ce$FHeadB      -mean(ce$FHeadB      ,na.rm=T)
ce$FHeadHc      <-ce$FHeadH      -mean(ce$FHeadH      ,na.rm=T)
ce$NoHighTc     <-ce$NoHighT     -mean(ce$NoHighT     ,na.rm=T)
ce$NoHighWc     <-ce$NoHighW     -mean(ce$NoHighW     ,na.rm=T)
ce$NoHighBc     <-ce$NoHighB     -mean(ce$NoHighB     ,na.rm=T)
ce$NoHighHc     <-ce$NoHighH     -mean(ce$NoHighH     ,na.rm=T)
ce$UnempTc      <-ce$UnempT      -mean(ce$UnempT      ,na.rm=T)
ce$UnempWc      <-ce$UnempW      -mean(ce$UnempW      ,na.rm=T)
ce$UnempBc      <-ce$UnempB      -mean(ce$UnempB      ,na.rm=T)
ce$UnempHc      <-ce$UnempH      -mean(ce$UnempH      ,na.rm=T)
ce$CPovTc       <-ce$CPovT       -mean(ce$CPovT       ,na.rm=T)
ce$CPovWc       <-ce$CPovW       -mean(ce$CPovW       ,na.rm=T)
ce$CPovBc       <-ce$CPovB       -mean(ce$CPovB       ,na.rm=T)
ce$CPovHc       <-ce$CPovH       -mean(ce$CPovH       ,na.rm=T)
ce$CPov1c       <-ce$CPov1       -mean(ce$CPov1       ,na.rm=T)
ce$CPov2c       <-ce$CPov2       -mean(ce$CPov2       ,na.rm=T)
ce$CPov3c       <-ce$CPov3       -mean(ce$CPov3       ,na.rm=T)
ce$PubAsTc      <-ce$PubAsT      -mean(ce$PubAsT      ,na.rm=T)
ce$WelfarTc     <-ce$WelfarT     -mean(ce$WelfarT     ,na.rm=T)
ce$SnapTc       <-ce$SnapT       -mean(ce$SnapT       ,na.rm=T)
ce$SnapWc       <-ce$SnapW       -mean(ce$SnapW       ,na.rm=T)
ce$SnapBc       <-ce$SnapB       -mean(ce$SnapB       ,na.rm=T)
ce$SnapHc       <-ce$SnapH       -mean(ce$SnapH       ,na.rm=T)
ce$IncomeT1kc   <-ce$IncomeT1k   -mean(ce$IncomeT1k   ,na.rm=T)
ce$IncomeW1kc   <-ce$IncomeW1k   -mean(ce$IncomeW1k   ,na.rm=T)
ce$IncomeB1kc   <-ce$IncomeB1k   -mean(ce$IncomeB1k   ,na.rm=T)
ce$IncomeH1kc   <-ce$IncomeH1k   -mean(ce$IncomeH1k   ,na.rm=T)
ce$GiniT100c    <-ce$GiniT100    -mean(ce$GiniT100    ,na.rm=T)
ce$HValueT10kc  <-ce$HValueT10k  -mean(ce$HValueT10k  ,na.rm=T)
ce$MCostT100c   <-ce$MCostT100   -mean(ce$MCostT100   ,na.rm=T)
ce$OCostDT100c  <-ce$OCostDT100  -mean(ce$OCostDT100  ,na.rm=T)
ce$MRentDT100c  <-ce$MRentDT100  -mean(ce$MRentDT100  ,na.rm=T)
ce$OCostPTc     <-ce$OCostPT     -mean(ce$OCostPT     ,na.rm=T)
ce$MRentPTc     <-ce$MRentPT     -mean(ce$MRentPT     ,na.rm=T)
ce$MortgTc      <-ce$MortgT      -mean(ce$MortgT      ,na.rm=T)
ce$LangAPTc     <-ce$LangAPT     -mean(ce$LangAPT     ,na.rm=T)
ce$LangAPWc     <-ce$LangAPW     -mean(ce$LangAPW     ,na.rm=T)
ce$LangAPBc     <-ce$LangAPB     -mean(ce$LangAPB     ,na.rm=T)
ce$LangAPHc     <-ce$LangAPH     -mean(ce$LangAPH     ,na.rm=T)
ce$LangBPTc     <-ce$LangBPT     -mean(ce$LangBPT     ,na.rm=T)
ce$LangBPWc     <-ce$LangBPW     -mean(ce$LangBPW     ,na.rm=T)
ce$LangBPBc     <-ce$LangBPB     -mean(ce$LangBPB     ,na.rm=T)
ce$LangBPHc     <-ce$LangBPH     -mean(ce$LangBPH     ,na.rm=T)
ce$LangCPTc     <-ce$LangCPT     -mean(ce$LangCPT     ,na.rm=T)
ce$OutUsTc      <-ce$OutUsT      -mean(ce$OutUsT      ,na.rm=T)
ce$OutUsWc      <-ce$OutUsW      -mean(ce$OutUsW      ,na.rm=T)
ce$OutUsBc      <-ce$OutUsB      -mean(ce$OutUsB      ,na.rm=T)
ce$OutUsHc      <-ce$OutUsH      -mean(ce$OutUsH      ,na.rm=T)
ce$FBornTc      <-ce$FBornT      -mean(ce$FBornT      ,na.rm=T)
ce$FBornWc      <-ce$FBornW      -mean(ce$FBornW      ,na.rm=T)
ce$FBornBc      <-ce$FBornB      -mean(ce$FBornB      ,na.rm=T)
ce$FBornHc      <-ce$FBornH      -mean(ce$FBornH      ,na.rm=T)
ce$NotCtzTc     <-ce$NotCtzT     -mean(ce$NotCtzT     ,na.rm=T)
ce$NotCtzWc     <-ce$NotCtzW     -mean(ce$NotCtzW     ,na.rm=T)
ce$NotCtzBc     <-ce$NotCtzB     -mean(ce$NotCtzB     ,na.rm=T)
ce$NotCtzHc     <-ce$NotCtzH     -mean(ce$NotCtzH     ,na.rm=T)
ce$MoveTc       <-ce$MoveT       -mean(ce$MoveT       ,na.rm=T)
ce$MoveWc       <-ce$MoveW       -mean(ce$MoveW       ,na.rm=T)
ce$MoveBc       <-ce$MoveB       -mean(ce$MoveB       ,na.rm=T)
ce$MoveHc       <-ce$MoveH       -mean(ce$MoveH       ,na.rm=T)
ce$VacantTc     <-ce$VacantT     -mean(ce$VacantT     ,na.rm=T)
ce$OwnerTc      <-ce$OwnerT      -mean(ce$OwnerT      ,na.rm=T)
ce$OwnerWc      <-ce$OwnerW      -mean(ce$OwnerW      ,na.rm=T)
ce$OwnerBc      <-ce$OwnerB      -mean(ce$OwnerB      ,na.rm=T)
ce$OwnerHc      <-ce$OwnerH      -mean(ce$OwnerH      ,na.rm=T)
ce$CrowdTc      <-ce$CrowdT      -mean(ce$CrowdT      ,na.rm=T)
ce$CrowdWc      <-ce$CrowdW      -mean(ce$CrowdW      ,na.rm=T)
ce$CrowdBc      <-ce$CrowdB      -mean(ce$CrowdB      ,na.rm=T)
ce$CrowdHc      <-ce$CrowdH      -mean(ce$CrowdH      ,na.rm=T)
ce$MobileTc     <-ce$MobileT     -mean(ce$MobileT     ,na.rm=T)
ce$MobileWc     <-ce$MobileW     -mean(ce$MobileW     ,na.rm=T)
ce$MobileBc     <-ce$MobileB     -mean(ce$MobileB     ,na.rm=T)
ce$MobileHc     <-ce$MobileH     -mean(ce$MobileH     ,na.rm=T)
ce$DisablTc     <-ce$DisablT     -mean(ce$DisablT     ,na.rm=T)
ce$DisablWc     <-ce$DisablW     -mean(ce$DisablW     ,na.rm=T)
ce$DisablBc     <-ce$DisablB     -mean(ce$DisablB     ,na.rm=T)
ce$DisablHc     <-ce$DisablH     -mean(ce$DisablH     ,na.rm=T)
ce$DisablTCc    <-ce$DisablTC    -mean(ce$DisablTC    ,na.rm=T)
ce$DisablWCc    <-ce$DisablWC    -mean(ce$DisablWC    ,na.rm=T)
ce$DisablBCc    <-ce$DisablBC    -mean(ce$DisablBC    ,na.rm=T)
ce$DisablHCc    <-ce$DisablHC    -mean(ce$DisablHC    ,na.rm=T)
ce$DisablTMc    <-ce$DisablTM    -mean(ce$DisablTM    ,na.rm=T)
ce$DisablTFc    <-ce$DisablTF    -mean(ce$DisablTF    ,na.rm=T)
ce$Urban1c      <-ce$Urban1      -mean(ce$Urban1      ,na.rm=T)
ce$Urban2c      <-ce$Urban2      -mean(ce$Urban2      ,na.rm=T)
ce$LBWT1rc      <-ce$LBWT1r      -mean(ce$LBWT1r      ,na.rm=T)
ce$LBWM1rc      <-ce$LBWM1r      -mean(ce$LBWM1r      ,na.rm=T)
ce$LBWF1rc      <-ce$LBWF1r      -mean(ce$LBWF1r      ,na.rm=T)
ce$LBWW1rc      <-ce$LBWW1r      -mean(ce$LBWW1r      ,na.rm=T)
ce$LBWB1rc      <-ce$LBWB1r      -mean(ce$LBWB1r      ,na.rm=T)
ce$LBWH1rc      <-ce$LBWH1r      -mean(ce$LBWH1r      ,na.rm=T)
ce$PTBT1rc      <-ce$PTBT1r      -mean(ce$PTBT1r      ,na.rm=T)
ce$PTBM1rc      <-ce$PTBM1r      -mean(ce$PTBM1r      ,na.rm=T)
ce$PTBF1rc      <-ce$PTBF1r      -mean(ce$PTBF1r      ,na.rm=T)
ce$PTBW1rc      <-ce$PTBW1r      -mean(ce$PTBW1r      ,na.rm=T)
ce$PTBB1rc      <-ce$PTBB1r      -mean(ce$PTBB1r      ,na.rm=T)
ce$PTBH1rc      <-ce$PTBH1r      -mean(ce$PTBH1r      ,na.rm=T)
ce$PNCT1rc      <-ce$PNCT1r      -mean(ce$PNCT1r      ,na.rm=T)
ce$PNCM1rc      <-ce$PNCM1r      -mean(ce$PNCM1r      ,na.rm=T)
ce$PNCF1rc      <-ce$PNCF1r      -mean(ce$PNCF1r      ,na.rm=T)
ce$PNCW1rc      <-ce$PNCW1r      -mean(ce$PNCW1r      ,na.rm=T)
ce$PNCB1rc      <-ce$PNCB1r      -mean(ce$PNCB1r      ,na.rm=T)
ce$PNCH1rc      <-ce$PNCH1r      -mean(ce$PNCH1r      ,na.rm=T)
ce$TBBT1rc      <-ce$TBBT1r      -mean(ce$TBBT1r      ,na.rm=T)
ce$TBBM1rc      <-ce$TBBM1r      -mean(ce$TBBM1r      ,na.rm=T)
ce$TBBF1rc      <-ce$TBBF1r      -mean(ce$TBBF1r      ,na.rm=T)
ce$TBBW1rc      <-ce$TBBW1r      -mean(ce$TBBW1r      ,na.rm=T)
ce$TBBB1rc      <-ce$TBBB1r      -mean(ce$TBBB1r      ,na.rm=T)
ce$TBBH1rc      <-ce$TBBH1r      -mean(ce$TBBH1r      ,na.rm=T)
ce$TBTT1rc      <-ce$TBTT1r      -mean(ce$TBTT1r      ,na.rm=T)
ce$TBTM1rc      <-ce$TBTM1r      -mean(ce$TBTM1r      ,na.rm=T)
ce$TBTF1rc      <-ce$TBTF1r      -mean(ce$TBTF1r      ,na.rm=T)
ce$TBTW1rc      <-ce$TBTW1r      -mean(ce$TBTW1r      ,na.rm=T)
ce$TBTB1rc      <-ce$TBTB1r      -mean(ce$TBTB1r      ,na.rm=T)
ce$TBTH1rc      <-ce$TBTH1r      -mean(ce$TBTH1r      ,na.rm=T)
ce$LBWT5rc      <-ce$LBWT5r      -mean(ce$LBWT5r      ,na.rm=T)
ce$LBWM5rc      <-ce$LBWM5r      -mean(ce$LBWM5r      ,na.rm=T)
ce$LBWF5rc      <-ce$LBWF5r      -mean(ce$LBWF5r      ,na.rm=T)
ce$LBWW5rc      <-ce$LBWW5r      -mean(ce$LBWW5r      ,na.rm=T)
ce$LBWB5rc      <-ce$LBWB5r      -mean(ce$LBWB5r      ,na.rm=T)
ce$LBWH5rc      <-ce$LBWH5r      -mean(ce$LBWH5r      ,na.rm=T)
ce$PTBT5rc      <-ce$PTBT5r      -mean(ce$PTBT5r      ,na.rm=T)
ce$PTBM5rc      <-ce$PTBM5r      -mean(ce$PTBM5r      ,na.rm=T)
ce$PTBF5rc      <-ce$PTBF5r      -mean(ce$PTBF5r      ,na.rm=T)
ce$PTBW5rc      <-ce$PTBW5r      -mean(ce$PTBW5r      ,na.rm=T)
ce$PTBB5rc      <-ce$PTBB5r      -mean(ce$PTBB5r      ,na.rm=T)
ce$PTBH5rc      <-ce$PTBH5r      -mean(ce$PTBH5r      ,na.rm=T)
ce$PNCT5rc      <-ce$PNCT5r      -mean(ce$PNCT5r      ,na.rm=T)
ce$PNCM5rc      <-ce$PNCM5r      -mean(ce$PNCM5r      ,na.rm=T)
ce$PNCF5rc      <-ce$PNCF5r      -mean(ce$PNCF5r      ,na.rm=T)
ce$PNCW5rc      <-ce$PNCW5r      -mean(ce$PNCW5r      ,na.rm=T)
ce$PNCB5rc      <-ce$PNCB5r      -mean(ce$PNCB5r      ,na.rm=T)
ce$PNCH5rc      <-ce$PNCH5r      -mean(ce$PNCH5r      ,na.rm=T)
ce$TBBT5rc      <-ce$TBBT5r      -mean(ce$TBBT5r      ,na.rm=T)
ce$TBBM5rc      <-ce$TBBM5r      -mean(ce$TBBM5r      ,na.rm=T)
ce$TBBF5rc      <-ce$TBBF5r      -mean(ce$TBBF5r      ,na.rm=T)
ce$TBBW5rc      <-ce$TBBW5r      -mean(ce$TBBW5r      ,na.rm=T)
ce$TBBB5rc      <-ce$TBBB5r      -mean(ce$TBBB5r      ,na.rm=T)
ce$TBBH5rc      <-ce$TBBH5r      -mean(ce$TBBH5r      ,na.rm=T)
ce$TBTT5rc      <-ce$TBTT5r      -mean(ce$TBTT5r      ,na.rm=T)
ce$TBTM5rc      <-ce$TBTM5r      -mean(ce$TBTM5r      ,na.rm=T)
ce$TBTF5rc      <-ce$TBTF5r      -mean(ce$TBTF5r      ,na.rm=T)
ce$TBTW5rc      <-ce$TBTW5r      -mean(ce$TBTW5r      ,na.rm=T)
ce$TBTB5rc      <-ce$TBTB5r      -mean(ce$TBTB5r      ,na.rm=T)
ce$TBTH5rc      <-ce$TBTH5r      -mean(ce$TBTH5r      ,na.rm=T)
ce$Opioidc      <-ce$Opioid      -mean(ce$Opioid      ,na.rm=T)
ce$LifeExpc     <-ce$LifeExp     -mean(ce$LifeExp     ,na.rm=T)
ce$LifeExpBc    <-ce$LifeExpB    -mean(ce$LifeExpB    ,na.rm=T)
ce$LifeExpHc    <-ce$LifeExpH    -mean(ce$LifeExpH    ,na.rm=T)
ce$LifeExpWc    <-ce$LifeExpW    -mean(ce$LifeExpW    ,na.rm=T)
ce$ChdDeathc    <-ce$ChdDeath    -mean(ce$ChdDeath    ,na.rm=T)
ce$ChdDeathBc   <-ce$ChdDeathB   -mean(ce$ChdDeathB   ,na.rm=T)
ce$ChdDeathHc   <-ce$ChdDeathH   -mean(ce$ChdDeathH   ,na.rm=T)
ce$ChdDeathWc   <-ce$ChdDeathW   -mean(ce$ChdDeathW   ,na.rm=T)
ce$InfDeathc    <-ce$InfDeath    -mean(ce$InfDeath    ,na.rm=T)
ce$InfDeathBc   <-ce$InfDeathB   -mean(ce$InfDeathB   ,na.rm=T)
ce$InfDeathHc   <-ce$InfDeathH   -mean(ce$InfDeathH   ,na.rm=T)
ce$InfDeathWc   <-ce$InfDeathW   -mean(ce$InfDeathW   ,na.rm=T)
ce$Injuryc      <-ce$Injury      -mean(ce$Injury      ,na.rm=T)
ce$InjuryBc     <-ce$InjuryB     -mean(ce$InjuryB     ,na.rm=T)
ce$InjuryHc     <-ce$InjuryH     -mean(ce$InjuryH     ,na.rm=T)
ce$InjuryWc     <-ce$InjuryW     -mean(ce$InjuryW     ,na.rm=T)
ce$GunDeathc    <-ce$GunDeath    -mean(ce$GunDeath    ,na.rm=T)
ce$GunDeathBc   <-ce$GunDeathB   -mean(ce$GunDeathB   ,na.rm=T)
ce$GunDeathWc   <-ce$GunDeathW   -mean(ce$GunDeathW   ,na.rm=T)
ce$PrmDeath_c   <-ce$PrmDeath    -mean(ce$PrmDeath    ,na.rm=T)
ce$PrmDeathcc   <-ce$PrmDeathc   -mean(ce$PrmDeathc   ,na.rm=T)
ce$PrmDeathBc   <-ce$PrmDeathB   -mean(ce$PrmDeathB   ,na.rm=T)
ce$PrmDeathHc   <-ce$PrmDeathH   -mean(ce$PrmDeathH   ,na.rm=T)
ce$PrmDeathWc   <-ce$PrmDeathW   -mean(ce$PrmDeathW   ,na.rm=T)
ce$PrmDeath2_c  <-ce$PrmDeath2   -mean(ce$PrmDeath2   ,na.rm=T)
ce$PrmDeath2cc  <-ce$PrmDeath2c  -mean(ce$PrmDeath2c  ,na.rm=T)
ce$PrmDeath2Bc  <-ce$PrmDeath2B  -mean(ce$PrmDeath2B  ,na.rm=T)
ce$PrmDeath2Hc  <-ce$PrmDeath2H  -mean(ce$PrmDeath2H  ,na.rm=T)
ce$PrmDeath2Wc  <-ce$PrmDeath2W  -mean(ce$PrmDeath2W  ,na.rm=T)
ce$Suicidec     <-ce$Suicide     -mean(ce$Suicide     ,na.rm=T)
ce$Diabetc      <-ce$Diabet      -mean(ce$Diabet      ,na.rm=T)
ce$Obesityc     <-ce$Obesity     -mean(ce$Obesity     ,na.rm=T)
ce$Physicalc    <-ce$Physical    -mean(ce$Physical    ,na.rm=T)
ce$PoorHlthc    <-ce$PoorHlth    -mean(ce$PoorHlth    ,na.rm=T)
ce$PoorMHc      <-ce$PoorMH      -mean(ce$PoorMH      ,na.rm=T)
ce$PoorPhyc     <-ce$PoorPhy     -mean(ce$PoorPhy     ,na.rm=T)
ce$Sleepc       <-ce$Sleep       -mean(ce$Sleep       ,na.rm=T)
ce$DrugOdc      <-ce$DrugOd      -mean(ce$DrugOd      ,na.rm=T)
ce$DrugOdBc     <-ce$DrugOdB     -mean(ce$DrugOdB     ,na.rm=T)
ce$DrugOdHc     <-ce$DrugOdH     -mean(ce$DrugOdH     ,na.rm=T)
ce$DrugOdWc     <-ce$DrugOdW     -mean(ce$DrugOdW     ,na.rm=T)
ce$DWIDeathc    <-ce$DWIDeath    -mean(ce$DWIDeath    ,na.rm=T)
ce$EDrinkc      <-ce$EDrink      -mean(ce$EDrink      ,na.rm=T)
ce$Smokec       <-ce$Smoke       -mean(ce$Smoke       ,na.rm=T)
ce$FastFoodc    <-ce$FastFood    -mean(ce$FastFood    ,na.rm=T)
ce$FoodEnvc     <-ce$FoodEnv     -mean(ce$FoodEnv     ,na.rm=T)
ce$FoodInsc     <-ce$FoodIns     -mean(ce$FoodIns     ,na.rm=T)
ce$FrLunchc     <-ce$FrLunch     -mean(ce$FrLunch     ,na.rm=T)
ce$LAccFoodc    <-ce$LAccFood    -mean(ce$LAccFood    ,na.rm=T)
ce$Gymc         <-ce$Gym         -mean(ce$Gym         ,na.rm=T)
ce$Gym2c        <-ce$Gym2        -mean(ce$Gym2        ,na.rm=T)
ce$Inactivec    <-ce$Inactive    -mean(ce$Inactive    ,na.rm=T)
ce$HousCostc    <-ce$HousCost    -mean(ce$HousCost    ,na.rm=T)
ce$HousCostsc   <-ce$HousCosts   -mean(ce$HousCosts   ,na.rm=T)
ce$HousCrowdc   <-ce$HousCrowd   -mean(ce$HousCrowd   ,na.rm=T)
ce$Housingc     <-ce$Housing     -mean(ce$Housing     ,na.rm=T)
ce$HousPlumbc   <-ce$HousPlumb   -mean(ce$HousPlumb   ,na.rm=T)
ce$Insuredc     <-ce$Insured     -mean(ce$Insured     ,na.rm=T)
ce$InsuredAc    <-ce$InsuredA    -mean(ce$InsuredA    ,na.rm=T)
ce$InsuredCc    <-ce$InsuredC    -mean(ce$InsuredC    ,na.rm=T)
ce$JuvArrc      <-ce$JuvArr      -mean(ce$JuvArr      ,na.rm=T)
ce$Murderc      <-ce$Murder      -mean(ce$Murder      ,na.rm=T)
ce$Violentc     <-ce$Violent     -mean(ce$Violent     ,na.rm=T)
ce$LongCommc    <-ce$LongComm    -mean(ce$LongComm    ,na.rm=T)
ce$LowBWc       <-ce$LowBW       -mean(ce$LowBW       ,na.rm=T)
ce$LowBWBc      <-ce$LowBWB      -mean(ce$LowBWB      ,na.rm=T)
ce$LowBWHc      <-ce$LowBWH      -mean(ce$LowBWH      ,na.rm=T)
ce$LowBWWc      <-ce$LowBWW      -mean(ce$LowBWW      ,na.rm=T)
ce$TeenBthc     <-ce$TeenBth     -mean(ce$TeenBth     ,na.rm=T)
ce$TeenBthBc    <-ce$TeenBthB    -mean(ce$TeenBthB    ,na.rm=T)
ce$TeenBthHc    <-ce$TeenBthH    -mean(ce$TeenBthH    ,na.rm=T)
ce$TeenBthWc    <-ce$TeenBthW    -mean(ce$TeenBthW    ,na.rm=T)
ce$Mentalc      <-ce$Mental      -mean(ce$Mental      ,na.rm=T)
ce$MHPrvdc      <-ce$MHPrvd      -mean(ce$MHPrvd      ,na.rm=T)
ce$PCPc         <-ce$PCP         -mean(ce$PCP         ,na.rm=T)
ce$PCP2c        <-ce$PCP2        -mean(ce$PCP2        ,na.rm=T)
ce$Dentistc     <-ce$Dentist     -mean(ce$Dentist     ,na.rm=T)
ce$PrvtHospc    <-ce$PrvtHosp    -mean(ce$PrvtHosp    ,na.rm=T)
ce$PrvtHospBc   <-ce$PrvtHospB   -mean(ce$PrvtHospB   ,na.rm=T)
ce$PrvtHospHc   <-ce$PrvtHospH   -mean(ce$PrvtHospH   ,na.rm=T)
ce$PrvtHospWc   <-ce$PrvtHospW   -mean(ce$PrvtHospW   ,na.rm=T)
ce$SegBWc       <-ce$SegBW       -mean(ce$SegBW       ,na.rm=T)
ce$SegNWc       <-ce$SegNW       -mean(ce$SegNW       ,na.rm=T)
ce$SocAssoc     <-ce$SocAsso     -mean(ce$SocAsso     ,na.rm=T)
ce$SocSuppc     <-ce$SocSupp     -mean(ce$SocSupp     ,na.rm=T)
ce$MIECHVc      <-ce$MIECHV      -mean(ce$MIECHV      ,na.rm=T)
ce$NHVRCc       <-ce$NHVRC       -mean(ce$NHVRC       ,na.rm=T)
ce$HomeV2c      <-ce$HomeV2      -mean(ce$HomeV2      ,na.rm=T)
ce$FoodInsecurec<-ce$FoodInsecure-mean(ce$FoodInsecure,na.rm=T)

ce<-cbind(ce,demean(ce,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cem01<-lmer(EmoTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem02<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem03<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem04<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem05<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=ce)
cem06<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=ce)
cem07<-lmer(EmoTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=ce)

tab_model(cem01,cem02,cem03,cem04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cem04,cem05,cem06,cem07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cem01CI<-confint(cem01,method='boot',nsim=500,boot.type='perc')
cem02CI<-confint(cem02,method='boot',nsim=500,boot.type='perc')
cem03CI<-confint(cem03,method='boot',nsim=500,boot.type='perc')
cem04CI<-confint(cem04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cem01)
check_collinearity(cem02)
check_collinearity(cem03)
check_collinearity(cem04)
isSingular(cem01)
isSingular(cem02)
isSingular(cem03)
isSingular(cem04)




# Model building
cem01a<-lmer(EmoTr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem02a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem03a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem04a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ce)
cem05a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=ce)
cem06a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=ce)
cem07a<-lmer(EmoTr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=ce)

tab_model(cem01a,cem02a,cem03a,cem04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cem04a,cem05a,cem06a,cem07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cem01aCI<-confint(cem01a,method='boot',nsim=500,boot.type='perc')
cem02aCI<-confint(cem02a,method='boot',nsim=500,boot.type='perc')
cem03aCI<-confint(cem03a,method='boot',nsim=500,boot.type='perc')
cem04aCI<-confint(cem04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cem01a)
check_collinearity(cem02a)
check_collinearity(cem03a)
check_collinearity(cem04a)
isSingular(cem01a)
isSingular(cem02a)
isSingular(cem03a)
isSingular(cem04a)





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cw$CPopBPc      <-cw$CPopBP      -mean(cw$CPopBP      ,na.rm=T)
cw$CPopHPc      <-cw$CPopHP      -mean(cw$CPopHP      ,na.rm=T)
cw$ChildPTc     <-cw$ChildPT     -mean(cw$ChildPT     ,na.rm=T)
cw$ChildPWc     <-cw$ChildPW     -mean(cw$ChildPW     ,na.rm=T)
cw$ChildPBc     <-cw$ChildPB     -mean(cw$ChildPB     ,na.rm=T)
cw$ChildPHc     <-cw$ChildPH     -mean(cw$ChildPH     ,na.rm=T)
cw$CARatioT100c <-cw$CARatioT100 -mean(cw$CARatioT100 ,na.rm=T)
cw$CARatioW100c <-cw$CARatioW100 -mean(cw$CARatioW100 ,na.rm=T)
cw$CARatioB100c <-cw$CARatioB100 -mean(cw$CARatioB100 ,na.rm=T)
cw$CARatioH100c <-cw$CARatioH100 -mean(cw$CARatioH100 ,na.rm=T)
cw$MalePTc      <-cw$MalePT      -mean(cw$MalePT      ,na.rm=T)
cw$MalePWc      <-cw$MalePW      -mean(cw$MalePW      ,na.rm=T)
cw$MalePBc      <-cw$MalePB      -mean(cw$MalePB      ,na.rm=T)
cw$MalePHc      <-cw$MalePH      -mean(cw$MalePH      ,na.rm=T)
cw$MFRatioT100c <-cw$MFRatioT100 -mean(cw$MFRatioT100 ,na.rm=T)
cw$MFRatioW100c <-cw$MFRatioW100 -mean(cw$MFRatioW100 ,na.rm=T)
cw$MFRatioB100c <-cw$MFRatioB100 -mean(cw$MFRatioB100 ,na.rm=T)
cw$MFRatioH100c <-cw$MFRatioH100 -mean(cw$MFRatioH100 ,na.rm=T)
cw$ElderTc      <-cw$ElderT      -mean(cw$ElderT      ,na.rm=T)
cw$ElderWc      <-cw$ElderW      -mean(cw$ElderW      ,na.rm=T)
cw$ElderBc      <-cw$ElderB      -mean(cw$ElderB      ,na.rm=T)
cw$ElderHc      <-cw$ElderH      -mean(cw$ElderH      ,na.rm=T)
cw$SingleTc     <-cw$SingleT     -mean(cw$SingleT     ,na.rm=T)
cw$SingleWc     <-cw$SingleW     -mean(cw$SingleW     ,na.rm=T)
cw$SingleBc     <-cw$SingleB     -mean(cw$SingleB     ,na.rm=T)
cw$SingleHc     <-cw$SingleH     -mean(cw$SingleH     ,na.rm=T)
cw$FHeadTc      <-cw$FHeadT      -mean(cw$FHeadT      ,na.rm=T)
cw$FHeadWc      <-cw$FHeadW      -mean(cw$FHeadW      ,na.rm=T)
cw$FHeadBc      <-cw$FHeadB      -mean(cw$FHeadB      ,na.rm=T)
cw$FHeadHc      <-cw$FHeadH      -mean(cw$FHeadH      ,na.rm=T)
cw$NoHighTc     <-cw$NoHighT     -mean(cw$NoHighT     ,na.rm=T)
cw$NoHighWc     <-cw$NoHighW     -mean(cw$NoHighW     ,na.rm=T)
cw$NoHighBc     <-cw$NoHighB     -mean(cw$NoHighB     ,na.rm=T)
cw$NoHighHc     <-cw$NoHighH     -mean(cw$NoHighH     ,na.rm=T)
cw$UnempTc      <-cw$UnempT      -mean(cw$UnempT      ,na.rm=T)
cw$UnempWc      <-cw$UnempW      -mean(cw$UnempW      ,na.rm=T)
cw$UnempBc      <-cw$UnempB      -mean(cw$UnempB      ,na.rm=T)
cw$UnempHc      <-cw$UnempH      -mean(cw$UnempH      ,na.rm=T)
cw$CPovTc       <-cw$CPovT       -mean(cw$CPovT       ,na.rm=T)
cw$CPovWc       <-cw$CPovW       -mean(cw$CPovW       ,na.rm=T)
cw$CPovBc       <-cw$CPovB       -mean(cw$CPovB       ,na.rm=T)
cw$CPovHc       <-cw$CPovH       -mean(cw$CPovH       ,na.rm=T)
cw$CPov1c       <-cw$CPov1       -mean(cw$CPov1       ,na.rm=T)
cw$CPov2c       <-cw$CPov2       -mean(cw$CPov2       ,na.rm=T)
cw$CPov3c       <-cw$CPov3       -mean(cw$CPov3       ,na.rm=T)
cw$PubAsTc      <-cw$PubAsT      -mean(cw$PubAsT      ,na.rm=T)
cw$WelfarTc     <-cw$WelfarT     -mean(cw$WelfarT     ,na.rm=T)
cw$SnapTc       <-cw$SnapT       -mean(cw$SnapT       ,na.rm=T)
cw$SnapWc       <-cw$SnapW       -mean(cw$SnapW       ,na.rm=T)
cw$SnapBc       <-cw$SnapB       -mean(cw$SnapB       ,na.rm=T)
cw$SnapHc       <-cw$SnapH       -mean(cw$SnapH       ,na.rm=T)
cw$IncomeT1kc   <-cw$IncomeT1k   -mean(cw$IncomeT1k   ,na.rm=T)
cw$IncomeW1kc   <-cw$IncomeW1k   -mean(cw$IncomeW1k   ,na.rm=T)
cw$IncomeB1kc   <-cw$IncomeB1k   -mean(cw$IncomeB1k   ,na.rm=T)
cw$IncomeH1kc   <-cw$IncomeH1k   -mean(cw$IncomeH1k   ,na.rm=T)
cw$GiniT100c    <-cw$GiniT100    -mean(cw$GiniT100    ,na.rm=T)
cw$HValueT10kc  <-cw$HValueT10k  -mean(cw$HValueT10k  ,na.rm=T)
cw$MCostT100c   <-cw$MCostT100   -mean(cw$MCostT100   ,na.rm=T)
cw$OCostDT100c  <-cw$OCostDT100  -mean(cw$OCostDT100  ,na.rm=T)
cw$MRentDT100c  <-cw$MRentDT100  -mean(cw$MRentDT100  ,na.rm=T)
cw$OCostPTc     <-cw$OCostPT     -mean(cw$OCostPT     ,na.rm=T)
cw$MRentPTc     <-cw$MRentPT     -mean(cw$MRentPT     ,na.rm=T)
cw$MortgTc      <-cw$MortgT      -mean(cw$MortgT      ,na.rm=T)
cw$LangAPTc     <-cw$LangAPT     -mean(cw$LangAPT     ,na.rm=T)
cw$LangAPWc     <-cw$LangAPW     -mean(cw$LangAPW     ,na.rm=T)
cw$LangAPBc     <-cw$LangAPB     -mean(cw$LangAPB     ,na.rm=T)
cw$LangAPHc     <-cw$LangAPH     -mean(cw$LangAPH     ,na.rm=T)
cw$LangBPTc     <-cw$LangBPT     -mean(cw$LangBPT     ,na.rm=T)
cw$LangBPWc     <-cw$LangBPW     -mean(cw$LangBPW     ,na.rm=T)
cw$LangBPBc     <-cw$LangBPB     -mean(cw$LangBPB     ,na.rm=T)
cw$LangBPHc     <-cw$LangBPH     -mean(cw$LangBPH     ,na.rm=T)
cw$LangCPTc     <-cw$LangCPT     -mean(cw$LangCPT     ,na.rm=T)
cw$OutUsTc      <-cw$OutUsT      -mean(cw$OutUsT      ,na.rm=T)
cw$OutUsWc      <-cw$OutUsW      -mean(cw$OutUsW      ,na.rm=T)
cw$OutUsBc      <-cw$OutUsB      -mean(cw$OutUsB      ,na.rm=T)
cw$OutUsHc      <-cw$OutUsH      -mean(cw$OutUsH      ,na.rm=T)
cw$FBornTc      <-cw$FBornT      -mean(cw$FBornT      ,na.rm=T)
cw$FBornWc      <-cw$FBornW      -mean(cw$FBornW      ,na.rm=T)
cw$FBornBc      <-cw$FBornB      -mean(cw$FBornB      ,na.rm=T)
cw$FBornHc      <-cw$FBornH      -mean(cw$FBornH      ,na.rm=T)
cw$NotCtzTc     <-cw$NotCtzT     -mean(cw$NotCtzT     ,na.rm=T)
cw$NotCtzWc     <-cw$NotCtzW     -mean(cw$NotCtzW     ,na.rm=T)
cw$NotCtzBc     <-cw$NotCtzB     -mean(cw$NotCtzB     ,na.rm=T)
cw$NotCtzHc     <-cw$NotCtzH     -mean(cw$NotCtzH     ,na.rm=T)
cw$MoveTc       <-cw$MoveT       -mean(cw$MoveT       ,na.rm=T)
cw$MoveWc       <-cw$MoveW       -mean(cw$MoveW       ,na.rm=T)
cw$MoveBc       <-cw$MoveB       -mean(cw$MoveB       ,na.rm=T)
cw$MoveHc       <-cw$MoveH       -mean(cw$MoveH       ,na.rm=T)
cw$VacantTc     <-cw$VacantT     -mean(cw$VacantT     ,na.rm=T)
cw$OwnerTc      <-cw$OwnerT      -mean(cw$OwnerT      ,na.rm=T)
cw$OwnerWc      <-cw$OwnerW      -mean(cw$OwnerW      ,na.rm=T)
cw$OwnerBc      <-cw$OwnerB      -mean(cw$OwnerB      ,na.rm=T)
cw$OwnerHc      <-cw$OwnerH      -mean(cw$OwnerH      ,na.rm=T)
cw$CrowdTc      <-cw$CrowdT      -mean(cw$CrowdT      ,na.rm=T)
cw$CrowdWc      <-cw$CrowdW      -mean(cw$CrowdW      ,na.rm=T)
cw$CrowdBc      <-cw$CrowdB      -mean(cw$CrowdB      ,na.rm=T)
cw$CrowdHc      <-cw$CrowdH      -mean(cw$CrowdH      ,na.rm=T)
cw$MobileTc     <-cw$MobileT     -mean(cw$MobileT     ,na.rm=T)
cw$MobileWc     <-cw$MobileW     -mean(cw$MobileW     ,na.rm=T)
cw$MobileBc     <-cw$MobileB     -mean(cw$MobileB     ,na.rm=T)
cw$MobileHc     <-cw$MobileH     -mean(cw$MobileH     ,na.rm=T)
cw$DisablTc     <-cw$DisablT     -mean(cw$DisablT     ,na.rm=T)
cw$DisablWc     <-cw$DisablW     -mean(cw$DisablW     ,na.rm=T)
cw$DisablBc     <-cw$DisablB     -mean(cw$DisablB     ,na.rm=T)
cw$DisablHc     <-cw$DisablH     -mean(cw$DisablH     ,na.rm=T)
cw$DisablTCc    <-cw$DisablTC    -mean(cw$DisablTC    ,na.rm=T)
cw$DisablWCc    <-cw$DisablWC    -mean(cw$DisablWC    ,na.rm=T)
cw$DisablBCc    <-cw$DisablBC    -mean(cw$DisablBC    ,na.rm=T)
cw$DisablHCc    <-cw$DisablHC    -mean(cw$DisablHC    ,na.rm=T)
cw$DisablTMc    <-cw$DisablTM    -mean(cw$DisablTM    ,na.rm=T)
cw$DisablTFc    <-cw$DisablTF    -mean(cw$DisablTF    ,na.rm=T)
cw$Urban1c      <-cw$Urban1      -mean(cw$Urban1      ,na.rm=T)
cw$Urban2c      <-cw$Urban2      -mean(cw$Urban2      ,na.rm=T)
cw$LBWT1rc      <-cw$LBWT1r      -mean(cw$LBWT1r      ,na.rm=T)
cw$LBWM1rc      <-cw$LBWM1r      -mean(cw$LBWM1r      ,na.rm=T)
cw$LBWF1rc      <-cw$LBWF1r      -mean(cw$LBWF1r      ,na.rm=T)
cw$LBWW1rc      <-cw$LBWW1r      -mean(cw$LBWW1r      ,na.rm=T)
cw$LBWB1rc      <-cw$LBWB1r      -mean(cw$LBWB1r      ,na.rm=T)
cw$LBWH1rc      <-cw$LBWH1r      -mean(cw$LBWH1r      ,na.rm=T)
cw$PTBT1rc      <-cw$PTBT1r      -mean(cw$PTBT1r      ,na.rm=T)
cw$PTBM1rc      <-cw$PTBM1r      -mean(cw$PTBM1r      ,na.rm=T)
cw$PTBF1rc      <-cw$PTBF1r      -mean(cw$PTBF1r      ,na.rm=T)
cw$PTBW1rc      <-cw$PTBW1r      -mean(cw$PTBW1r      ,na.rm=T)
cw$PTBB1rc      <-cw$PTBB1r      -mean(cw$PTBB1r      ,na.rm=T)
cw$PTBH1rc      <-cw$PTBH1r      -mean(cw$PTBH1r      ,na.rm=T)
cw$PNCT1rc      <-cw$PNCT1r      -mean(cw$PNCT1r      ,na.rm=T)
cw$PNCM1rc      <-cw$PNCM1r      -mean(cw$PNCM1r      ,na.rm=T)
cw$PNCF1rc      <-cw$PNCF1r      -mean(cw$PNCF1r      ,na.rm=T)
cw$PNCW1rc      <-cw$PNCW1r      -mean(cw$PNCW1r      ,na.rm=T)
cw$PNCB1rc      <-cw$PNCB1r      -mean(cw$PNCB1r      ,na.rm=T)
cw$PNCH1rc      <-cw$PNCH1r      -mean(cw$PNCH1r      ,na.rm=T)
cw$TBBT1rc      <-cw$TBBT1r      -mean(cw$TBBT1r      ,na.rm=T)
cw$TBBM1rc      <-cw$TBBM1r      -mean(cw$TBBM1r      ,na.rm=T)
cw$TBBF1rc      <-cw$TBBF1r      -mean(cw$TBBF1r      ,na.rm=T)
cw$TBBW1rc      <-cw$TBBW1r      -mean(cw$TBBW1r      ,na.rm=T)
cw$TBBB1rc      <-cw$TBBB1r      -mean(cw$TBBB1r      ,na.rm=T)
cw$TBBH1rc      <-cw$TBBH1r      -mean(cw$TBBH1r      ,na.rm=T)
cw$TBTT1rc      <-cw$TBTT1r      -mean(cw$TBTT1r      ,na.rm=T)
cw$TBTM1rc      <-cw$TBTM1r      -mean(cw$TBTM1r      ,na.rm=T)
cw$TBTF1rc      <-cw$TBTF1r      -mean(cw$TBTF1r      ,na.rm=T)
cw$TBTW1rc      <-cw$TBTW1r      -mean(cw$TBTW1r      ,na.rm=T)
cw$TBTB1rc      <-cw$TBTB1r      -mean(cw$TBTB1r      ,na.rm=T)
cw$TBTH1rc      <-cw$TBTH1r      -mean(cw$TBTH1r      ,na.rm=T)
cw$LBWT5rc      <-cw$LBWT5r      -mean(cw$LBWT5r      ,na.rm=T)
cw$LBWM5rc      <-cw$LBWM5r      -mean(cw$LBWM5r      ,na.rm=T)
cw$LBWF5rc      <-cw$LBWF5r      -mean(cw$LBWF5r      ,na.rm=T)
cw$LBWW5rc      <-cw$LBWW5r      -mean(cw$LBWW5r      ,na.rm=T)
cw$LBWB5rc      <-cw$LBWB5r      -mean(cw$LBWB5r      ,na.rm=T)
cw$LBWH5rc      <-cw$LBWH5r      -mean(cw$LBWH5r      ,na.rm=T)
cw$PTBT5rc      <-cw$PTBT5r      -mean(cw$PTBT5r      ,na.rm=T)
cw$PTBM5rc      <-cw$PTBM5r      -mean(cw$PTBM5r      ,na.rm=T)
cw$PTBF5rc      <-cw$PTBF5r      -mean(cw$PTBF5r      ,na.rm=T)
cw$PTBW5rc      <-cw$PTBW5r      -mean(cw$PTBW5r      ,na.rm=T)
cw$PTBB5rc      <-cw$PTBB5r      -mean(cw$PTBB5r      ,na.rm=T)
cw$PTBH5rc      <-cw$PTBH5r      -mean(cw$PTBH5r      ,na.rm=T)
cw$PNCT5rc      <-cw$PNCT5r      -mean(cw$PNCT5r      ,na.rm=T)
cw$PNCM5rc      <-cw$PNCM5r      -mean(cw$PNCM5r      ,na.rm=T)
cw$PNCF5rc      <-cw$PNCF5r      -mean(cw$PNCF5r      ,na.rm=T)
cw$PNCW5rc      <-cw$PNCW5r      -mean(cw$PNCW5r      ,na.rm=T)
cw$PNCB5rc      <-cw$PNCB5r      -mean(cw$PNCB5r      ,na.rm=T)
cw$PNCH5rc      <-cw$PNCH5r      -mean(cw$PNCH5r      ,na.rm=T)
cw$TBBT5rc      <-cw$TBBT5r      -mean(cw$TBBT5r      ,na.rm=T)
cw$TBBM5rc      <-cw$TBBM5r      -mean(cw$TBBM5r      ,na.rm=T)
cw$TBBF5rc      <-cw$TBBF5r      -mean(cw$TBBF5r      ,na.rm=T)
cw$TBBW5rc      <-cw$TBBW5r      -mean(cw$TBBW5r      ,na.rm=T)
cw$TBBB5rc      <-cw$TBBB5r      -mean(cw$TBBB5r      ,na.rm=T)
cw$TBBH5rc      <-cw$TBBH5r      -mean(cw$TBBH5r      ,na.rm=T)
cw$TBTT5rc      <-cw$TBTT5r      -mean(cw$TBTT5r      ,na.rm=T)
cw$TBTM5rc      <-cw$TBTM5r      -mean(cw$TBTM5r      ,na.rm=T)
cw$TBTF5rc      <-cw$TBTF5r      -mean(cw$TBTF5r      ,na.rm=T)
cw$TBTW5rc      <-cw$TBTW5r      -mean(cw$TBTW5r      ,na.rm=T)
cw$TBTB5rc      <-cw$TBTB5r      -mean(cw$TBTB5r      ,na.rm=T)
cw$TBTH5rc      <-cw$TBTH5r      -mean(cw$TBTH5r      ,na.rm=T)
cw$Opioidc      <-cw$Opioid      -mean(cw$Opioid      ,na.rm=T)
cw$LifeExpc     <-cw$LifeExp     -mean(cw$LifeExp     ,na.rm=T)
cw$LifeExpBc    <-cw$LifeExpB    -mean(cw$LifeExpB    ,na.rm=T)
cw$LifeExpHc    <-cw$LifeExpH    -mean(cw$LifeExpH    ,na.rm=T)
cw$LifeExpWc    <-cw$LifeExpW    -mean(cw$LifeExpW    ,na.rm=T)
cw$ChdDeathc    <-cw$ChdDeath    -mean(cw$ChdDeath    ,na.rm=T)
cw$ChdDeathBc   <-cw$ChdDeathB   -mean(cw$ChdDeathB   ,na.rm=T)
cw$ChdDeathHc   <-cw$ChdDeathH   -mean(cw$ChdDeathH   ,na.rm=T)
cw$ChdDeathWc   <-cw$ChdDeathW   -mean(cw$ChdDeathW   ,na.rm=T)
cw$InfDeathc    <-cw$InfDeath    -mean(cw$InfDeath    ,na.rm=T)
cw$InfDeathBc   <-cw$InfDeathB   -mean(cw$InfDeathB   ,na.rm=T)
cw$InfDeathHc   <-cw$InfDeathH   -mean(cw$InfDeathH   ,na.rm=T)
cw$InfDeathWc   <-cw$InfDeathW   -mean(cw$InfDeathW   ,na.rm=T)
cw$Injuryc      <-cw$Injury      -mean(cw$Injury      ,na.rm=T)
cw$InjuryBc     <-cw$InjuryB     -mean(cw$InjuryB     ,na.rm=T)
cw$InjuryHc     <-cw$InjuryH     -mean(cw$InjuryH     ,na.rm=T)
cw$InjuryWc     <-cw$InjuryW     -mean(cw$InjuryW     ,na.rm=T)
cw$GunDeathc    <-cw$GunDeath    -mean(cw$GunDeath    ,na.rm=T)
cw$GunDeathBc   <-cw$GunDeathB   -mean(cw$GunDeathB   ,na.rm=T)
cw$GunDeathWc   <-cw$GunDeathW   -mean(cw$GunDeathW   ,na.rm=T)
cw$PrmDeath_c   <-cw$PrmDeath    -mean(cw$PrmDeath    ,na.rm=T)
cw$PrmDeathcc   <-cw$PrmDeathc   -mean(cw$PrmDeathc   ,na.rm=T)
cw$PrmDeathBc   <-cw$PrmDeathB   -mean(cw$PrmDeathB   ,na.rm=T)
cw$PrmDeathHc   <-cw$PrmDeathH   -mean(cw$PrmDeathH   ,na.rm=T)
cw$PrmDeathWc   <-cw$PrmDeathW   -mean(cw$PrmDeathW   ,na.rm=T)
cw$PrmDeath2_c  <-cw$PrmDeath2   -mean(cw$PrmDeath2   ,na.rm=T)
cw$PrmDeath2cc  <-cw$PrmDeath2c  -mean(cw$PrmDeath2c  ,na.rm=T)
cw$PrmDeath2Bc  <-cw$PrmDeath2B  -mean(cw$PrmDeath2B  ,na.rm=T)
cw$PrmDeath2Hc  <-cw$PrmDeath2H  -mean(cw$PrmDeath2H  ,na.rm=T)
cw$PrmDeath2Wc  <-cw$PrmDeath2W  -mean(cw$PrmDeath2W  ,na.rm=T)
cw$Suicidec     <-cw$Suicide     -mean(cw$Suicide     ,na.rm=T)
cw$Diabetc      <-cw$Diabet      -mean(cw$Diabet      ,na.rm=T)
cw$Obesityc     <-cw$Obesity     -mean(cw$Obesity     ,na.rm=T)
cw$Physicalc    <-cw$Physical    -mean(cw$Physical    ,na.rm=T)
cw$PoorHlthc    <-cw$PoorHlth    -mean(cw$PoorHlth    ,na.rm=T)
cw$PoorMHc      <-cw$PoorMH      -mean(cw$PoorMH      ,na.rm=T)
cw$PoorPhyc     <-cw$PoorPhy     -mean(cw$PoorPhy     ,na.rm=T)
cw$Sleepc       <-cw$Sleep       -mean(cw$Sleep       ,na.rm=T)
cw$DrugOdc      <-cw$DrugOd      -mean(cw$DrugOd      ,na.rm=T)
cw$DrugOdBc     <-cw$DrugOdB     -mean(cw$DrugOdB     ,na.rm=T)
cw$DrugOdHc     <-cw$DrugOdH     -mean(cw$DrugOdH     ,na.rm=T)
cw$DrugOdWc     <-cw$DrugOdW     -mean(cw$DrugOdW     ,na.rm=T)
cw$DWIDeathc    <-cw$DWIDeath    -mean(cw$DWIDeath    ,na.rm=T)
cw$EDrinkc      <-cw$EDrink      -mean(cw$EDrink      ,na.rm=T)
cw$Smokec       <-cw$Smoke       -mean(cw$Smoke       ,na.rm=T)
cw$FastFoodc    <-cw$FastFood    -mean(cw$FastFood    ,na.rm=T)
cw$FoodEnvc     <-cw$FoodEnv     -mean(cw$FoodEnv     ,na.rm=T)
cw$FoodInsc     <-cw$FoodIns     -mean(cw$FoodIns     ,na.rm=T)
cw$FrLunchc     <-cw$FrLunch     -mean(cw$FrLunch     ,na.rm=T)
cw$LAccFoodc    <-cw$LAccFood    -mean(cw$LAccFood    ,na.rm=T)
cw$Gymc         <-cw$Gym         -mean(cw$Gym         ,na.rm=T)
cw$Gym2c        <-cw$Gym2        -mean(cw$Gym2        ,na.rm=T)
cw$Inactivec    <-cw$Inactive    -mean(cw$Inactive    ,na.rm=T)
cw$HousCostc    <-cw$HousCost    -mean(cw$HousCost    ,na.rm=T)
cw$HousCostsc   <-cw$HousCosts   -mean(cw$HousCosts   ,na.rm=T)
cw$HousCrowdc   <-cw$HousCrowd   -mean(cw$HousCrowd   ,na.rm=T)
cw$Housingc     <-cw$Housing     -mean(cw$Housing     ,na.rm=T)
cw$HousPlumbc   <-cw$HousPlumb   -mean(cw$HousPlumb   ,na.rm=T)
cw$Insuredc     <-cw$Insured     -mean(cw$Insured     ,na.rm=T)
cw$InsuredAc    <-cw$InsuredA    -mean(cw$InsuredA    ,na.rm=T)
cw$InsuredCc    <-cw$InsuredC    -mean(cw$InsuredC    ,na.rm=T)
cw$JuvArrc      <-cw$JuvArr      -mean(cw$JuvArr      ,na.rm=T)
cw$Murderc      <-cw$Murder      -mean(cw$Murder      ,na.rm=T)
cw$Violentc     <-cw$Violent     -mean(cw$Violent     ,na.rm=T)
cw$LongCommc    <-cw$LongComm    -mean(cw$LongComm    ,na.rm=T)
cw$LowBWc       <-cw$LowBW       -mean(cw$LowBW       ,na.rm=T)
cw$LowBWBc      <-cw$LowBWB      -mean(cw$LowBWB      ,na.rm=T)
cw$LowBWHc      <-cw$LowBWH      -mean(cw$LowBWH      ,na.rm=T)
cw$LowBWWc      <-cw$LowBWW      -mean(cw$LowBWW      ,na.rm=T)
cw$TeenBthc     <-cw$TeenBth     -mean(cw$TeenBth     ,na.rm=T)
cw$TeenBthBc    <-cw$TeenBthB    -mean(cw$TeenBthB    ,na.rm=T)
cw$TeenBthHc    <-cw$TeenBthH    -mean(cw$TeenBthH    ,na.rm=T)
cw$TeenBthWc    <-cw$TeenBthW    -mean(cw$TeenBthW    ,na.rm=T)
cw$Mentalc      <-cw$Mental      -mean(cw$Mental      ,na.rm=T)
cw$MHPrvdc      <-cw$MHPrvd      -mean(cw$MHPrvd      ,na.rm=T)
cw$PCPc         <-cw$PCP         -mean(cw$PCP         ,na.rm=T)
cw$PCP2c        <-cw$PCP2        -mean(cw$PCP2        ,na.rm=T)
cw$Dentistc     <-cw$Dentist     -mean(cw$Dentist     ,na.rm=T)
cw$PrvtHospc    <-cw$PrvtHosp    -mean(cw$PrvtHosp    ,na.rm=T)
cw$PrvtHospBc   <-cw$PrvtHospB   -mean(cw$PrvtHospB   ,na.rm=T)
cw$PrvtHospHc   <-cw$PrvtHospH   -mean(cw$PrvtHospH   ,na.rm=T)
cw$PrvtHospWc   <-cw$PrvtHospW   -mean(cw$PrvtHospW   ,na.rm=T)
cw$SegBWc       <-cw$SegBW       -mean(cw$SegBW       ,na.rm=T)
cw$SegNWc       <-cw$SegNW       -mean(cw$SegNW       ,na.rm=T)
cw$SocAssoc     <-cw$SocAsso     -mean(cw$SocAsso     ,na.rm=T)
cw$SocSuppc     <-cw$SocSupp     -mean(cw$SocSupp     ,na.rm=T)
cw$MIECHVc      <-cw$MIECHV      -mean(cw$MIECHV      ,na.rm=T)
cw$NHVRCc       <-cw$NHVRC       -mean(cw$NHVRC       ,na.rm=T)
cw$HomeV2c      <-cw$HomeV2      -mean(cw$HomeV2      ,na.rm=T)
cw$FoodInsecurec<-cw$FoodInsecure-mean(cw$FoodInsecure,na.rm=T)

cw<-cbind(cw,demean(cw,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cwm01<-lmer(RptWr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm02<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm03<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm04<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm05<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm06<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm07<-lmer(RptWr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cwm01,cwm02,cwm03,cwm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm04,cwm05,cwm06,cwm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cwm01CI<-confint(cwm01,method='boot',nsim=500,boot.type='perc')
cwm02CI<-confint(cwm02,method='boot',nsim=500,boot.type='perc')
cwm03CI<-confint(cwm03,method='boot',nsim=500,boot.type='perc')
cwm04CI<-confint(cwm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cwm01)
check_collinearity(cwm02)
check_collinearity(cwm03)
check_collinearity(cwm04)
isSingular(cwm01)
isSingular(cwm02)
isSingular(cwm03)
isSingular(cwm04)




# Model building
cwm01a<-lmer(RptWr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm02a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm03a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm04a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm05a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm06a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))
cwm07a<-lmer(RptWr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cw,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cwm01a,cwm02a,cwm03a,cwm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm04a,cwm05a,cwm06a,cwm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cwm01aCI<-confint(cwm01a,method='boot',nsim=500,boot.type='perc')
cwm02aCI<-confint(cwm02a,method='boot',nsim=500,boot.type='perc')
cwm03aCI<-confint(cwm03a,method='boot',nsim=500,boot.type='perc')
cwm04aCI<-confint(cwm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cwm01a)
check_collinearity(cwm02a)
check_collinearity(cwm03a)
check_collinearity(cwm04a)
isSingular(cwm01a)
isSingular(cwm02a)
isSingular(cwm03a)
isSingular(cwm04a)



cwg02<-glmmTMB(RptW~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
                 ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopW)),data=cw,family=nbinom2)
cwg02a<-glmmTMB(RptW~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornWc_within+FBornWc_between+
                  ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopW)),data=cw,family=nbinom2)




###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cb$CPopBPc      <-cb$CPopBP      -mean(cb$CPopBP      ,na.rm=T)
cb$CPopHPc      <-cb$CPopHP      -mean(cb$CPopHP      ,na.rm=T)
cb$ChildPTc     <-cb$ChildPT     -mean(cb$ChildPT     ,na.rm=T)
cb$ChildPWc     <-cb$ChildPW     -mean(cb$ChildPW     ,na.rm=T)
cb$ChildPBc     <-cb$ChildPB     -mean(cb$ChildPB     ,na.rm=T)
cb$ChildPHc     <-cb$ChildPH     -mean(cb$ChildPH     ,na.rm=T)
cb$CARatioT100c <-cb$CARatioT100 -mean(cb$CARatioT100 ,na.rm=T)
cb$CARatioW100c <-cb$CARatioW100 -mean(cb$CARatioW100 ,na.rm=T)
cb$CARatioB100c <-cb$CARatioB100 -mean(cb$CARatioB100 ,na.rm=T)
cb$CARatioH100c <-cb$CARatioH100 -mean(cb$CARatioH100 ,na.rm=T)
cb$MalePTc      <-cb$MalePT      -mean(cb$MalePT      ,na.rm=T)
cb$MalePWc      <-cb$MalePW      -mean(cb$MalePW      ,na.rm=T)
cb$MalePBc      <-cb$MalePB      -mean(cb$MalePB      ,na.rm=T)
cb$MalePHc      <-cb$MalePH      -mean(cb$MalePH      ,na.rm=T)
cb$MFRatioT100c <-cb$MFRatioT100 -mean(cb$MFRatioT100 ,na.rm=T)
cb$MFRatioW100c <-cb$MFRatioW100 -mean(cb$MFRatioW100 ,na.rm=T)
cb$MFRatioB100c <-cb$MFRatioB100 -mean(cb$MFRatioB100 ,na.rm=T)
cb$MFRatioH100c <-cb$MFRatioH100 -mean(cb$MFRatioH100 ,na.rm=T)
cb$ElderTc      <-cb$ElderT      -mean(cb$ElderT      ,na.rm=T)
cb$ElderWc      <-cb$ElderW      -mean(cb$ElderW      ,na.rm=T)
cb$ElderBc      <-cb$ElderB      -mean(cb$ElderB      ,na.rm=T)
cb$ElderHc      <-cb$ElderH      -mean(cb$ElderH      ,na.rm=T)
cb$SingleTc     <-cb$SingleT     -mean(cb$SingleT     ,na.rm=T)
cb$SingleWc     <-cb$SingleW     -mean(cb$SingleW     ,na.rm=T)
cb$SingleBc     <-cb$SingleB     -mean(cb$SingleB     ,na.rm=T)
cb$SingleHc     <-cb$SingleH     -mean(cb$SingleH     ,na.rm=T)
cb$FHeadTc      <-cb$FHeadT      -mean(cb$FHeadT      ,na.rm=T)
cb$FHeadWc      <-cb$FHeadW      -mean(cb$FHeadW      ,na.rm=T)
cb$FHeadBc      <-cb$FHeadB      -mean(cb$FHeadB      ,na.rm=T)
cb$FHeadHc      <-cb$FHeadH      -mean(cb$FHeadH      ,na.rm=T)
cb$NoHighTc     <-cb$NoHighT     -mean(cb$NoHighT     ,na.rm=T)
cb$NoHighWc     <-cb$NoHighW     -mean(cb$NoHighW     ,na.rm=T)
cb$NoHighBc     <-cb$NoHighB     -mean(cb$NoHighB     ,na.rm=T)
cb$NoHighHc     <-cb$NoHighH     -mean(cb$NoHighH     ,na.rm=T)
cb$UnempTc      <-cb$UnempT      -mean(cb$UnempT      ,na.rm=T)
cb$UnempWc      <-cb$UnempW      -mean(cb$UnempW      ,na.rm=T)
cb$UnempBc      <-cb$UnempB      -mean(cb$UnempB      ,na.rm=T)
cb$UnempHc      <-cb$UnempH      -mean(cb$UnempH      ,na.rm=T)
cb$CPovTc       <-cb$CPovT       -mean(cb$CPovT       ,na.rm=T)
cb$CPovWc       <-cb$CPovW       -mean(cb$CPovW       ,na.rm=T)
cb$CPovBc       <-cb$CPovB       -mean(cb$CPovB       ,na.rm=T)
cb$CPovHc       <-cb$CPovH       -mean(cb$CPovH       ,na.rm=T)
cb$CPov1c       <-cb$CPov1       -mean(cb$CPov1       ,na.rm=T)
cb$CPov2c       <-cb$CPov2       -mean(cb$CPov2       ,na.rm=T)
cb$CPov3c       <-cb$CPov3       -mean(cb$CPov3       ,na.rm=T)
cb$PubAsTc      <-cb$PubAsT      -mean(cb$PubAsT      ,na.rm=T)
cb$WelfarTc     <-cb$WelfarT     -mean(cb$WelfarT     ,na.rm=T)
cb$SnapTc       <-cb$SnapT       -mean(cb$SnapT       ,na.rm=T)
cb$SnapWc       <-cb$SnapW       -mean(cb$SnapW       ,na.rm=T)
cb$SnapBc       <-cb$SnapB       -mean(cb$SnapB       ,na.rm=T)
cb$SnapHc       <-cb$SnapH       -mean(cb$SnapH       ,na.rm=T)
cb$IncomeT1kc   <-cb$IncomeT1k   -mean(cb$IncomeT1k   ,na.rm=T)
cb$IncomeW1kc   <-cb$IncomeW1k   -mean(cb$IncomeW1k   ,na.rm=T)
cb$IncomeB1kc   <-cb$IncomeB1k   -mean(cb$IncomeB1k   ,na.rm=T)
cb$IncomeH1kc   <-cb$IncomeH1k   -mean(cb$IncomeH1k   ,na.rm=T)
cb$GiniT100c    <-cb$GiniT100    -mean(cb$GiniT100    ,na.rm=T)
cb$HValueT10kc  <-cb$HValueT10k  -mean(cb$HValueT10k  ,na.rm=T)
cb$MCostT100c   <-cb$MCostT100   -mean(cb$MCostT100   ,na.rm=T)
cb$OCostDT100c  <-cb$OCostDT100  -mean(cb$OCostDT100  ,na.rm=T)
cb$MRentDT100c  <-cb$MRentDT100  -mean(cb$MRentDT100  ,na.rm=T)
cb$OCostPTc     <-cb$OCostPT     -mean(cb$OCostPT     ,na.rm=T)
cb$MRentPTc     <-cb$MRentPT     -mean(cb$MRentPT     ,na.rm=T)
cb$MortgTc      <-cb$MortgT      -mean(cb$MortgT      ,na.rm=T)
cb$LangAPTc     <-cb$LangAPT     -mean(cb$LangAPT     ,na.rm=T)
cb$LangAPWc     <-cb$LangAPW     -mean(cb$LangAPW     ,na.rm=T)
cb$LangAPBc     <-cb$LangAPB     -mean(cb$LangAPB     ,na.rm=T)
cb$LangAPHc     <-cb$LangAPH     -mean(cb$LangAPH     ,na.rm=T)
cb$LangBPTc     <-cb$LangBPT     -mean(cb$LangBPT     ,na.rm=T)
cb$LangBPWc     <-cb$LangBPW     -mean(cb$LangBPW     ,na.rm=T)
cb$LangBPBc     <-cb$LangBPB     -mean(cb$LangBPB     ,na.rm=T)
cb$LangBPHc     <-cb$LangBPH     -mean(cb$LangBPH     ,na.rm=T)
cb$LangCPTc     <-cb$LangCPT     -mean(cb$LangCPT     ,na.rm=T)
cb$OutUsTc      <-cb$OutUsT      -mean(cb$OutUsT      ,na.rm=T)
cb$OutUsWc      <-cb$OutUsW      -mean(cb$OutUsW      ,na.rm=T)
cb$OutUsBc      <-cb$OutUsB      -mean(cb$OutUsB      ,na.rm=T)
cb$OutUsHc      <-cb$OutUsH      -mean(cb$OutUsH      ,na.rm=T)
cb$FBornTc      <-cb$FBornT      -mean(cb$FBornT      ,na.rm=T)
cb$FBornWc      <-cb$FBornW      -mean(cb$FBornW      ,na.rm=T)
cb$FBornBc      <-cb$FBornB      -mean(cb$FBornB      ,na.rm=T)
cb$FBornHc      <-cb$FBornH      -mean(cb$FBornH      ,na.rm=T)
cb$NotCtzTc     <-cb$NotCtzT     -mean(cb$NotCtzT     ,na.rm=T)
cb$NotCtzWc     <-cb$NotCtzW     -mean(cb$NotCtzW     ,na.rm=T)
cb$NotCtzBc     <-cb$NotCtzB     -mean(cb$NotCtzB     ,na.rm=T)
cb$NotCtzHc     <-cb$NotCtzH     -mean(cb$NotCtzH     ,na.rm=T)
cb$MoveTc       <-cb$MoveT       -mean(cb$MoveT       ,na.rm=T)
cb$MoveWc       <-cb$MoveW       -mean(cb$MoveW       ,na.rm=T)
cb$MoveBc       <-cb$MoveB       -mean(cb$MoveB       ,na.rm=T)
cb$MoveHc       <-cb$MoveH       -mean(cb$MoveH       ,na.rm=T)
cb$VacantTc     <-cb$VacantT     -mean(cb$VacantT     ,na.rm=T)
cb$OwnerTc      <-cb$OwnerT      -mean(cb$OwnerT      ,na.rm=T)
cb$OwnerWc      <-cb$OwnerW      -mean(cb$OwnerW      ,na.rm=T)
cb$OwnerBc      <-cb$OwnerB      -mean(cb$OwnerB      ,na.rm=T)
cb$OwnerHc      <-cb$OwnerH      -mean(cb$OwnerH      ,na.rm=T)
cb$CrowdTc      <-cb$CrowdT      -mean(cb$CrowdT      ,na.rm=T)
cb$CrowdWc      <-cb$CrowdW      -mean(cb$CrowdW      ,na.rm=T)
cb$CrowdBc      <-cb$CrowdB      -mean(cb$CrowdB      ,na.rm=T)
cb$CrowdHc      <-cb$CrowdH      -mean(cb$CrowdH      ,na.rm=T)
cb$MobileTc     <-cb$MobileT     -mean(cb$MobileT     ,na.rm=T)
cb$MobileWc     <-cb$MobileW     -mean(cb$MobileW     ,na.rm=T)
cb$MobileBc     <-cb$MobileB     -mean(cb$MobileB     ,na.rm=T)
cb$MobileHc     <-cb$MobileH     -mean(cb$MobileH     ,na.rm=T)
cb$DisablTc     <-cb$DisablT     -mean(cb$DisablT     ,na.rm=T)
cb$DisablWc     <-cb$DisablW     -mean(cb$DisablW     ,na.rm=T)
cb$DisablBc     <-cb$DisablB     -mean(cb$DisablB     ,na.rm=T)
cb$DisablHc     <-cb$DisablH     -mean(cb$DisablH     ,na.rm=T)
cb$DisablTCc    <-cb$DisablTC    -mean(cb$DisablTC    ,na.rm=T)
cb$DisablWCc    <-cb$DisablWC    -mean(cb$DisablWC    ,na.rm=T)
cb$DisablBCc    <-cb$DisablBC    -mean(cb$DisablBC    ,na.rm=T)
cb$DisablHCc    <-cb$DisablHC    -mean(cb$DisablHC    ,na.rm=T)
cb$DisablTMc    <-cb$DisablTM    -mean(cb$DisablTM    ,na.rm=T)
cb$DisablTFc    <-cb$DisablTF    -mean(cb$DisablTF    ,na.rm=T)
cb$Urban1c      <-cb$Urban1      -mean(cb$Urban1      ,na.rm=T)
cb$Urban2c      <-cb$Urban2      -mean(cb$Urban2      ,na.rm=T)
cb$LBWT1rc      <-cb$LBWT1r      -mean(cb$LBWT1r      ,na.rm=T)
cb$LBWM1rc      <-cb$LBWM1r      -mean(cb$LBWM1r      ,na.rm=T)
cb$LBWF1rc      <-cb$LBWF1r      -mean(cb$LBWF1r      ,na.rm=T)
cb$LBWW1rc      <-cb$LBWW1r      -mean(cb$LBWW1r      ,na.rm=T)
cb$LBWB1rc      <-cb$LBWB1r      -mean(cb$LBWB1r      ,na.rm=T)
cb$LBWH1rc      <-cb$LBWH1r      -mean(cb$LBWH1r      ,na.rm=T)
cb$PTBT1rc      <-cb$PTBT1r      -mean(cb$PTBT1r      ,na.rm=T)
cb$PTBM1rc      <-cb$PTBM1r      -mean(cb$PTBM1r      ,na.rm=T)
cb$PTBF1rc      <-cb$PTBF1r      -mean(cb$PTBF1r      ,na.rm=T)
cb$PTBW1rc      <-cb$PTBW1r      -mean(cb$PTBW1r      ,na.rm=T)
cb$PTBB1rc      <-cb$PTBB1r      -mean(cb$PTBB1r      ,na.rm=T)
cb$PTBH1rc      <-cb$PTBH1r      -mean(cb$PTBH1r      ,na.rm=T)
cb$PNCT1rc      <-cb$PNCT1r      -mean(cb$PNCT1r      ,na.rm=T)
cb$PNCM1rc      <-cb$PNCM1r      -mean(cb$PNCM1r      ,na.rm=T)
cb$PNCF1rc      <-cb$PNCF1r      -mean(cb$PNCF1r      ,na.rm=T)
cb$PNCW1rc      <-cb$PNCW1r      -mean(cb$PNCW1r      ,na.rm=T)
cb$PNCB1rc      <-cb$PNCB1r      -mean(cb$PNCB1r      ,na.rm=T)
cb$PNCH1rc      <-cb$PNCH1r      -mean(cb$PNCH1r      ,na.rm=T)
cb$TBBT1rc      <-cb$TBBT1r      -mean(cb$TBBT1r      ,na.rm=T)
cb$TBBM1rc      <-cb$TBBM1r      -mean(cb$TBBM1r      ,na.rm=T)
cb$TBBF1rc      <-cb$TBBF1r      -mean(cb$TBBF1r      ,na.rm=T)
cb$TBBW1rc      <-cb$TBBW1r      -mean(cb$TBBW1r      ,na.rm=T)
cb$TBBB1rc      <-cb$TBBB1r      -mean(cb$TBBB1r      ,na.rm=T)
cb$TBBH1rc      <-cb$TBBH1r      -mean(cb$TBBH1r      ,na.rm=T)
cb$TBTT1rc      <-cb$TBTT1r      -mean(cb$TBTT1r      ,na.rm=T)
cb$TBTM1rc      <-cb$TBTM1r      -mean(cb$TBTM1r      ,na.rm=T)
cb$TBTF1rc      <-cb$TBTF1r      -mean(cb$TBTF1r      ,na.rm=T)
cb$TBTW1rc      <-cb$TBTW1r      -mean(cb$TBTW1r      ,na.rm=T)
cb$TBTB1rc      <-cb$TBTB1r      -mean(cb$TBTB1r      ,na.rm=T)
cb$TBTH1rc      <-cb$TBTH1r      -mean(cb$TBTH1r      ,na.rm=T)
cb$LBWT5rc      <-cb$LBWT5r      -mean(cb$LBWT5r      ,na.rm=T)
cb$LBWM5rc      <-cb$LBWM5r      -mean(cb$LBWM5r      ,na.rm=T)
cb$LBWF5rc      <-cb$LBWF5r      -mean(cb$LBWF5r      ,na.rm=T)
cb$LBWW5rc      <-cb$LBWW5r      -mean(cb$LBWW5r      ,na.rm=T)
cb$LBWB5rc      <-cb$LBWB5r      -mean(cb$LBWB5r      ,na.rm=T)
cb$LBWH5rc      <-cb$LBWH5r      -mean(cb$LBWH5r      ,na.rm=T)
cb$PTBT5rc      <-cb$PTBT5r      -mean(cb$PTBT5r      ,na.rm=T)
cb$PTBM5rc      <-cb$PTBM5r      -mean(cb$PTBM5r      ,na.rm=T)
cb$PTBF5rc      <-cb$PTBF5r      -mean(cb$PTBF5r      ,na.rm=T)
cb$PTBW5rc      <-cb$PTBW5r      -mean(cb$PTBW5r      ,na.rm=T)
cb$PTBB5rc      <-cb$PTBB5r      -mean(cb$PTBB5r      ,na.rm=T)
cb$PTBH5rc      <-cb$PTBH5r      -mean(cb$PTBH5r      ,na.rm=T)
cb$PNCT5rc      <-cb$PNCT5r      -mean(cb$PNCT5r      ,na.rm=T)
cb$PNCM5rc      <-cb$PNCM5r      -mean(cb$PNCM5r      ,na.rm=T)
cb$PNCF5rc      <-cb$PNCF5r      -mean(cb$PNCF5r      ,na.rm=T)
cb$PNCW5rc      <-cb$PNCW5r      -mean(cb$PNCW5r      ,na.rm=T)
cb$PNCB5rc      <-cb$PNCB5r      -mean(cb$PNCB5r      ,na.rm=T)
cb$PNCH5rc      <-cb$PNCH5r      -mean(cb$PNCH5r      ,na.rm=T)
cb$TBBT5rc      <-cb$TBBT5r      -mean(cb$TBBT5r      ,na.rm=T)
cb$TBBM5rc      <-cb$TBBM5r      -mean(cb$TBBM5r      ,na.rm=T)
cb$TBBF5rc      <-cb$TBBF5r      -mean(cb$TBBF5r      ,na.rm=T)
cb$TBBW5rc      <-cb$TBBW5r      -mean(cb$TBBW5r      ,na.rm=T)
cb$TBBB5rc      <-cb$TBBB5r      -mean(cb$TBBB5r      ,na.rm=T)
cb$TBBH5rc      <-cb$TBBH5r      -mean(cb$TBBH5r      ,na.rm=T)
cb$TBTT5rc      <-cb$TBTT5r      -mean(cb$TBTT5r      ,na.rm=T)
cb$TBTM5rc      <-cb$TBTM5r      -mean(cb$TBTM5r      ,na.rm=T)
cb$TBTF5rc      <-cb$TBTF5r      -mean(cb$TBTF5r      ,na.rm=T)
cb$TBTW5rc      <-cb$TBTW5r      -mean(cb$TBTW5r      ,na.rm=T)
cb$TBTB5rc      <-cb$TBTB5r      -mean(cb$TBTB5r      ,na.rm=T)
cb$TBTH5rc      <-cb$TBTH5r      -mean(cb$TBTH5r      ,na.rm=T)
cb$Opioidc      <-cb$Opioid      -mean(cb$Opioid      ,na.rm=T)
cb$LifeExpc     <-cb$LifeExp     -mean(cb$LifeExp     ,na.rm=T)
cb$LifeExpBc    <-cb$LifeExpB    -mean(cb$LifeExpB    ,na.rm=T)
cb$LifeExpHc    <-cb$LifeExpH    -mean(cb$LifeExpH    ,na.rm=T)
cb$LifeExpWc    <-cb$LifeExpW    -mean(cb$LifeExpW    ,na.rm=T)
cb$ChdDeathc    <-cb$ChdDeath    -mean(cb$ChdDeath    ,na.rm=T)
cb$ChdDeathBc   <-cb$ChdDeathB   -mean(cb$ChdDeathB   ,na.rm=T)
cb$ChdDeathHc   <-cb$ChdDeathH   -mean(cb$ChdDeathH   ,na.rm=T)
cb$ChdDeathWc   <-cb$ChdDeathW   -mean(cb$ChdDeathW   ,na.rm=T)
cb$InfDeathc    <-cb$InfDeath    -mean(cb$InfDeath    ,na.rm=T)
cb$InfDeathBc   <-cb$InfDeathB   -mean(cb$InfDeathB   ,na.rm=T)
cb$InfDeathHc   <-cb$InfDeathH   -mean(cb$InfDeathH   ,na.rm=T)
cb$InfDeathWc   <-cb$InfDeathW   -mean(cb$InfDeathW   ,na.rm=T)
cb$Injuryc      <-cb$Injury      -mean(cb$Injury      ,na.rm=T)
cb$InjuryBc     <-cb$InjuryB     -mean(cb$InjuryB     ,na.rm=T)
cb$InjuryHc     <-cb$InjuryH     -mean(cb$InjuryH     ,na.rm=T)
cb$InjuryWc     <-cb$InjuryW     -mean(cb$InjuryW     ,na.rm=T)
cb$GunDeathc    <-cb$GunDeath    -mean(cb$GunDeath    ,na.rm=T)
cb$GunDeathBc   <-cb$GunDeathB   -mean(cb$GunDeathB   ,na.rm=T)
cb$GunDeathWc   <-cb$GunDeathW   -mean(cb$GunDeathW   ,na.rm=T)
cb$PrmDeath_c   <-cb$PrmDeath    -mean(cb$PrmDeath    ,na.rm=T)
cb$PrmDeathcc   <-cb$PrmDeathc   -mean(cb$PrmDeathc   ,na.rm=T)
cb$PrmDeathBc   <-cb$PrmDeathB   -mean(cb$PrmDeathB   ,na.rm=T)
cb$PrmDeathHc   <-cb$PrmDeathH   -mean(cb$PrmDeathH   ,na.rm=T)
cb$PrmDeathWc   <-cb$PrmDeathW   -mean(cb$PrmDeathW   ,na.rm=T)
cb$PrmDeath2_c  <-cb$PrmDeath2   -mean(cb$PrmDeath2   ,na.rm=T)
cb$PrmDeath2cc  <-cb$PrmDeath2c  -mean(cb$PrmDeath2c  ,na.rm=T)
cb$PrmDeath2Bc  <-cb$PrmDeath2B  -mean(cb$PrmDeath2B  ,na.rm=T)
cb$PrmDeath2Hc  <-cb$PrmDeath2H  -mean(cb$PrmDeath2H  ,na.rm=T)
cb$PrmDeath2Wc  <-cb$PrmDeath2W  -mean(cb$PrmDeath2W  ,na.rm=T)
cb$Suicidec     <-cb$Suicide     -mean(cb$Suicide     ,na.rm=T)
cb$Diabetc      <-cb$Diabet      -mean(cb$Diabet      ,na.rm=T)
cb$Obesityc     <-cb$Obesity     -mean(cb$Obesity     ,na.rm=T)
cb$Physicalc    <-cb$Physical    -mean(cb$Physical    ,na.rm=T)
cb$PoorHlthc    <-cb$PoorHlth    -mean(cb$PoorHlth    ,na.rm=T)
cb$PoorMHc      <-cb$PoorMH      -mean(cb$PoorMH      ,na.rm=T)
cb$PoorPhyc     <-cb$PoorPhy     -mean(cb$PoorPhy     ,na.rm=T)
cb$Sleepc       <-cb$Sleep       -mean(cb$Sleep       ,na.rm=T)
cb$DrugOdc      <-cb$DrugOd      -mean(cb$DrugOd      ,na.rm=T)
cb$DrugOdBc     <-cb$DrugOdB     -mean(cb$DrugOdB     ,na.rm=T)
cb$DrugOdHc     <-cb$DrugOdH     -mean(cb$DrugOdH     ,na.rm=T)
cb$DrugOdWc     <-cb$DrugOdW     -mean(cb$DrugOdW     ,na.rm=T)
cb$DWIDeathc    <-cb$DWIDeath    -mean(cb$DWIDeath    ,na.rm=T)
cb$EDrinkc      <-cb$EDrink      -mean(cb$EDrink      ,na.rm=T)
cb$Smokec       <-cb$Smoke       -mean(cb$Smoke       ,na.rm=T)
cb$FastFoodc    <-cb$FastFood    -mean(cb$FastFood    ,na.rm=T)
cb$FoodEnvc     <-cb$FoodEnv     -mean(cb$FoodEnv     ,na.rm=T)
cb$FoodInsc     <-cb$FoodIns     -mean(cb$FoodIns     ,na.rm=T)
cb$FrLunchc     <-cb$FrLunch     -mean(cb$FrLunch     ,na.rm=T)
cb$LAccFoodc    <-cb$LAccFood    -mean(cb$LAccFood    ,na.rm=T)
cb$Gymc         <-cb$Gym         -mean(cb$Gym         ,na.rm=T)
cb$Gym2c        <-cb$Gym2        -mean(cb$Gym2        ,na.rm=T)
cb$Inactivec    <-cb$Inactive    -mean(cb$Inactive    ,na.rm=T)
cb$HousCostc    <-cb$HousCost    -mean(cb$HousCost    ,na.rm=T)
cb$HousCostsc   <-cb$HousCosts   -mean(cb$HousCosts   ,na.rm=T)
cb$HousCrowdc   <-cb$HousCrowd   -mean(cb$HousCrowd   ,na.rm=T)
cb$Housingc     <-cb$Housing     -mean(cb$Housing     ,na.rm=T)
cb$HousPlumbc   <-cb$HousPlumb   -mean(cb$HousPlumb   ,na.rm=T)
cb$Insuredc     <-cb$Insured     -mean(cb$Insured     ,na.rm=T)
cb$InsuredAc    <-cb$InsuredA    -mean(cb$InsuredA    ,na.rm=T)
cb$InsuredCc    <-cb$InsuredC    -mean(cb$InsuredC    ,na.rm=T)
cb$JuvArrc      <-cb$JuvArr      -mean(cb$JuvArr      ,na.rm=T)
cb$Murderc      <-cb$Murder      -mean(cb$Murder      ,na.rm=T)
cb$Violentc     <-cb$Violent     -mean(cb$Violent     ,na.rm=T)
cb$LongCommc    <-cb$LongComm    -mean(cb$LongComm    ,na.rm=T)
cb$LowBWc       <-cb$LowBW       -mean(cb$LowBW       ,na.rm=T)
cb$LowBWBc      <-cb$LowBWB      -mean(cb$LowBWB      ,na.rm=T)
cb$LowBWHc      <-cb$LowBWH      -mean(cb$LowBWH      ,na.rm=T)
cb$LowBWWc      <-cb$LowBWW      -mean(cb$LowBWW      ,na.rm=T)
cb$TeenBthc     <-cb$TeenBth     -mean(cb$TeenBth     ,na.rm=T)
cb$TeenBthBc    <-cb$TeenBthB    -mean(cb$TeenBthB    ,na.rm=T)
cb$TeenBthHc    <-cb$TeenBthH    -mean(cb$TeenBthH    ,na.rm=T)
cb$TeenBthWc    <-cb$TeenBthW    -mean(cb$TeenBthW    ,na.rm=T)
cb$Mentalc      <-cb$Mental      -mean(cb$Mental      ,na.rm=T)
cb$MHPrvdc      <-cb$MHPrvd      -mean(cb$MHPrvd      ,na.rm=T)
cb$PCPc         <-cb$PCP         -mean(cb$PCP         ,na.rm=T)
cb$PCP2c        <-cb$PCP2        -mean(cb$PCP2        ,na.rm=T)
cb$Dentistc     <-cb$Dentist     -mean(cb$Dentist     ,na.rm=T)
cb$PrvtHospc    <-cb$PrvtHosp    -mean(cb$PrvtHosp    ,na.rm=T)
cb$PrvtHospBc   <-cb$PrvtHospB   -mean(cb$PrvtHospB   ,na.rm=T)
cb$PrvtHospHc   <-cb$PrvtHospH   -mean(cb$PrvtHospH   ,na.rm=T)
cb$PrvtHospWc   <-cb$PrvtHospW   -mean(cb$PrvtHospW   ,na.rm=T)
cb$SegBWc       <-cb$SegBW       -mean(cb$SegBW       ,na.rm=T)
cb$SegNWc       <-cb$SegNW       -mean(cb$SegNW       ,na.rm=T)
cb$SocAssoc     <-cb$SocAsso     -mean(cb$SocAsso     ,na.rm=T)
cb$SocSuppc     <-cb$SocSupp     -mean(cb$SocSupp     ,na.rm=T)
cb$MIECHVc      <-cb$MIECHV      -mean(cb$MIECHV      ,na.rm=T)
cb$NHVRCc       <-cb$NHVRC       -mean(cb$NHVRC       ,na.rm=T)
cb$HomeV2c      <-cb$HomeV2      -mean(cb$HomeV2      ,na.rm=T)
cb$FoodInsecurec<-cb$FoodInsecure-mean(cb$FoodInsecure,na.rm=T)

cb<-cbind(cb,demean(cb,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Model building
cbm01<-lmer(RptBr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm02<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm03<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm04<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm05<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm06<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm07<-lmer(RptBr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cbm01,cbm02,cbm03,cbm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cbm04,cbm05,cbm06,cbm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cbm01CI<-confint(cbm01,method='boot',nsim=500,boot.type='perc')
cbm02CI<-confint(cbm02,method='boot',nsim=500,boot.type='perc')
cbm03CI<-confint(cbm03,method='boot',nsim=500,boot.type='perc')
cbm04CI<-confint(cbm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cbm01)
check_collinearity(cbm02)
check_collinearity(cbm03)
check_collinearity(cbm04)
isSingular(cbm01)
isSingular(cbm02)
isSingular(cbm03)
isSingular(cbm04)




# Model building
cbm01a<-lmer(RptBr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm02a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm03a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm04a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm05a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm06a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))
cbm07a<-lmer(RptBr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=cb,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(cbm01a,cbm02a,cbm03a,cbm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cbm04a,cbm05a,cbm06a,cbm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
cbm01aCI<-confint(cbm01a,method='boot',nsim=500,boot.type='perc')
cbm02aCI<-confint(cbm02a,method='boot',nsim=500,boot.type='perc')
cbm03aCI<-confint(cbm03a,method='boot',nsim=500,boot.type='perc')
cbm04aCI<-confint(cbm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cbm01a)
check_collinearity(cbm02a)
check_collinearity(cbm03a)
check_collinearity(cbm04a)
isSingular(cbm01a)
isSingular(cbm02a)
isSingular(cbm03a)
isSingular(cbm04a)





cbg02<-glmmTMB(RptB~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
                 ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopB)),data=cb,family=nbinom2)
cbg02a<-glmmTMB(RptB~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornBc_within+FBornBc_between+
                  ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopB)),data=cb,family=nbinom2)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

ch$CPopBPc      <-ch$CPopBP      -mean(ch$CPopBP      ,na.rm=T)
ch$CPopHPc      <-ch$CPopHP      -mean(ch$CPopHP      ,na.rm=T)
ch$ChildPTc     <-ch$ChildPT     -mean(ch$ChildPT     ,na.rm=T)
ch$ChildPWc     <-ch$ChildPW     -mean(ch$ChildPW     ,na.rm=T)
ch$ChildPBc     <-ch$ChildPB     -mean(ch$ChildPB     ,na.rm=T)
ch$ChildPHc     <-ch$ChildPH     -mean(ch$ChildPH     ,na.rm=T)
ch$CARatioT100c <-ch$CARatioT100 -mean(ch$CARatioT100 ,na.rm=T)
ch$CARatioW100c <-ch$CARatioW100 -mean(ch$CARatioW100 ,na.rm=T)
ch$CARatioB100c <-ch$CARatioB100 -mean(ch$CARatioB100 ,na.rm=T)
ch$CARatioH100c <-ch$CARatioH100 -mean(ch$CARatioH100 ,na.rm=T)
ch$MalePTc      <-ch$MalePT      -mean(ch$MalePT      ,na.rm=T)
ch$MalePWc      <-ch$MalePW      -mean(ch$MalePW      ,na.rm=T)
ch$MalePBc      <-ch$MalePB      -mean(ch$MalePB      ,na.rm=T)
ch$MalePHc      <-ch$MalePH      -mean(ch$MalePH      ,na.rm=T)
ch$MFRatioT100c <-ch$MFRatioT100 -mean(ch$MFRatioT100 ,na.rm=T)
ch$MFRatioW100c <-ch$MFRatioW100 -mean(ch$MFRatioW100 ,na.rm=T)
ch$MFRatioB100c <-ch$MFRatioB100 -mean(ch$MFRatioB100 ,na.rm=T)
ch$MFRatioH100c <-ch$MFRatioH100 -mean(ch$MFRatioH100 ,na.rm=T)
ch$ElderTc      <-ch$ElderT      -mean(ch$ElderT      ,na.rm=T)
ch$ElderWc      <-ch$ElderW      -mean(ch$ElderW      ,na.rm=T)
ch$ElderBc      <-ch$ElderB      -mean(ch$ElderB      ,na.rm=T)
ch$ElderHc      <-ch$ElderH      -mean(ch$ElderH      ,na.rm=T)
ch$SingleTc     <-ch$SingleT     -mean(ch$SingleT     ,na.rm=T)
ch$SingleWc     <-ch$SingleW     -mean(ch$SingleW     ,na.rm=T)
ch$SingleBc     <-ch$SingleB     -mean(ch$SingleB     ,na.rm=T)
ch$SingleHc     <-ch$SingleH     -mean(ch$SingleH     ,na.rm=T)
ch$FHeadTc      <-ch$FHeadT      -mean(ch$FHeadT      ,na.rm=T)
ch$FHeadWc      <-ch$FHeadW      -mean(ch$FHeadW      ,na.rm=T)
ch$FHeadBc      <-ch$FHeadB      -mean(ch$FHeadB      ,na.rm=T)
ch$FHeadHc      <-ch$FHeadH      -mean(ch$FHeadH      ,na.rm=T)
ch$NoHighTc     <-ch$NoHighT     -mean(ch$NoHighT     ,na.rm=T)
ch$NoHighWc     <-ch$NoHighW     -mean(ch$NoHighW     ,na.rm=T)
ch$NoHighBc     <-ch$NoHighB     -mean(ch$NoHighB     ,na.rm=T)
ch$NoHighHc     <-ch$NoHighH     -mean(ch$NoHighH     ,na.rm=T)
ch$UnempTc      <-ch$UnempT      -mean(ch$UnempT      ,na.rm=T)
ch$UnempWc      <-ch$UnempW      -mean(ch$UnempW      ,na.rm=T)
ch$UnempBc      <-ch$UnempB      -mean(ch$UnempB      ,na.rm=T)
ch$UnempHc      <-ch$UnempH      -mean(ch$UnempH      ,na.rm=T)
ch$CPovTc       <-ch$CPovT       -mean(ch$CPovT       ,na.rm=T)
ch$CPovWc       <-ch$CPovW       -mean(ch$CPovW       ,na.rm=T)
ch$CPovBc       <-ch$CPovB       -mean(ch$CPovB       ,na.rm=T)
ch$CPovHc       <-ch$CPovH       -mean(ch$CPovH       ,na.rm=T)
ch$CPov1c       <-ch$CPov1       -mean(ch$CPov1       ,na.rm=T)
ch$CPov2c       <-ch$CPov2       -mean(ch$CPov2       ,na.rm=T)
ch$CPov3c       <-ch$CPov3       -mean(ch$CPov3       ,na.rm=T)
ch$PubAsTc      <-ch$PubAsT      -mean(ch$PubAsT      ,na.rm=T)
ch$WelfarTc     <-ch$WelfarT     -mean(ch$WelfarT     ,na.rm=T)
ch$SnapTc       <-ch$SnapT       -mean(ch$SnapT       ,na.rm=T)
ch$SnapWc       <-ch$SnapW       -mean(ch$SnapW       ,na.rm=T)
ch$SnapBc       <-ch$SnapB       -mean(ch$SnapB       ,na.rm=T)
ch$SnapHc       <-ch$SnapH       -mean(ch$SnapH       ,na.rm=T)
ch$IncomeT1kc   <-ch$IncomeT1k   -mean(ch$IncomeT1k   ,na.rm=T)
ch$IncomeW1kc   <-ch$IncomeW1k   -mean(ch$IncomeW1k   ,na.rm=T)
ch$IncomeB1kc   <-ch$IncomeB1k   -mean(ch$IncomeB1k   ,na.rm=T)
ch$IncomeH1kc   <-ch$IncomeH1k   -mean(ch$IncomeH1k   ,na.rm=T)
ch$GiniT100c    <-ch$GiniT100    -mean(ch$GiniT100    ,na.rm=T)
ch$HValueT10kc  <-ch$HValueT10k  -mean(ch$HValueT10k  ,na.rm=T)
ch$MCostT100c   <-ch$MCostT100   -mean(ch$MCostT100   ,na.rm=T)
ch$OCostDT100c  <-ch$OCostDT100  -mean(ch$OCostDT100  ,na.rm=T)
ch$MRentDT100c  <-ch$MRentDT100  -mean(ch$MRentDT100  ,na.rm=T)
ch$OCostPTc     <-ch$OCostPT     -mean(ch$OCostPT     ,na.rm=T)
ch$MRentPTc     <-ch$MRentPT     -mean(ch$MRentPT     ,na.rm=T)
ch$MortgTc      <-ch$MortgT      -mean(ch$MortgT      ,na.rm=T)
ch$LangAPTc     <-ch$LangAPT     -mean(ch$LangAPT     ,na.rm=T)
ch$LangAPWc     <-ch$LangAPW     -mean(ch$LangAPW     ,na.rm=T)
ch$LangAPBc     <-ch$LangAPB     -mean(ch$LangAPB     ,na.rm=T)
ch$LangAPHc     <-ch$LangAPH     -mean(ch$LangAPH     ,na.rm=T)
ch$LangBPTc     <-ch$LangBPT     -mean(ch$LangBPT     ,na.rm=T)
ch$LangBPWc     <-ch$LangBPW     -mean(ch$LangBPW     ,na.rm=T)
ch$LangBPBc     <-ch$LangBPB     -mean(ch$LangBPB     ,na.rm=T)
ch$LangBPHc     <-ch$LangBPH     -mean(ch$LangBPH     ,na.rm=T)
ch$LangCPTc     <-ch$LangCPT     -mean(ch$LangCPT     ,na.rm=T)
ch$OutUsTc      <-ch$OutUsT      -mean(ch$OutUsT      ,na.rm=T)
ch$OutUsWc      <-ch$OutUsW      -mean(ch$OutUsW      ,na.rm=T)
ch$OutUsBc      <-ch$OutUsB      -mean(ch$OutUsB      ,na.rm=T)
ch$OutUsHc      <-ch$OutUsH      -mean(ch$OutUsH      ,na.rm=T)
ch$FBornTc      <-ch$FBornT      -mean(ch$FBornT      ,na.rm=T)
ch$FBornWc      <-ch$FBornW      -mean(ch$FBornW      ,na.rm=T)
ch$FBornBc      <-ch$FBornB      -mean(ch$FBornB      ,na.rm=T)
ch$FBornHc      <-ch$FBornH      -mean(ch$FBornH      ,na.rm=T)
ch$NotCtzTc     <-ch$NotCtzT     -mean(ch$NotCtzT     ,na.rm=T)
ch$NotCtzWc     <-ch$NotCtzW     -mean(ch$NotCtzW     ,na.rm=T)
ch$NotCtzBc     <-ch$NotCtzB     -mean(ch$NotCtzB     ,na.rm=T)
ch$NotCtzHc     <-ch$NotCtzH     -mean(ch$NotCtzH     ,na.rm=T)
ch$MoveTc       <-ch$MoveT       -mean(ch$MoveT       ,na.rm=T)
ch$MoveWc       <-ch$MoveW       -mean(ch$MoveW       ,na.rm=T)
ch$MoveBc       <-ch$MoveB       -mean(ch$MoveB       ,na.rm=T)
ch$MoveHc       <-ch$MoveH       -mean(ch$MoveH       ,na.rm=T)
ch$VacantTc     <-ch$VacantT     -mean(ch$VacantT     ,na.rm=T)
ch$OwnerTc      <-ch$OwnerT      -mean(ch$OwnerT      ,na.rm=T)
ch$OwnerWc      <-ch$OwnerW      -mean(ch$OwnerW      ,na.rm=T)
ch$OwnerBc      <-ch$OwnerB      -mean(ch$OwnerB      ,na.rm=T)
ch$OwnerHc      <-ch$OwnerH      -mean(ch$OwnerH      ,na.rm=T)
ch$CrowdTc      <-ch$CrowdT      -mean(ch$CrowdT      ,na.rm=T)
ch$CrowdWc      <-ch$CrowdW      -mean(ch$CrowdW      ,na.rm=T)
ch$CrowdBc      <-ch$CrowdB      -mean(ch$CrowdB      ,na.rm=T)
ch$CrowdHc      <-ch$CrowdH      -mean(ch$CrowdH      ,na.rm=T)
ch$MobileTc     <-ch$MobileT     -mean(ch$MobileT     ,na.rm=T)
ch$MobileWc     <-ch$MobileW     -mean(ch$MobileW     ,na.rm=T)
ch$MobileBc     <-ch$MobileB     -mean(ch$MobileB     ,na.rm=T)
ch$MobileHc     <-ch$MobileH     -mean(ch$MobileH     ,na.rm=T)
ch$DisablTc     <-ch$DisablT     -mean(ch$DisablT     ,na.rm=T)
ch$DisablWc     <-ch$DisablW     -mean(ch$DisablW     ,na.rm=T)
ch$DisablBc     <-ch$DisablB     -mean(ch$DisablB     ,na.rm=T)
ch$DisablHc     <-ch$DisablH     -mean(ch$DisablH     ,na.rm=T)
ch$DisablTCc    <-ch$DisablTC    -mean(ch$DisablTC    ,na.rm=T)
ch$DisablWCc    <-ch$DisablWC    -mean(ch$DisablWC    ,na.rm=T)
ch$DisablBCc    <-ch$DisablBC    -mean(ch$DisablBC    ,na.rm=T)
ch$DisablHCc    <-ch$DisablHC    -mean(ch$DisablHC    ,na.rm=T)
ch$DisablTMc    <-ch$DisablTM    -mean(ch$DisablTM    ,na.rm=T)
ch$DisablTFc    <-ch$DisablTF    -mean(ch$DisablTF    ,na.rm=T)
ch$Urban1c      <-ch$Urban1      -mean(ch$Urban1      ,na.rm=T)
ch$Urban2c      <-ch$Urban2      -mean(ch$Urban2      ,na.rm=T)
ch$LBWT1rc      <-ch$LBWT1r      -mean(ch$LBWT1r      ,na.rm=T)
ch$LBWM1rc      <-ch$LBWM1r      -mean(ch$LBWM1r      ,na.rm=T)
ch$LBWF1rc      <-ch$LBWF1r      -mean(ch$LBWF1r      ,na.rm=T)
ch$LBWW1rc      <-ch$LBWW1r      -mean(ch$LBWW1r      ,na.rm=T)
ch$LBWB1rc      <-ch$LBWB1r      -mean(ch$LBWB1r      ,na.rm=T)
ch$LBWH1rc      <-ch$LBWH1r      -mean(ch$LBWH1r      ,na.rm=T)
ch$PTBT1rc      <-ch$PTBT1r      -mean(ch$PTBT1r      ,na.rm=T)
ch$PTBM1rc      <-ch$PTBM1r      -mean(ch$PTBM1r      ,na.rm=T)
ch$PTBF1rc      <-ch$PTBF1r      -mean(ch$PTBF1r      ,na.rm=T)
ch$PTBW1rc      <-ch$PTBW1r      -mean(ch$PTBW1r      ,na.rm=T)
ch$PTBB1rc      <-ch$PTBB1r      -mean(ch$PTBB1r      ,na.rm=T)
ch$PTBH1rc      <-ch$PTBH1r      -mean(ch$PTBH1r      ,na.rm=T)
ch$PNCT1rc      <-ch$PNCT1r      -mean(ch$PNCT1r      ,na.rm=T)
ch$PNCM1rc      <-ch$PNCM1r      -mean(ch$PNCM1r      ,na.rm=T)
ch$PNCF1rc      <-ch$PNCF1r      -mean(ch$PNCF1r      ,na.rm=T)
ch$PNCW1rc      <-ch$PNCW1r      -mean(ch$PNCW1r      ,na.rm=T)
ch$PNCB1rc      <-ch$PNCB1r      -mean(ch$PNCB1r      ,na.rm=T)
ch$PNCH1rc      <-ch$PNCH1r      -mean(ch$PNCH1r      ,na.rm=T)
ch$TBBT1rc      <-ch$TBBT1r      -mean(ch$TBBT1r      ,na.rm=T)
ch$TBBM1rc      <-ch$TBBM1r      -mean(ch$TBBM1r      ,na.rm=T)
ch$TBBF1rc      <-ch$TBBF1r      -mean(ch$TBBF1r      ,na.rm=T)
ch$TBBW1rc      <-ch$TBBW1r      -mean(ch$TBBW1r      ,na.rm=T)
ch$TBBB1rc      <-ch$TBBB1r      -mean(ch$TBBB1r      ,na.rm=T)
ch$TBBH1rc      <-ch$TBBH1r      -mean(ch$TBBH1r      ,na.rm=T)
ch$TBTT1rc      <-ch$TBTT1r      -mean(ch$TBTT1r      ,na.rm=T)
ch$TBTM1rc      <-ch$TBTM1r      -mean(ch$TBTM1r      ,na.rm=T)
ch$TBTF1rc      <-ch$TBTF1r      -mean(ch$TBTF1r      ,na.rm=T)
ch$TBTW1rc      <-ch$TBTW1r      -mean(ch$TBTW1r      ,na.rm=T)
ch$TBTB1rc      <-ch$TBTB1r      -mean(ch$TBTB1r      ,na.rm=T)
ch$TBTH1rc      <-ch$TBTH1r      -mean(ch$TBTH1r      ,na.rm=T)
ch$LBWT5rc      <-ch$LBWT5r      -mean(ch$LBWT5r      ,na.rm=T)
ch$LBWM5rc      <-ch$LBWM5r      -mean(ch$LBWM5r      ,na.rm=T)
ch$LBWF5rc      <-ch$LBWF5r      -mean(ch$LBWF5r      ,na.rm=T)
ch$LBWW5rc      <-ch$LBWW5r      -mean(ch$LBWW5r      ,na.rm=T)
ch$LBWB5rc      <-ch$LBWB5r      -mean(ch$LBWB5r      ,na.rm=T)
ch$LBWH5rc      <-ch$LBWH5r      -mean(ch$LBWH5r      ,na.rm=T)
ch$PTBT5rc      <-ch$PTBT5r      -mean(ch$PTBT5r      ,na.rm=T)
ch$PTBM5rc      <-ch$PTBM5r      -mean(ch$PTBM5r      ,na.rm=T)
ch$PTBF5rc      <-ch$PTBF5r      -mean(ch$PTBF5r      ,na.rm=T)
ch$PTBW5rc      <-ch$PTBW5r      -mean(ch$PTBW5r      ,na.rm=T)
ch$PTBB5rc      <-ch$PTBB5r      -mean(ch$PTBB5r      ,na.rm=T)
ch$PTBH5rc      <-ch$PTBH5r      -mean(ch$PTBH5r      ,na.rm=T)
ch$PNCT5rc      <-ch$PNCT5r      -mean(ch$PNCT5r      ,na.rm=T)
ch$PNCM5rc      <-ch$PNCM5r      -mean(ch$PNCM5r      ,na.rm=T)
ch$PNCF5rc      <-ch$PNCF5r      -mean(ch$PNCF5r      ,na.rm=T)
ch$PNCW5rc      <-ch$PNCW5r      -mean(ch$PNCW5r      ,na.rm=T)
ch$PNCB5rc      <-ch$PNCB5r      -mean(ch$PNCB5r      ,na.rm=T)
ch$PNCH5rc      <-ch$PNCH5r      -mean(ch$PNCH5r      ,na.rm=T)
ch$TBBT5rc      <-ch$TBBT5r      -mean(ch$TBBT5r      ,na.rm=T)
ch$TBBM5rc      <-ch$TBBM5r      -mean(ch$TBBM5r      ,na.rm=T)
ch$TBBF5rc      <-ch$TBBF5r      -mean(ch$TBBF5r      ,na.rm=T)
ch$TBBW5rc      <-ch$TBBW5r      -mean(ch$TBBW5r      ,na.rm=T)
ch$TBBB5rc      <-ch$TBBB5r      -mean(ch$TBBB5r      ,na.rm=T)
ch$TBBH5rc      <-ch$TBBH5r      -mean(ch$TBBH5r      ,na.rm=T)
ch$TBTT5rc      <-ch$TBTT5r      -mean(ch$TBTT5r      ,na.rm=T)
ch$TBTM5rc      <-ch$TBTM5r      -mean(ch$TBTM5r      ,na.rm=T)
ch$TBTF5rc      <-ch$TBTF5r      -mean(ch$TBTF5r      ,na.rm=T)
ch$TBTW5rc      <-ch$TBTW5r      -mean(ch$TBTW5r      ,na.rm=T)
ch$TBTB5rc      <-ch$TBTB5r      -mean(ch$TBTB5r      ,na.rm=T)
ch$TBTH5rc      <-ch$TBTH5r      -mean(ch$TBTH5r      ,na.rm=T)
ch$Opioidc      <-ch$Opioid      -mean(ch$Opioid      ,na.rm=T)
ch$LifeExpc     <-ch$LifeExp     -mean(ch$LifeExp     ,na.rm=T)
ch$LifeExpBc    <-ch$LifeExpB    -mean(ch$LifeExpB    ,na.rm=T)
ch$LifeExpHc    <-ch$LifeExpH    -mean(ch$LifeExpH    ,na.rm=T)
ch$LifeExpWc    <-ch$LifeExpW    -mean(ch$LifeExpW    ,na.rm=T)
ch$ChdDeathc    <-ch$ChdDeath    -mean(ch$ChdDeath    ,na.rm=T)
ch$ChdDeathBc   <-ch$ChdDeathB   -mean(ch$ChdDeathB   ,na.rm=T)
ch$ChdDeathHc   <-ch$ChdDeathH   -mean(ch$ChdDeathH   ,na.rm=T)
ch$ChdDeathWc   <-ch$ChdDeathW   -mean(ch$ChdDeathW   ,na.rm=T)
ch$InfDeathc    <-ch$InfDeath    -mean(ch$InfDeath    ,na.rm=T)
ch$InfDeathBc   <-ch$InfDeathB   -mean(ch$InfDeathB   ,na.rm=T)
ch$InfDeathHc   <-ch$InfDeathH   -mean(ch$InfDeathH   ,na.rm=T)
ch$InfDeathWc   <-ch$InfDeathW   -mean(ch$InfDeathW   ,na.rm=T)
ch$Injuryc      <-ch$Injury      -mean(ch$Injury      ,na.rm=T)
ch$InjuryBc     <-ch$InjuryB     -mean(ch$InjuryB     ,na.rm=T)
ch$InjuryHc     <-ch$InjuryH     -mean(ch$InjuryH     ,na.rm=T)
ch$InjuryWc     <-ch$InjuryW     -mean(ch$InjuryW     ,na.rm=T)
ch$GunDeathc    <-ch$GunDeath    -mean(ch$GunDeath    ,na.rm=T)
ch$GunDeathBc   <-ch$GunDeathB   -mean(ch$GunDeathB   ,na.rm=T)
ch$GunDeathWc   <-ch$GunDeathW   -mean(ch$GunDeathW   ,na.rm=T)
ch$PrmDeath_c   <-ch$PrmDeath    -mean(ch$PrmDeath    ,na.rm=T)
ch$PrmDeathcc   <-ch$PrmDeathc   -mean(ch$PrmDeathc   ,na.rm=T)
ch$PrmDeathBc   <-ch$PrmDeathB   -mean(ch$PrmDeathB   ,na.rm=T)
ch$PrmDeathHc   <-ch$PrmDeathH   -mean(ch$PrmDeathH   ,na.rm=T)
ch$PrmDeathWc   <-ch$PrmDeathW   -mean(ch$PrmDeathW   ,na.rm=T)
ch$PrmDeath2_c  <-ch$PrmDeath2   -mean(ch$PrmDeath2   ,na.rm=T)
ch$PrmDeath2cc  <-ch$PrmDeath2c  -mean(ch$PrmDeath2c  ,na.rm=T)
ch$PrmDeath2Bc  <-ch$PrmDeath2B  -mean(ch$PrmDeath2B  ,na.rm=T)
ch$PrmDeath2Hc  <-ch$PrmDeath2H  -mean(ch$PrmDeath2H  ,na.rm=T)
ch$PrmDeath2Wc  <-ch$PrmDeath2W  -mean(ch$PrmDeath2W  ,na.rm=T)
ch$Suicidec     <-ch$Suicide     -mean(ch$Suicide     ,na.rm=T)
ch$Diabetc      <-ch$Diabet      -mean(ch$Diabet      ,na.rm=T)
ch$Obesityc     <-ch$Obesity     -mean(ch$Obesity     ,na.rm=T)
ch$Physicalc    <-ch$Physical    -mean(ch$Physical    ,na.rm=T)
ch$PoorHlthc    <-ch$PoorHlth    -mean(ch$PoorHlth    ,na.rm=T)
ch$PoorMHc      <-ch$PoorMH      -mean(ch$PoorMH      ,na.rm=T)
ch$PoorPhyc     <-ch$PoorPhy     -mean(ch$PoorPhy     ,na.rm=T)
ch$Sleepc       <-ch$Sleep       -mean(ch$Sleep       ,na.rm=T)
ch$DrugOdc      <-ch$DrugOd      -mean(ch$DrugOd      ,na.rm=T)
ch$DrugOdBc     <-ch$DrugOdB     -mean(ch$DrugOdB     ,na.rm=T)
ch$DrugOdHc     <-ch$DrugOdH     -mean(ch$DrugOdH     ,na.rm=T)
ch$DrugOdWc     <-ch$DrugOdW     -mean(ch$DrugOdW     ,na.rm=T)
ch$DWIDeathc    <-ch$DWIDeath    -mean(ch$DWIDeath    ,na.rm=T)
ch$EDrinkc      <-ch$EDrink      -mean(ch$EDrink      ,na.rm=T)
ch$Smokec       <-ch$Smoke       -mean(ch$Smoke       ,na.rm=T)
ch$FastFoodc    <-ch$FastFood    -mean(ch$FastFood    ,na.rm=T)
ch$FoodEnvc     <-ch$FoodEnv     -mean(ch$FoodEnv     ,na.rm=T)
ch$FoodInsc     <-ch$FoodIns     -mean(ch$FoodIns     ,na.rm=T)
ch$FrLunchc     <-ch$FrLunch     -mean(ch$FrLunch     ,na.rm=T)
ch$LAccFoodc    <-ch$LAccFood    -mean(ch$LAccFood    ,na.rm=T)
ch$Gymc         <-ch$Gym         -mean(ch$Gym         ,na.rm=T)
ch$Gym2c        <-ch$Gym2        -mean(ch$Gym2        ,na.rm=T)
ch$Inactivec    <-ch$Inactive    -mean(ch$Inactive    ,na.rm=T)
ch$HousCostc    <-ch$HousCost    -mean(ch$HousCost    ,na.rm=T)
ch$HousCostsc   <-ch$HousCosts   -mean(ch$HousCosts   ,na.rm=T)
ch$HousCrowdc   <-ch$HousCrowd   -mean(ch$HousCrowd   ,na.rm=T)
ch$Housingc     <-ch$Housing     -mean(ch$Housing     ,na.rm=T)
ch$HousPlumbc   <-ch$HousPlumb   -mean(ch$HousPlumb   ,na.rm=T)
ch$Insuredc     <-ch$Insured     -mean(ch$Insured     ,na.rm=T)
ch$InsuredAc    <-ch$InsuredA    -mean(ch$InsuredA    ,na.rm=T)
ch$InsuredCc    <-ch$InsuredC    -mean(ch$InsuredC    ,na.rm=T)
ch$JuvArrc      <-ch$JuvArr      -mean(ch$JuvArr      ,na.rm=T)
ch$Murderc      <-ch$Murder      -mean(ch$Murder      ,na.rm=T)
ch$Violentc     <-ch$Violent     -mean(ch$Violent     ,na.rm=T)
ch$LongCommc    <-ch$LongComm    -mean(ch$LongComm    ,na.rm=T)
ch$LowBWc       <-ch$LowBW       -mean(ch$LowBW       ,na.rm=T)
ch$LowBWBc      <-ch$LowBWB      -mean(ch$LowBWB      ,na.rm=T)
ch$LowBWHc      <-ch$LowBWH      -mean(ch$LowBWH      ,na.rm=T)
ch$LowBWWc      <-ch$LowBWW      -mean(ch$LowBWW      ,na.rm=T)
ch$TeenBthc     <-ch$TeenBth     -mean(ch$TeenBth     ,na.rm=T)
ch$TeenBthBc    <-ch$TeenBthB    -mean(ch$TeenBthB    ,na.rm=T)
ch$TeenBthHc    <-ch$TeenBthH    -mean(ch$TeenBthH    ,na.rm=T)
ch$TeenBthWc    <-ch$TeenBthW    -mean(ch$TeenBthW    ,na.rm=T)
ch$Mentalc      <-ch$Mental      -mean(ch$Mental      ,na.rm=T)
ch$MHPrvdc      <-ch$MHPrvd      -mean(ch$MHPrvd      ,na.rm=T)
ch$PCPc         <-ch$PCP         -mean(ch$PCP         ,na.rm=T)
ch$PCP2c        <-ch$PCP2        -mean(ch$PCP2        ,na.rm=T)
ch$Dentistc     <-ch$Dentist     -mean(ch$Dentist     ,na.rm=T)
ch$PrvtHospc    <-ch$PrvtHosp    -mean(ch$PrvtHosp    ,na.rm=T)
ch$PrvtHospBc   <-ch$PrvtHospB   -mean(ch$PrvtHospB   ,na.rm=T)
ch$PrvtHospHc   <-ch$PrvtHospH   -mean(ch$PrvtHospH   ,na.rm=T)
ch$PrvtHospWc   <-ch$PrvtHospW   -mean(ch$PrvtHospW   ,na.rm=T)
ch$SegBWc       <-ch$SegBW       -mean(ch$SegBW       ,na.rm=T)
ch$SegNWc       <-ch$SegNW       -mean(ch$SegNW       ,na.rm=T)
ch$SocAssoc     <-ch$SocAsso     -mean(ch$SocAsso     ,na.rm=T)
ch$SocSuppc     <-ch$SocSupp     -mean(ch$SocSupp     ,na.rm=T)
ch$MIECHVc      <-ch$MIECHV      -mean(ch$MIECHV      ,na.rm=T)
ch$NHVRCc       <-ch$NHVRC       -mean(ch$NHVRC       ,na.rm=T)
ch$HomeV2c      <-ch$HomeV2      -mean(ch$HomeV2      ,na.rm=T)
ch$FoodInsecurec<-ch$FoodInsecure-mean(ch$FoodInsecure,na.rm=T)

ch<-cbind(ch,demean(ch,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Physical","PoorHlth","PoorMH","PoorPhy","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "Mental","MHPrvd","PCP","PCP2","Dentist","Mentalc","MHPrvdc","PCPc","PCP2c","Dentistc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc","HomeV2c",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))



# Model building
chm01<-lmer(RptHr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm02<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm03<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm04<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm05<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (NHVRCc_within|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm06<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(NHVRCc_within|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm07<-lmer(RptHr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(NHVRCc_between|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(chm01,chm02,chm03,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(chm04,chm05,chm06,chm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
chm01CI<-confint(chm01,method='boot',nsim=500,boot.type='perc')
chm02CI<-confint(chm02,method='boot',nsim=500,boot.type='perc')
chm03CI<-confint(chm03,method='boot',nsim=500,boot.type='perc')
chm04CI<-confint(chm04,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(chm01)
check_collinearity(chm02)
check_collinearity(chm03)
check_collinearity(chm04)
isSingular(chm01)
isSingular(chm02)
isSingular(chm03)
isSingular(chm04)




# Model building
chm01a<-lmer(RptHr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm02a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm03a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm04a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm05a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (MIECHVc_within|CountyFIPS)+(1|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm06a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(MIECHVc_within|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))
chm07a<-lmer(RptHr~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(MIECHVc_between|StateFIPS),data=ch,control=lmerControl(optimizer="Nelder_Mead"))

tab_model(chm01a,chm02a,chm03a,chm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(chm04a,chm05a,chm06a,chm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# bootstrap confidence interval
chm01aCI<-confint(chm01a,method='boot',nsim=500,boot.type='perc')
chm02aCI<-confint(chm02a,method='boot',nsim=500,boot.type='perc')
chm03aCI<-confint(chm03a,method='boot',nsim=500,boot.type='perc')
chm04aCI<-confint(chm04a,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(chm01a)
check_collinearity(chm02a)
check_collinearity(chm03a)
check_collinearity(chm04a)
isSingular(chm01a)
isSingular(chm02a)
isSingular(chm03a)
isSingular(chm04a)






tab_model(cwm04,cbm04,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm04a,cbm04a,chm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)






chg02<-glmmTMB(RptH~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+
                 IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
                 CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
                 ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
                 (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopH)),data=ch,family=nbinom2)
chg02a<-glmmTMB(RptH~Yearf+USDA_RUC+MIECHVc_within+MIECHVc_between+
                  IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
                  CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornHc_within+FBornHc_between+
                  ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
                  (1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopH)),data=ch,family=nbinom2)










###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################





# Checking
library(kableExtra)

tab_model(ctm01,ctm02,ctm03,ctm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04,ctm05,ctm06,ctm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm01CI %>% kbl(caption="ctm01CI") %>% kable_paper("striped","hover",full_width=F)
ctm02CI %>% kbl(caption="ctm02CI") %>% kable_paper("striped","hover",full_width=F)
ctm03CI %>% kbl(caption="ctm03CI") %>% kable_paper("striped","hover",full_width=F)
ctm04CI %>% kbl(caption="ctm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(ctm04,ctm041,ctm042,ctm043,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm04CI  %>% kbl(caption="ctm04CI" ) %>% kable_paper("striped","hover",full_width=F)
ctm041CI %>% kbl(caption="ctm041CI") %>% kable_paper("striped","hover",full_width=F)
ctm042CI %>% kbl(caption="ctm042CI") %>% kable_paper("striped","hover",full_width=F)
ctm043CI %>% kbl(caption="ctm043CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m01,c1m02,c1m03,c1m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c1m04,c1m05,c1m06,c1m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m01CI %>% kbl(caption="c1m01CI") %>% kable_paper("striped","hover",full_width=F)
c1m02CI %>% kbl(caption="c1m02CI") %>% kable_paper("striped","hover",full_width=F)
c1m03CI %>% kbl(caption="c1m03CI") %>% kable_paper("striped","hover",full_width=F)
c1m04CI %>% kbl(caption="c1m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c2m01,c2m02,c2m03,c2m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c2m04,c2m05,c2m06,c2m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c2m01CI %>% kbl(caption="c2m01CI") %>% kable_paper("striped","hover",full_width=F)
c2m02CI %>% kbl(caption="c2m02CI") %>% kable_paper("striped","hover",full_width=F)
c2m03CI %>% kbl(caption="c2m03CI") %>% kable_paper("striped","hover",full_width=F)
c2m04CI %>% kbl(caption="c2m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c3m01,c3m02,c3m03,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c3m04,c3m05,c3m06,c3m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c3m01CI %>% kbl(caption="c3m01CI") %>% kable_paper("striped","hover",full_width=F)
c3m02CI %>% kbl(caption="c3m02CI") %>% kable_paper("striped","hover",full_width=F)
c3m03CI %>% kbl(caption="c3m03CI") %>% kable_paper("striped","hover",full_width=F)
c3m04CI %>% kbl(caption="c3m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m04,c2m04,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m04CI %>% kbl(caption="c1m04CI") %>% kable_paper("striped","hover",full_width=F)
c2m04CI %>% kbl(caption="c2m04CI") %>% kable_paper("striped","hover",full_width=F)
c3m04CI %>% kbl(caption="c3m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm01,cmm02,cmm03,cmm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cmm04,cmm05,cmm06,cmm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm01CI %>% kbl(caption="cmm01CI") %>% kable_paper("striped","hover",full_width=F)
cmm02CI %>% kbl(caption="cmm02CI") %>% kable_paper("striped","hover",full_width=F)
cmm03CI %>% kbl(caption="cmm03CI") %>% kable_paper("striped","hover",full_width=F)
cmm04CI %>% kbl(caption="cmm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cfm01,cfm02,cfm03,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cfm04,cfm05,cfm06,cfm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cfm01CI %>% kbl(caption="cfm01CI") %>% kable_paper("striped","hover",full_width=F)
cfm02CI %>% kbl(caption="cfm02CI") %>% kable_paper("striped","hover",full_width=F)
cfm03CI %>% kbl(caption="cfm03CI") %>% kable_paper("striped","hover",full_width=F)
cfm04CI %>% kbl(caption="cfm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm04,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm04CI %>% kbl(caption="cmm04CI") %>% kable_paper("striped","hover",full_width=F)
cfm04CI %>% kbl(caption="cfm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm01,cnm02,cnm03,cnm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cnm04,cnm05,cnm06,cnm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm01CI %>% kbl(caption="cnm01CI") %>% kable_paper("striped","hover",full_width=F)
cnm02CI %>% kbl(caption="cnm02CI") %>% kable_paper("striped","hover",full_width=F)
cnm03CI %>% kbl(caption="cnm03CI") %>% kable_paper("striped","hover",full_width=F)
cnm04CI %>% kbl(caption="cnm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cpm01,cpm02,cpm03,cpm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cpm04,cpm05,cpm06,cpm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cpm01CI %>% kbl(caption="cpm01CI") %>% kable_paper("striped","hover",full_width=F)
cpm02CI %>% kbl(caption="cpm02CI") %>% kable_paper("striped","hover",full_width=F)
cpm03CI %>% kbl(caption="cpm03CI") %>% kable_paper("striped","hover",full_width=F)
cpm04CI %>% kbl(caption="cpm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(csm01,csm02,csm03,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(csm04,csm05,csm06,csm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
csm01CI %>% kbl(caption="csm01CI") %>% kable_paper("striped","hover",full_width=F)
csm02CI %>% kbl(caption="csm02CI") %>% kable_paper("striped","hover",full_width=F)
csm03CI %>% kbl(caption="csm03CI") %>% kable_paper("striped","hover",full_width=F)
csm04CI %>% kbl(caption="csm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm04,cpm04,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm04CI %>% kbl(caption="cnm04CI") %>% kable_paper("striped","hover",full_width=F)
cpm04CI %>% kbl(caption="cpm04CI") %>% kable_paper("striped","hover",full_width=F)
csm04CI %>% kbl(caption="csm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm01,cwm02,cwm03,cwm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm04,cwm05,cwm06,cwm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm01CI %>% kbl(caption="cwm01CI") %>% kable_paper("striped","hover",full_width=F)
cwm02CI %>% kbl(caption="cwm02CI") %>% kable_paper("striped","hover",full_width=F)
cwm03CI %>% kbl(caption="cwm03CI") %>% kable_paper("striped","hover",full_width=F)
cwm04CI %>% kbl(caption="cwm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cbm01,cbm02,cbm03,cbm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cbm04,cbm05,cbm06,cbm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cbm01CI %>% kbl(caption="cbm01CI") %>% kable_paper("striped","hover",full_width=F)
cbm02CI %>% kbl(caption="cbm02CI") %>% kable_paper("striped","hover",full_width=F)
cbm03CI %>% kbl(caption="cbm03CI") %>% kable_paper("striped","hover",full_width=F)
cbm04CI %>% kbl(caption="cbm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(chm01,chm02,chm03,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(chm04,chm05,chm06,chm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
chm01CI %>% kbl(caption="chm01CI") %>% kable_paper("striped","hover",full_width=F)
chm02CI %>% kbl(caption="chm02CI") %>% kable_paper("striped","hover",full_width=F)
chm03CI %>% kbl(caption="chm03CI") %>% kable_paper("striped","hover",full_width=F)
chm04CI %>% kbl(caption="chm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm04,cbm04,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm04CI %>% kbl(caption="cwm04CI") %>% kable_paper("striped","hover",full_width=F)
cbm04CI %>% kbl(caption="cbm04CI") %>% kable_paper("striped","hover",full_width=F)
chm04CI %>% kbl(caption="chm04CI") %>% kable_paper("striped","hover",full_width=F)

###

tab_model(ctm01a,ctm02a,ctm03a,ctm04a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(ctm04a,ctm05a,ctm06a,ctm07a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm01aCI %>% kbl(caption="ctm01CIa") %>% kable_paper("striped","hover",full_width=F)
ctm02aCI %>% kbl(caption="ctm02CIa") %>% kable_paper("striped","hover",full_width=F)
ctm03aCI %>% kbl(caption="ctm03CIa") %>% kable_paper("striped","hover",full_width=F)
ctm04aCI %>% kbl(caption="ctm04CIa") %>% kable_paper("striped","hover",full_width=F)

tab_model(ctm04a,ctm041a,ctm042a,ctm043a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm04aCI  %>% kbl(caption="ctm04aCI" ) %>% kable_paper("striped","hover",full_width=F)
ctm041aCI %>% kbl(caption="ctm041aCI") %>% kable_paper("striped","hover",full_width=F)
ctm042aCI %>% kbl(caption="ctm042aCI") %>% kable_paper("striped","hover",full_width=F)
ctm043aCI %>% kbl(caption="ctm043aCI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m01,c1m02,c1m03,c1m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c1m04,c1m05,c1m06,c1m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m01CI %>% kbl(caption="c1m01CI") %>% kable_paper("striped","hover",full_width=F)
c1m02CI %>% kbl(caption="c1m02CI") %>% kable_paper("striped","hover",full_width=F)
c1m03CI %>% kbl(caption="c1m03CI") %>% kable_paper("striped","hover",full_width=F)
c1m04CI %>% kbl(caption="c1m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c2m01,c2m02,c2m03,c2m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c2m04,c2m05,c2m06,c2m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c2m01CI %>% kbl(caption="c2m01CI") %>% kable_paper("striped","hover",full_width=F)
c2m02CI %>% kbl(caption="c2m02CI") %>% kable_paper("striped","hover",full_width=F)
c2m03CI %>% kbl(caption="c2m03CI") %>% kable_paper("striped","hover",full_width=F)
c2m04CI %>% kbl(caption="c2m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c3m01,c3m02,c3m03,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(c3m04,c3m05,c3m06,c3m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c3m01CI %>% kbl(caption="c3m01CI") %>% kable_paper("striped","hover",full_width=F)
c3m02CI %>% kbl(caption="c3m02CI") %>% kable_paper("striped","hover",full_width=F)
c3m03CI %>% kbl(caption="c3m03CI") %>% kable_paper("striped","hover",full_width=F)
c3m04CI %>% kbl(caption="c3m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m04,c2m04,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m04CI %>% kbl(caption="c1m04CI") %>% kable_paper("striped","hover",full_width=F)
c2m04CI %>% kbl(caption="c2m04CI") %>% kable_paper("striped","hover",full_width=F)
c3m04CI %>% kbl(caption="c3m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm01,cmm02,cmm03,cmm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cmm04,cmm05,cmm06,cmm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm01CI %>% kbl(caption="cmm01CI") %>% kable_paper("striped","hover",full_width=F)
cmm02CI %>% kbl(caption="cmm02CI") %>% kable_paper("striped","hover",full_width=F)
cmm03CI %>% kbl(caption="cmm03CI") %>% kable_paper("striped","hover",full_width=F)
cmm04CI %>% kbl(caption="cmm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cfm01,cfm02,cfm03,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cfm04,cfm05,cfm06,cfm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cfm01CI %>% kbl(caption="cfm01CI") %>% kable_paper("striped","hover",full_width=F)
cfm02CI %>% kbl(caption="cfm02CI") %>% kable_paper("striped","hover",full_width=F)
cfm03CI %>% kbl(caption="cfm03CI") %>% kable_paper("striped","hover",full_width=F)
cfm04CI %>% kbl(caption="cfm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm04,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm04CI %>% kbl(caption="cmm04CI") %>% kable_paper("striped","hover",full_width=F)
cfm04CI %>% kbl(caption="cfm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm01,cnm02,cnm03,cnm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cnm04,cnm05,cnm06,cnm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm01CI %>% kbl(caption="cnm01CI") %>% kable_paper("striped","hover",full_width=F)
cnm02CI %>% kbl(caption="cnm02CI") %>% kable_paper("striped","hover",full_width=F)
cnm03CI %>% kbl(caption="cnm03CI") %>% kable_paper("striped","hover",full_width=F)
cnm04CI %>% kbl(caption="cnm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cpm01,cpm02,cpm03,cpm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cpm04,cpm05,cpm06,cpm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cpm01CI %>% kbl(caption="cpm01CI") %>% kable_paper("striped","hover",full_width=F)
cpm02CI %>% kbl(caption="cpm02CI") %>% kable_paper("striped","hover",full_width=F)
cpm03CI %>% kbl(caption="cpm03CI") %>% kable_paper("striped","hover",full_width=F)
cpm04CI %>% kbl(caption="cpm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(csm01,csm02,csm03,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(csm04,csm05,csm06,csm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
csm01CI %>% kbl(caption="csm01CI") %>% kable_paper("striped","hover",full_width=F)
csm02CI %>% kbl(caption="csm02CI") %>% kable_paper("striped","hover",full_width=F)
csm03CI %>% kbl(caption="csm03CI") %>% kable_paper("striped","hover",full_width=F)
csm04CI %>% kbl(caption="csm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm04,cpm04,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm04CI %>% kbl(caption="cnm04CI") %>% kable_paper("striped","hover",full_width=F)
cpm04CI %>% kbl(caption="cpm04CI") %>% kable_paper("striped","hover",full_width=F)
csm04CI %>% kbl(caption="csm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm01,cwm02,cwm03,cwm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm04,cwm05,cwm06,cwm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm01CI %>% kbl(caption="cwm01CI") %>% kable_paper("striped","hover",full_width=F)
cwm02CI %>% kbl(caption="cwm02CI") %>% kable_paper("striped","hover",full_width=F)
cwm03CI %>% kbl(caption="cwm03CI") %>% kable_paper("striped","hover",full_width=F)
cwm04CI %>% kbl(caption="cwm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cbm01,cbm02,cbm03,cbm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cbm04,cbm05,cbm06,cbm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cbm01CI %>% kbl(caption="cbm01CI") %>% kable_paper("striped","hover",full_width=F)
cbm02CI %>% kbl(caption="cbm02CI") %>% kable_paper("striped","hover",full_width=F)
cbm03CI %>% kbl(caption="cbm03CI") %>% kable_paper("striped","hover",full_width=F)
cbm04CI %>% kbl(caption="cbm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(chm01,chm02,chm03,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(chm04,chm05,chm06,chm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
chm01CI %>% kbl(caption="chm01CI") %>% kable_paper("striped","hover",full_width=F)
chm02CI %>% kbl(caption="chm02CI") %>% kable_paper("striped","hover",full_width=F)
chm03CI %>% kbl(caption="chm03CI") %>% kable_paper("striped","hover",full_width=F)
chm04CI %>% kbl(caption="chm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm04,cbm04,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm04CI %>% kbl(caption="cwm04CI") %>% kable_paper("striped","hover",full_width=F)
cbm04CI %>% kbl(caption="cbm04CI") %>% kable_paper("striped","hover",full_width=F)
chm04CI %>% kbl(caption="chm04CI") %>% kable_paper("striped","hover",full_width=F)





# Revise the below codes
# Revise the below codes
# Revise the below codes
# Revise the below codes
# Revise the below codes

MTotal1<-data.table(Name=c(names(fixef(ctm01)),as.data.table(VarCorr(ctm01))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm01),as.data.table(VarCorr(ctm01))$vcov,AIC(ctm01),r2(ctm01)[[2]],r2(ctm01)[[1]],nobs(ctm01),ngrps(ctm01)),4),LL=round(c(ctm01CI[-(1:3),1],ctm01CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm01CI[-(1:3),2],ctm01CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal2<-data.table(Name=c(names(fixef(ctm02)),as.data.table(VarCorr(ctm02))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm02),as.data.table(VarCorr(ctm02))$vcov,AIC(ctm02),r2(ctm02)[[2]],r2(ctm02)[[1]],nobs(ctm02),ngrps(ctm02)),4),LL=round(c(ctm02CI[-(1:3),1],ctm02CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm02CI[-(1:3),2],ctm02CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal3<-data.table(Name=c(names(fixef(ctm03)),as.data.table(VarCorr(ctm03))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm03),as.data.table(VarCorr(ctm03))$vcov,AIC(ctm03),r2(ctm03)[[2]],r2(ctm03)[[1]],nobs(ctm03),ngrps(ctm03)),4),LL=round(c(ctm03CI[-(1:3),1],ctm03CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm03CI[-(1:3),2],ctm03CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal4<-data.table(Name=c(names(fixef(ctm04)),as.data.table(VarCorr(ctm04))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm04),as.data.table(VarCorr(ctm04))$vcov,AIC(ctm04),r2(ctm04)[[2]],r2(ctm04)[[1]],nobs(ctm04),ngrps(ctm04)),4),LL=round(c(ctm04CI[-(1:3),1],ctm04CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm04CI[-(1:3),2],ctm04CI[1:3,2]^2,0,0,0,0,0,0),4))

MTotal12<-data.table(Name=c(names(fixef(ctm11)),as.data.table(VarCorr(ctm11))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm11),as.data.table(VarCorr(ctm11))$vcov,AIC(ctm11),r2(ctm11)[[2]],r2(ctm11)[[1]],nobs(ctm11),ngrps(ctm11)),4),LL=round(c(ctm11CI[-(1:3),1],ctm11CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm11CI[-(1:3),2],ctm11CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal22<-data.table(Name=c(names(fixef(ctm12)),as.data.table(VarCorr(ctm12))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm12),as.data.table(VarCorr(ctm12))$vcov,AIC(ctm12),r2(ctm12)[[2]],r2(ctm12)[[1]],nobs(ctm12),ngrps(ctm12)),4),LL=round(c(ctm12CI[-(1:3),1],ctm12CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm12CI[-(1:3),2],ctm12CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal32<-data.table(Name=c(names(fixef(ctm13)),as.data.table(VarCorr(ctm13))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm13),as.data.table(VarCorr(ctm13))$vcov,AIC(ctm13),r2(ctm13)[[2]],r2(ctm13)[[1]],nobs(ctm13),ngrps(ctm13)),4),LL=round(c(ctm13CI[-(1:3),1],ctm13CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm13CI[-(1:3),2],ctm13CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal42<-data.table(Name=c(names(fixef(ctm14)),as.data.table(VarCorr(ctm14))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm14),as.data.table(VarCorr(ctm14))$vcov,AIC(ctm14),r2(ctm14)[[2]],r2(ctm14)[[1]],nobs(ctm14),ngrps(ctm14)),4),LL=round(c(ctm14CI[-(1:3),1],ctm14CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm14CI[-(1:3),2],ctm14CI[1:3,2]^2,0,0,0,0,0,0),4))

MUrban<-data.table(Name=c(names(fixef(ctm04)[6:7]),"HV_w*SUrban","HV_b*Rural","HV_w*SUrban","HV_b*Rural","AIC","R2M","R2C","N1","N2","N3"),
                   M1Est=round(c(fixef(ctm04 )[6:7],0,0,0,0,AIC(ctm04),r2(ctm04)[[2]],r2(ctm04)[[1]],nobs(ctm04),ngrps(ctm04)),4),M1LL=round(c(ctm04CI[9:10,1],0,0,0,0,0,0,0,0,0,0),4),M1UL=round(c(ctm04CI[9:10,2],0,0,0,0,0,0,0,0,0,0),4),
                   M2Est=round(c(fixef(ctm041)[6:7],fixef(ctm041)[24:25],0,0,AIC(ctm041),r2(ctm041)[[2]],r2(ctm041)[[1]],nobs(ctm041),ngrps(ctm041)),4),M2LL=round(c(ctm041CI[9:10,1],ctm041CI[27:28,1],0,0,0,0,0,0,0,0),4),M2UL=round(c(ctm041CI[9:10,2],ctm041CI[27:28,2],0,0,0,0,0,0,0,0),4),
                   M3Est=round(c(fixef(ctm042)[7:6],0,0,fixef(ctm042)[24:25],AIC(ctm042),r2(ctm042)[[2]],r2(ctm042)[[1]],nobs(ctm042),ngrps(ctm042)),4),M3LL=round(c(ctm042CI[10:9,1],0,0,ctm042CI[27:28,1],0,0,0,0,0,0),4),M3UL=round(c(ctm042CI[10:9,2],0,0,ctm042CI[27:28,2],0,0,0,0,0,0),4))

MUrban2<-data.table(Name=c(names(fixef(ctm14)[6:7]),"HV_w*SUrban","HV_b*Rural","HV_w*SUrban","HV_b*Rural","AIC","R2M","R2C","N1","N2","N3"),
                    M1Est=round(c(fixef(ctm14 )[6:7],0,0,0,0,AIC(ctm14),r2(ctm14)[[2]],r2(ctm14)[[1]],nobs(ctm14),ngrps(ctm14)),4),M1LL=round(c(ctm14CI[9:10,1],0,0,0,0,0,0,0,0,0,0),4),M1UL=round(c(ctm14CI[9:10,2],0,0,0,0,0,0,0,0,0,0),4),
                    M2Est=round(c(fixef(ctm141)[6:7],fixef(ctm141)[24:25],0,0,AIC(ctm141),r2(ctm141)[[2]],r2(ctm141)[[1]],nobs(ctm141),ngrps(ctm141)),4),M2LL=round(c(ctm141CI[9:10,1],ctm141CI[27:28,1],0,0,0,0,0,0,0,0),4),M2UL=round(c(ctm141CI[9:10,2],ctm141CI[27:28,2],0,0,0,0,0,0,0,0),4),
                    M3Est=round(c(fixef(ctm142)[7:6],0,0,fixef(ctm142)[24:25],AIC(ctm142),r2(ctm142)[[2]],r2(ctm142)[[1]],nobs(ctm142),ngrps(ctm142)),4),M3LL=round(c(ctm142CI[10:9,1],0,0,ctm142CI[27:28,1],0,0,0,0,0,0),4),M3UL=round(c(ctm142CI[10:9,2],0,0,ctm142CI[27:28,2],0,0,0,0,0,0),4))

MAge<-data.table(Name=c(names(fixef(c1m04)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                 C1Est=round(c(fixef(c1m04)[6:7],mean(c1$Rpt1r),fixef(c1m04)[6:7]/mean(c1$Rpt1r)*100,r2(c1m04)[[2]],r2(c1m04)[[1]],nobs(c1m04),ngrps(c1m04)),4),C1LL=round(c(c1m04CI[9:10,1],mean(c1$Rpt1r),c1m04CI[9:10,1]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),C1UL=round(c(c1m04CI[9:10,2],mean(c1$Rpt1r),c1m04CI[9:10,2]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),
                 C2Est=round(c(fixef(c2m04)[6:7],mean(c2$Rpt2r),fixef(c2m04)[6:7]/mean(c2$Rpt2r)*100,r2(c2m04)[[2]],r2(c2m04)[[1]],nobs(c2m04),ngrps(c2m04)),4),C2LL=round(c(c2m04CI[9:10,1],mean(c2$Rpt2r),c2m04CI[9:10,1]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),C2UL=round(c(c2m04CI[9:10,2],mean(c2$Rpt2r),c2m04CI[9:10,2]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),
                 C3Est=round(c(fixef(c3m04)[6:7],mean(c3$Rpt3r),fixef(c3m04)[6:7]/mean(c3$Rpt3r)*100,r2(c3m04)[[2]],r2(c3m04)[[1]],nobs(c3m04),ngrps(c3m04)),4),C3LL=round(c(c3m04CI[9:10,1],mean(c3$Rpt3r),c3m04CI[9:10,1]/mean(c3$Rpt3r)*100,0,0,0,0,0),4),C3UL=round(c(c3m04CI[9:10,2],mean(c3$Rpt3r),c3m04CI[9:10,2]/mean(c3$Rpt3r)*100,0,0,0,0,0),4))

MAge2<-data.table(Name=c(names(fixef(c1m14)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                  C1Est=round(c(fixef(c1m14)[6:7],mean(c1$Rpt1r),fixef(c1m14)[6:7]/mean(c1$Rpt1r)*100,r2(c1m14)[[2]],r2(c1m14)[[1]],nobs(c1m14),ngrps(c1m14)),4),C1LL=round(c(c1m14CI[9:10,1],mean(c1$Rpt1r),c1m14CI[9:10,1]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),C1UL=round(c(c1m14CI[9:10,2],mean(c1$Rpt1r),c1m14CI[9:10,2]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),
                  C2Est=round(c(fixef(c2m14)[6:7],mean(c2$Rpt2r),fixef(c2m14)[6:7]/mean(c2$Rpt2r)*100,r2(c2m14)[[2]],r2(c2m14)[[1]],nobs(c2m14),ngrps(c2m14)),4),C2LL=round(c(c2m14CI[9:10,1],mean(c2$Rpt2r),c2m14CI[9:10,1]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),C2UL=round(c(c2m14CI[9:10,2],mean(c2$Rpt2r),c2m14CI[9:10,2]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),
                  C3Est=round(c(fixef(c3m14)[6:7],mean(c3$Rpt3r),fixef(c3m14)[6:7]/mean(c3$Rpt3r)*100,r2(c3m14)[[2]],r2(c3m14)[[1]],nobs(c3m14),ngrps(c3m14)),4),C3LL=round(c(c3m14CI[9:10,1],mean(c3$Rpt3r),c3m14CI[9:10,1]/mean(c3$Rpt3r)*100,0,0,0,0,0),4),C3UL=round(c(c3m14CI[9:10,2],mean(c3$Rpt3r),c3m14CI[9:10,2]/mean(c3$Rpt3r)*100,0,0,0,0,0),4))

MSex<-data.table(Name=c(names(fixef(cmm04)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                 CmEst=round(c(fixef(cmm04)[6:7],mean(cm$RptMr),fixef(cmm04)[6:7]/mean(cm$RptMr)*100,r2(cmm04)[[2]],r2(cmm04)[[1]],nobs(cmm04),ngrps(cmm04)),4),CmLL=round(c(cmm04CI[9:10,1],mean(cm$RptMr),cmm04CI[9:10,1]/mean(cm$RptMr)*100,0,0,0,0,0),4),CmUL=round(c(cmm04CI[9:10,2],mean(cm$RptMr),cmm04CI[9:10,2]/mean(cm$RptMr)*100,0,0,0,0,0),4),
                 CfEst=round(c(fixef(cfm04)[6:7],mean(cf$RptFr),fixef(cfm04)[6:7]/mean(cf$RptFr)*100,r2(cfm04)[[2]],r2(cfm04)[[1]],nobs(cfm04),ngrps(cfm04)),4),CfLL=round(c(cfm04CI[9:10,1],mean(cf$RptFr),cfm04CI[9:10,1]/mean(cf$RptFr)*100,0,0,0,0,0),4),CfUL=round(c(cfm04CI[9:10,2],mean(cf$RptFr),cfm04CI[9:10,2]/mean(cf$RptFr)*100,0,0,0,0,0),4))

MSex2<-data.table(Name=c(names(fixef(cmm14)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                  CmEst=round(c(fixef(cmm14)[6:7],mean(cm$RptMr),fixef(cmm14)[6:7]/mean(cm$RptMr)*100,r2(cmm14)[[2]],r2(cmm14)[[1]],nobs(cmm14),ngrps(cmm14)),4),CmLL=round(c(cmm14CI[9:10,1],mean(cm$RptMr),cmm14CI[9:10,1]/mean(cm$RptMr)*100,0,0,0,0,0),4),CmUL=round(c(cmm14CI[9:10,2],mean(cm$RptMr),cmm14CI[9:10,2]/mean(cm$RptMr)*100,0,0,0,0,0),4),
                  CfEst=round(c(fixef(cfm14)[6:7],mean(cf$RptFr),fixef(cfm14)[6:7]/mean(cf$RptFr)*100,r2(cfm14)[[2]],r2(cfm14)[[1]],nobs(cfm14),ngrps(cfm14)),4),CfLL=round(c(cfm14CI[9:10,1],mean(cf$RptFr),cfm14CI[9:10,1]/mean(cf$RptFr)*100,0,0,0,0,0),4),CfUL=round(c(cfm14CI[9:10,2],mean(cf$RptFr),cfm14CI[9:10,2]/mean(cf$RptFr)*100,0,0,0,0,0),4))

MType<-data.table(Name=c(names(fixef(cnm04)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                  CnEst=round(c(fixef(cnm04)[6:7],mean(cn$NegTr),fixef(cnm04)[6:7]/mean(cn$NegTr)*100,r2(cnm04)[[2]],r2(cnm04)[[1]],nobs(cnm04),ngrps(cnm04)),4),CnLL=round(c(cnm04CI[9:10,1],mean(cn$NegTr),cnm04CI[9:10,1]/mean(cn$NegTr)*100,0,0,0,0,0),4),CnUL=round(c(cnm04CI[9:10,2],mean(cn$NegTr),cnm04CI[9:10,2]/mean(cn$NegTr)*100,0,0,0,0,0),4),
                  CpEst=round(c(fixef(cpm04)[6:7],mean(cp$PhyTr),fixef(cpm04)[6:7]/mean(cp$PhyTr)*100,r2(cpm04)[[2]],r2(cpm04)[[1]],nobs(cpm04),ngrps(cpm04)),4),CpLL=round(c(cpm04CI[9:10,1],mean(cp$PhyTr),cpm04CI[9:10,1]/mean(cp$PhyTr)*100,0,0,0,0,0),4),CpUL=round(c(cpm04CI[9:10,2],mean(cp$PhyTr),cpm04CI[9:10,2]/mean(cp$PhyTr)*100,0,0,0,0,0),4),
                  CsEst=round(c(fixef(csm04)[6:7],mean(cs$SexTr),fixef(csm04)[6:7]/mean(cs$SexTr)*100,r2(csm04)[[2]],r2(csm04)[[1]],nobs(csm04),ngrps(csm04)),4),CsLL=round(c(csm04CI[9:10,1],mean(cs$SexTr),csm04CI[9:10,1]/mean(cs$SexTr)*100,0,0,0,0,0),4),CsUL=round(c(csm04CI[9:10,2],mean(cs$SexTr),csm04CI[9:10,2]/mean(cs$SexTr)*100,0,0,0,0,0),4))

MType2<-data.table(Name=c(names(fixef(cnm14)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                   CnEst=round(c(fixef(cnm14)[6:7],mean(cn$NegTr),fixef(cnm14)[6:7]/mean(cn$NegTr)*100,r2(cnm14)[[2]],r2(cnm14)[[1]],nobs(cnm14),ngrps(cnm14)),4),CnLL=round(c(cnm14CI[9:10,1],mean(cn$NegTr),cnm14CI[9:10,1]/mean(cn$NegTr)*100,0,0,0,0,0),4),CnUL=round(c(cnm14CI[9:10,2],mean(cn$NegTr),cnm14CI[9:10,2]/mean(cn$NegTr)*100,0,0,0,0,0),4),
                   CpEst=round(c(fixef(cpm14)[6:7],mean(cp$PhyTr),fixef(cpm14)[6:7]/mean(cp$PhyTr)*100,r2(cpm14)[[2]],r2(cpm14)[[1]],nobs(cpm14),ngrps(cpm14)),4),CpLL=round(c(cpm14CI[9:10,1],mean(cp$PhyTr),cpm14CI[9:10,1]/mean(cp$PhyTr)*100,0,0,0,0,0),4),CpUL=round(c(cpm14CI[9:10,2],mean(cp$PhyTr),cpm14CI[9:10,2]/mean(cp$PhyTr)*100,0,0,0,0,0),4),
                   CsEst=round(c(fixef(csm14)[6:7],mean(cs$SexTr),fixef(csm14)[6:7]/mean(cs$SexTr)*100,r2(csm14)[[2]],r2(csm14)[[1]],nobs(csm14),ngrps(csm14)),4),CsLL=round(c(csm14CI[9:10,1],mean(cs$SexTr),csm14CI[9:10,1]/mean(cs$SexTr)*100,0,0,0,0,0),4),CsUL=round(c(csm14CI[9:10,2],mean(cs$SexTr),csm14CI[9:10,2]/mean(cs$SexTr)*100,0,0,0,0,0),4))

MRace<-data.table(Name=c(names(fixef(cwm04)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                  CwEst=round(c(fixef(cwm04)[6:7],mean(cw$RptWr),fixef(cwm04)[6:7]/mean(cw$RptWr)*100,r2(cwm04)[[2]],r2(cwm04)[[1]],nobs(cwm04),ngrps(cwm04)),4),CwLL=round(c(cwm04CI[9:10,1],mean(cw$RptWr),cwm04CI[9:10,1]/mean(cw$RptWr)*100,0,0,0,0,0),4),CwUL=round(c(cwm04CI[9:10,2],mean(cw$RptWr),cwm04CI[9:10,2]/mean(cw$RptWr)*100,0,0,0,0,0),4),
                  CbEst=round(c(fixef(cbm04)[6:7],mean(cb$RptBr),fixef(cbm04)[6:7]/mean(cb$RptBr)*100,r2(cbm04)[[2]],r2(cbm04)[[1]],nobs(cbm04),ngrps(cbm04)),4),CbLL=round(c(cbm04CI[9:10,1],mean(cb$RptBr),cbm04CI[9:10,1]/mean(cb$RptBr)*100,0,0,0,0,0),4),CbUL=round(c(cbm04CI[9:10,2],mean(cb$RptBr),cbm04CI[9:10,2]/mean(cb$RptBr)*100,0,0,0,0,0),4),
                  ChEst=round(c(fixef(chm04)[6:7],mean(ch$RptHr),fixef(chm04)[6:7]/mean(ch$RptHr)*100,r2(chm04)[[2]],r2(chm04)[[1]],nobs(chm04),ngrps(chm04)),4),ChLL=round(c(chm04CI[9:10,1],mean(ch$RptHr),chm04CI[9:10,1]/mean(ch$RptHr)*100,0,0,0,0,0),4),ChUL=round(c(chm04CI[9:10,2],mean(ch$RptHr),chm04CI[9:10,2]/mean(ch$RptHr)*100,0,0,0,0,0),4))

MRace2<-data.table(Name=c(names(fixef(cwm14)[6:7]),"MeanY","RSize_HV_w","RSize_HV_b","R2M","R2C","N1","N2","N3"),
                   CwEst=round(c(fixef(cwm14)[6:7],mean(cw$RptWr),fixef(cwm14)[6:7]/mean(cw$RptWr)*100,r2(cwm14)[[2]],r2(cwm14)[[1]],nobs(cwm14),ngrps(cwm14)),4),CwLL=round(c(cwm14CI[9:10,1],mean(cw$RptWr),cwm14CI[9:10,1]/mean(cw$RptWr)*100,0,0,0,0,0),4),CwUL=round(c(cwm14CI[9:10,2],mean(cw$RptWr),cwm14CI[9:10,2]/mean(cw$RptWr)*100,0,0,0,0,0),4),
                   CbEst=round(c(fixef(cbm14)[6:7],mean(cb$RptBr),fixef(cbm14)[6:7]/mean(cb$RptBr)*100,r2(cbm14)[[2]],r2(cbm14)[[1]],nobs(cbm14),ngrps(cbm14)),4),CbLL=round(c(cbm14CI[9:10,1],mean(cb$RptBr),cbm14CI[9:10,1]/mean(cb$RptBr)*100,0,0,0,0,0),4),CbUL=round(c(cbm14CI[9:10,2],mean(cb$RptBr),cbm14CI[9:10,2]/mean(cb$RptBr)*100,0,0,0,0,0),4),
                   ChEst=round(c(fixef(chm14)[6:7],mean(ch$RptHr),fixef(chm14)[6:7]/mean(ch$RptHr)*100,r2(chm14)[[2]],r2(chm14)[[1]],nobs(chm14),ngrps(chm14)),4),ChLL=round(c(chm14CI[9:10,1],mean(ch$RptHr),chm14CI[9:10,1]/mean(ch$RptHr)*100,0,0,0,0,0),4),ChUL=round(c(chm14CI[9:10,2],mean(ch$RptHr),chm14CI[9:10,2]/mean(ch$RptHr)*100,0,0,0,0,0),4))

write.csv(MTotal1,"Z:/CDCK01/Analysis/HomeVisit/MTotal1_2.csv")
write.csv(MTotal2,"Z:/CDCK01/Analysis/HomeVisit/MTotal2_2.csv")
write.csv(MTotal3,"Z:/CDCK01/Analysis/HomeVisit/MTotal3_2.csv")
write.csv(MTotal4,"Z:/CDCK01/Analysis/HomeVisit/MTotal4_2.csv")
write.csv(MUrban,"Z:/CDCK01/Analysis/HomeVisit/MUrban_2.csv")
write.csv(MAge,"Z:/CDCK01/Analysis/HomeVisit/MAge_2.csv")
write.csv(MSex,"Z:/CDCK01/Analysis/HomeVisit/MSex_2.csv")
write.csv(MType,"Z:/CDCK01/Analysis/HomeVisit/MType_2.csv")
write.csv(MRace,"Z:/CDCK01/Analysis/HomeVisit/MRace_2.csv")

write.csv(MTotal12,"Z:/CDCK01/Analysis/HomeVisit/MTotal12_2.csv")
write.csv(MTotal22,"Z:/CDCK01/Analysis/HomeVisit/MTotal22_2.csv")
write.csv(MTotal32,"Z:/CDCK01/Analysis/HomeVisit/MTotal32_2.csv")
write.csv(MTotal42,"Z:/CDCK01/Analysis/HomeVisit/MTotal42_2.csv")
write.csv(MUrban2,"Z:/CDCK01/Analysis/HomeVisit/MUrban2_2.csv")
write.csv(MAge2,"Z:/CDCK01/Analysis/HomeVisit/MAge2_2.csv")
write.csv(MSex2,"Z:/CDCK01/Analysis/HomeVisit/MSex2_2.csv")
write.csv(MType2,"Z:/CDCK01/Analysis/HomeVisit/MType2_2.csv")
write.csv(MRace2,"Z:/CDCK01/Analysis/HomeVisit/MRace2_2.csv")




summary(ctg02)
summary(c1g02)
summary(c2g02)
summary(c3g02)
summary(cmg02)
summary(cfg02)
summary(cng02)
summary(cpg02)
summary(csg02)
summary(cwg02)
summary(cbg02)
summary(chg02)

summary(ctg02a)
summary(c1g02a)
summary(c2g02a)
summary(c3g02a)
summary(cmg02a)
summary(cfg02a)
summary(cng02a)
summary(cpg02a)
summary(csg02a)
summary(cwg02a)
summary(cbg02a)
summary(chg02a)



###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

Table1<-data.table(
  Name=c("Total","Young","Middle","Old","Male","Female","White","Black","Latino","Neglect","Physical","Sexual","HV in 2016-2018","HV in 2016","HV in 2017","HV in 2018","MHV in 2016-2018","MHV in 2016","MHV in 2017","MHV in 2018","Income","Single","% Black","% Latino","Foreign-born","% Child","Disability","Mobility","Large Urban","Small Urban","Rural","2016","2017","2018"),
  N1=c(nrow(ct),nrow(c1),nrow(c2),nrow(c3),nrow(cm),nrow(cf),nrow(cw),nrow(cb),nrow(ch),nrow(cn),nrow(cp),nrow(cs),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  N2=c(length(unique(ct$CountyFIPS)),length(unique(c1$CountyFIPS)),length(unique(c2$CountyFIPS)),length(unique(c3$CountyFIPS)),length(unique(cm$CountyFIPS)),length(unique(cf$CountyFIPS)),length(unique(cw$CountyFIPS)),length(unique(cb$CountyFIPS)),length(unique(ch$CountyFIPS)),length(unique(cn$CountyFIPS)),length(unique(cp$CountyFIPS)),length(unique(cs$CountyFIPS)),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  N3=c(length(unique(ct$StateFIPS)),length(unique(c1$StateFIPS)),length(unique(c2$StateFIPS)),length(unique(c3$StateFIPS)),length(unique(cm$StateFIPS)),length(unique(cf$StateFIPS)),length(unique(cw$StateFIPS)),length(unique(cb$StateFIPS)),length(unique(ch$StateFIPS)),length(unique(cn$StateFIPS)),length(unique(cp$StateFIPS)),length(unique(cs$StateFIPS)),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  Mean=c(mean(ct$RptTr),mean(c1$Rpt1r),mean(c2$Rpt2r),mean(c3$Rpt3r),mean(cm$RptMr),mean(cf$RptFr),mean(cw$RptWr),mean(cb$RptBr),mean(ch$RptHr),mean(cn$NegTr),mean(cp$PhyTr),mean(cs$SexTr),mean(ct$NHVRC),mean(ct$NHVRC[ct$Year==2016]),mean(ct$NHVRC[ct$Year==2017]),mean(ct$NHVRC[ct$Year==2018]),mean(ct$MIECHV),mean(ct$MIECHV[ct$Year==2016]),mean(ct$MIECHV[ct$Year==2017]),mean(ct$MIECHV[ct$Year==2018]),mean(ct$IncomeT1k),mean(ct$SingleT),mean(ct$CPopBP),mean(ct$CPopHP),mean(ct$FBornT),mean(ct$ChildPT),mean(ct$DisablT),mean(ct$MoveT),prop.table(table(ct$USDA_RUC))*100,prop.table(table(ct$Yearf))*100),
  SD=c(sd(ct$RptTr),sd(c1$Rpt1r),sd(c2$Rpt2r),sd(c3$Rpt3r),sd(cm$RptMr),sd(cf$RptFr),sd(cw$RptWr),sd(cb$RptBr),sd(ch$RptHr),sd(cn$NegTr),sd(cp$PhyTr),sd(cs$SexTr),NA,NA,NA,NA,NA,NA,NA,NA,sd(ct$IncomeT1k),sd(ct$SingleT),sd(ct$CPopBP),sd(ct$CPopHP),sd(ct$FBornT),sd(ct$ChildPT),sd(ct$DisablT),sd(ct$MoveT),NA,NA,NA,NA,NA,NA)
)
Table1

mean(ct$RptTr)
mean(c1$Rpt1r)
mean(c2$Rpt2r)
mean(c3$Rpt3r)
mean(cm$RptMr)
mean(cf$RptFr)
mean(cw$RptWr)
mean(cb$RptBr)
mean(ch$RptHr)
mean(cn$NegTr)
mean(cp$PhyTr)
mean(cs$SexTr)
mean(ct$NHVRC)
mean(ct$NHVRC[ct$Year==2016])
mean(ct$NHVRC[ct$Year==2017])
mean(ct$NHVRC[ct$Year==2018])
mean(ct$MIECHV)
mean(ct$MIECHV[ct$Year==2016])
mean(ct$MIECHV[ct$Year==2017])
mean(ct$MIECHV[ct$Year==2018])
mean(ct$IncomeT1k)
mean(ct$SingleT)
mean(ct$CPopBP)
mean(ct$CPopHP)
mean(ct$FBornT)
mean(ct$ChildPT)
mean(ct$DisablT)
mean(ct$MoveT)
prop.table(table(ct$USDA_RUC))*100
prop.table(table(ct$Yearf))*100

sd(ct$RptTr)
sd(c1$Rpt1r)
sd(c2$Rpt2r)
sd(c3$Rpt3r)
sd(cm$RptMr)
sd(cf$RptFr)
sd(cw$RptWr)
sd(cb$RptBr)
sd(ch$RptHr)
sd(cn$NegTr)
sd(cp$PhyTr)
sd(cs$SexTr)
sd(ct$NHVRC)
sd(ct$NHVRC[ct$Year==2016])
sd(ct$NHVRC[ct$Year==2017])
sd(ct$NHVRC[ct$Year==2018])
sd(ct$MIECHV)
sd(ct$MIECHV[ct$Year==2016])
sd(ct$MIECHV[ct$Year==2017])
sd(ct$MIECHV[ct$Year==2018])
sd(ct$IncomeT1k)
sd(ct$SingleT)
sd(ct$CPopBP)
sd(ct$CPopHP)
sd(ct$FBornT)
sd(ct$ChildPT)
sd(ct$DisablT)
sd(ct$MoveT)
prop.table(table(ct$USDA_RUC))*100
prop.table(table(ct$Yearf))*100









ct[, NHVRC_n := shift(NHVRC,n=-1,fill=NA), by = CountyFIPS] # n=1 is default; n=-1 will look forward
ct[, NHVRC_p := shift(NHVRC,n=1,fill=NA), by = CountyFIPS]
View(ct[,c("CountyFIPS","Year","NHVRC","NHVRC_n","NHVRC_p")])

ct[, MIECHV_n := shift(MIECHV,n=-1,fill=NA), by = CountyFIPS] # n=1 is default; n=-1 will look forward
ct[, MIECHV_p := shift(MIECHV,n=1,fill=NA), by = CountyFIPS]
View(ct[,c("CountyFIPS","Year","MIECHV","MIECHV_n","MIECHV_p")])


# Pre - All
table(ct$NHVRC[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018]) # 139
table(ct$NHVRC[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018]) #  39
table(ct$NHVRC[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018]) #  19
table(ct$NHVRC[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018]) # 987
# Post - All
table(ct$NHVRC[ct$NHVRC_p==0 & ct$NHVRC==0 & ct$Year!=2016]) # 139
table(ct$NHVRC[ct$NHVRC_p==0 & ct$NHVRC==1 & ct$Year!=2016]) #  39
table(ct$NHVRC[ct$NHVRC_p==1 & ct$NHVRC==0 & ct$Year!=2016]) #  19
table(ct$NHVRC[ct$NHVRC_p==1 & ct$NHVRC==1 & ct$Year!=2016]) # 987
# Pre - All (2016 or 2017)
mean(ct$RptTr[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018]) # 67.9809
mean(ct$RptTr[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018]) # 71.46824
mean(ct$RptTr[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018]) # 66.67543
mean(ct$RptTr[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018]) # 59.13093
# Post - All (2017 or 2018)
mean(ct$RptTr[ct$NHVRC_p==0 & ct$NHVRC==0 & ct$Year!=2016]) # 68.86892
mean(ct$RptTr[ct$NHVRC_p==0 & ct$NHVRC==1 & ct$Year!=2016]) # 70.18574
mean(ct$RptTr[ct$NHVRC_p==1 & ct$NHVRC==0 & ct$Year!=2016]) # 68.05537
mean(ct$RptTr[ct$NHVRC_p==1 & ct$NHVRC==1 & ct$Year!=2016]) # 60.56543


# Pre 
mean(ct$NHVRCc_within[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018])
mean(ct$NHVRCc_within[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018])
mean(ct$NHVRCc_within[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018])
mean(ct$NHVRCc_within[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018])

mean(ct$NHVRCc_between[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018])
mean(ct$NHVRCc_between[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018])
mean(ct$NHVRCc_between[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018])
mean(ct$NHVRCc_between[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018])

# Post
mean(ct$NHVRCc_within[ct$NHVRC_p==0 & ct$NHVRC==0 & ct$Year!=2016]) 
mean(ct$NHVRCc_within[ct$NHVRC_p==0 & ct$NHVRC==1 & ct$Year!=2016]) 
mean(ct$NHVRCc_within[ct$NHVRC_p==1 & ct$NHVRC==0 & ct$Year!=2016]) 
mean(ct$NHVRCc_within[ct$NHVRC_p==1 & ct$NHVRC==1 & ct$Year!=2016]) 

mean(ct$NHVRCc_between[ct$NHVRC_p==0 & ct$NHVRC==0 & ct$Year!=2016]) 
mean(ct$NHVRCc_between[ct$NHVRC_p==0 & ct$NHVRC==1 & ct$Year!=2016]) 
mean(ct$NHVRCc_between[ct$NHVRC_p==1 & ct$NHVRC==0 & ct$Year!=2016]) 
mean(ct$NHVRCc_between[ct$NHVRC_p==1 & ct$NHVRC==1 & ct$Year!=2016]) 

prop.table(table(ct$Year))
prop.table(table(ct$USDA_RUC))
mean(ct$NHVRCc_between)

summary(ctm04)
prop.table(table(ct$USDA_RUC)) # 0.3513514 0.5219595 0.1266892
prop.table(table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018])) # 0.3956835 0.3237410 0.2805755 
prop.table(table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018])) # 0.2307692 0.4871795 0.2820513
prop.table(table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018])) # 0.2631579 0.5263158 0.2105263
prop.table(table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018])) # 0.35157042 0.55116515 0.09726444

table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018]) #  55  45  39 
table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018]) #   9  19  11
table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018]) #   5  10   4
table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018]) # 347 544  96

table(ct$StateFIPS[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018]) # 5 12 13 17 18 22 24 26 28 31 33 34 35 36 37 40 47 48 51 54
table(ct$StateFIPS[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018]) # 5  6 10 12 13 16 17 22 26 36 37 39 41 47 48 51 54
table(ct$StateFIPS[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018]) # 5 12 13 17 21 22 33 40 47 48 51 54
table(ct$StateFIPS[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018]) # 1  2  4  5  6  8  9 10 11 12 13 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 44 45 46 47 48 49 51 53 54 55






# Pre - All
table(ct$MIECHV[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018]) # 603
table(ct$MIECHV[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018]) #  17
table(ct$MIECHV[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018]) #  10
table(ct$MIECHV[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018]) # 554
# Post - All
table(ct$MIECHV[ct$MIECHV_p==0 & ct$MIECHV==0 & ct$Year!=2016]) # 603
table(ct$MIECHV[ct$MIECHV_p==0 & ct$MIECHV==1 & ct$Year!=2016]) #  17
table(ct$MIECHV[ct$MIECHV_p==1 & ct$MIECHV==0 & ct$Year!=2016]) #  10
table(ct$MIECHV[ct$MIECHV_p==1 & ct$MIECHV==1 & ct$Year!=2016]) # 554
# Pre - All (2016 or 2017)
mean(ct$RptTr[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018]) # 62.5132
mean(ct$RptTr[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018]) # 70.30494
mean(ct$RptTr[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018]) # 59.1896
mean(ct$RptTr[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018]) # 58.4533
# Post - All (2017 or 2018)
mean(ct$RptTr[ct$MIECHV_p==0 & ct$MIECHV==0 & ct$Year!=2016]) # 63.96742
mean(ct$RptTr[ct$MIECHV_p==0 & ct$MIECHV==1 & ct$Year!=2016]) # 71.76018
mean(ct$RptTr[ct$MIECHV_p==1 & ct$MIECHV==0 & ct$Year!=2016]) # 59.87722
mean(ct$RptTr[ct$MIECHV_p==1 & ct$MIECHV==1 & ct$Year!=2016]) # 59.54893


# Pre - All (2016 or 2017)
t.test(ct$RptTr[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018]) # 62.5132
mean(ct$RptTr[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018]) # 70.30494
mean(ct$RptTr[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018]) # 59.1896
mean(ct$RptTr[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018]) # 58.4533
# Post - All (2017 or 2018)
mean(ct$RptTr[ct$MIECHV_p==0 & ct$MIECHV==0 & ct$Year!=2016]) # 63.96742
mean(ct$RptTr[ct$MIECHV_p==0 & ct$MIECHV==1 & ct$Year!=2016]) # 71.76018
mean(ct$RptTr[ct$MIECHV_p==1 & ct$MIECHV==0 & ct$Year!=2016]) # 59.87722
mean(ct$RptTr[ct$MIECHV_p==1 & ct$MIECHV==1 & ct$Year!=2016]) # 59.54893




# Pre 
mean(ct$MIECHVc_within[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018]) # -0.002763958
mean(ct$MIECHVc_within[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018]) # -0.6078431
mean(ct$MIECHVc_within[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018]) # 0.4
mean(ct$MIECHVc_within[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018]) # 0.01083032

# Post
mean(ct$MIECHVc_within[ct$MIECHV_p==0 & ct$MIECHV==0 & ct$Year!=2016]) # -0.002763958
mean(ct$MIECHVc_within[ct$MIECHV_p==0 & ct$MIECHV==1 & ct$Year!=2016]) # 0.3921569
mean(ct$MIECHVc_within[ct$MIECHV_p==1 & ct$MIECHV==0 & ct$Year!=2016]) # -0.6
mean(ct$MIECHVc_within[ct$MIECHV_p==1 & ct$MIECHV==1 & ct$Year!=2016]) # 0.01083032



prop.table(table(ct$USDA_RUC[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018])) # 0.3482587 0.4643449 0.1873964
prop.table(table(ct$USDA_RUC[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018])) # 0.2941176 0.5882353 0.1176471
prop.table(table(ct$USDA_RUC[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018])) # 0.1 0.8 0.1
prop.table(table(ct$USDA_RUC[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018])) # 0.36101083 0.57761733 0.06137184

table(ct$USDA_RUC[ct$MIECHV==0 & ct$MIECHV_n==0 & ct$Year!=2018])
table(ct$USDA_RUC[ct$MIECHV==0 & ct$MIECHV_n==1 & ct$Year!=2018])
table(ct$USDA_RUC[ct$MIECHV==1 & ct$MIECHV_n==0 & ct$Year!=2018])
table(ct$USDA_RUC[ct$MIECHV==1 & ct$MIECHV_n==1 & ct$Year!=2018])






prop.table(table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==0 & ct$Year!=2018])) # 0.3956835 0.3237410 0.2805755
prop.table(table(ct$USDA_RUC[ct$NHVRC==0 & ct$NHVRC_n==1 & ct$Year!=2018])) # 0.2307692 0.4871795 0.2820513 
prop.table(table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==0 & ct$Year!=2018])) # 0.2631579 0.5263158 0.2105263
prop.table(table(ct$USDA_RUC[ct$NHVRC==1 & ct$NHVRC_n==1 & ct$Year!=2018])) # 

mean(ct$RptTr[ct$USDA_RUC==1]) # 45.75657
mean(ct$RptTr[ct$USDA_RUC==2]) # 64.66686
mean(ct$RptTr[ct$USDA_RUC==3]) # 90.88126

# Post - All (2017 or 2018)
mean(ct$RptTr[ct$NHVRC_p==0 & ct$NHVRC==0 & ct$Year!=2016]) # 68.86892
mean(ct$RptTr[ct$NHVRC_p==0 & ct$NHVRC==1 & ct$Year!=2016]) # 70.18574
mean(ct$RptTr[ct$NHVRC_p==1 & ct$NHVRC==0 & ct$Year!=2016]) # 68.05537
mean(ct$RptTr[ct$NHVRC_p==1 & ct$NHVRC==1 & ct$Year!=2016]) # 60.56543






AIC1<-anova(ctm02,ctm03,ctm04,ctm041,ctm042)$AIC
BIC1<-anova(ctm02,ctm03,ctm04,ctm041,ctm042)$BIC
Table2.1<-data.table(
  Name   =c("HVW","HVW*S","HVW*R","HVB","HVB*S","HVB*R","AIC","BIC"),
  Model1 =c(fixef(ctm02)["NHVRCc_within"],NA,NA,fixef(ctm02)["NHVRCc_between"],NA,NA,AIC1[1],BIC1[1]),
  Model1L=c(ctm02CI["NHVRCc_within",1]   ,NA,NA,ctm02CI["NHVRCc_between",1]   ,NA,NA,NA,NA),
  Model1U=c(ctm02CI["NHVRCc_within",2]   ,NA,NA,ctm02CI["NHVRCc_between",2]   ,NA,NA,NA,NA),
  Model2 =c(fixef(ctm03)["NHVRCc_within"],NA,NA,fixef(ctm03)["NHVRCc_between"],NA,NA,AIC1[2],BIC1[2]),
  Model2L=c(ctm03CI["NHVRCc_within",1]   ,NA,NA,ctm03CI["NHVRCc_between",1]   ,NA,NA,NA,NA),
  Model2U=c(ctm03CI["NHVRCc_within",2]   ,NA,NA,ctm03CI["NHVRCc_between",2]   ,NA,NA,NA,NA),
  Model3 =c(fixef(ctm04)["NHVRCc_within"],NA,NA,fixef(ctm04)["NHVRCc_between"],NA,NA,AIC1[3],BIC1[3]),
  Model3L=c(ctm04CI["NHVRCc_within",1]   ,NA,NA,ctm04CI["NHVRCc_between",1]   ,NA,NA,NA,NA),
  Model3U=c(ctm04CI["NHVRCc_within",2]   ,NA,NA,ctm04CI["NHVRCc_between",2]   ,NA,NA,NA,NA),
  Model4 =c(fixef(ctm041)["NHVRCc_within"],fixef(ctm041)["USDA_RUC2:NHVRCc_within"],fixef(ctm041)["USDA_RUC3:NHVRCc_within"],fixef(ctm041)["NHVRCc_between"],NA,NA,AIC1[4],BIC1[4]),
  Model4L=c(ctm041CI["NHVRCc_within",1]   ,ctm041CI["USDA_RUC2:NHVRCc_within",1]   ,ctm041CI["USDA_RUC3:NHVRCc_within",1]   ,ctm041CI["NHVRCc_between",1]   ,NA,NA,NA,NA),
  Model4U=c(ctm041CI["NHVRCc_within",2]   ,ctm041CI["USDA_RUC2:NHVRCc_within",2]   ,ctm041CI["USDA_RUC3:NHVRCc_within",2]   ,ctm041CI["NHVRCc_between",2]   ,NA,NA,NA,NA),
  Model5 =c(fixef(ctm042)["NHVRCc_within"],NA,NA,fixef(ctm042)["NHVRCc_between"],fixef(ctm042)["USDA_RUC2:NHVRCc_between"],fixef(ctm042)["USDA_RUC3:NHVRCc_between"],AIC1[5],BIC1[5]),
  Model5L=c(ctm042CI["NHVRCc_within",1]   ,NA,NA,ctm042CI["NHVRCc_between",1]   ,ctm042CI["USDA_RUC2:NHVRCc_between",1]   ,ctm042CI["USDA_RUC3:NHVRCc_between",1]   ,NA,NA),
  Model5U=c(ctm042CI["NHVRCc_within",2]   ,NA,NA,ctm042CI["NHVRCc_between",2]   ,ctm042CI["USDA_RUC2:NHVRCc_between",2]   ,ctm042CI["USDA_RUC3:NHVRCc_between",2]   ,NA,NA)
)
Table2.1


AIC2<-anova(ctm02a,ctm03a,ctm04a,ctm041a,ctm042a)$AIC
BIC2<-anova(ctm02a,ctm03a,ctm04a,ctm041a,ctm042a)$BIC
Table2.2<-data.table(
  Name   =c("MHVW","MHVW*S","MHVW*R","MHVB","MHVB*S","MHVB*R","AIC","BIC"),
  Model1 =c(fixef(ctm02a)["MIECHVc_within"],NA,NA,fixef(ctm02a)["MIECHVc_between"],NA,NA,AIC2[1],BIC2[1]),
  Model1L=c(ctm02aCI["MIECHVc_within",1]   ,NA,NA,ctm02aCI["MIECHVc_between",1]   ,NA,NA,NA,NA),
  Model1U=c(ctm02aCI["MIECHVc_within",2]   ,NA,NA,ctm02aCI["MIECHVc_between",2]   ,NA,NA,NA,NA),
  Model2 =c(fixef(ctm03a)["MIECHVc_within"],NA,NA,fixef(ctm03a)["MIECHVc_between"],NA,NA,AIC2[2],BIC2[2]),
  Model2L=c(ctm03aCI["MIECHVc_within",1]   ,NA,NA,ctm03aCI["MIECHVc_between",1]   ,NA,NA,NA,NA),
  Model2U=c(ctm03aCI["MIECHVc_within",2]   ,NA,NA,ctm03aCI["MIECHVc_between",2]   ,NA,NA,NA,NA),
  Model3 =c(fixef(ctm04a)["MIECHVc_within"],NA,NA,fixef(ctm04a)["MIECHVc_between"],NA,NA,AIC2[3],BIC2[3]),
  Model3L=c(ctm04aCI["MIECHVc_within",1]   ,NA,NA,ctm04aCI["MIECHVc_between",1]   ,NA,NA,NA,NA),
  Model3U=c(ctm04aCI["MIECHVc_within",2]   ,NA,NA,ctm04aCI["MIECHVc_between",2]   ,NA,NA,NA,NA),
  Model4 =c(fixef(ctm041a)["MIECHVc_within"],fixef(ctm041a)["USDA_RUC2:MIECHVc_within"],fixef(ctm041a)["USDA_RUC3:MIECHVc_within"],fixef(ctm041a)["MIECHVc_between"],NA,NA,AIC2[4],BIC2[4]),
  Model4L=c(ctm041aCI["MIECHVc_within",1]   ,ctm041aCI["USDA_RUC2:MIECHVc_within",1]   ,ctm041aCI["USDA_RUC3:MIECHVc_within",1]   ,ctm041aCI["MIECHVc_between",1]   ,NA,NA,NA,NA),
  Model4U=c(ctm041aCI["MIECHVc_within",2]   ,ctm041aCI["USDA_RUC2:MIECHVc_within",2]   ,ctm041aCI["USDA_RUC3:MIECHVc_within",2]   ,ctm041aCI["MIECHVc_between",2]   ,NA,NA,NA,NA),
  Model5 =c(fixef(ctm042a)["MIECHVc_within"],NA,NA,fixef(ctm042a)["MIECHVc_between"],fixef(ctm042a)["USDA_RUC2:MIECHVc_between"],fixef(ctm042a)["USDA_RUC3:MIECHVc_between"],AIC2[5],BIC2[5]),
  Model5L=c(ctm042aCI["MIECHVc_within",1]   ,NA,NA,ctm042aCI["MIECHVc_between",1]   ,ctm042aCI["USDA_RUC2:MIECHVc_between",1]   ,ctm042aCI["USDA_RUC3:MIECHVc_between",1]   ,NA,NA),
  Model5U=c(ctm042aCI["MIECHVc_within",2]   ,NA,NA,ctm042aCI["MIECHVc_between",2]   ,ctm042aCI["USDA_RUC2:MIECHVc_between",2]   ,ctm042aCI["USDA_RUC3:MIECHVc_between",2]   ,NA,NA)
)
Table2.2





Table3.1<-data.table(
  Name=c("1_N","1_HVW","1_HVB",
         "2_N","2_HVW","2_HVB",
         "3_N","3_HVW","3_HVB",
         "M_N","M_HVW","M_HVB",
         "F_N","F_HVW","F_HVB",
         "W_N","W_HVW","W_HVB",
         "B_N","B_HVW","B_HVB",
         "H_N","H_HVW","H_HVB",
         "N_N","N_HVW","N_HVB",
         "P_N","P_HVW","P_HVB",
         "S_N","S_HVW","S_HVB"),
  Coef=c(nrow(c1),fixef(c1m04)["NHVRCc_within"],fixef(c1m04)["NHVRCc_between"],
         nrow(c2),fixef(c2m04)["NHVRCc_within"],fixef(c2m04)["NHVRCc_between"],
         nrow(c3),fixef(c3m04)["NHVRCc_within"],fixef(c3m04)["NHVRCc_between"],
         nrow(cm),fixef(cmm04)["NHVRCc_within"],fixef(cmm04)["NHVRCc_between"],
         nrow(cf),fixef(cfm04)["NHVRCc_within"],fixef(cfm04)["NHVRCc_between"],
         nrow(cw),fixef(cwm04)["NHVRCc_within"],fixef(cwm04)["NHVRCc_between"],
         nrow(cb),fixef(cbm04)["NHVRCc_within"],fixef(cbm04)["NHVRCc_between"],
         nrow(ch),fixef(chm04)["NHVRCc_within"],fixef(chm04)["NHVRCc_between"],
         nrow(cn),fixef(cnm04)["NHVRCc_within"],fixef(cnm04)["NHVRCc_between"],
         nrow(cp),fixef(cpm04)["NHVRCc_within"],fixef(cpm04)["NHVRCc_between"],
         nrow(cs),fixef(csm04)["NHVRCc_within"],fixef(csm04)["NHVRCc_between"]),
  LL  =c(length(unique(c1$CountyFIPS)),c1m04CI["NHVRCc_within",1],c1m04CI["NHVRCc_between",1],
         length(unique(c2$CountyFIPS)),c2m04CI["NHVRCc_within",1],c2m04CI["NHVRCc_between",1],
         length(unique(c3$CountyFIPS)),c3m04CI["NHVRCc_within",1],c3m04CI["NHVRCc_between",1],
         length(unique(cm$CountyFIPS)),cmm04CI["NHVRCc_within",1],cmm04CI["NHVRCc_between",1],
         length(unique(cf$CountyFIPS)),cfm04CI["NHVRCc_within",1],cfm04CI["NHVRCc_between",1],
         length(unique(cw$CountyFIPS)),cwm04CI["NHVRCc_within",1],cwm04CI["NHVRCc_between",1],
         length(unique(cb$CountyFIPS)),cbm04CI["NHVRCc_within",1],cbm04CI["NHVRCc_between",1],
         length(unique(ch$CountyFIPS)),chm04CI["NHVRCc_within",1],chm04CI["NHVRCc_between",1],
         length(unique(cn$CountyFIPS)),cnm04CI["NHVRCc_within",1],cnm04CI["NHVRCc_between",1],
         length(unique(cp$CountyFIPS)),cpm04CI["NHVRCc_within",1],cpm04CI["NHVRCc_between",1],
         length(unique(cs$CountyFIPS)),csm04CI["NHVRCc_within",1],csm04CI["NHVRCc_between",1]),
  UL  =c(length(unique(c1$StateFIPS)),c1m04CI["NHVRCc_within",2],c1m04CI["NHVRCc_between",2],
         length(unique(c2$StateFIPS)),c2m04CI["NHVRCc_within",2],c2m04CI["NHVRCc_between",2],
         length(unique(c3$StateFIPS)),c3m04CI["NHVRCc_within",2],c3m04CI["NHVRCc_between",2],
         length(unique(cm$StateFIPS)),cmm04CI["NHVRCc_within",2],cmm04CI["NHVRCc_between",2],
         length(unique(cf$StateFIPS)),cfm04CI["NHVRCc_within",2],cfm04CI["NHVRCc_between",2],
         length(unique(cw$StateFIPS)),cwm04CI["NHVRCc_within",2],cwm04CI["NHVRCc_between",2],
         length(unique(cb$StateFIPS)),cbm04CI["NHVRCc_within",2],cbm04CI["NHVRCc_between",2],
         length(unique(ch$StateFIPS)),chm04CI["NHVRCc_within",2],chm04CI["NHVRCc_between",2],
         length(unique(cn$StateFIPS)),cnm04CI["NHVRCc_within",2],cnm04CI["NHVRCc_between",2],
         length(unique(cp$StateFIPS)),cpm04CI["NHVRCc_within",2],cpm04CI["NHVRCc_between",2],
         length(unique(cs$StateFIPS)),csm04CI["NHVRCc_within",2],csm04CI["NHVRCc_between",2])
)
Table3.1

Table3.2<-data.table(
  Name=c("1_N","1_MHVW","1_MHVB",
         "2_N","2_MHVW","2_MHVB",
         "3_N","3_MHVW","3_MHVB",
         "M_N","M_MHVW","M_MHVB",
         "F_N","F_MHVW","F_MHVB",
         "W_N","W_MHVW","W_MHVB",
         "B_N","B_MHVW","B_MHVB",
         "H_N","H_MHVW","H_MHVB",
         "N_N","N_MHVW","N_MHVB",
         "P_N","P_MHVW","P_MHVB",
         "S_N","S_MHVW","S_MHVB"),
  Coef=c(nrow(c1),fixef(c1m04a)["MIECHVc_within"],fixef(c1m04a)["MIECHVc_between"],
         nrow(c2),fixef(c2m04a)["MIECHVc_within"],fixef(c2m04a)["MIECHVc_between"],
         nrow(c3),fixef(c3m04a)["MIECHVc_within"],fixef(c3m04a)["MIECHVc_between"],
         nrow(cm),fixef(cmm04a)["MIECHVc_within"],fixef(cmm04a)["MIECHVc_between"],
         nrow(cf),fixef(cfm04a)["MIECHVc_within"],fixef(cfm04a)["MIECHVc_between"],
         nrow(cw),fixef(cwm04a)["MIECHVc_within"],fixef(cwm04a)["MIECHVc_between"],
         nrow(cb),fixef(cbm04a)["MIECHVc_within"],fixef(cbm04a)["MIECHVc_between"],
         nrow(ch),fixef(chm04a)["MIECHVc_within"],fixef(chm04a)["MIECHVc_between"],
         nrow(cn),fixef(cnm04a)["MIECHVc_within"],fixef(cnm04a)["MIECHVc_between"],
         nrow(cp),fixef(cpm04a)["MIECHVc_within"],fixef(cpm04a)["MIECHVc_between"],
         nrow(cs),fixef(csm04a)["MIECHVc_within"],fixef(csm04a)["MIECHVc_between"]),
  LL  =c(length(unique(c1$CountyFIPS)),c1m04aCI["MIECHVc_within",1],c1m04aCI["MIECHVc_between",1],
         length(unique(c2$CountyFIPS)),c2m04aCI["MIECHVc_within",1],c2m04aCI["MIECHVc_between",1],
         length(unique(c3$CountyFIPS)),c3m04aCI["MIECHVc_within",1],c3m04aCI["MIECHVc_between",1],
         length(unique(cm$CountyFIPS)),cmm04aCI["MIECHVc_within",1],cmm04aCI["MIECHVc_between",1],
         length(unique(cf$CountyFIPS)),cfm04aCI["MIECHVc_within",1],cfm04aCI["MIECHVc_between",1],
         length(unique(cw$CountyFIPS)),cwm04aCI["MIECHVc_within",1],cwm04aCI["MIECHVc_between",1],
         length(unique(cb$CountyFIPS)),cbm04aCI["MIECHVc_within",1],cbm04aCI["MIECHVc_between",1],
         length(unique(ch$CountyFIPS)),chm04aCI["MIECHVc_within",1],chm04aCI["MIECHVc_between",1],
         length(unique(cn$CountyFIPS)),cnm04aCI["MIECHVc_within",1],cnm04aCI["MIECHVc_between",1],
         length(unique(cp$CountyFIPS)),cpm04aCI["MIECHVc_within",1],cpm04aCI["MIECHVc_between",1],
         length(unique(cs$CountyFIPS)),csm04aCI["MIECHVc_within",1],csm04aCI["MIECHVc_between",1]),
  UL  =c(length(unique(c1$StateFIPS)),c1m04aCI["MIECHVc_within",2],c1m04aCI["MIECHVc_between",2],
         length(unique(c2$StateFIPS)),c2m04aCI["MIECHVc_within",2],c2m04aCI["MIECHVc_between",2],
         length(unique(c3$StateFIPS)),c3m04aCI["MIECHVc_within",2],c3m04aCI["MIECHVc_between",2],
         length(unique(cm$StateFIPS)),cmm04aCI["MIECHVc_within",2],cmm04aCI["MIECHVc_between",2],
         length(unique(cf$StateFIPS)),cfm04aCI["MIECHVc_within",2],cfm04aCI["MIECHVc_between",2],
         length(unique(cw$StateFIPS)),cwm04aCI["MIECHVc_within",2],cwm04aCI["MIECHVc_between",2],
         length(unique(cb$StateFIPS)),cbm04aCI["MIECHVc_within",2],cbm04aCI["MIECHVc_between",2],
         length(unique(ch$StateFIPS)),chm04aCI["MIECHVc_within",2],chm04aCI["MIECHVc_between",2],
         length(unique(cn$StateFIPS)),cnm04aCI["MIECHVc_within",2],cnm04aCI["MIECHVc_between",2],
         length(unique(cp$StateFIPS)),cpm04aCI["MIECHVc_within",2],cpm04aCI["MIECHVc_between",2],
         length(unique(cs$StateFIPS)),csm04aCI["MIECHVc_within",2],csm04aCI["MIECHVc_between",2])
)
Table3.2

write.csv(Table1,"Z:/CDCK01/Analysis/County/HomeVisit/Table1_2.csv")
write.csv(Table2.1,"Z:/CDCK01/Analysis/County/HomeVisit/Table2.1_2.csv")
write.csv(Table2.2,"Z:/CDCK01/Analysis/County/HomeVisit/Table2.2_2.csv")
write.csv(Table3.1,"Z:/CDCK01/Analysis/County/HomeVisit/Table3.1_2.csv")
write.csv(Table3.2,"Z:/CDCK01/Analysis/County/HomeVisit/Table3.2_2.csv")



ct$NHVRC_p2<-0
ct$NHVRC_p2[ct$NHVRC_p==1]<-1

ctm04_2<-lmer(RptTr~Yearf+USDA_RUC+NHVRCc_within+NHVRCc_between+NHVRC_p2+
              IncomeT1kc_within+IncomeT1kc_between+SingleTc_within+SingleTc_between+
              CPopBPc_within+CPopBPc_between+CPopHPc_within+CPopHPc_between+FBornTc_within+FBornTc_between+
              ChildPTc_within+ChildPTc_between+DisablTc_within+DisablTc_between+MoveTc_within+MoveTc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="Nelder_Mead"))
summary(ctm04_2)


