


# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(moments)    # for skewness


# Loading Data
c<-read_sas("Z:/CDCK01/Data_County/cdck01county.sas7bdat") # N= 6153, 1011 variables
c<-data.table(c)

AY1<-as.data.table(table(c$Year));setnames(AY1,"N","Total")
AY2<-as.data.table(table(c$Year[!is.na(c$Dentist)]));setnames(AY2,"N","Dentist")
AY3<-as.data.table(table(c$Year[!is.na(c$MHPrvd)]));setnames(AY3,"N","MHPrvd")
AY4<-as.data.table(table(c$Year[!is.na(c$PCP)]));setnames(AY4,"N","PCP")
AY5<-as.data.table(table(c$Year[!is.na(c$PCP2)]));setnames(AY5,"N","PCP2")
AY6<-as.data.table(table(c$Year[!is.na(c$Mental)]));setnames(AY6,"N","Mental")
AY7<-as.data.table(table(c$Year[!is.na(c$Physical)]));setnames(AY7,"N","Physical")
AY8<-as.data.table(table(c$Year[!is.na(c$PoorMH)]));setnames(AY8,"N","PoorMH")
AY9<-as.data.table(table(c$Year[!is.na(c$PoorPhy)]));setnames(AY9,"N","PoorPhy")
AY10<-as.data.table(table(c$Year[!is.na(c$PoorHlth)]));setnames(AY10,"N","PoorHlth")


AY<-merge(AY1,AY2 ,by="V1",all=T)
AY<-merge(AY ,AY3 ,by="V1",all=T)
AY<-merge(AY ,AY4 ,by="V1",all=T)
AY<-merge(AY ,AY5 ,by="V1",all=T)
AY<-merge(AY ,AY6 ,by="V1",all=T)
AY<-merge(AY ,AY7 ,by="V1",all=T)
AY<-merge(AY ,AY8 ,by="V1",all=T)
AY<-merge(AY ,AY9 ,by="V1",all=T)
AY<-merge(AY ,AY10,by="V1",all=T)
AY

table(c$Year)


# Selecting Years Available for All Data (2014-2017)
  # Mental Distress   (2014-2017)
  # Physical Distress (2014-2017)
  # MHPrvd            (2012,2014-2018)
  # PCP               (2009,2011-2017)
c<-c[Year>2013 & Year<2018] # 2544
c$CountyFIPS[is.na(c$PCP)]
# Excluding county-years with missing PCP
c<-c[!is.na(PCP)]           # 2540
table(c$Year)

# as.integer -- for negative binomial DV and offset
c$CPopT <-as.integer(c$CPopT )
c$CPopW <-as.integer(c$CPopW )
c$CPopB <-as.integer(c$CPopB )
c$CPopH <-as.integer(c$CPopH )
c$CPopTM<-as.integer(c$CPopTM)
c$CPopTF<-as.integer(c$CPopTF)
c$CPop1 <-as.integer(c$CPop1 )
c$CPop2 <-as.integer(c$CPop2 )
c$CPop3 <-as.integer(c$CPop3 )
c$RptT  <-as.integer(c$RptT  )
c$RptW  <-as.integer(c$RptW  )
c$RptB  <-as.integer(c$RptB  )
c$RptH  <-as.integer(c$RptH  )
c$RptM  <-as.integer(c$RptM  )
c$RptF  <-as.integer(c$RptF  )
c$Rpt1  <-as.integer(c$Rpt1  )
c$Rpt2  <-as.integer(c$Rpt2  )
c$Rpt3  <-as.integer(c$Rpt3  )
c$NegT  <-as.integer(c$NegT  )
c$PhyT  <-as.integer(c$PhyT  )
c$SexT  <-as.integer(c$SexT  )
c$EmoT  <-as.integer(c$EmoT  )



# making categorical variables as.factor & scaling (roughly 0-100) continuous variables
c$PCPAll     <-c$PCP+c$PCP2
c$MH_PCP     <-c$PCP+c$PCP2+c$MHPrvd
c$Yearf      <-as.factor(c$Year)
c$NCHS_RUC   <-as.factor(c$NCHS_RUC)
c$USDA_RUC   <-as.factor(c$USDA_RUC)
c$IncomeT1k  <-c$IncomeT /1000
c$IncomeW1k  <-c$IncomeW /1000
c$IncomeB1k  <-c$IncomeB /1000
c$IncomeH1k  <-c$IncomeH /1000
c$HValueT10k <-c$HValueT /10000
c$MCostT100  <-c$MCostT  /100
c$OCostDT100 <-c$OCostDT /100
c$MRentDT100 <-c$MRentDT /100
c$CARatioT100<-c$CARatioT*100
c$CARatioW100<-c$CARatioW*100
c$CARatioB100<-c$CARatioB*100
c$CARatioH100<-c$CARatioH*100
c$MFRatioT100<-c$MFRatioT*100
c$MFRatioW100<-c$MFRatioW*100
c$MFRatioB100<-c$MFRatioB*100
c$MFRatioH100<-c$MFRatioH*100
c$OwnerT     <-c$OwnNT/c$OHUnitT*100
c$OwnerW     <-c$OwnNW/c$OHUnitW*100
c$OwnerB     <-c$OwnNB/c$OHUnitB*100
c$OwnerH     <-c$OwnNH/c$OHUnitH*100
c$GiniT100   <-c$GiniT*100
c$MHPrvd     <-c$MHPrvd/10
c$PCP        <-c$PCP/10
c$PCP2       <-c$PCP2/10

# MHPrvd: Mental health providers: # Mental Health Providers per 10k population
# PCP   : Primary care physicians: Primary care physicians in patient care per 10k population
# PCP2  : Other primary care providers: Primary care providers other than physicians 
        # (ie, nurse practitioners, physician assistants, clinical nurse specialists) per 10k population

# Creating Outcome-Specific Data
ct<-c # total
cw<-c # White
cb<-c # Black
ch<-c # Hispanic
cm<-c # Male
cf<-c # Female
c1<-c # Age 0-5
c2<-c # Age 6-11
c3<-c # Age 12-17
cn<-c # Neglect
cp<-c # Physical abuse
cs<-c # Sexual abuse
ce<-c # Emotional abuse

# Excluding Counties with Low Child Population, Missing Outcome, or Outlier
ct<-ct[CPopT >=300,] # N=2540 -> 2540
cw<-cw[CPopW >=300,] # N=2540 -> 2540
cb<-cb[CPopB >=300,] # N=2540 -> 2327
ch<-ch[CPopH >=300,] # N=2540 -> 2515
cm<-cm[CPopTM>=300,] # N=2540 -> 2540
cf<-cf[CPopTF>=300,] # N=2540 -> 2540
c1<-c1[CPop1 >=300,] # N=2540 -> 2540
c2<-c2[CPop2 >=300,] # N=2540 -> 2540
c3<-c3[CPop3 >=300,] # N=2540 -> 2540
cn<-cn[CPopT >=300,] # N=2540 -> 2540
cp<-cp[CPopT >=300,] # N=2540 -> 2540
cs<-cs[CPopT >=300,] # N=2540 -> 2540
ce<-ce[CPopT >=300,] # N=2540 -> 2540

# Excluding Counties with Missing Median Income
cb<-cb[!is.na(cb$IncomeB),] # N=2327 -> 2272
ch<-ch[!is.na(ch$IncomeH),] # N=2515 -> 2485

sum(ct$CPopT)

ct[,list(mean=mean(MHPrvd)),by=Year]
ct[,list(mean=mean(MHPrvd)),by=.(Year,USDA_RUC)]

ct[,list(mean=mean(PCP)),by=Year]
ct[,list(mean=mean(PCP)),by=.(Year,USDA_RUC)]

summary(ct$PCP_within)
summary(ct$MHPrvd_within)

mean(ct$PCP_within)
mean(ct$MHPrvd_within)

sd(ct$PCP_within)
sd(ct$MHPrvd_within)

summary(ct$PCP_between)
summary(ct$MHPrvd_between)

sd(ct$PCP_between)
sd(ct$MHPrvd_between)

mean(ct$PCP_between)
mean(ct$MHPrvd_between)



###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
# Home Visiting - Total
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Checking Sample Size
# length(ct1$CountyFIPS)
# length(ct4$CountyFIPS)
# length(unique(ct1$CountyFIPS))
# length(unique(ct4$CountyFIPS))
# sum(ct1$CPopT)
# sum(ct4$CPopT)

# Check DV Distribution
# boxplot(ct4$RptTr)
# skewness(ct4$RptTr)
# plot(density(ct4$RptTr))

# Check IV Distribution
# boxplot(ct4$CPovT)
# boxplot(ct4$IncomeT)
# boxplot(ct4$FoodInsecure)
# plot(density(ct4$CPovT))
# plot(density(ct4$IncomeT))
# plot(density(ct4$FoodInsecure))

# Longitudinal Trend
# ct4[,list(mean=mean(RptTr)),by=Year]
# ct4[,list(mean=mean(CPovT)),by=Year]
# ct4[,list(mean=mean(IncomeT1k)),by=Year]
# ct4[,list(mean=mean(FoodInsecure)),by=Year]
# ggline(ct4, x="Year", y="FoodInsecure", add=c("mean_se"))
# ggline(ct4, x="Year", y="RptTr", add=c("mean_se"))
# ggline(ct4, x="Year", y="IncomeT1k", add=c("mean_se"))
# ggline(ct4, x="Year", y="CPovT", add=c("mean_se"))
# ggplot(ct4,aes(x=Year,y=FoodInsecure,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=RptTr       ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=IncomeT1k    ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=CPovT       ,group=CountyFIPS,color=StateFIPS))+geom_line()



# Centering Variables
ct$CPopBPc      <-ct$CPopBP      -mean(ct$CPopBP      ,na.rm=T)
ct$CPopHPc      <-ct$CPopHP      -mean(ct$CPopHP      ,na.rm=T)
ct$ChildPTc     <-ct$ChildPT     -mean(ct$ChildPT     ,na.rm=T)
ct$ChildPWc     <-ct$ChildPW     -mean(ct$ChildPW     ,na.rm=T)
ct$ChildPBc     <-ct$ChildPB     -mean(ct$ChildPB     ,na.rm=T)
ct$ChildPHc     <-ct$ChildPH     -mean(ct$ChildPH     ,na.rm=T)
ct$CARatioT100c <-ct$CARatioT100 -mean(ct$CARatioT100 ,na.rm=T)
ct$CARatioW100c <-ct$CARatioW100 -mean(ct$CARatioW100 ,na.rm=T)
ct$CARatioB100c <-ct$CARatioB100 -mean(ct$CARatioB100 ,na.rm=T)
ct$CARatioH100c <-ct$CARatioH100 -mean(ct$CARatioH100 ,na.rm=T)
ct$MalePTc      <-ct$MalePT      -mean(ct$MalePT      ,na.rm=T)
ct$MalePWc      <-ct$MalePW      -mean(ct$MalePW      ,na.rm=T)
ct$MalePBc      <-ct$MalePB      -mean(ct$MalePB      ,na.rm=T)
ct$MalePHc      <-ct$MalePH      -mean(ct$MalePH      ,na.rm=T)
ct$MFRatioT100c <-ct$MFRatioT100 -mean(ct$MFRatioT100 ,na.rm=T)
ct$MFRatioW100c <-ct$MFRatioW100 -mean(ct$MFRatioW100 ,na.rm=T)
ct$MFRatioB100c <-ct$MFRatioB100 -mean(ct$MFRatioB100 ,na.rm=T)
ct$MFRatioH100c <-ct$MFRatioH100 -mean(ct$MFRatioH100 ,na.rm=T)
ct$ElderTc      <-ct$ElderT      -mean(ct$ElderT      ,na.rm=T)
ct$ElderWc      <-ct$ElderW      -mean(ct$ElderW      ,na.rm=T)
ct$ElderBc      <-ct$ElderB      -mean(ct$ElderB      ,na.rm=T)
ct$ElderHc      <-ct$ElderH      -mean(ct$ElderH      ,na.rm=T)
ct$SingleTc     <-ct$SingleT     -mean(ct$SingleT     ,na.rm=T)
ct$SingleWc     <-ct$SingleW     -mean(ct$SingleW     ,na.rm=T)
ct$SingleBc     <-ct$SingleB     -mean(ct$SingleB     ,na.rm=T)
ct$SingleHc     <-ct$SingleH     -mean(ct$SingleH     ,na.rm=T)
ct$FHeadTc      <-ct$FHeadT      -mean(ct$FHeadT      ,na.rm=T)
ct$FHeadWc      <-ct$FHeadW      -mean(ct$FHeadW      ,na.rm=T)
ct$FHeadBc      <-ct$FHeadB      -mean(ct$FHeadB      ,na.rm=T)
ct$FHeadHc      <-ct$FHeadH      -mean(ct$FHeadH      ,na.rm=T)
ct$NoHighTc     <-ct$NoHighT     -mean(ct$NoHighT     ,na.rm=T)
ct$NoHighWc     <-ct$NoHighW     -mean(ct$NoHighW     ,na.rm=T)
ct$NoHighBc     <-ct$NoHighB     -mean(ct$NoHighB     ,na.rm=T)
ct$NoHighHc     <-ct$NoHighH     -mean(ct$NoHighH     ,na.rm=T)
ct$UnempTc      <-ct$UnempT      -mean(ct$UnempT      ,na.rm=T)
ct$UnempWc      <-ct$UnempW      -mean(ct$UnempW      ,na.rm=T)
ct$UnempBc      <-ct$UnempB      -mean(ct$UnempB      ,na.rm=T)
ct$UnempHc      <-ct$UnempH      -mean(ct$UnempH      ,na.rm=T)
ct$PovTc        <-ct$PovT        -mean(ct$PovT        ,na.rm=T)
ct$CPovTc       <-ct$CPovT       -mean(ct$CPovT       ,na.rm=T)
ct$CPovWc       <-ct$CPovW       -mean(ct$CPovW       ,na.rm=T)
ct$CPovBc       <-ct$CPovB       -mean(ct$CPovB       ,na.rm=T)
ct$CPovHc       <-ct$CPovH       -mean(ct$CPovH       ,na.rm=T)
ct$CPov1c       <-ct$CPov1       -mean(ct$CPov1       ,na.rm=T)
ct$CPov2c       <-ct$CPov2       -mean(ct$CPov2       ,na.rm=T)
ct$CPov3c       <-ct$CPov3       -mean(ct$CPov3       ,na.rm=T)
ct$PubAsTc      <-ct$PubAsT      -mean(ct$PubAsT      ,na.rm=T)
ct$WelfarTc     <-ct$WelfarT     -mean(ct$WelfarT     ,na.rm=T)
ct$SnapTc       <-ct$SnapT       -mean(ct$SnapT       ,na.rm=T)
ct$SnapWc       <-ct$SnapW       -mean(ct$SnapW       ,na.rm=T)
ct$SnapBc       <-ct$SnapB       -mean(ct$SnapB       ,na.rm=T)
ct$SnapHc       <-ct$SnapH       -mean(ct$SnapH       ,na.rm=T)
ct$IncomeT1kc   <-ct$IncomeT1k   -mean(ct$IncomeT1k   ,na.rm=T)
ct$IncomeW1kc   <-ct$IncomeW1k   -mean(ct$IncomeW1k   ,na.rm=T)
ct$IncomeB1kc   <-ct$IncomeB1k   -mean(ct$IncomeB1k   ,na.rm=T)
ct$IncomeH1kc   <-ct$IncomeH1k   -mean(ct$IncomeH1k   ,na.rm=T)
ct$GiniT100c    <-ct$GiniT100    -mean(ct$GiniT100    ,na.rm=T)
ct$HValueT10kc  <-ct$HValueT10k  -mean(ct$HValueT10k  ,na.rm=T)
ct$MCostT100c   <-ct$MCostT100   -mean(ct$MCostT100   ,na.rm=T)
ct$OCostDT100c  <-ct$OCostDT100  -mean(ct$OCostDT100  ,na.rm=T)
ct$MRentDT100c  <-ct$MRentDT100  -mean(ct$MRentDT100  ,na.rm=T)
ct$OCostPTc     <-ct$OCostPT     -mean(ct$OCostPT     ,na.rm=T)
ct$MRentPTc     <-ct$MRentPT     -mean(ct$MRentPT     ,na.rm=T)
ct$MortgTc      <-ct$MortgT      -mean(ct$MortgT      ,na.rm=T)
ct$LangAPTc     <-ct$LangAPT     -mean(ct$LangAPT     ,na.rm=T)
ct$LangAPWc     <-ct$LangAPW     -mean(ct$LangAPW     ,na.rm=T)
ct$LangAPBc     <-ct$LangAPB     -mean(ct$LangAPB     ,na.rm=T)
ct$LangAPHc     <-ct$LangAPH     -mean(ct$LangAPH     ,na.rm=T)
ct$LangBPTc     <-ct$LangBPT     -mean(ct$LangBPT     ,na.rm=T)
ct$LangBPWc     <-ct$LangBPW     -mean(ct$LangBPW     ,na.rm=T)
ct$LangBPBc     <-ct$LangBPB     -mean(ct$LangBPB     ,na.rm=T)
ct$LangBPHc     <-ct$LangBPH     -mean(ct$LangBPH     ,na.rm=T)
ct$LangCPTc     <-ct$LangCPT     -mean(ct$LangCPT     ,na.rm=T)
ct$OutUsTc      <-ct$OutUsT      -mean(ct$OutUsT      ,na.rm=T)
ct$OutUsWc      <-ct$OutUsW      -mean(ct$OutUsW      ,na.rm=T)
ct$OutUsBc      <-ct$OutUsB      -mean(ct$OutUsB      ,na.rm=T)
ct$OutUsHc      <-ct$OutUsH      -mean(ct$OutUsH      ,na.rm=T)
ct$FBornTc      <-ct$FBornT      -mean(ct$FBornT      ,na.rm=T)
ct$FBornWc      <-ct$FBornW      -mean(ct$FBornW      ,na.rm=T)
ct$FBornBc      <-ct$FBornB      -mean(ct$FBornB      ,na.rm=T)
ct$FBornHc      <-ct$FBornH      -mean(ct$FBornH      ,na.rm=T)
ct$NotCtzTc     <-ct$NotCtzT     -mean(ct$NotCtzT     ,na.rm=T)
ct$NotCtzWc     <-ct$NotCtzW     -mean(ct$NotCtzW     ,na.rm=T)
ct$NotCtzBc     <-ct$NotCtzB     -mean(ct$NotCtzB     ,na.rm=T)
ct$NotCtzHc     <-ct$NotCtzH     -mean(ct$NotCtzH     ,na.rm=T)
ct$MoveTc       <-ct$MoveT       -mean(ct$MoveT       ,na.rm=T)
ct$MoveWc       <-ct$MoveW       -mean(ct$MoveW       ,na.rm=T)
ct$MoveBc       <-ct$MoveB       -mean(ct$MoveB       ,na.rm=T)
ct$MoveHc       <-ct$MoveH       -mean(ct$MoveH       ,na.rm=T)
ct$VacantTc     <-ct$VacantT     -mean(ct$VacantT     ,na.rm=T)
ct$OwnerTc      <-ct$OwnerT      -mean(ct$OwnerT      ,na.rm=T)
ct$OwnerWc      <-ct$OwnerW      -mean(ct$OwnerW      ,na.rm=T)
ct$OwnerBc      <-ct$OwnerB      -mean(ct$OwnerB      ,na.rm=T)
ct$OwnerHc      <-ct$OwnerH      -mean(ct$OwnerH      ,na.rm=T)
ct$CrowdTc      <-ct$CrowdT      -mean(ct$CrowdT      ,na.rm=T)
ct$CrowdWc      <-ct$CrowdW      -mean(ct$CrowdW      ,na.rm=T)
ct$CrowdBc      <-ct$CrowdB      -mean(ct$CrowdB      ,na.rm=T)
ct$CrowdHc      <-ct$CrowdH      -mean(ct$CrowdH      ,na.rm=T)
ct$MobileTc     <-ct$MobileT     -mean(ct$MobileT     ,na.rm=T)
ct$MobileWc     <-ct$MobileW     -mean(ct$MobileW     ,na.rm=T)
ct$MobileBc     <-ct$MobileB     -mean(ct$MobileB     ,na.rm=T)
ct$MobileHc     <-ct$MobileH     -mean(ct$MobileH     ,na.rm=T)
ct$DisablTc     <-ct$DisablT     -mean(ct$DisablT     ,na.rm=T)
ct$DisablWc     <-ct$DisablW     -mean(ct$DisablW     ,na.rm=T)
ct$DisablBc     <-ct$DisablB     -mean(ct$DisablB     ,na.rm=T)
ct$DisablHc     <-ct$DisablH     -mean(ct$DisablH     ,na.rm=T)
ct$DisablTCc    <-ct$DisablTC    -mean(ct$DisablTC    ,na.rm=T)
ct$DisablWCc    <-ct$DisablWC    -mean(ct$DisablWC    ,na.rm=T)
ct$DisablBCc    <-ct$DisablBC    -mean(ct$DisablBC    ,na.rm=T)
ct$DisablHCc    <-ct$DisablHC    -mean(ct$DisablHC    ,na.rm=T)
ct$DisablTMc    <-ct$DisablTM    -mean(ct$DisablTM    ,na.rm=T)
ct$DisablTFc    <-ct$DisablTF    -mean(ct$DisablTF    ,na.rm=T)
ct$Urban1c      <-ct$Urban1      -mean(ct$Urban1      ,na.rm=T)
ct$Urban2c      <-ct$Urban2      -mean(ct$Urban2      ,na.rm=T)
ct$LBWT1rc      <-ct$LBWT1r      -mean(ct$LBWT1r      ,na.rm=T)
ct$LBWM1rc      <-ct$LBWM1r      -mean(ct$LBWM1r      ,na.rm=T)
ct$LBWF1rc      <-ct$LBWF1r      -mean(ct$LBWF1r      ,na.rm=T)
ct$LBWW1rc      <-ct$LBWW1r      -mean(ct$LBWW1r      ,na.rm=T)
ct$LBWB1rc      <-ct$LBWB1r      -mean(ct$LBWB1r      ,na.rm=T)
ct$LBWH1rc      <-ct$LBWH1r      -mean(ct$LBWH1r      ,na.rm=T)
ct$PTBT1rc      <-ct$PTBT1r      -mean(ct$PTBT1r      ,na.rm=T)
ct$PTBM1rc      <-ct$PTBM1r      -mean(ct$PTBM1r      ,na.rm=T)
ct$PTBF1rc      <-ct$PTBF1r      -mean(ct$PTBF1r      ,na.rm=T)
ct$PTBW1rc      <-ct$PTBW1r      -mean(ct$PTBW1r      ,na.rm=T)
ct$PTBB1rc      <-ct$PTBB1r      -mean(ct$PTBB1r      ,na.rm=T)
ct$PTBH1rc      <-ct$PTBH1r      -mean(ct$PTBH1r      ,na.rm=T)
ct$PNCT1rc      <-ct$PNCT1r      -mean(ct$PNCT1r      ,na.rm=T)
ct$PNCM1rc      <-ct$PNCM1r      -mean(ct$PNCM1r      ,na.rm=T)
ct$PNCF1rc      <-ct$PNCF1r      -mean(ct$PNCF1r      ,na.rm=T)
ct$PNCW1rc      <-ct$PNCW1r      -mean(ct$PNCW1r      ,na.rm=T)
ct$PNCB1rc      <-ct$PNCB1r      -mean(ct$PNCB1r      ,na.rm=T)
ct$PNCH1rc      <-ct$PNCH1r      -mean(ct$PNCH1r      ,na.rm=T)
ct$TBBT1rc      <-ct$TBBT1r      -mean(ct$TBBT1r      ,na.rm=T)
ct$TBBM1rc      <-ct$TBBM1r      -mean(ct$TBBM1r      ,na.rm=T)
ct$TBBF1rc      <-ct$TBBF1r      -mean(ct$TBBF1r      ,na.rm=T)
ct$TBBW1rc      <-ct$TBBW1r      -mean(ct$TBBW1r      ,na.rm=T)
ct$TBBB1rc      <-ct$TBBB1r      -mean(ct$TBBB1r      ,na.rm=T)
ct$TBBH1rc      <-ct$TBBH1r      -mean(ct$TBBH1r      ,na.rm=T)
ct$TBTT1rc      <-ct$TBTT1r      -mean(ct$TBTT1r      ,na.rm=T)
ct$TBTM1rc      <-ct$TBTM1r      -mean(ct$TBTM1r      ,na.rm=T)
ct$TBTF1rc      <-ct$TBTF1r      -mean(ct$TBTF1r      ,na.rm=T)
ct$TBTW1rc      <-ct$TBTW1r      -mean(ct$TBTW1r      ,na.rm=T)
ct$TBTB1rc      <-ct$TBTB1r      -mean(ct$TBTB1r      ,na.rm=T)
ct$TBTH1rc      <-ct$TBTH1r      -mean(ct$TBTH1r      ,na.rm=T)
ct$LBWT5rc      <-ct$LBWT5r      -mean(ct$LBWT5r      ,na.rm=T)
ct$LBWM5rc      <-ct$LBWM5r      -mean(ct$LBWM5r      ,na.rm=T)
ct$LBWF5rc      <-ct$LBWF5r      -mean(ct$LBWF5r      ,na.rm=T)
ct$LBWW5rc      <-ct$LBWW5r      -mean(ct$LBWW5r      ,na.rm=T)
ct$LBWB5rc      <-ct$LBWB5r      -mean(ct$LBWB5r      ,na.rm=T)
ct$LBWH5rc      <-ct$LBWH5r      -mean(ct$LBWH5r      ,na.rm=T)
ct$PTBT5rc      <-ct$PTBT5r      -mean(ct$PTBT5r      ,na.rm=T)
ct$PTBM5rc      <-ct$PTBM5r      -mean(ct$PTBM5r      ,na.rm=T)
ct$PTBF5rc      <-ct$PTBF5r      -mean(ct$PTBF5r      ,na.rm=T)
ct$PTBW5rc      <-ct$PTBW5r      -mean(ct$PTBW5r      ,na.rm=T)
ct$PTBB5rc      <-ct$PTBB5r      -mean(ct$PTBB5r      ,na.rm=T)
ct$PTBH5rc      <-ct$PTBH5r      -mean(ct$PTBH5r      ,na.rm=T)
ct$PNCT5rc      <-ct$PNCT5r      -mean(ct$PNCT5r      ,na.rm=T)
ct$PNCM5rc      <-ct$PNCM5r      -mean(ct$PNCM5r      ,na.rm=T)
ct$PNCF5rc      <-ct$PNCF5r      -mean(ct$PNCF5r      ,na.rm=T)
ct$PNCW5rc      <-ct$PNCW5r      -mean(ct$PNCW5r      ,na.rm=T)
ct$PNCB5rc      <-ct$PNCB5r      -mean(ct$PNCB5r      ,na.rm=T)
ct$PNCH5rc      <-ct$PNCH5r      -mean(ct$PNCH5r      ,na.rm=T)
ct$TBBT5rc      <-ct$TBBT5r      -mean(ct$TBBT5r      ,na.rm=T)
ct$TBBM5rc      <-ct$TBBM5r      -mean(ct$TBBM5r      ,na.rm=T)
ct$TBBF5rc      <-ct$TBBF5r      -mean(ct$TBBF5r      ,na.rm=T)
ct$TBBW5rc      <-ct$TBBW5r      -mean(ct$TBBW5r      ,na.rm=T)
ct$TBBB5rc      <-ct$TBBB5r      -mean(ct$TBBB5r      ,na.rm=T)
ct$TBBH5rc      <-ct$TBBH5r      -mean(ct$TBBH5r      ,na.rm=T)
ct$TBTT5rc      <-ct$TBTT5r      -mean(ct$TBTT5r      ,na.rm=T)
ct$TBTM5rc      <-ct$TBTM5r      -mean(ct$TBTM5r      ,na.rm=T)
ct$TBTF5rc      <-ct$TBTF5r      -mean(ct$TBTF5r      ,na.rm=T)
ct$TBTW5rc      <-ct$TBTW5r      -mean(ct$TBTW5r      ,na.rm=T)
ct$TBTB5rc      <-ct$TBTB5r      -mean(ct$TBTB5r      ,na.rm=T)
ct$TBTH5rc      <-ct$TBTH5r      -mean(ct$TBTH5r      ,na.rm=T)
ct$Opioidc      <-ct$Opioid      -mean(ct$Opioid      ,na.rm=T)
ct$LifeExpc     <-ct$LifeExp     -mean(ct$LifeExp     ,na.rm=T)
ct$LifeExpBc    <-ct$LifeExpB    -mean(ct$LifeExpB    ,na.rm=T)
ct$LifeExpHc    <-ct$LifeExpH    -mean(ct$LifeExpH    ,na.rm=T)
ct$LifeExpWc    <-ct$LifeExpW    -mean(ct$LifeExpW    ,na.rm=T)
ct$ChdDeathc    <-ct$ChdDeath    -mean(ct$ChdDeath    ,na.rm=T)
ct$ChdDeathBc   <-ct$ChdDeathB   -mean(ct$ChdDeathB   ,na.rm=T)
ct$ChdDeathHc   <-ct$ChdDeathH   -mean(ct$ChdDeathH   ,na.rm=T)
ct$ChdDeathWc   <-ct$ChdDeathW   -mean(ct$ChdDeathW   ,na.rm=T)
ct$InfDeathc    <-ct$InfDeath    -mean(ct$InfDeath    ,na.rm=T)
ct$InfDeathBc   <-ct$InfDeathB   -mean(ct$InfDeathB   ,na.rm=T)
ct$InfDeathHc   <-ct$InfDeathH   -mean(ct$InfDeathH   ,na.rm=T)
ct$InfDeathWc   <-ct$InfDeathW   -mean(ct$InfDeathW   ,na.rm=T)
ct$Injuryc      <-ct$Injury      -mean(ct$Injury      ,na.rm=T)
ct$InjuryBc     <-ct$InjuryB     -mean(ct$InjuryB     ,na.rm=T)
ct$InjuryHc     <-ct$InjuryH     -mean(ct$InjuryH     ,na.rm=T)
ct$InjuryWc     <-ct$InjuryW     -mean(ct$InjuryW     ,na.rm=T)
ct$GunDeathc    <-ct$GunDeath    -mean(ct$GunDeath    ,na.rm=T)
ct$GunDeathBc   <-ct$GunDeathB   -mean(ct$GunDeathB   ,na.rm=T)
ct$GunDeathWc   <-ct$GunDeathW   -mean(ct$GunDeathW   ,na.rm=T)
ct$PrmDeath_c   <-ct$PrmDeath    -mean(ct$PrmDeath    ,na.rm=T)
ct$PrmDeathcc   <-ct$PrmDeathc   -mean(ct$PrmDeathc   ,na.rm=T)
ct$PrmDeathBc   <-ct$PrmDeathB   -mean(ct$PrmDeathB   ,na.rm=T)
ct$PrmDeathHc   <-ct$PrmDeathH   -mean(ct$PrmDeathH   ,na.rm=T)
ct$PrmDeathWc   <-ct$PrmDeathW   -mean(ct$PrmDeathW   ,na.rm=T)
ct$PrmDeath2_c  <-ct$PrmDeath2   -mean(ct$PrmDeath2   ,na.rm=T)
ct$PrmDeath2cc  <-ct$PrmDeath2c  -mean(ct$PrmDeath2c  ,na.rm=T)
ct$PrmDeath2Bc  <-ct$PrmDeath2B  -mean(ct$PrmDeath2B  ,na.rm=T)
ct$PrmDeath2Hc  <-ct$PrmDeath2H  -mean(ct$PrmDeath2H  ,na.rm=T)
ct$PrmDeath2Wc  <-ct$PrmDeath2W  -mean(ct$PrmDeath2W  ,na.rm=T)
ct$Suicidec     <-ct$Suicide     -mean(ct$Suicide     ,na.rm=T)
ct$Diabetc      <-ct$Diabet      -mean(ct$Diabet      ,na.rm=T)
ct$Obesityc     <-ct$Obesity     -mean(ct$Obesity     ,na.rm=T)
ct$Physicalc    <-ct$Physical    -mean(ct$Physical    ,na.rm=T)
ct$PoorHlthc    <-ct$PoorHlth    -mean(ct$PoorHlth    ,na.rm=T)
ct$PoorMHc      <-ct$PoorMH      -mean(ct$PoorMH      ,na.rm=T)
ct$PoorPhyc     <-ct$PoorPhy     -mean(ct$PoorPhy     ,na.rm=T)
ct$Sleepc       <-ct$Sleep       -mean(ct$Sleep       ,na.rm=T)
ct$DrugOdc      <-ct$DrugOd      -mean(ct$DrugOd      ,na.rm=T)
ct$DrugOdBc     <-ct$DrugOdB     -mean(ct$DrugOdB     ,na.rm=T)
ct$DrugOdHc     <-ct$DrugOdH     -mean(ct$DrugOdH     ,na.rm=T)
ct$DrugOdWc     <-ct$DrugOdW     -mean(ct$DrugOdW     ,na.rm=T)
ct$DWIDeathc    <-ct$DWIDeath    -mean(ct$DWIDeath    ,na.rm=T)
ct$EDrinkc      <-ct$EDrink      -mean(ct$EDrink      ,na.rm=T)
ct$Smokec       <-ct$Smoke       -mean(ct$Smoke       ,na.rm=T)
ct$FastFoodc    <-ct$FastFood    -mean(ct$FastFood    ,na.rm=T)
ct$FoodEnvc     <-ct$FoodEnv     -mean(ct$FoodEnv     ,na.rm=T)
ct$FoodInsc     <-ct$FoodIns     -mean(ct$FoodIns     ,na.rm=T)
ct$FrLunchc     <-ct$FrLunch     -mean(ct$FrLunch     ,na.rm=T)
ct$LAccFoodc    <-ct$LAccFood    -mean(ct$LAccFood    ,na.rm=T)
ct$Gymc         <-ct$Gym         -mean(ct$Gym         ,na.rm=T)
ct$Gym2c        <-ct$Gym2        -mean(ct$Gym2        ,na.rm=T)
ct$Inactivec    <-ct$Inactive    -mean(ct$Inactive    ,na.rm=T)
ct$HousCostc    <-ct$HousCost    -mean(ct$HousCost    ,na.rm=T)
ct$HousCostsc   <-ct$HousCosts   -mean(ct$HousCosts   ,na.rm=T)
ct$HousCrowdc   <-ct$HousCrowd   -mean(ct$HousCrowd   ,na.rm=T)
ct$Housingc     <-ct$Housing     -mean(ct$Housing     ,na.rm=T)
ct$HousPlumbc   <-ct$HousPlumb   -mean(ct$HousPlumb   ,na.rm=T)
ct$Insuredc     <-ct$Insured     -mean(ct$Insured     ,na.rm=T)
ct$InsuredAc    <-ct$InsuredA    -mean(ct$InsuredA    ,na.rm=T)
ct$InsuredCc    <-ct$InsuredC    -mean(ct$InsuredC    ,na.rm=T)
ct$JuvArrc      <-ct$JuvArr      -mean(ct$JuvArr      ,na.rm=T)
ct$Murderc      <-ct$Murder      -mean(ct$Murder      ,na.rm=T)
ct$Violentc     <-ct$Violent     -mean(ct$Violent     ,na.rm=T)
ct$LongCommc    <-ct$LongComm    -mean(ct$LongComm    ,na.rm=T)
ct$LowBWc       <-ct$LowBW       -mean(ct$LowBW       ,na.rm=T)
ct$LowBWBc      <-ct$LowBWB      -mean(ct$LowBWB      ,na.rm=T)
ct$LowBWHc      <-ct$LowBWH      -mean(ct$LowBWH      ,na.rm=T)
ct$LowBWWc      <-ct$LowBWW      -mean(ct$LowBWW      ,na.rm=T)
ct$TeenBthc     <-ct$TeenBth     -mean(ct$TeenBth     ,na.rm=T)
ct$TeenBthBc    <-ct$TeenBthB    -mean(ct$TeenBthB    ,na.rm=T)
ct$TeenBthHc    <-ct$TeenBthH    -mean(ct$TeenBthH    ,na.rm=T)
ct$TeenBthWc    <-ct$TeenBthW    -mean(ct$TeenBthW    ,na.rm=T)
ct$Mentalc      <-ct$Mental      -mean(ct$Mental      ,na.rm=T)
ct$MHPrvdc      <-ct$MHPrvd      -mean(ct$MHPrvd      ,na.rm=T)
ct$PCPc         <-ct$PCP         -mean(ct$PCP         ,na.rm=T)
ct$PCP2c        <-ct$PCP2        -mean(ct$PCP2        ,na.rm=T)
ct$Dentistc     <-ct$Dentist     -mean(ct$Dentist     ,na.rm=T)
ct$PrvtHospc    <-ct$PrvtHosp    -mean(ct$PrvtHosp    ,na.rm=T)
ct$PrvtHospBc   <-ct$PrvtHospB   -mean(ct$PrvtHospB   ,na.rm=T)
ct$PrvtHospHc   <-ct$PrvtHospH   -mean(ct$PrvtHospH   ,na.rm=T)
ct$PrvtHospWc   <-ct$PrvtHospW   -mean(ct$PrvtHospW   ,na.rm=T)
ct$SegBWc       <-ct$SegBW       -mean(ct$SegBW       ,na.rm=T)
ct$SegNWc       <-ct$SegNW       -mean(ct$SegNW       ,na.rm=T)
ct$SocAssoc     <-ct$SocAsso     -mean(ct$SocAsso     ,na.rm=T)
ct$SocSuppc     <-ct$SocSupp     -mean(ct$SocSupp     ,na.rm=T)
ct$MIECHVc      <-ct$MIECHV      -mean(ct$MIECHV      ,na.rm=T)
ct$NHVRCc       <-ct$NHVRC       -mean(ct$NHVRC       ,na.rm=T)
ct$FoodInsecurec<-ct$FoodInsecure-mean(ct$FoodInsecure,na.rm=T)
ct$PCPAllc      <-ct$PCPAll      -mean(ct$PCPAll      ,na.rm=T)
ct$MH_PCPc      <-ct$MH_PCP      -mean(ct$MH_PCP      ,na.rm=T)




# demean - within and between variables
ct<-cbind(ct,demean(ct,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "PovT","PovTc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))

cor(ct$Mental,ct$Physical)
cor(ct$MHPrvd,ct$PCP)
cor(ct$Mental,ct$MHPrvd)
cor(ct$Physical,ct$PCP)

# Modeling Building
ctm01<-lmer(RptTr~Yearf+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
# Mental Health
ctm02<-lmer(RptTr~Yearf+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm03<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm04<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
ctm05<-lmer(RptTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm06<-lmer(RptTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm07<-lmer(RptTr~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm08<-lmer(RptTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
ctm09<-lmer(RptTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm10<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm11<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm12<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm13<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
BIC(ctm04,ctm05,ctm06,ctm07,ctm08,ctm09,ctm10,ctm11,ctm12,ctm13)
summary(ctm04)
summary(ctm09)
summary(ctm10)
summary(ctm11)
summary(ctm12)
summary(ctm13)
# Physical Health
ctm22<-lmer(RptTr~Yearf+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm23<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm24<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
ctm25<-lmer(RptTr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm26<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm27<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
ctm28<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
ctm29<-lmer(RptTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=ct,control=lmerControl(optimizer="bobyqa"))
BIC(ctm22,ctm23,ctm24,ctm25,ctm26,ctm27,ctm28,ctm29)
summary(ctm24)
summary(ctm29)
# Mental Health and Physical Health - Multicollinearity Problem
ctm30<-lmer(RptTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=ct)
check_collinearity(ctm30)
# bootstrap confidence interval
ctm02CI<-confint(ctm02,method='boot',nsim=500,boot.type='perc')
ctm04CI<-confint(ctm04,method='boot',nsim=500,boot.type='perc')
ctm12CI<-confint(ctm12,method='boot',nsim=500,boot.type='perc')
ctm22CI<-confint(ctm22,method='boot',nsim=500,boot.type='perc')
ctm24CI<-confint(ctm24,method='boot',nsim=500,boot.type='perc')
ctm29CI<-confint(ctm29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(ctm12)
check_collinearity(ctm29)
isSingular(ctm12)
isSingular(ctm29)

skewness(resid(ctm12))
skewness(resid(ctm29))

summary(ctm12)
summary(ctm29)



# Negative Binomial
ctg11<-glmmTMB(RptT~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom1,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
ctg12<-glmmTMB(RptT~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom1,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
ctg21<-glmmTMB(RptT~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
ctg22<-glmmTMB(RptT~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
BIC(ctg11,ctg12,ctg21,ctg22)
ctg13<-glmmTMB(RptT~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom1,control=glmmTMBControl(optimizer=optim, optArgs=list(method="BFGS")))
ctg23<-glmmTMB(RptT~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim, optArgs=list(method="BFGS")))
BIC(ctg13,ctg23)

ctg1 <-glmmTMB(RptT~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
ctg2 <-glmmTMB(RptT~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim,optArgs=list(method="BFGS")))
ctg3 <-glmmTMB(RptT~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim, optArgs=list(method="BFGS")))
ctg4 <-glmmTMB(RptT~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS)+offset(log(CPopT)),data=ct,family=nbinom2,control=glmmTMBControl(optimizer=optim, optArgs=list(method="BFGS")))

summary(ctg1)
summary(ctg2)
summary(ctg3)
summary(ctg4)


###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
c1$CPopBPc      <-c1$CPopBP      -mean(c1$CPopBP      ,na.rm=T)
c1$CPopHPc      <-c1$CPopHP      -mean(c1$CPopHP      ,na.rm=T)
c1$ChildPTc     <-c1$ChildPT     -mean(c1$ChildPT     ,na.rm=T)
c1$ChildPWc     <-c1$ChildPW     -mean(c1$ChildPW     ,na.rm=T)
c1$ChildPBc     <-c1$ChildPB     -mean(c1$ChildPB     ,na.rm=T)
c1$ChildPHc     <-c1$ChildPH     -mean(c1$ChildPH     ,na.rm=T)
c1$CARatioT100c <-c1$CARatioT100 -mean(c1$CARatioT100 ,na.rm=T)
c1$CARatioW100c <-c1$CARatioW100 -mean(c1$CARatioW100 ,na.rm=T)
c1$CARatioB100c <-c1$CARatioB100 -mean(c1$CARatioB100 ,na.rm=T)
c1$CARatioH100c <-c1$CARatioH100 -mean(c1$CARatioH100 ,na.rm=T)
c1$MalePTc      <-c1$MalePT      -mean(c1$MalePT      ,na.rm=T)
c1$MalePWc      <-c1$MalePW      -mean(c1$MalePW      ,na.rm=T)
c1$MalePBc      <-c1$MalePB      -mean(c1$MalePB      ,na.rm=T)
c1$MalePHc      <-c1$MalePH      -mean(c1$MalePH      ,na.rm=T)
c1$MFRatioT100c <-c1$MFRatioT100 -mean(c1$MFRatioT100 ,na.rm=T)
c1$MFRatioW100c <-c1$MFRatioW100 -mean(c1$MFRatioW100 ,na.rm=T)
c1$MFRatioB100c <-c1$MFRatioB100 -mean(c1$MFRatioB100 ,na.rm=T)
c1$MFRatioH100c <-c1$MFRatioH100 -mean(c1$MFRatioH100 ,na.rm=T)
c1$ElderTc      <-c1$ElderT      -mean(c1$ElderT      ,na.rm=T)
c1$ElderWc      <-c1$ElderW      -mean(c1$ElderW      ,na.rm=T)
c1$ElderBc      <-c1$ElderB      -mean(c1$ElderB      ,na.rm=T)
c1$ElderHc      <-c1$ElderH      -mean(c1$ElderH      ,na.rm=T)
c1$SingleTc     <-c1$SingleT     -mean(c1$SingleT     ,na.rm=T)
c1$SingleWc     <-c1$SingleW     -mean(c1$SingleW     ,na.rm=T)
c1$SingleBc     <-c1$SingleB     -mean(c1$SingleB     ,na.rm=T)
c1$SingleHc     <-c1$SingleH     -mean(c1$SingleH     ,na.rm=T)
c1$FHeadTc      <-c1$FHeadT      -mean(c1$FHeadT      ,na.rm=T)
c1$FHeadWc      <-c1$FHeadW      -mean(c1$FHeadW      ,na.rm=T)
c1$FHeadBc      <-c1$FHeadB      -mean(c1$FHeadB      ,na.rm=T)
c1$FHeadHc      <-c1$FHeadH      -mean(c1$FHeadH      ,na.rm=T)
c1$NoHighTc     <-c1$NoHighT     -mean(c1$NoHighT     ,na.rm=T)
c1$NoHighWc     <-c1$NoHighW     -mean(c1$NoHighW     ,na.rm=T)
c1$NoHighBc     <-c1$NoHighB     -mean(c1$NoHighB     ,na.rm=T)
c1$NoHighHc     <-c1$NoHighH     -mean(c1$NoHighH     ,na.rm=T)
c1$UnempTc      <-c1$UnempT      -mean(c1$UnempT      ,na.rm=T)
c1$UnempWc      <-c1$UnempW      -mean(c1$UnempW      ,na.rm=T)
c1$UnempBc      <-c1$UnempB      -mean(c1$UnempB      ,na.rm=T)
c1$UnempHc      <-c1$UnempH      -mean(c1$UnempH      ,na.rm=T)
c1$CPovTc       <-c1$CPovT       -mean(c1$CPovT       ,na.rm=T)
c1$CPovWc       <-c1$CPovW       -mean(c1$CPovW       ,na.rm=T)
c1$CPovBc       <-c1$CPovB       -mean(c1$CPovB       ,na.rm=T)
c1$CPovHc       <-c1$CPovH       -mean(c1$CPovH       ,na.rm=T)
c1$CPov1c       <-c1$CPov1       -mean(c1$CPov1       ,na.rm=T)
c1$CPov2c       <-c1$CPov2       -mean(c1$CPov2       ,na.rm=T)
c1$CPov3c       <-c1$CPov3       -mean(c1$CPov3       ,na.rm=T)
c1$PubAsTc      <-c1$PubAsT      -mean(c1$PubAsT      ,na.rm=T)
c1$WelfarTc     <-c1$WelfarT     -mean(c1$WelfarT     ,na.rm=T)
c1$SnapTc       <-c1$SnapT       -mean(c1$SnapT       ,na.rm=T)
c1$SnapWc       <-c1$SnapW       -mean(c1$SnapW       ,na.rm=T)
c1$SnapBc       <-c1$SnapB       -mean(c1$SnapB       ,na.rm=T)
c1$SnapHc       <-c1$SnapH       -mean(c1$SnapH       ,na.rm=T)
c1$IncomeT1kc   <-c1$IncomeT1k   -mean(c1$IncomeT1k   ,na.rm=T)
c1$IncomeW1kc   <-c1$IncomeW1k   -mean(c1$IncomeW1k   ,na.rm=T)
c1$IncomeB1kc   <-c1$IncomeB1k   -mean(c1$IncomeB1k   ,na.rm=T)
c1$IncomeH1kc   <-c1$IncomeH1k   -mean(c1$IncomeH1k   ,na.rm=T)
c1$GiniT100c    <-c1$GiniT100    -mean(c1$GiniT100    ,na.rm=T)
c1$HValueT10kc  <-c1$HValueT10k  -mean(c1$HValueT10k  ,na.rm=T)
c1$MCostT100c   <-c1$MCostT100   -mean(c1$MCostT100   ,na.rm=T)
c1$OCostDT100c  <-c1$OCostDT100  -mean(c1$OCostDT100  ,na.rm=T)
c1$MRentDT100c  <-c1$MRentDT100  -mean(c1$MRentDT100  ,na.rm=T)
c1$OCostPTc     <-c1$OCostPT     -mean(c1$OCostPT     ,na.rm=T)
c1$MRentPTc     <-c1$MRentPT     -mean(c1$MRentPT     ,na.rm=T)
c1$MortgTc      <-c1$MortgT      -mean(c1$MortgT      ,na.rm=T)
c1$LangAPTc     <-c1$LangAPT     -mean(c1$LangAPT     ,na.rm=T)
c1$LangAPWc     <-c1$LangAPW     -mean(c1$LangAPW     ,na.rm=T)
c1$LangAPBc     <-c1$LangAPB     -mean(c1$LangAPB     ,na.rm=T)
c1$LangAPHc     <-c1$LangAPH     -mean(c1$LangAPH     ,na.rm=T)
c1$LangBPTc     <-c1$LangBPT     -mean(c1$LangBPT     ,na.rm=T)
c1$LangBPWc     <-c1$LangBPW     -mean(c1$LangBPW     ,na.rm=T)
c1$LangBPBc     <-c1$LangBPB     -mean(c1$LangBPB     ,na.rm=T)
c1$LangBPHc     <-c1$LangBPH     -mean(c1$LangBPH     ,na.rm=T)
c1$LangCPTc     <-c1$LangCPT     -mean(c1$LangCPT     ,na.rm=T)
c1$OutUsTc      <-c1$OutUsT      -mean(c1$OutUsT      ,na.rm=T)
c1$OutUsWc      <-c1$OutUsW      -mean(c1$OutUsW      ,na.rm=T)
c1$OutUsBc      <-c1$OutUsB      -mean(c1$OutUsB      ,na.rm=T)
c1$OutUsHc      <-c1$OutUsH      -mean(c1$OutUsH      ,na.rm=T)
c1$FBornTc      <-c1$FBornT      -mean(c1$FBornT      ,na.rm=T)
c1$FBornWc      <-c1$FBornW      -mean(c1$FBornW      ,na.rm=T)
c1$FBornBc      <-c1$FBornB      -mean(c1$FBornB      ,na.rm=T)
c1$FBornHc      <-c1$FBornH      -mean(c1$FBornH      ,na.rm=T)
c1$NotCtzTc     <-c1$NotCtzT     -mean(c1$NotCtzT     ,na.rm=T)
c1$NotCtzWc     <-c1$NotCtzW     -mean(c1$NotCtzW     ,na.rm=T)
c1$NotCtzBc     <-c1$NotCtzB     -mean(c1$NotCtzB     ,na.rm=T)
c1$NotCtzHc     <-c1$NotCtzH     -mean(c1$NotCtzH     ,na.rm=T)
c1$MoveTc       <-c1$MoveT       -mean(c1$MoveT       ,na.rm=T)
c1$MoveWc       <-c1$MoveW       -mean(c1$MoveW       ,na.rm=T)
c1$MoveBc       <-c1$MoveB       -mean(c1$MoveB       ,na.rm=T)
c1$MoveHc       <-c1$MoveH       -mean(c1$MoveH       ,na.rm=T)
c1$VacantTc     <-c1$VacantT     -mean(c1$VacantT     ,na.rm=T)
c1$OwnerTc      <-c1$OwnerT      -mean(c1$OwnerT      ,na.rm=T)
c1$OwnerWc      <-c1$OwnerW      -mean(c1$OwnerW      ,na.rm=T)
c1$OwnerBc      <-c1$OwnerB      -mean(c1$OwnerB      ,na.rm=T)
c1$OwnerHc      <-c1$OwnerH      -mean(c1$OwnerH      ,na.rm=T)
c1$CrowdTc      <-c1$CrowdT      -mean(c1$CrowdT      ,na.rm=T)
c1$CrowdWc      <-c1$CrowdW      -mean(c1$CrowdW      ,na.rm=T)
c1$CrowdBc      <-c1$CrowdB      -mean(c1$CrowdB      ,na.rm=T)
c1$CrowdHc      <-c1$CrowdH      -mean(c1$CrowdH      ,na.rm=T)
c1$MobileTc     <-c1$MobileT     -mean(c1$MobileT     ,na.rm=T)
c1$MobileWc     <-c1$MobileW     -mean(c1$MobileW     ,na.rm=T)
c1$MobileBc     <-c1$MobileB     -mean(c1$MobileB     ,na.rm=T)
c1$MobileHc     <-c1$MobileH     -mean(c1$MobileH     ,na.rm=T)
c1$DisablTc     <-c1$DisablT     -mean(c1$DisablT     ,na.rm=T)
c1$DisablWc     <-c1$DisablW     -mean(c1$DisablW     ,na.rm=T)
c1$DisablBc     <-c1$DisablB     -mean(c1$DisablB     ,na.rm=T)
c1$DisablHc     <-c1$DisablH     -mean(c1$DisablH     ,na.rm=T)
c1$DisablTCc    <-c1$DisablTC    -mean(c1$DisablTC    ,na.rm=T)
c1$DisablWCc    <-c1$DisablWC    -mean(c1$DisablWC    ,na.rm=T)
c1$DisablBCc    <-c1$DisablBC    -mean(c1$DisablBC    ,na.rm=T)
c1$DisablHCc    <-c1$DisablHC    -mean(c1$DisablHC    ,na.rm=T)
c1$DisablTMc    <-c1$DisablTM    -mean(c1$DisablTM    ,na.rm=T)
c1$DisablTFc    <-c1$DisablTF    -mean(c1$DisablTF    ,na.rm=T)
c1$Urban1c      <-c1$Urban1      -mean(c1$Urban1      ,na.rm=T)
c1$Urban2c      <-c1$Urban2      -mean(c1$Urban2      ,na.rm=T)
c1$LBWT1rc      <-c1$LBWT1r      -mean(c1$LBWT1r      ,na.rm=T)
c1$LBWM1rc      <-c1$LBWM1r      -mean(c1$LBWM1r      ,na.rm=T)
c1$LBWF1rc      <-c1$LBWF1r      -mean(c1$LBWF1r      ,na.rm=T)
c1$LBWW1rc      <-c1$LBWW1r      -mean(c1$LBWW1r      ,na.rm=T)
c1$LBWB1rc      <-c1$LBWB1r      -mean(c1$LBWB1r      ,na.rm=T)
c1$LBWH1rc      <-c1$LBWH1r      -mean(c1$LBWH1r      ,na.rm=T)
c1$PTBT1rc      <-c1$PTBT1r      -mean(c1$PTBT1r      ,na.rm=T)
c1$PTBM1rc      <-c1$PTBM1r      -mean(c1$PTBM1r      ,na.rm=T)
c1$PTBF1rc      <-c1$PTBF1r      -mean(c1$PTBF1r      ,na.rm=T)
c1$PTBW1rc      <-c1$PTBW1r      -mean(c1$PTBW1r      ,na.rm=T)
c1$PTBB1rc      <-c1$PTBB1r      -mean(c1$PTBB1r      ,na.rm=T)
c1$PTBH1rc      <-c1$PTBH1r      -mean(c1$PTBH1r      ,na.rm=T)
c1$PNCT1rc      <-c1$PNCT1r      -mean(c1$PNCT1r      ,na.rm=T)
c1$PNCM1rc      <-c1$PNCM1r      -mean(c1$PNCM1r      ,na.rm=T)
c1$PNCF1rc      <-c1$PNCF1r      -mean(c1$PNCF1r      ,na.rm=T)
c1$PNCW1rc      <-c1$PNCW1r      -mean(c1$PNCW1r      ,na.rm=T)
c1$PNCB1rc      <-c1$PNCB1r      -mean(c1$PNCB1r      ,na.rm=T)
c1$PNCH1rc      <-c1$PNCH1r      -mean(c1$PNCH1r      ,na.rm=T)
c1$TBBT1rc      <-c1$TBBT1r      -mean(c1$TBBT1r      ,na.rm=T)
c1$TBBM1rc      <-c1$TBBM1r      -mean(c1$TBBM1r      ,na.rm=T)
c1$TBBF1rc      <-c1$TBBF1r      -mean(c1$TBBF1r      ,na.rm=T)
c1$TBBW1rc      <-c1$TBBW1r      -mean(c1$TBBW1r      ,na.rm=T)
c1$TBBB1rc      <-c1$TBBB1r      -mean(c1$TBBB1r      ,na.rm=T)
c1$TBBH1rc      <-c1$TBBH1r      -mean(c1$TBBH1r      ,na.rm=T)
c1$TBTT1rc      <-c1$TBTT1r      -mean(c1$TBTT1r      ,na.rm=T)
c1$TBTM1rc      <-c1$TBTM1r      -mean(c1$TBTM1r      ,na.rm=T)
c1$TBTF1rc      <-c1$TBTF1r      -mean(c1$TBTF1r      ,na.rm=T)
c1$TBTW1rc      <-c1$TBTW1r      -mean(c1$TBTW1r      ,na.rm=T)
c1$TBTB1rc      <-c1$TBTB1r      -mean(c1$TBTB1r      ,na.rm=T)
c1$TBTH1rc      <-c1$TBTH1r      -mean(c1$TBTH1r      ,na.rm=T)
c1$LBWT5rc      <-c1$LBWT5r      -mean(c1$LBWT5r      ,na.rm=T)
c1$LBWM5rc      <-c1$LBWM5r      -mean(c1$LBWM5r      ,na.rm=T)
c1$LBWF5rc      <-c1$LBWF5r      -mean(c1$LBWF5r      ,na.rm=T)
c1$LBWW5rc      <-c1$LBWW5r      -mean(c1$LBWW5r      ,na.rm=T)
c1$LBWB5rc      <-c1$LBWB5r      -mean(c1$LBWB5r      ,na.rm=T)
c1$LBWH5rc      <-c1$LBWH5r      -mean(c1$LBWH5r      ,na.rm=T)
c1$PTBT5rc      <-c1$PTBT5r      -mean(c1$PTBT5r      ,na.rm=T)
c1$PTBM5rc      <-c1$PTBM5r      -mean(c1$PTBM5r      ,na.rm=T)
c1$PTBF5rc      <-c1$PTBF5r      -mean(c1$PTBF5r      ,na.rm=T)
c1$PTBW5rc      <-c1$PTBW5r      -mean(c1$PTBW5r      ,na.rm=T)
c1$PTBB5rc      <-c1$PTBB5r      -mean(c1$PTBB5r      ,na.rm=T)
c1$PTBH5rc      <-c1$PTBH5r      -mean(c1$PTBH5r      ,na.rm=T)
c1$PNCT5rc      <-c1$PNCT5r      -mean(c1$PNCT5r      ,na.rm=T)
c1$PNCM5rc      <-c1$PNCM5r      -mean(c1$PNCM5r      ,na.rm=T)
c1$PNCF5rc      <-c1$PNCF5r      -mean(c1$PNCF5r      ,na.rm=T)
c1$PNCW5rc      <-c1$PNCW5r      -mean(c1$PNCW5r      ,na.rm=T)
c1$PNCB5rc      <-c1$PNCB5r      -mean(c1$PNCB5r      ,na.rm=T)
c1$PNCH5rc      <-c1$PNCH5r      -mean(c1$PNCH5r      ,na.rm=T)
c1$TBBT5rc      <-c1$TBBT5r      -mean(c1$TBBT5r      ,na.rm=T)
c1$TBBM5rc      <-c1$TBBM5r      -mean(c1$TBBM5r      ,na.rm=T)
c1$TBBF5rc      <-c1$TBBF5r      -mean(c1$TBBF5r      ,na.rm=T)
c1$TBBW5rc      <-c1$TBBW5r      -mean(c1$TBBW5r      ,na.rm=T)
c1$TBBB5rc      <-c1$TBBB5r      -mean(c1$TBBB5r      ,na.rm=T)
c1$TBBH5rc      <-c1$TBBH5r      -mean(c1$TBBH5r      ,na.rm=T)
c1$TBTT5rc      <-c1$TBTT5r      -mean(c1$TBTT5r      ,na.rm=T)
c1$TBTM5rc      <-c1$TBTM5r      -mean(c1$TBTM5r      ,na.rm=T)
c1$TBTF5rc      <-c1$TBTF5r      -mean(c1$TBTF5r      ,na.rm=T)
c1$TBTW5rc      <-c1$TBTW5r      -mean(c1$TBTW5r      ,na.rm=T)
c1$TBTB5rc      <-c1$TBTB5r      -mean(c1$TBTB5r      ,na.rm=T)
c1$TBTH5rc      <-c1$TBTH5r      -mean(c1$TBTH5r      ,na.rm=T)
c1$Opioidc      <-c1$Opioid      -mean(c1$Opioid      ,na.rm=T)
c1$LifeExpc     <-c1$LifeExp     -mean(c1$LifeExp     ,na.rm=T)
c1$LifeExpBc    <-c1$LifeExpB    -mean(c1$LifeExpB    ,na.rm=T)
c1$LifeExpHc    <-c1$LifeExpH    -mean(c1$LifeExpH    ,na.rm=T)
c1$LifeExpWc    <-c1$LifeExpW    -mean(c1$LifeExpW    ,na.rm=T)
c1$ChdDeathc    <-c1$ChdDeath    -mean(c1$ChdDeath    ,na.rm=T)
c1$ChdDeathBc   <-c1$ChdDeathB   -mean(c1$ChdDeathB   ,na.rm=T)
c1$ChdDeathHc   <-c1$ChdDeathH   -mean(c1$ChdDeathH   ,na.rm=T)
c1$ChdDeathWc   <-c1$ChdDeathW   -mean(c1$ChdDeathW   ,na.rm=T)
c1$InfDeathc    <-c1$InfDeath    -mean(c1$InfDeath    ,na.rm=T)
c1$InfDeathBc   <-c1$InfDeathB   -mean(c1$InfDeathB   ,na.rm=T)
c1$InfDeathHc   <-c1$InfDeathH   -mean(c1$InfDeathH   ,na.rm=T)
c1$InfDeathWc   <-c1$InfDeathW   -mean(c1$InfDeathW   ,na.rm=T)
c1$Injuryc      <-c1$Injury      -mean(c1$Injury      ,na.rm=T)
c1$InjuryBc     <-c1$InjuryB     -mean(c1$InjuryB     ,na.rm=T)
c1$InjuryHc     <-c1$InjuryH     -mean(c1$InjuryH     ,na.rm=T)
c1$InjuryWc     <-c1$InjuryW     -mean(c1$InjuryW     ,na.rm=T)
c1$GunDeathc    <-c1$GunDeath    -mean(c1$GunDeath    ,na.rm=T)
c1$GunDeathBc   <-c1$GunDeathB   -mean(c1$GunDeathB   ,na.rm=T)
c1$GunDeathWc   <-c1$GunDeathW   -mean(c1$GunDeathW   ,na.rm=T)
c1$PrmDeath_c   <-c1$PrmDeath    -mean(c1$PrmDeath    ,na.rm=T)
c1$PrmDeathcc   <-c1$PrmDeathc   -mean(c1$PrmDeathc   ,na.rm=T)
c1$PrmDeathBc   <-c1$PrmDeathB   -mean(c1$PrmDeathB   ,na.rm=T)
c1$PrmDeathHc   <-c1$PrmDeathH   -mean(c1$PrmDeathH   ,na.rm=T)
c1$PrmDeathWc   <-c1$PrmDeathW   -mean(c1$PrmDeathW   ,na.rm=T)
c1$PrmDeath2_c  <-c1$PrmDeath2   -mean(c1$PrmDeath2   ,na.rm=T)
c1$PrmDeath2cc  <-c1$PrmDeath2c  -mean(c1$PrmDeath2c  ,na.rm=T)
c1$PrmDeath2Bc  <-c1$PrmDeath2B  -mean(c1$PrmDeath2B  ,na.rm=T)
c1$PrmDeath2Hc  <-c1$PrmDeath2H  -mean(c1$PrmDeath2H  ,na.rm=T)
c1$PrmDeath2Wc  <-c1$PrmDeath2W  -mean(c1$PrmDeath2W  ,na.rm=T)
c1$Suicidec     <-c1$Suicide     -mean(c1$Suicide     ,na.rm=T)
c1$Diabetc      <-c1$Diabet      -mean(c1$Diabet      ,na.rm=T)
c1$Obesityc     <-c1$Obesity     -mean(c1$Obesity     ,na.rm=T)
c1$Physicalc    <-c1$Physical    -mean(c1$Physical    ,na.rm=T)
c1$PoorHlthc    <-c1$PoorHlth    -mean(c1$PoorHlth    ,na.rm=T)
c1$PoorMHc      <-c1$PoorMH      -mean(c1$PoorMH      ,na.rm=T)
c1$PoorPhyc     <-c1$PoorPhy     -mean(c1$PoorPhy     ,na.rm=T)
c1$Sleepc       <-c1$Sleep       -mean(c1$Sleep       ,na.rm=T)
c1$DrugOdc      <-c1$DrugOd      -mean(c1$DrugOd      ,na.rm=T)
c1$DrugOdBc     <-c1$DrugOdB     -mean(c1$DrugOdB     ,na.rm=T)
c1$DrugOdHc     <-c1$DrugOdH     -mean(c1$DrugOdH     ,na.rm=T)
c1$DrugOdWc     <-c1$DrugOdW     -mean(c1$DrugOdW     ,na.rm=T)
c1$DWIDeathc    <-c1$DWIDeath    -mean(c1$DWIDeath    ,na.rm=T)
c1$EDrinkc      <-c1$EDrink      -mean(c1$EDrink      ,na.rm=T)
c1$Smokec       <-c1$Smoke       -mean(c1$Smoke       ,na.rm=T)
c1$FastFoodc    <-c1$FastFood    -mean(c1$FastFood    ,na.rm=T)
c1$FoodEnvc     <-c1$FoodEnv     -mean(c1$FoodEnv     ,na.rm=T)
c1$FoodInsc     <-c1$FoodIns     -mean(c1$FoodIns     ,na.rm=T)
c1$FrLunchc     <-c1$FrLunch     -mean(c1$FrLunch     ,na.rm=T)
c1$LAccFoodc    <-c1$LAccFood    -mean(c1$LAccFood    ,na.rm=T)
c1$Gymc         <-c1$Gym         -mean(c1$Gym         ,na.rm=T)
c1$Gym2c        <-c1$Gym2        -mean(c1$Gym2        ,na.rm=T)
c1$Inactivec    <-c1$Inactive    -mean(c1$Inactive    ,na.rm=T)
c1$HousCostc    <-c1$HousCost    -mean(c1$HousCost    ,na.rm=T)
c1$HousCostsc   <-c1$HousCosts   -mean(c1$HousCosts   ,na.rm=T)
c1$HousCrowdc   <-c1$HousCrowd   -mean(c1$HousCrowd   ,na.rm=T)
c1$Housingc     <-c1$Housing     -mean(c1$Housing     ,na.rm=T)
c1$HousPlumbc   <-c1$HousPlumb   -mean(c1$HousPlumb   ,na.rm=T)
c1$Insuredc     <-c1$Insured     -mean(c1$Insured     ,na.rm=T)
c1$InsuredAc    <-c1$InsuredA    -mean(c1$InsuredA    ,na.rm=T)
c1$InsuredCc    <-c1$InsuredC    -mean(c1$InsuredC    ,na.rm=T)
c1$JuvArrc      <-c1$JuvArr      -mean(c1$JuvArr      ,na.rm=T)
c1$Murderc      <-c1$Murder      -mean(c1$Murder      ,na.rm=T)
c1$Violentc     <-c1$Violent     -mean(c1$Violent     ,na.rm=T)
c1$LongCommc    <-c1$LongComm    -mean(c1$LongComm    ,na.rm=T)
c1$LowBWc       <-c1$LowBW       -mean(c1$LowBW       ,na.rm=T)
c1$LowBWBc      <-c1$LowBWB      -mean(c1$LowBWB      ,na.rm=T)
c1$LowBWHc      <-c1$LowBWH      -mean(c1$LowBWH      ,na.rm=T)
c1$LowBWWc      <-c1$LowBWW      -mean(c1$LowBWW      ,na.rm=T)
c1$TeenBthc     <-c1$TeenBth     -mean(c1$TeenBth     ,na.rm=T)
c1$TeenBthBc    <-c1$TeenBthB    -mean(c1$TeenBthB    ,na.rm=T)
c1$TeenBthHc    <-c1$TeenBthH    -mean(c1$TeenBthH    ,na.rm=T)
c1$TeenBthWc    <-c1$TeenBthW    -mean(c1$TeenBthW    ,na.rm=T)
c1$Mentalc      <-c1$Mental      -mean(c1$Mental      ,na.rm=T)
c1$MHPrvdc      <-c1$MHPrvd      -mean(c1$MHPrvd      ,na.rm=T)
c1$PCPc         <-c1$PCP         -mean(c1$PCP         ,na.rm=T)
c1$PCP2c        <-c1$PCP2        -mean(c1$PCP2        ,na.rm=T)
c1$Dentistc     <-c1$Dentist     -mean(c1$Dentist     ,na.rm=T)
c1$PrvtHospc    <-c1$PrvtHosp    -mean(c1$PrvtHosp    ,na.rm=T)
c1$PrvtHospBc   <-c1$PrvtHospB   -mean(c1$PrvtHospB   ,na.rm=T)
c1$PrvtHospHc   <-c1$PrvtHospH   -mean(c1$PrvtHospH   ,na.rm=T)
c1$PrvtHospWc   <-c1$PrvtHospW   -mean(c1$PrvtHospW   ,na.rm=T)
c1$SegBWc       <-c1$SegBW       -mean(c1$SegBW       ,na.rm=T)
c1$SegNWc       <-c1$SegNW       -mean(c1$SegNW       ,na.rm=T)
c1$SocAssoc     <-c1$SocAsso     -mean(c1$SocAsso     ,na.rm=T)
c1$SocSuppc     <-c1$SocSupp     -mean(c1$SocSupp     ,na.rm=T)
c1$MIECHVc      <-c1$MIECHV      -mean(c1$MIECHV      ,na.rm=T)
c1$NHVRCc       <-c1$NHVRC       -mean(c1$NHVRC       ,na.rm=T)
c1$FoodInsecurec<-c1$FoodInsecure-mean(c1$FoodInsecure,na.rm=T)
c1$PCPAllc      <-c1$PCPAll      -mean(c1$PCPAll      ,na.rm=T)
c1$MH_PCPc      <-c1$MH_PCP      -mean(c1$MH_PCP      ,na.rm=T)

c1<-cbind(c1,demean(c1,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))




# Modeling Building
c1m01<-lmer(Rpt1r~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
# Mental Health
c1m02<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m03<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m04<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
c1m05<-lmer(Rpt1r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m06<-lmer(Rpt1r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m07<-lmer(Rpt1r~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m08<-lmer(Rpt1r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
c1m09<-lmer(Rpt1r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m10<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m11<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m12<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m13<-lmer(Rpt1r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
BIC(c1m04,c1m05,c1m06,c1m07,c1m08,c1m09,c1m10,c1m11,c1m12,c1m13)
summary(c1m12)
# Physical Health
c1m22<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m23<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m24<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
c1m25<-lmer(Rpt1r~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m26<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m27<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
c1m28<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
BIC(c1m24,c1m25,c1m26,c1m27,c1m28)
summary(c1m24)
# Physical Health Random Slope
c1m29<-lmer(Rpt1r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=c1,control=lmerControl(optimizer="bobyqa"))
summary(c1m29)
# bootstrap confidence interval
c1m12CI<-confint(c1m12,method='boot',nsim=500,boot.type='perc')
c1m29CI<-confint(c1m29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c1m12)
check_collinearity(c1m29)
isSingular(c1m12)
isSingular(c1m29)

skewness(resid(c1m12))
skewness(resid(c1m29))



###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
c2$CPopBPc      <-c2$CPopBP      -mean(c2$CPopBP      ,na.rm=T)
c2$CPopHPc      <-c2$CPopHP      -mean(c2$CPopHP      ,na.rm=T)
c2$ChildPTc     <-c2$ChildPT     -mean(c2$ChildPT     ,na.rm=T)
c2$ChildPWc     <-c2$ChildPW     -mean(c2$ChildPW     ,na.rm=T)
c2$ChildPBc     <-c2$ChildPB     -mean(c2$ChildPB     ,na.rm=T)
c2$ChildPHc     <-c2$ChildPH     -mean(c2$ChildPH     ,na.rm=T)
c2$CARatioT100c <-c2$CARatioT100 -mean(c2$CARatioT100 ,na.rm=T)
c2$CARatioW100c <-c2$CARatioW100 -mean(c2$CARatioW100 ,na.rm=T)
c2$CARatioB100c <-c2$CARatioB100 -mean(c2$CARatioB100 ,na.rm=T)
c2$CARatioH100c <-c2$CARatioH100 -mean(c2$CARatioH100 ,na.rm=T)
c2$MalePTc      <-c2$MalePT      -mean(c2$MalePT      ,na.rm=T)
c2$MalePWc      <-c2$MalePW      -mean(c2$MalePW      ,na.rm=T)
c2$MalePBc      <-c2$MalePB      -mean(c2$MalePB      ,na.rm=T)
c2$MalePHc      <-c2$MalePH      -mean(c2$MalePH      ,na.rm=T)
c2$MFRatioT100c <-c2$MFRatioT100 -mean(c2$MFRatioT100 ,na.rm=T)
c2$MFRatioW100c <-c2$MFRatioW100 -mean(c2$MFRatioW100 ,na.rm=T)
c2$MFRatioB100c <-c2$MFRatioB100 -mean(c2$MFRatioB100 ,na.rm=T)
c2$MFRatioH100c <-c2$MFRatioH100 -mean(c2$MFRatioH100 ,na.rm=T)
c2$ElderTc      <-c2$ElderT      -mean(c2$ElderT      ,na.rm=T)
c2$ElderWc      <-c2$ElderW      -mean(c2$ElderW      ,na.rm=T)
c2$ElderBc      <-c2$ElderB      -mean(c2$ElderB      ,na.rm=T)
c2$ElderHc      <-c2$ElderH      -mean(c2$ElderH      ,na.rm=T)
c2$SingleTc     <-c2$SingleT     -mean(c2$SingleT     ,na.rm=T)
c2$SingleWc     <-c2$SingleW     -mean(c2$SingleW     ,na.rm=T)
c2$SingleBc     <-c2$SingleB     -mean(c2$SingleB     ,na.rm=T)
c2$SingleHc     <-c2$SingleH     -mean(c2$SingleH     ,na.rm=T)
c2$FHeadTc      <-c2$FHeadT      -mean(c2$FHeadT      ,na.rm=T)
c2$FHeadWc      <-c2$FHeadW      -mean(c2$FHeadW      ,na.rm=T)
c2$FHeadBc      <-c2$FHeadB      -mean(c2$FHeadB      ,na.rm=T)
c2$FHeadHc      <-c2$FHeadH      -mean(c2$FHeadH      ,na.rm=T)
c2$NoHighTc     <-c2$NoHighT     -mean(c2$NoHighT     ,na.rm=T)
c2$NoHighWc     <-c2$NoHighW     -mean(c2$NoHighW     ,na.rm=T)
c2$NoHighBc     <-c2$NoHighB     -mean(c2$NoHighB     ,na.rm=T)
c2$NoHighHc     <-c2$NoHighH     -mean(c2$NoHighH     ,na.rm=T)
c2$UnempTc      <-c2$UnempT      -mean(c2$UnempT      ,na.rm=T)
c2$UnempWc      <-c2$UnempW      -mean(c2$UnempW      ,na.rm=T)
c2$UnempBc      <-c2$UnempB      -mean(c2$UnempB      ,na.rm=T)
c2$UnempHc      <-c2$UnempH      -mean(c2$UnempH      ,na.rm=T)
c2$CPovTc       <-c2$CPovT       -mean(c2$CPovT       ,na.rm=T)
c2$CPovWc       <-c2$CPovW       -mean(c2$CPovW       ,na.rm=T)
c2$CPovBc       <-c2$CPovB       -mean(c2$CPovB       ,na.rm=T)
c2$CPovHc       <-c2$CPovH       -mean(c2$CPovH       ,na.rm=T)
c2$CPov1c       <-c2$CPov1       -mean(c2$CPov1       ,na.rm=T)
c2$CPov2c       <-c2$CPov2       -mean(c2$CPov2       ,na.rm=T)
c2$CPov3c       <-c2$CPov3       -mean(c2$CPov3       ,na.rm=T)
c2$PubAsTc      <-c2$PubAsT      -mean(c2$PubAsT      ,na.rm=T)
c2$WelfarTc     <-c2$WelfarT     -mean(c2$WelfarT     ,na.rm=T)
c2$SnapTc       <-c2$SnapT       -mean(c2$SnapT       ,na.rm=T)
c2$SnapWc       <-c2$SnapW       -mean(c2$SnapW       ,na.rm=T)
c2$SnapBc       <-c2$SnapB       -mean(c2$SnapB       ,na.rm=T)
c2$SnapHc       <-c2$SnapH       -mean(c2$SnapH       ,na.rm=T)
c2$IncomeT1kc   <-c2$IncomeT1k   -mean(c2$IncomeT1k   ,na.rm=T)
c2$IncomeW1kc   <-c2$IncomeW1k   -mean(c2$IncomeW1k   ,na.rm=T)
c2$IncomeB1kc   <-c2$IncomeB1k   -mean(c2$IncomeB1k   ,na.rm=T)
c2$IncomeH1kc   <-c2$IncomeH1k   -mean(c2$IncomeH1k   ,na.rm=T)
c2$GiniT100c    <-c2$GiniT100    -mean(c2$GiniT100    ,na.rm=T)
c2$HValueT10kc  <-c2$HValueT10k  -mean(c2$HValueT10k  ,na.rm=T)
c2$MCostT100c   <-c2$MCostT100   -mean(c2$MCostT100   ,na.rm=T)
c2$OCostDT100c  <-c2$OCostDT100  -mean(c2$OCostDT100  ,na.rm=T)
c2$MRentDT100c  <-c2$MRentDT100  -mean(c2$MRentDT100  ,na.rm=T)
c2$OCostPTc     <-c2$OCostPT     -mean(c2$OCostPT     ,na.rm=T)
c2$MRentPTc     <-c2$MRentPT     -mean(c2$MRentPT     ,na.rm=T)
c2$MortgTc      <-c2$MortgT      -mean(c2$MortgT      ,na.rm=T)
c2$LangAPTc     <-c2$LangAPT     -mean(c2$LangAPT     ,na.rm=T)
c2$LangAPWc     <-c2$LangAPW     -mean(c2$LangAPW     ,na.rm=T)
c2$LangAPBc     <-c2$LangAPB     -mean(c2$LangAPB     ,na.rm=T)
c2$LangAPHc     <-c2$LangAPH     -mean(c2$LangAPH     ,na.rm=T)
c2$LangBPTc     <-c2$LangBPT     -mean(c2$LangBPT     ,na.rm=T)
c2$LangBPWc     <-c2$LangBPW     -mean(c2$LangBPW     ,na.rm=T)
c2$LangBPBc     <-c2$LangBPB     -mean(c2$LangBPB     ,na.rm=T)
c2$LangBPHc     <-c2$LangBPH     -mean(c2$LangBPH     ,na.rm=T)
c2$LangCPTc     <-c2$LangCPT     -mean(c2$LangCPT     ,na.rm=T)
c2$OutUsTc      <-c2$OutUsT      -mean(c2$OutUsT      ,na.rm=T)
c2$OutUsWc      <-c2$OutUsW      -mean(c2$OutUsW      ,na.rm=T)
c2$OutUsBc      <-c2$OutUsB      -mean(c2$OutUsB      ,na.rm=T)
c2$OutUsHc      <-c2$OutUsH      -mean(c2$OutUsH      ,na.rm=T)
c2$FBornTc      <-c2$FBornT      -mean(c2$FBornT      ,na.rm=T)
c2$FBornWc      <-c2$FBornW      -mean(c2$FBornW      ,na.rm=T)
c2$FBornBc      <-c2$FBornB      -mean(c2$FBornB      ,na.rm=T)
c2$FBornHc      <-c2$FBornH      -mean(c2$FBornH      ,na.rm=T)
c2$NotCtzTc     <-c2$NotCtzT     -mean(c2$NotCtzT     ,na.rm=T)
c2$NotCtzWc     <-c2$NotCtzW     -mean(c2$NotCtzW     ,na.rm=T)
c2$NotCtzBc     <-c2$NotCtzB     -mean(c2$NotCtzB     ,na.rm=T)
c2$NotCtzHc     <-c2$NotCtzH     -mean(c2$NotCtzH     ,na.rm=T)
c2$MoveTc       <-c2$MoveT       -mean(c2$MoveT       ,na.rm=T)
c2$MoveWc       <-c2$MoveW       -mean(c2$MoveW       ,na.rm=T)
c2$MoveBc       <-c2$MoveB       -mean(c2$MoveB       ,na.rm=T)
c2$MoveHc       <-c2$MoveH       -mean(c2$MoveH       ,na.rm=T)
c2$VacantTc     <-c2$VacantT     -mean(c2$VacantT     ,na.rm=T)
c2$OwnerTc      <-c2$OwnerT      -mean(c2$OwnerT      ,na.rm=T)
c2$OwnerWc      <-c2$OwnerW      -mean(c2$OwnerW      ,na.rm=T)
c2$OwnerBc      <-c2$OwnerB      -mean(c2$OwnerB      ,na.rm=T)
c2$OwnerHc      <-c2$OwnerH      -mean(c2$OwnerH      ,na.rm=T)
c2$CrowdTc      <-c2$CrowdT      -mean(c2$CrowdT      ,na.rm=T)
c2$CrowdWc      <-c2$CrowdW      -mean(c2$CrowdW      ,na.rm=T)
c2$CrowdBc      <-c2$CrowdB      -mean(c2$CrowdB      ,na.rm=T)
c2$CrowdHc      <-c2$CrowdH      -mean(c2$CrowdH      ,na.rm=T)
c2$MobileTc     <-c2$MobileT     -mean(c2$MobileT     ,na.rm=T)
c2$MobileWc     <-c2$MobileW     -mean(c2$MobileW     ,na.rm=T)
c2$MobileBc     <-c2$MobileB     -mean(c2$MobileB     ,na.rm=T)
c2$MobileHc     <-c2$MobileH     -mean(c2$MobileH     ,na.rm=T)
c2$DisablTc     <-c2$DisablT     -mean(c2$DisablT     ,na.rm=T)
c2$DisablWc     <-c2$DisablW     -mean(c2$DisablW     ,na.rm=T)
c2$DisablBc     <-c2$DisablB     -mean(c2$DisablB     ,na.rm=T)
c2$DisablHc     <-c2$DisablH     -mean(c2$DisablH     ,na.rm=T)
c2$DisablTCc    <-c2$DisablTC    -mean(c2$DisablTC    ,na.rm=T)
c2$DisablWCc    <-c2$DisablWC    -mean(c2$DisablWC    ,na.rm=T)
c2$DisablBCc    <-c2$DisablBC    -mean(c2$DisablBC    ,na.rm=T)
c2$DisablHCc    <-c2$DisablHC    -mean(c2$DisablHC    ,na.rm=T)
c2$DisablTMc    <-c2$DisablTM    -mean(c2$DisablTM    ,na.rm=T)
c2$DisablTFc    <-c2$DisablTF    -mean(c2$DisablTF    ,na.rm=T)
c2$Urban1c      <-c2$Urban1      -mean(c2$Urban1      ,na.rm=T)
c2$Urban2c      <-c2$Urban2      -mean(c2$Urban2      ,na.rm=T)
c2$LBWT1rc      <-c2$LBWT1r      -mean(c2$LBWT1r      ,na.rm=T)
c2$LBWM1rc      <-c2$LBWM1r      -mean(c2$LBWM1r      ,na.rm=T)
c2$LBWF1rc      <-c2$LBWF1r      -mean(c2$LBWF1r      ,na.rm=T)
c2$LBWW1rc      <-c2$LBWW1r      -mean(c2$LBWW1r      ,na.rm=T)
c2$LBWB1rc      <-c2$LBWB1r      -mean(c2$LBWB1r      ,na.rm=T)
c2$LBWH1rc      <-c2$LBWH1r      -mean(c2$LBWH1r      ,na.rm=T)
c2$PTBT1rc      <-c2$PTBT1r      -mean(c2$PTBT1r      ,na.rm=T)
c2$PTBM1rc      <-c2$PTBM1r      -mean(c2$PTBM1r      ,na.rm=T)
c2$PTBF1rc      <-c2$PTBF1r      -mean(c2$PTBF1r      ,na.rm=T)
c2$PTBW1rc      <-c2$PTBW1r      -mean(c2$PTBW1r      ,na.rm=T)
c2$PTBB1rc      <-c2$PTBB1r      -mean(c2$PTBB1r      ,na.rm=T)
c2$PTBH1rc      <-c2$PTBH1r      -mean(c2$PTBH1r      ,na.rm=T)
c2$PNCT1rc      <-c2$PNCT1r      -mean(c2$PNCT1r      ,na.rm=T)
c2$PNCM1rc      <-c2$PNCM1r      -mean(c2$PNCM1r      ,na.rm=T)
c2$PNCF1rc      <-c2$PNCF1r      -mean(c2$PNCF1r      ,na.rm=T)
c2$PNCW1rc      <-c2$PNCW1r      -mean(c2$PNCW1r      ,na.rm=T)
c2$PNCB1rc      <-c2$PNCB1r      -mean(c2$PNCB1r      ,na.rm=T)
c2$PNCH1rc      <-c2$PNCH1r      -mean(c2$PNCH1r      ,na.rm=T)
c2$TBBT1rc      <-c2$TBBT1r      -mean(c2$TBBT1r      ,na.rm=T)
c2$TBBM1rc      <-c2$TBBM1r      -mean(c2$TBBM1r      ,na.rm=T)
c2$TBBF1rc      <-c2$TBBF1r      -mean(c2$TBBF1r      ,na.rm=T)
c2$TBBW1rc      <-c2$TBBW1r      -mean(c2$TBBW1r      ,na.rm=T)
c2$TBBB1rc      <-c2$TBBB1r      -mean(c2$TBBB1r      ,na.rm=T)
c2$TBBH1rc      <-c2$TBBH1r      -mean(c2$TBBH1r      ,na.rm=T)
c2$TBTT1rc      <-c2$TBTT1r      -mean(c2$TBTT1r      ,na.rm=T)
c2$TBTM1rc      <-c2$TBTM1r      -mean(c2$TBTM1r      ,na.rm=T)
c2$TBTF1rc      <-c2$TBTF1r      -mean(c2$TBTF1r      ,na.rm=T)
c2$TBTW1rc      <-c2$TBTW1r      -mean(c2$TBTW1r      ,na.rm=T)
c2$TBTB1rc      <-c2$TBTB1r      -mean(c2$TBTB1r      ,na.rm=T)
c2$TBTH1rc      <-c2$TBTH1r      -mean(c2$TBTH1r      ,na.rm=T)
c2$LBWT5rc      <-c2$LBWT5r      -mean(c2$LBWT5r      ,na.rm=T)
c2$LBWM5rc      <-c2$LBWM5r      -mean(c2$LBWM5r      ,na.rm=T)
c2$LBWF5rc      <-c2$LBWF5r      -mean(c2$LBWF5r      ,na.rm=T)
c2$LBWW5rc      <-c2$LBWW5r      -mean(c2$LBWW5r      ,na.rm=T)
c2$LBWB5rc      <-c2$LBWB5r      -mean(c2$LBWB5r      ,na.rm=T)
c2$LBWH5rc      <-c2$LBWH5r      -mean(c2$LBWH5r      ,na.rm=T)
c2$PTBT5rc      <-c2$PTBT5r      -mean(c2$PTBT5r      ,na.rm=T)
c2$PTBM5rc      <-c2$PTBM5r      -mean(c2$PTBM5r      ,na.rm=T)
c2$PTBF5rc      <-c2$PTBF5r      -mean(c2$PTBF5r      ,na.rm=T)
c2$PTBW5rc      <-c2$PTBW5r      -mean(c2$PTBW5r      ,na.rm=T)
c2$PTBB5rc      <-c2$PTBB5r      -mean(c2$PTBB5r      ,na.rm=T)
c2$PTBH5rc      <-c2$PTBH5r      -mean(c2$PTBH5r      ,na.rm=T)
c2$PNCT5rc      <-c2$PNCT5r      -mean(c2$PNCT5r      ,na.rm=T)
c2$PNCM5rc      <-c2$PNCM5r      -mean(c2$PNCM5r      ,na.rm=T)
c2$PNCF5rc      <-c2$PNCF5r      -mean(c2$PNCF5r      ,na.rm=T)
c2$PNCW5rc      <-c2$PNCW5r      -mean(c2$PNCW5r      ,na.rm=T)
c2$PNCB5rc      <-c2$PNCB5r      -mean(c2$PNCB5r      ,na.rm=T)
c2$PNCH5rc      <-c2$PNCH5r      -mean(c2$PNCH5r      ,na.rm=T)
c2$TBBT5rc      <-c2$TBBT5r      -mean(c2$TBBT5r      ,na.rm=T)
c2$TBBM5rc      <-c2$TBBM5r      -mean(c2$TBBM5r      ,na.rm=T)
c2$TBBF5rc      <-c2$TBBF5r      -mean(c2$TBBF5r      ,na.rm=T)
c2$TBBW5rc      <-c2$TBBW5r      -mean(c2$TBBW5r      ,na.rm=T)
c2$TBBB5rc      <-c2$TBBB5r      -mean(c2$TBBB5r      ,na.rm=T)
c2$TBBH5rc      <-c2$TBBH5r      -mean(c2$TBBH5r      ,na.rm=T)
c2$TBTT5rc      <-c2$TBTT5r      -mean(c2$TBTT5r      ,na.rm=T)
c2$TBTM5rc      <-c2$TBTM5r      -mean(c2$TBTM5r      ,na.rm=T)
c2$TBTF5rc      <-c2$TBTF5r      -mean(c2$TBTF5r      ,na.rm=T)
c2$TBTW5rc      <-c2$TBTW5r      -mean(c2$TBTW5r      ,na.rm=T)
c2$TBTB5rc      <-c2$TBTB5r      -mean(c2$TBTB5r      ,na.rm=T)
c2$TBTH5rc      <-c2$TBTH5r      -mean(c2$TBTH5r      ,na.rm=T)
c2$Opioidc      <-c2$Opioid      -mean(c2$Opioid      ,na.rm=T)
c2$LifeExpc     <-c2$LifeExp     -mean(c2$LifeExp     ,na.rm=T)
c2$LifeExpBc    <-c2$LifeExpB    -mean(c2$LifeExpB    ,na.rm=T)
c2$LifeExpHc    <-c2$LifeExpH    -mean(c2$LifeExpH    ,na.rm=T)
c2$LifeExpWc    <-c2$LifeExpW    -mean(c2$LifeExpW    ,na.rm=T)
c2$ChdDeathc    <-c2$ChdDeath    -mean(c2$ChdDeath    ,na.rm=T)
c2$ChdDeathBc   <-c2$ChdDeathB   -mean(c2$ChdDeathB   ,na.rm=T)
c2$ChdDeathHc   <-c2$ChdDeathH   -mean(c2$ChdDeathH   ,na.rm=T)
c2$ChdDeathWc   <-c2$ChdDeathW   -mean(c2$ChdDeathW   ,na.rm=T)
c2$InfDeathc    <-c2$InfDeath    -mean(c2$InfDeath    ,na.rm=T)
c2$InfDeathBc   <-c2$InfDeathB   -mean(c2$InfDeathB   ,na.rm=T)
c2$InfDeathHc   <-c2$InfDeathH   -mean(c2$InfDeathH   ,na.rm=T)
c2$InfDeathWc   <-c2$InfDeathW   -mean(c2$InfDeathW   ,na.rm=T)
c2$Injuryc      <-c2$Injury      -mean(c2$Injury      ,na.rm=T)
c2$InjuryBc     <-c2$InjuryB     -mean(c2$InjuryB     ,na.rm=T)
c2$InjuryHc     <-c2$InjuryH     -mean(c2$InjuryH     ,na.rm=T)
c2$InjuryWc     <-c2$InjuryW     -mean(c2$InjuryW     ,na.rm=T)
c2$GunDeathc    <-c2$GunDeath    -mean(c2$GunDeath    ,na.rm=T)
c2$GunDeathBc   <-c2$GunDeathB   -mean(c2$GunDeathB   ,na.rm=T)
c2$GunDeathWc   <-c2$GunDeathW   -mean(c2$GunDeathW   ,na.rm=T)
c2$PrmDeath_c   <-c2$PrmDeath    -mean(c2$PrmDeath    ,na.rm=T)
c2$PrmDeathcc   <-c2$PrmDeathc   -mean(c2$PrmDeathc   ,na.rm=T)
c2$PrmDeathBc   <-c2$PrmDeathB   -mean(c2$PrmDeathB   ,na.rm=T)
c2$PrmDeathHc   <-c2$PrmDeathH   -mean(c2$PrmDeathH   ,na.rm=T)
c2$PrmDeathWc   <-c2$PrmDeathW   -mean(c2$PrmDeathW   ,na.rm=T)
c2$PrmDeath2_c  <-c2$PrmDeath2   -mean(c2$PrmDeath2   ,na.rm=T)
c2$PrmDeath2cc  <-c2$PrmDeath2c  -mean(c2$PrmDeath2c  ,na.rm=T)
c2$PrmDeath2Bc  <-c2$PrmDeath2B  -mean(c2$PrmDeath2B  ,na.rm=T)
c2$PrmDeath2Hc  <-c2$PrmDeath2H  -mean(c2$PrmDeath2H  ,na.rm=T)
c2$PrmDeath2Wc  <-c2$PrmDeath2W  -mean(c2$PrmDeath2W  ,na.rm=T)
c2$Suicidec     <-c2$Suicide     -mean(c2$Suicide     ,na.rm=T)
c2$Diabetc      <-c2$Diabet      -mean(c2$Diabet      ,na.rm=T)
c2$Obesityc     <-c2$Obesity     -mean(c2$Obesity     ,na.rm=T)
c2$Physicalc    <-c2$Physical    -mean(c2$Physical    ,na.rm=T)
c2$PoorHlthc    <-c2$PoorHlth    -mean(c2$PoorHlth    ,na.rm=T)
c2$PoorMHc      <-c2$PoorMH      -mean(c2$PoorMH      ,na.rm=T)
c2$PoorPhyc     <-c2$PoorPhy     -mean(c2$PoorPhy     ,na.rm=T)
c2$Sleepc       <-c2$Sleep       -mean(c2$Sleep       ,na.rm=T)
c2$DrugOdc      <-c2$DrugOd      -mean(c2$DrugOd      ,na.rm=T)
c2$DrugOdBc     <-c2$DrugOdB     -mean(c2$DrugOdB     ,na.rm=T)
c2$DrugOdHc     <-c2$DrugOdH     -mean(c2$DrugOdH     ,na.rm=T)
c2$DrugOdWc     <-c2$DrugOdW     -mean(c2$DrugOdW     ,na.rm=T)
c2$DWIDeathc    <-c2$DWIDeath    -mean(c2$DWIDeath    ,na.rm=T)
c2$EDrinkc      <-c2$EDrink      -mean(c2$EDrink      ,na.rm=T)
c2$Smokec       <-c2$Smoke       -mean(c2$Smoke       ,na.rm=T)
c2$FastFoodc    <-c2$FastFood    -mean(c2$FastFood    ,na.rm=T)
c2$FoodEnvc     <-c2$FoodEnv     -mean(c2$FoodEnv     ,na.rm=T)
c2$FoodInsc     <-c2$FoodIns     -mean(c2$FoodIns     ,na.rm=T)
c2$FrLunchc     <-c2$FrLunch     -mean(c2$FrLunch     ,na.rm=T)
c2$LAccFoodc    <-c2$LAccFood    -mean(c2$LAccFood    ,na.rm=T)
c2$Gymc         <-c2$Gym         -mean(c2$Gym         ,na.rm=T)
c2$Gym2c        <-c2$Gym2        -mean(c2$Gym2        ,na.rm=T)
c2$Inactivec    <-c2$Inactive    -mean(c2$Inactive    ,na.rm=T)
c2$HousCostc    <-c2$HousCost    -mean(c2$HousCost    ,na.rm=T)
c2$HousCostsc   <-c2$HousCosts   -mean(c2$HousCosts   ,na.rm=T)
c2$HousCrowdc   <-c2$HousCrowd   -mean(c2$HousCrowd   ,na.rm=T)
c2$Housingc     <-c2$Housing     -mean(c2$Housing     ,na.rm=T)
c2$HousPlumbc   <-c2$HousPlumb   -mean(c2$HousPlumb   ,na.rm=T)
c2$Insuredc     <-c2$Insured     -mean(c2$Insured     ,na.rm=T)
c2$InsuredAc    <-c2$InsuredA    -mean(c2$InsuredA    ,na.rm=T)
c2$InsuredCc    <-c2$InsuredC    -mean(c2$InsuredC    ,na.rm=T)
c2$JuvArrc      <-c2$JuvArr      -mean(c2$JuvArr      ,na.rm=T)
c2$Murderc      <-c2$Murder      -mean(c2$Murder      ,na.rm=T)
c2$Violentc     <-c2$Violent     -mean(c2$Violent     ,na.rm=T)
c2$LongCommc    <-c2$LongComm    -mean(c2$LongComm    ,na.rm=T)
c2$LowBWc       <-c2$LowBW       -mean(c2$LowBW       ,na.rm=T)
c2$LowBWBc      <-c2$LowBWB      -mean(c2$LowBWB      ,na.rm=T)
c2$LowBWHc      <-c2$LowBWH      -mean(c2$LowBWH      ,na.rm=T)
c2$LowBWWc      <-c2$LowBWW      -mean(c2$LowBWW      ,na.rm=T)
c2$TeenBthc     <-c2$TeenBth     -mean(c2$TeenBth     ,na.rm=T)
c2$TeenBthBc    <-c2$TeenBthB    -mean(c2$TeenBthB    ,na.rm=T)
c2$TeenBthHc    <-c2$TeenBthH    -mean(c2$TeenBthH    ,na.rm=T)
c2$TeenBthWc    <-c2$TeenBthW    -mean(c2$TeenBthW    ,na.rm=T)
c2$Mentalc      <-c2$Mental      -mean(c2$Mental      ,na.rm=T)
c2$MHPrvdc      <-c2$MHPrvd      -mean(c2$MHPrvd      ,na.rm=T)
c2$PCPc         <-c2$PCP         -mean(c2$PCP         ,na.rm=T)
c2$PCP2c        <-c2$PCP2        -mean(c2$PCP2        ,na.rm=T)
c2$Dentistc     <-c2$Dentist     -mean(c2$Dentist     ,na.rm=T)
c2$PrvtHospc    <-c2$PrvtHosp    -mean(c2$PrvtHosp    ,na.rm=T)
c2$PrvtHospBc   <-c2$PrvtHospB   -mean(c2$PrvtHospB   ,na.rm=T)
c2$PrvtHospHc   <-c2$PrvtHospH   -mean(c2$PrvtHospH   ,na.rm=T)
c2$PrvtHospWc   <-c2$PrvtHospW   -mean(c2$PrvtHospW   ,na.rm=T)
c2$SegBWc       <-c2$SegBW       -mean(c2$SegBW       ,na.rm=T)
c2$SegNWc       <-c2$SegNW       -mean(c2$SegNW       ,na.rm=T)
c2$SocAssoc     <-c2$SocAsso     -mean(c2$SocAsso     ,na.rm=T)
c2$SocSuppc     <-c2$SocSupp     -mean(c2$SocSupp     ,na.rm=T)
c2$MIECHVc      <-c2$MIECHV      -mean(c2$MIECHV      ,na.rm=T)
c2$NHVRCc       <-c2$NHVRC       -mean(c2$NHVRC       ,na.rm=T)
c2$FoodInsecurec<-c2$FoodInsecure-mean(c2$FoodInsecure,na.rm=T)
c2$PCPAllc      <-c2$PCPAll      -mean(c2$PCPAll      ,na.rm=T)
c2$MH_PCPc      <-c2$MH_PCP      -mean(c2$MH_PCP      ,na.rm=T)

c2<-cbind(c2,demean(c2,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
c2m01<-lmer(Rpt2r~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
# Mental Health
c2m02<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m03<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m04<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
c2m05<-lmer(Rpt2r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m06<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m07<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m08<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
c2m09<-lmer(Rpt2r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m10<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m11<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m12<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m13<-lmer(Rpt2r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
BIC(c2m04,c2m05,c2m06,c2m07,c2m08,c2m09,c2m10,c2m11,c2m12,c2m13)
summary(c2m12)
# Physical Health
c2m22<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m23<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m24<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
c2m25<-lmer(Rpt2r~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m26<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m27<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
c2m28<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
c2m29<-lmer(Rpt2r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=c2,control=lmerControl(optimizer="bobyqa"))
BIC(c2m24,c2m25,c2m26,c2m27,c2m28,c2m29)
summary(c2m29)
# bootstrap confidence interval
c2m12CI<-confint(c2m12,method='boot',nsim=500,boot.type='perc')
c2m29CI<-confint(c2m29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c2m12)
check_collinearity(c2m29)
isSingular(c2m12)
isSingular(c2m29)

skewness(resid(c2m12))
skewness(resid(c2m29))




###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
c3$CPopBPc      <-c3$CPopBP      -mean(c3$CPopBP      ,na.rm=T)
c3$CPopHPc      <-c3$CPopHP      -mean(c3$CPopHP      ,na.rm=T)
c3$ChildPTc     <-c3$ChildPT     -mean(c3$ChildPT     ,na.rm=T)
c3$ChildPWc     <-c3$ChildPW     -mean(c3$ChildPW     ,na.rm=T)
c3$ChildPBc     <-c3$ChildPB     -mean(c3$ChildPB     ,na.rm=T)
c3$ChildPHc     <-c3$ChildPH     -mean(c3$ChildPH     ,na.rm=T)
c3$CARatioT100c <-c3$CARatioT100 -mean(c3$CARatioT100 ,na.rm=T)
c3$CARatioW100c <-c3$CARatioW100 -mean(c3$CARatioW100 ,na.rm=T)
c3$CARatioB100c <-c3$CARatioB100 -mean(c3$CARatioB100 ,na.rm=T)
c3$CARatioH100c <-c3$CARatioH100 -mean(c3$CARatioH100 ,na.rm=T)
c3$MalePTc      <-c3$MalePT      -mean(c3$MalePT      ,na.rm=T)
c3$MalePWc      <-c3$MalePW      -mean(c3$MalePW      ,na.rm=T)
c3$MalePBc      <-c3$MalePB      -mean(c3$MalePB      ,na.rm=T)
c3$MalePHc      <-c3$MalePH      -mean(c3$MalePH      ,na.rm=T)
c3$MFRatioT100c <-c3$MFRatioT100 -mean(c3$MFRatioT100 ,na.rm=T)
c3$MFRatioW100c <-c3$MFRatioW100 -mean(c3$MFRatioW100 ,na.rm=T)
c3$MFRatioB100c <-c3$MFRatioB100 -mean(c3$MFRatioB100 ,na.rm=T)
c3$MFRatioH100c <-c3$MFRatioH100 -mean(c3$MFRatioH100 ,na.rm=T)
c3$ElderTc      <-c3$ElderT      -mean(c3$ElderT      ,na.rm=T)
c3$ElderWc      <-c3$ElderW      -mean(c3$ElderW      ,na.rm=T)
c3$ElderBc      <-c3$ElderB      -mean(c3$ElderB      ,na.rm=T)
c3$ElderHc      <-c3$ElderH      -mean(c3$ElderH      ,na.rm=T)
c3$SingleTc     <-c3$SingleT     -mean(c3$SingleT     ,na.rm=T)
c3$SingleWc     <-c3$SingleW     -mean(c3$SingleW     ,na.rm=T)
c3$SingleBc     <-c3$SingleB     -mean(c3$SingleB     ,na.rm=T)
c3$SingleHc     <-c3$SingleH     -mean(c3$SingleH     ,na.rm=T)
c3$FHeadTc      <-c3$FHeadT      -mean(c3$FHeadT      ,na.rm=T)
c3$FHeadWc      <-c3$FHeadW      -mean(c3$FHeadW      ,na.rm=T)
c3$FHeadBc      <-c3$FHeadB      -mean(c3$FHeadB      ,na.rm=T)
c3$FHeadHc      <-c3$FHeadH      -mean(c3$FHeadH      ,na.rm=T)
c3$NoHighTc     <-c3$NoHighT     -mean(c3$NoHighT     ,na.rm=T)
c3$NoHighWc     <-c3$NoHighW     -mean(c3$NoHighW     ,na.rm=T)
c3$NoHighBc     <-c3$NoHighB     -mean(c3$NoHighB     ,na.rm=T)
c3$NoHighHc     <-c3$NoHighH     -mean(c3$NoHighH     ,na.rm=T)
c3$UnempTc      <-c3$UnempT      -mean(c3$UnempT      ,na.rm=T)
c3$UnempWc      <-c3$UnempW      -mean(c3$UnempW      ,na.rm=T)
c3$UnempBc      <-c3$UnempB      -mean(c3$UnempB      ,na.rm=T)
c3$UnempHc      <-c3$UnempH      -mean(c3$UnempH      ,na.rm=T)
c3$CPovTc       <-c3$CPovT       -mean(c3$CPovT       ,na.rm=T)
c3$CPovWc       <-c3$CPovW       -mean(c3$CPovW       ,na.rm=T)
c3$CPovBc       <-c3$CPovB       -mean(c3$CPovB       ,na.rm=T)
c3$CPovHc       <-c3$CPovH       -mean(c3$CPovH       ,na.rm=T)
c3$CPov1c       <-c3$CPov1       -mean(c3$CPov1       ,na.rm=T)
c3$CPov2c       <-c3$CPov2       -mean(c3$CPov2       ,na.rm=T)
c3$CPov3c       <-c3$CPov3       -mean(c3$CPov3       ,na.rm=T)
c3$PubAsTc      <-c3$PubAsT      -mean(c3$PubAsT      ,na.rm=T)
c3$WelfarTc     <-c3$WelfarT     -mean(c3$WelfarT     ,na.rm=T)
c3$SnapTc       <-c3$SnapT       -mean(c3$SnapT       ,na.rm=T)
c3$SnapWc       <-c3$SnapW       -mean(c3$SnapW       ,na.rm=T)
c3$SnapBc       <-c3$SnapB       -mean(c3$SnapB       ,na.rm=T)
c3$SnapHc       <-c3$SnapH       -mean(c3$SnapH       ,na.rm=T)
c3$IncomeT1kc   <-c3$IncomeT1k   -mean(c3$IncomeT1k   ,na.rm=T)
c3$IncomeW1kc   <-c3$IncomeW1k   -mean(c3$IncomeW1k   ,na.rm=T)
c3$IncomeB1kc   <-c3$IncomeB1k   -mean(c3$IncomeB1k   ,na.rm=T)
c3$IncomeH1kc   <-c3$IncomeH1k   -mean(c3$IncomeH1k   ,na.rm=T)
c3$GiniT100c    <-c3$GiniT100    -mean(c3$GiniT100    ,na.rm=T)
c3$HValueT10kc  <-c3$HValueT10k  -mean(c3$HValueT10k  ,na.rm=T)
c3$MCostT100c   <-c3$MCostT100   -mean(c3$MCostT100   ,na.rm=T)
c3$OCostDT100c  <-c3$OCostDT100  -mean(c3$OCostDT100  ,na.rm=T)
c3$MRentDT100c  <-c3$MRentDT100  -mean(c3$MRentDT100  ,na.rm=T)
c3$OCostPTc     <-c3$OCostPT     -mean(c3$OCostPT     ,na.rm=T)
c3$MRentPTc     <-c3$MRentPT     -mean(c3$MRentPT     ,na.rm=T)
c3$MortgTc      <-c3$MortgT      -mean(c3$MortgT      ,na.rm=T)
c3$LangAPTc     <-c3$LangAPT     -mean(c3$LangAPT     ,na.rm=T)
c3$LangAPWc     <-c3$LangAPW     -mean(c3$LangAPW     ,na.rm=T)
c3$LangAPBc     <-c3$LangAPB     -mean(c3$LangAPB     ,na.rm=T)
c3$LangAPHc     <-c3$LangAPH     -mean(c3$LangAPH     ,na.rm=T)
c3$LangBPTc     <-c3$LangBPT     -mean(c3$LangBPT     ,na.rm=T)
c3$LangBPWc     <-c3$LangBPW     -mean(c3$LangBPW     ,na.rm=T)
c3$LangBPBc     <-c3$LangBPB     -mean(c3$LangBPB     ,na.rm=T)
c3$LangBPHc     <-c3$LangBPH     -mean(c3$LangBPH     ,na.rm=T)
c3$LangCPTc     <-c3$LangCPT     -mean(c3$LangCPT     ,na.rm=T)
c3$OutUsTc      <-c3$OutUsT      -mean(c3$OutUsT      ,na.rm=T)
c3$OutUsWc      <-c3$OutUsW      -mean(c3$OutUsW      ,na.rm=T)
c3$OutUsBc      <-c3$OutUsB      -mean(c3$OutUsB      ,na.rm=T)
c3$OutUsHc      <-c3$OutUsH      -mean(c3$OutUsH      ,na.rm=T)
c3$FBornTc      <-c3$FBornT      -mean(c3$FBornT      ,na.rm=T)
c3$FBornWc      <-c3$FBornW      -mean(c3$FBornW      ,na.rm=T)
c3$FBornBc      <-c3$FBornB      -mean(c3$FBornB      ,na.rm=T)
c3$FBornHc      <-c3$FBornH      -mean(c3$FBornH      ,na.rm=T)
c3$NotCtzTc     <-c3$NotCtzT     -mean(c3$NotCtzT     ,na.rm=T)
c3$NotCtzWc     <-c3$NotCtzW     -mean(c3$NotCtzW     ,na.rm=T)
c3$NotCtzBc     <-c3$NotCtzB     -mean(c3$NotCtzB     ,na.rm=T)
c3$NotCtzHc     <-c3$NotCtzH     -mean(c3$NotCtzH     ,na.rm=T)
c3$MoveTc       <-c3$MoveT       -mean(c3$MoveT       ,na.rm=T)
c3$MoveWc       <-c3$MoveW       -mean(c3$MoveW       ,na.rm=T)
c3$MoveBc       <-c3$MoveB       -mean(c3$MoveB       ,na.rm=T)
c3$MoveHc       <-c3$MoveH       -mean(c3$MoveH       ,na.rm=T)
c3$VacantTc     <-c3$VacantT     -mean(c3$VacantT     ,na.rm=T)
c3$OwnerTc      <-c3$OwnerT      -mean(c3$OwnerT      ,na.rm=T)
c3$OwnerWc      <-c3$OwnerW      -mean(c3$OwnerW      ,na.rm=T)
c3$OwnerBc      <-c3$OwnerB      -mean(c3$OwnerB      ,na.rm=T)
c3$OwnerHc      <-c3$OwnerH      -mean(c3$OwnerH      ,na.rm=T)
c3$CrowdTc      <-c3$CrowdT      -mean(c3$CrowdT      ,na.rm=T)
c3$CrowdWc      <-c3$CrowdW      -mean(c3$CrowdW      ,na.rm=T)
c3$CrowdBc      <-c3$CrowdB      -mean(c3$CrowdB      ,na.rm=T)
c3$CrowdHc      <-c3$CrowdH      -mean(c3$CrowdH      ,na.rm=T)
c3$MobileTc     <-c3$MobileT     -mean(c3$MobileT     ,na.rm=T)
c3$MobileWc     <-c3$MobileW     -mean(c3$MobileW     ,na.rm=T)
c3$MobileBc     <-c3$MobileB     -mean(c3$MobileB     ,na.rm=T)
c3$MobileHc     <-c3$MobileH     -mean(c3$MobileH     ,na.rm=T)
c3$DisablTc     <-c3$DisablT     -mean(c3$DisablT     ,na.rm=T)
c3$DisablWc     <-c3$DisablW     -mean(c3$DisablW     ,na.rm=T)
c3$DisablBc     <-c3$DisablB     -mean(c3$DisablB     ,na.rm=T)
c3$DisablHc     <-c3$DisablH     -mean(c3$DisablH     ,na.rm=T)
c3$DisablTCc    <-c3$DisablTC    -mean(c3$DisablTC    ,na.rm=T)
c3$DisablWCc    <-c3$DisablWC    -mean(c3$DisablWC    ,na.rm=T)
c3$DisablBCc    <-c3$DisablBC    -mean(c3$DisablBC    ,na.rm=T)
c3$DisablHCc    <-c3$DisablHC    -mean(c3$DisablHC    ,na.rm=T)
c3$DisablTMc    <-c3$DisablTM    -mean(c3$DisablTM    ,na.rm=T)
c3$DisablTFc    <-c3$DisablTF    -mean(c3$DisablTF    ,na.rm=T)
c3$Urban1c      <-c3$Urban1      -mean(c3$Urban1      ,na.rm=T)
c3$Urban2c      <-c3$Urban2      -mean(c3$Urban2      ,na.rm=T)
c3$LBWT1rc      <-c3$LBWT1r      -mean(c3$LBWT1r      ,na.rm=T)
c3$LBWM1rc      <-c3$LBWM1r      -mean(c3$LBWM1r      ,na.rm=T)
c3$LBWF1rc      <-c3$LBWF1r      -mean(c3$LBWF1r      ,na.rm=T)
c3$LBWW1rc      <-c3$LBWW1r      -mean(c3$LBWW1r      ,na.rm=T)
c3$LBWB1rc      <-c3$LBWB1r      -mean(c3$LBWB1r      ,na.rm=T)
c3$LBWH1rc      <-c3$LBWH1r      -mean(c3$LBWH1r      ,na.rm=T)
c3$PTBT1rc      <-c3$PTBT1r      -mean(c3$PTBT1r      ,na.rm=T)
c3$PTBM1rc      <-c3$PTBM1r      -mean(c3$PTBM1r      ,na.rm=T)
c3$PTBF1rc      <-c3$PTBF1r      -mean(c3$PTBF1r      ,na.rm=T)
c3$PTBW1rc      <-c3$PTBW1r      -mean(c3$PTBW1r      ,na.rm=T)
c3$PTBB1rc      <-c3$PTBB1r      -mean(c3$PTBB1r      ,na.rm=T)
c3$PTBH1rc      <-c3$PTBH1r      -mean(c3$PTBH1r      ,na.rm=T)
c3$PNCT1rc      <-c3$PNCT1r      -mean(c3$PNCT1r      ,na.rm=T)
c3$PNCM1rc      <-c3$PNCM1r      -mean(c3$PNCM1r      ,na.rm=T)
c3$PNCF1rc      <-c3$PNCF1r      -mean(c3$PNCF1r      ,na.rm=T)
c3$PNCW1rc      <-c3$PNCW1r      -mean(c3$PNCW1r      ,na.rm=T)
c3$PNCB1rc      <-c3$PNCB1r      -mean(c3$PNCB1r      ,na.rm=T)
c3$PNCH1rc      <-c3$PNCH1r      -mean(c3$PNCH1r      ,na.rm=T)
c3$TBBT1rc      <-c3$TBBT1r      -mean(c3$TBBT1r      ,na.rm=T)
c3$TBBM1rc      <-c3$TBBM1r      -mean(c3$TBBM1r      ,na.rm=T)
c3$TBBF1rc      <-c3$TBBF1r      -mean(c3$TBBF1r      ,na.rm=T)
c3$TBBW1rc      <-c3$TBBW1r      -mean(c3$TBBW1r      ,na.rm=T)
c3$TBBB1rc      <-c3$TBBB1r      -mean(c3$TBBB1r      ,na.rm=T)
c3$TBBH1rc      <-c3$TBBH1r      -mean(c3$TBBH1r      ,na.rm=T)
c3$TBTT1rc      <-c3$TBTT1r      -mean(c3$TBTT1r      ,na.rm=T)
c3$TBTM1rc      <-c3$TBTM1r      -mean(c3$TBTM1r      ,na.rm=T)
c3$TBTF1rc      <-c3$TBTF1r      -mean(c3$TBTF1r      ,na.rm=T)
c3$TBTW1rc      <-c3$TBTW1r      -mean(c3$TBTW1r      ,na.rm=T)
c3$TBTB1rc      <-c3$TBTB1r      -mean(c3$TBTB1r      ,na.rm=T)
c3$TBTH1rc      <-c3$TBTH1r      -mean(c3$TBTH1r      ,na.rm=T)
c3$LBWT5rc      <-c3$LBWT5r      -mean(c3$LBWT5r      ,na.rm=T)
c3$LBWM5rc      <-c3$LBWM5r      -mean(c3$LBWM5r      ,na.rm=T)
c3$LBWF5rc      <-c3$LBWF5r      -mean(c3$LBWF5r      ,na.rm=T)
c3$LBWW5rc      <-c3$LBWW5r      -mean(c3$LBWW5r      ,na.rm=T)
c3$LBWB5rc      <-c3$LBWB5r      -mean(c3$LBWB5r      ,na.rm=T)
c3$LBWH5rc      <-c3$LBWH5r      -mean(c3$LBWH5r      ,na.rm=T)
c3$PTBT5rc      <-c3$PTBT5r      -mean(c3$PTBT5r      ,na.rm=T)
c3$PTBM5rc      <-c3$PTBM5r      -mean(c3$PTBM5r      ,na.rm=T)
c3$PTBF5rc      <-c3$PTBF5r      -mean(c3$PTBF5r      ,na.rm=T)
c3$PTBW5rc      <-c3$PTBW5r      -mean(c3$PTBW5r      ,na.rm=T)
c3$PTBB5rc      <-c3$PTBB5r      -mean(c3$PTBB5r      ,na.rm=T)
c3$PTBH5rc      <-c3$PTBH5r      -mean(c3$PTBH5r      ,na.rm=T)
c3$PNCT5rc      <-c3$PNCT5r      -mean(c3$PNCT5r      ,na.rm=T)
c3$PNCM5rc      <-c3$PNCM5r      -mean(c3$PNCM5r      ,na.rm=T)
c3$PNCF5rc      <-c3$PNCF5r      -mean(c3$PNCF5r      ,na.rm=T)
c3$PNCW5rc      <-c3$PNCW5r      -mean(c3$PNCW5r      ,na.rm=T)
c3$PNCB5rc      <-c3$PNCB5r      -mean(c3$PNCB5r      ,na.rm=T)
c3$PNCH5rc      <-c3$PNCH5r      -mean(c3$PNCH5r      ,na.rm=T)
c3$TBBT5rc      <-c3$TBBT5r      -mean(c3$TBBT5r      ,na.rm=T)
c3$TBBM5rc      <-c3$TBBM5r      -mean(c3$TBBM5r      ,na.rm=T)
c3$TBBF5rc      <-c3$TBBF5r      -mean(c3$TBBF5r      ,na.rm=T)
c3$TBBW5rc      <-c3$TBBW5r      -mean(c3$TBBW5r      ,na.rm=T)
c3$TBBB5rc      <-c3$TBBB5r      -mean(c3$TBBB5r      ,na.rm=T)
c3$TBBH5rc      <-c3$TBBH5r      -mean(c3$TBBH5r      ,na.rm=T)
c3$TBTT5rc      <-c3$TBTT5r      -mean(c3$TBTT5r      ,na.rm=T)
c3$TBTM5rc      <-c3$TBTM5r      -mean(c3$TBTM5r      ,na.rm=T)
c3$TBTF5rc      <-c3$TBTF5r      -mean(c3$TBTF5r      ,na.rm=T)
c3$TBTW5rc      <-c3$TBTW5r      -mean(c3$TBTW5r      ,na.rm=T)
c3$TBTB5rc      <-c3$TBTB5r      -mean(c3$TBTB5r      ,na.rm=T)
c3$TBTH5rc      <-c3$TBTH5r      -mean(c3$TBTH5r      ,na.rm=T)
c3$Opioidc      <-c3$Opioid      -mean(c3$Opioid      ,na.rm=T)
c3$LifeExpc     <-c3$LifeExp     -mean(c3$LifeExp     ,na.rm=T)
c3$LifeExpBc    <-c3$LifeExpB    -mean(c3$LifeExpB    ,na.rm=T)
c3$LifeExpHc    <-c3$LifeExpH    -mean(c3$LifeExpH    ,na.rm=T)
c3$LifeExpWc    <-c3$LifeExpW    -mean(c3$LifeExpW    ,na.rm=T)
c3$ChdDeathc    <-c3$ChdDeath    -mean(c3$ChdDeath    ,na.rm=T)
c3$ChdDeathBc   <-c3$ChdDeathB   -mean(c3$ChdDeathB   ,na.rm=T)
c3$ChdDeathHc   <-c3$ChdDeathH   -mean(c3$ChdDeathH   ,na.rm=T)
c3$ChdDeathWc   <-c3$ChdDeathW   -mean(c3$ChdDeathW   ,na.rm=T)
c3$InfDeathc    <-c3$InfDeath    -mean(c3$InfDeath    ,na.rm=T)
c3$InfDeathBc   <-c3$InfDeathB   -mean(c3$InfDeathB   ,na.rm=T)
c3$InfDeathHc   <-c3$InfDeathH   -mean(c3$InfDeathH   ,na.rm=T)
c3$InfDeathWc   <-c3$InfDeathW   -mean(c3$InfDeathW   ,na.rm=T)
c3$Injuryc      <-c3$Injury      -mean(c3$Injury      ,na.rm=T)
c3$InjuryBc     <-c3$InjuryB     -mean(c3$InjuryB     ,na.rm=T)
c3$InjuryHc     <-c3$InjuryH     -mean(c3$InjuryH     ,na.rm=T)
c3$InjuryWc     <-c3$InjuryW     -mean(c3$InjuryW     ,na.rm=T)
c3$GunDeathc    <-c3$GunDeath    -mean(c3$GunDeath    ,na.rm=T)
c3$GunDeathBc   <-c3$GunDeathB   -mean(c3$GunDeathB   ,na.rm=T)
c3$GunDeathWc   <-c3$GunDeathW   -mean(c3$GunDeathW   ,na.rm=T)
c3$PrmDeath_c   <-c3$PrmDeath    -mean(c3$PrmDeath    ,na.rm=T)
c3$PrmDeathcc   <-c3$PrmDeathc   -mean(c3$PrmDeathc   ,na.rm=T)
c3$PrmDeathBc   <-c3$PrmDeathB   -mean(c3$PrmDeathB   ,na.rm=T)
c3$PrmDeathHc   <-c3$PrmDeathH   -mean(c3$PrmDeathH   ,na.rm=T)
c3$PrmDeathWc   <-c3$PrmDeathW   -mean(c3$PrmDeathW   ,na.rm=T)
c3$PrmDeath2_c  <-c3$PrmDeath2   -mean(c3$PrmDeath2   ,na.rm=T)
c3$PrmDeath2cc  <-c3$PrmDeath2c  -mean(c3$PrmDeath2c  ,na.rm=T)
c3$PrmDeath2Bc  <-c3$PrmDeath2B  -mean(c3$PrmDeath2B  ,na.rm=T)
c3$PrmDeath2Hc  <-c3$PrmDeath2H  -mean(c3$PrmDeath2H  ,na.rm=T)
c3$PrmDeath2Wc  <-c3$PrmDeath2W  -mean(c3$PrmDeath2W  ,na.rm=T)
c3$Suicidec     <-c3$Suicide     -mean(c3$Suicide     ,na.rm=T)
c3$Diabetc      <-c3$Diabet      -mean(c3$Diabet      ,na.rm=T)
c3$Obesityc     <-c3$Obesity     -mean(c3$Obesity     ,na.rm=T)
c3$Physicalc    <-c3$Physical    -mean(c3$Physical    ,na.rm=T)
c3$PoorHlthc    <-c3$PoorHlth    -mean(c3$PoorHlth    ,na.rm=T)
c3$PoorMHc      <-c3$PoorMH      -mean(c3$PoorMH      ,na.rm=T)
c3$PoorPhyc     <-c3$PoorPhy     -mean(c3$PoorPhy     ,na.rm=T)
c3$Sleepc       <-c3$Sleep       -mean(c3$Sleep       ,na.rm=T)
c3$DrugOdc      <-c3$DrugOd      -mean(c3$DrugOd      ,na.rm=T)
c3$DrugOdBc     <-c3$DrugOdB     -mean(c3$DrugOdB     ,na.rm=T)
c3$DrugOdHc     <-c3$DrugOdH     -mean(c3$DrugOdH     ,na.rm=T)
c3$DrugOdWc     <-c3$DrugOdW     -mean(c3$DrugOdW     ,na.rm=T)
c3$DWIDeathc    <-c3$DWIDeath    -mean(c3$DWIDeath    ,na.rm=T)
c3$EDrinkc      <-c3$EDrink      -mean(c3$EDrink      ,na.rm=T)
c3$Smokec       <-c3$Smoke       -mean(c3$Smoke       ,na.rm=T)
c3$FastFoodc    <-c3$FastFood    -mean(c3$FastFood    ,na.rm=T)
c3$FoodEnvc     <-c3$FoodEnv     -mean(c3$FoodEnv     ,na.rm=T)
c3$FoodInsc     <-c3$FoodIns     -mean(c3$FoodIns     ,na.rm=T)
c3$FrLunchc     <-c3$FrLunch     -mean(c3$FrLunch     ,na.rm=T)
c3$LAccFoodc    <-c3$LAccFood    -mean(c3$LAccFood    ,na.rm=T)
c3$Gymc         <-c3$Gym         -mean(c3$Gym         ,na.rm=T)
c3$Gym2c        <-c3$Gym2        -mean(c3$Gym2        ,na.rm=T)
c3$Inactivec    <-c3$Inactive    -mean(c3$Inactive    ,na.rm=T)
c3$HousCostc    <-c3$HousCost    -mean(c3$HousCost    ,na.rm=T)
c3$HousCostsc   <-c3$HousCosts   -mean(c3$HousCosts   ,na.rm=T)
c3$HousCrowdc   <-c3$HousCrowd   -mean(c3$HousCrowd   ,na.rm=T)
c3$Housingc     <-c3$Housing     -mean(c3$Housing     ,na.rm=T)
c3$HousPlumbc   <-c3$HousPlumb   -mean(c3$HousPlumb   ,na.rm=T)
c3$Insuredc     <-c3$Insured     -mean(c3$Insured     ,na.rm=T)
c3$InsuredAc    <-c3$InsuredA    -mean(c3$InsuredA    ,na.rm=T)
c3$InsuredCc    <-c3$InsuredC    -mean(c3$InsuredC    ,na.rm=T)
c3$JuvArrc      <-c3$JuvArr      -mean(c3$JuvArr      ,na.rm=T)
c3$Murderc      <-c3$Murder      -mean(c3$Murder      ,na.rm=T)
c3$Violentc     <-c3$Violent     -mean(c3$Violent     ,na.rm=T)
c3$LongCommc    <-c3$LongComm    -mean(c3$LongComm    ,na.rm=T)
c3$LowBWc       <-c3$LowBW       -mean(c3$LowBW       ,na.rm=T)
c3$LowBWBc      <-c3$LowBWB      -mean(c3$LowBWB      ,na.rm=T)
c3$LowBWHc      <-c3$LowBWH      -mean(c3$LowBWH      ,na.rm=T)
c3$LowBWWc      <-c3$LowBWW      -mean(c3$LowBWW      ,na.rm=T)
c3$TeenBthc     <-c3$TeenBth     -mean(c3$TeenBth     ,na.rm=T)
c3$TeenBthBc    <-c3$TeenBthB    -mean(c3$TeenBthB    ,na.rm=T)
c3$TeenBthHc    <-c3$TeenBthH    -mean(c3$TeenBthH    ,na.rm=T)
c3$TeenBthWc    <-c3$TeenBthW    -mean(c3$TeenBthW    ,na.rm=T)
c3$Mentalc      <-c3$Mental      -mean(c3$Mental      ,na.rm=T)
c3$MHPrvdc      <-c3$MHPrvd      -mean(c3$MHPrvd      ,na.rm=T)
c3$PCPc         <-c3$PCP         -mean(c3$PCP         ,na.rm=T)
c3$PCP2c        <-c3$PCP2        -mean(c3$PCP2        ,na.rm=T)
c3$Dentistc     <-c3$Dentist     -mean(c3$Dentist     ,na.rm=T)
c3$PrvtHospc    <-c3$PrvtHosp    -mean(c3$PrvtHosp    ,na.rm=T)
c3$PrvtHospBc   <-c3$PrvtHospB   -mean(c3$PrvtHospB   ,na.rm=T)
c3$PrvtHospHc   <-c3$PrvtHospH   -mean(c3$PrvtHospH   ,na.rm=T)
c3$PrvtHospWc   <-c3$PrvtHospW   -mean(c3$PrvtHospW   ,na.rm=T)
c3$SegBWc       <-c3$SegBW       -mean(c3$SegBW       ,na.rm=T)
c3$SegNWc       <-c3$SegNW       -mean(c3$SegNW       ,na.rm=T)
c3$SocAssoc     <-c3$SocAsso     -mean(c3$SocAsso     ,na.rm=T)
c3$SocSuppc     <-c3$SocSupp     -mean(c3$SocSupp     ,na.rm=T)
c3$MIECHVc      <-c3$MIECHV      -mean(c3$MIECHV      ,na.rm=T)
c3$NHVRCc       <-c3$NHVRC       -mean(c3$NHVRC       ,na.rm=T)
c3$FoodInsecurec<-c3$FoodInsecure-mean(c3$FoodInsecure,na.rm=T)
c3$PCPAllc      <-c3$PCPAll      -mean(c3$PCPAll      ,na.rm=T)
c3$MH_PCPc      <-c3$MH_PCP      -mean(c3$MH_PCP      ,na.rm=T)

c3<-cbind(c3,demean(c3,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
c3m01<-lmer(Rpt3r~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
# Mental Health
c3m02<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m03<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m04<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
c3m05<-lmer(Rpt3r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m06<-lmer(Rpt3r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m07<-lmer(Rpt3r~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m08<-lmer(Rpt3r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
c3m09<-lmer(Rpt3r~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m10<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m11<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m12<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m13<-lmer(Rpt3r~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
BIC(c3m04,c3m05,c3m06,c3m07,c3m08,c3m09,c3m10,c3m11,c3m12,c3m13,c3m14)
summary(c3m12)
# Physical Health
c3m22<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m23<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m24<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
c3m25<-lmer(Rpt3r~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m26<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m27<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
c3m28<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
c3m29<-lmer(Rpt3r~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=c3,control=lmerControl(optimizer="bobyqa"))
BIC(c3m24,c3m25,c3m26,c3m27,c3m28,c3m29)
summary(c3m29)
# bootstrap confidence interval
c3m12CI<-confint(c3m12,method='boot',nsim=500,boot.type='perc')
c3m29CI<-confint(c3m29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(c3m12)
check_collinearity(c3m29)
isSingular(c3m12)
isSingular(c3m29)


skewness(resid(c3m12))
skewness(resid(c3m29))



###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables

cm$CPopBPc      <-cm$CPopBP      -mean(cm$CPopBP      ,na.rm=T)
cm$CPopHPc      <-cm$CPopHP      -mean(cm$CPopHP      ,na.rm=T)
cm$ChildPTc     <-cm$ChildPT     -mean(cm$ChildPT     ,na.rm=T)
cm$ChildPWc     <-cm$ChildPW     -mean(cm$ChildPW     ,na.rm=T)
cm$ChildPBc     <-cm$ChildPB     -mean(cm$ChildPB     ,na.rm=T)
cm$ChildPHc     <-cm$ChildPH     -mean(cm$ChildPH     ,na.rm=T)
cm$CARatioT100c <-cm$CARatioT100 -mean(cm$CARatioT100 ,na.rm=T)
cm$CARatioW100c <-cm$CARatioW100 -mean(cm$CARatioW100 ,na.rm=T)
cm$CARatioB100c <-cm$CARatioB100 -mean(cm$CARatioB100 ,na.rm=T)
cm$CARatioH100c <-cm$CARatioH100 -mean(cm$CARatioH100 ,na.rm=T)
cm$MalePTc      <-cm$MalePT      -mean(cm$MalePT      ,na.rm=T)
cm$MalePWc      <-cm$MalePW      -mean(cm$MalePW      ,na.rm=T)
cm$MalePBc      <-cm$MalePB      -mean(cm$MalePB      ,na.rm=T)
cm$MalePHc      <-cm$MalePH      -mean(cm$MalePH      ,na.rm=T)
cm$MFRatioT100c <-cm$MFRatioT100 -mean(cm$MFRatioT100 ,na.rm=T)
cm$MFRatioW100c <-cm$MFRatioW100 -mean(cm$MFRatioW100 ,na.rm=T)
cm$MFRatioB100c <-cm$MFRatioB100 -mean(cm$MFRatioB100 ,na.rm=T)
cm$MFRatioH100c <-cm$MFRatioH100 -mean(cm$MFRatioH100 ,na.rm=T)
cm$ElderTc      <-cm$ElderT      -mean(cm$ElderT      ,na.rm=T)
cm$ElderWc      <-cm$ElderW      -mean(cm$ElderW      ,na.rm=T)
cm$ElderBc      <-cm$ElderB      -mean(cm$ElderB      ,na.rm=T)
cm$ElderHc      <-cm$ElderH      -mean(cm$ElderH      ,na.rm=T)
cm$SingleTc     <-cm$SingleT     -mean(cm$SingleT     ,na.rm=T)
cm$SingleWc     <-cm$SingleW     -mean(cm$SingleW     ,na.rm=T)
cm$SingleBc     <-cm$SingleB     -mean(cm$SingleB     ,na.rm=T)
cm$SingleHc     <-cm$SingleH     -mean(cm$SingleH     ,na.rm=T)
cm$FHeadTc      <-cm$FHeadT      -mean(cm$FHeadT      ,na.rm=T)
cm$FHeadWc      <-cm$FHeadW      -mean(cm$FHeadW      ,na.rm=T)
cm$FHeadBc      <-cm$FHeadB      -mean(cm$FHeadB      ,na.rm=T)
cm$FHeadHc      <-cm$FHeadH      -mean(cm$FHeadH      ,na.rm=T)
cm$NoHighTc     <-cm$NoHighT     -mean(cm$NoHighT     ,na.rm=T)
cm$NoHighWc     <-cm$NoHighW     -mean(cm$NoHighW     ,na.rm=T)
cm$NoHighBc     <-cm$NoHighB     -mean(cm$NoHighB     ,na.rm=T)
cm$NoHighHc     <-cm$NoHighH     -mean(cm$NoHighH     ,na.rm=T)
cm$UnempTc      <-cm$UnempT      -mean(cm$UnempT      ,na.rm=T)
cm$UnempWc      <-cm$UnempW      -mean(cm$UnempW      ,na.rm=T)
cm$UnempBc      <-cm$UnempB      -mean(cm$UnempB      ,na.rm=T)
cm$UnempHc      <-cm$UnempH      -mean(cm$UnempH      ,na.rm=T)
cm$CPovTc       <-cm$CPovT       -mean(cm$CPovT       ,na.rm=T)
cm$CPovWc       <-cm$CPovW       -mean(cm$CPovW       ,na.rm=T)
cm$CPovBc       <-cm$CPovB       -mean(cm$CPovB       ,na.rm=T)
cm$CPovHc       <-cm$CPovH       -mean(cm$CPovH       ,na.rm=T)
cm$CPov1c       <-cm$CPov1       -mean(cm$CPov1       ,na.rm=T)
cm$CPov2c       <-cm$CPov2       -mean(cm$CPov2       ,na.rm=T)
cm$CPov3c       <-cm$CPov3       -mean(cm$CPov3       ,na.rm=T)
cm$PubAsTc      <-cm$PubAsT      -mean(cm$PubAsT      ,na.rm=T)
cm$WelfarTc     <-cm$WelfarT     -mean(cm$WelfarT     ,na.rm=T)
cm$SnapTc       <-cm$SnapT       -mean(cm$SnapT       ,na.rm=T)
cm$SnapWc       <-cm$SnapW       -mean(cm$SnapW       ,na.rm=T)
cm$SnapBc       <-cm$SnapB       -mean(cm$SnapB       ,na.rm=T)
cm$SnapHc       <-cm$SnapH       -mean(cm$SnapH       ,na.rm=T)
cm$IncomeT1kc   <-cm$IncomeT1k   -mean(cm$IncomeT1k   ,na.rm=T)
cm$IncomeW1kc   <-cm$IncomeW1k   -mean(cm$IncomeW1k   ,na.rm=T)
cm$IncomeB1kc   <-cm$IncomeB1k   -mean(cm$IncomeB1k   ,na.rm=T)
cm$IncomeH1kc   <-cm$IncomeH1k   -mean(cm$IncomeH1k   ,na.rm=T)
cm$GiniT100c    <-cm$GiniT100    -mean(cm$GiniT100    ,na.rm=T)
cm$HValueT10kc  <-cm$HValueT10k  -mean(cm$HValueT10k  ,na.rm=T)
cm$MCostT100c   <-cm$MCostT100   -mean(cm$MCostT100   ,na.rm=T)
cm$OCostDT100c  <-cm$OCostDT100  -mean(cm$OCostDT100  ,na.rm=T)
cm$MRentDT100c  <-cm$MRentDT100  -mean(cm$MRentDT100  ,na.rm=T)
cm$OCostPTc     <-cm$OCostPT     -mean(cm$OCostPT     ,na.rm=T)
cm$MRentPTc     <-cm$MRentPT     -mean(cm$MRentPT     ,na.rm=T)
cm$MortgTc      <-cm$MortgT      -mean(cm$MortgT      ,na.rm=T)
cm$LangAPTc     <-cm$LangAPT     -mean(cm$LangAPT     ,na.rm=T)
cm$LangAPWc     <-cm$LangAPW     -mean(cm$LangAPW     ,na.rm=T)
cm$LangAPBc     <-cm$LangAPB     -mean(cm$LangAPB     ,na.rm=T)
cm$LangAPHc     <-cm$LangAPH     -mean(cm$LangAPH     ,na.rm=T)
cm$LangBPTc     <-cm$LangBPT     -mean(cm$LangBPT     ,na.rm=T)
cm$LangBPWc     <-cm$LangBPW     -mean(cm$LangBPW     ,na.rm=T)
cm$LangBPBc     <-cm$LangBPB     -mean(cm$LangBPB     ,na.rm=T)
cm$LangBPHc     <-cm$LangBPH     -mean(cm$LangBPH     ,na.rm=T)
cm$LangCPTc     <-cm$LangCPT     -mean(cm$LangCPT     ,na.rm=T)
cm$OutUsTc      <-cm$OutUsT      -mean(cm$OutUsT      ,na.rm=T)
cm$OutUsWc      <-cm$OutUsW      -mean(cm$OutUsW      ,na.rm=T)
cm$OutUsBc      <-cm$OutUsB      -mean(cm$OutUsB      ,na.rm=T)
cm$OutUsHc      <-cm$OutUsH      -mean(cm$OutUsH      ,na.rm=T)
cm$FBornTc      <-cm$FBornT      -mean(cm$FBornT      ,na.rm=T)
cm$FBornWc      <-cm$FBornW      -mean(cm$FBornW      ,na.rm=T)
cm$FBornBc      <-cm$FBornB      -mean(cm$FBornB      ,na.rm=T)
cm$FBornHc      <-cm$FBornH      -mean(cm$FBornH      ,na.rm=T)
cm$NotCtzTc     <-cm$NotCtzT     -mean(cm$NotCtzT     ,na.rm=T)
cm$NotCtzWc     <-cm$NotCtzW     -mean(cm$NotCtzW     ,na.rm=T)
cm$NotCtzBc     <-cm$NotCtzB     -mean(cm$NotCtzB     ,na.rm=T)
cm$NotCtzHc     <-cm$NotCtzH     -mean(cm$NotCtzH     ,na.rm=T)
cm$MoveTc       <-cm$MoveT       -mean(cm$MoveT       ,na.rm=T)
cm$MoveWc       <-cm$MoveW       -mean(cm$MoveW       ,na.rm=T)
cm$MoveBc       <-cm$MoveB       -mean(cm$MoveB       ,na.rm=T)
cm$MoveHc       <-cm$MoveH       -mean(cm$MoveH       ,na.rm=T)
cm$VacantTc     <-cm$VacantT     -mean(cm$VacantT     ,na.rm=T)
cm$OwnerTc      <-cm$OwnerT      -mean(cm$OwnerT      ,na.rm=T)
cm$OwnerWc      <-cm$OwnerW      -mean(cm$OwnerW      ,na.rm=T)
cm$OwnerBc      <-cm$OwnerB      -mean(cm$OwnerB      ,na.rm=T)
cm$OwnerHc      <-cm$OwnerH      -mean(cm$OwnerH      ,na.rm=T)
cm$CrowdTc      <-cm$CrowdT      -mean(cm$CrowdT      ,na.rm=T)
cm$CrowdWc      <-cm$CrowdW      -mean(cm$CrowdW      ,na.rm=T)
cm$CrowdBc      <-cm$CrowdB      -mean(cm$CrowdB      ,na.rm=T)
cm$CrowdHc      <-cm$CrowdH      -mean(cm$CrowdH      ,na.rm=T)
cm$MobileTc     <-cm$MobileT     -mean(cm$MobileT     ,na.rm=T)
cm$MobileWc     <-cm$MobileW     -mean(cm$MobileW     ,na.rm=T)
cm$MobileBc     <-cm$MobileB     -mean(cm$MobileB     ,na.rm=T)
cm$MobileHc     <-cm$MobileH     -mean(cm$MobileH     ,na.rm=T)
cm$DisablTc     <-cm$DisablT     -mean(cm$DisablT     ,na.rm=T)
cm$DisablWc     <-cm$DisablW     -mean(cm$DisablW     ,na.rm=T)
cm$DisablBc     <-cm$DisablB     -mean(cm$DisablB     ,na.rm=T)
cm$DisablHc     <-cm$DisablH     -mean(cm$DisablH     ,na.rm=T)
cm$DisablTCc    <-cm$DisablTC    -mean(cm$DisablTC    ,na.rm=T)
cm$DisablWCc    <-cm$DisablWC    -mean(cm$DisablWC    ,na.rm=T)
cm$DisablBCc    <-cm$DisablBC    -mean(cm$DisablBC    ,na.rm=T)
cm$DisablHCc    <-cm$DisablHC    -mean(cm$DisablHC    ,na.rm=T)
cm$DisablTMc    <-cm$DisablTM    -mean(cm$DisablTM    ,na.rm=T)
cm$DisablTFc    <-cm$DisablTF    -mean(cm$DisablTF    ,na.rm=T)
cm$Urban1c      <-cm$Urban1      -mean(cm$Urban1      ,na.rm=T)
cm$Urban2c      <-cm$Urban2      -mean(cm$Urban2      ,na.rm=T)
cm$LBWT1rc      <-cm$LBWT1r      -mean(cm$LBWT1r      ,na.rm=T)
cm$LBWM1rc      <-cm$LBWM1r      -mean(cm$LBWM1r      ,na.rm=T)
cm$LBWF1rc      <-cm$LBWF1r      -mean(cm$LBWF1r      ,na.rm=T)
cm$LBWW1rc      <-cm$LBWW1r      -mean(cm$LBWW1r      ,na.rm=T)
cm$LBWB1rc      <-cm$LBWB1r      -mean(cm$LBWB1r      ,na.rm=T)
cm$LBWH1rc      <-cm$LBWH1r      -mean(cm$LBWH1r      ,na.rm=T)
cm$PTBT1rc      <-cm$PTBT1r      -mean(cm$PTBT1r      ,na.rm=T)
cm$PTBM1rc      <-cm$PTBM1r      -mean(cm$PTBM1r      ,na.rm=T)
cm$PTBF1rc      <-cm$PTBF1r      -mean(cm$PTBF1r      ,na.rm=T)
cm$PTBW1rc      <-cm$PTBW1r      -mean(cm$PTBW1r      ,na.rm=T)
cm$PTBB1rc      <-cm$PTBB1r      -mean(cm$PTBB1r      ,na.rm=T)
cm$PTBH1rc      <-cm$PTBH1r      -mean(cm$PTBH1r      ,na.rm=T)
cm$PNCT1rc      <-cm$PNCT1r      -mean(cm$PNCT1r      ,na.rm=T)
cm$PNCM1rc      <-cm$PNCM1r      -mean(cm$PNCM1r      ,na.rm=T)
cm$PNCF1rc      <-cm$PNCF1r      -mean(cm$PNCF1r      ,na.rm=T)
cm$PNCW1rc      <-cm$PNCW1r      -mean(cm$PNCW1r      ,na.rm=T)
cm$PNCB1rc      <-cm$PNCB1r      -mean(cm$PNCB1r      ,na.rm=T)
cm$PNCH1rc      <-cm$PNCH1r      -mean(cm$PNCH1r      ,na.rm=T)
cm$TBBT1rc      <-cm$TBBT1r      -mean(cm$TBBT1r      ,na.rm=T)
cm$TBBM1rc      <-cm$TBBM1r      -mean(cm$TBBM1r      ,na.rm=T)
cm$TBBF1rc      <-cm$TBBF1r      -mean(cm$TBBF1r      ,na.rm=T)
cm$TBBW1rc      <-cm$TBBW1r      -mean(cm$TBBW1r      ,na.rm=T)
cm$TBBB1rc      <-cm$TBBB1r      -mean(cm$TBBB1r      ,na.rm=T)
cm$TBBH1rc      <-cm$TBBH1r      -mean(cm$TBBH1r      ,na.rm=T)
cm$TBTT1rc      <-cm$TBTT1r      -mean(cm$TBTT1r      ,na.rm=T)
cm$TBTM1rc      <-cm$TBTM1r      -mean(cm$TBTM1r      ,na.rm=T)
cm$TBTF1rc      <-cm$TBTF1r      -mean(cm$TBTF1r      ,na.rm=T)
cm$TBTW1rc      <-cm$TBTW1r      -mean(cm$TBTW1r      ,na.rm=T)
cm$TBTB1rc      <-cm$TBTB1r      -mean(cm$TBTB1r      ,na.rm=T)
cm$TBTH1rc      <-cm$TBTH1r      -mean(cm$TBTH1r      ,na.rm=T)
cm$LBWT5rc      <-cm$LBWT5r      -mean(cm$LBWT5r      ,na.rm=T)
cm$LBWM5rc      <-cm$LBWM5r      -mean(cm$LBWM5r      ,na.rm=T)
cm$LBWF5rc      <-cm$LBWF5r      -mean(cm$LBWF5r      ,na.rm=T)
cm$LBWW5rc      <-cm$LBWW5r      -mean(cm$LBWW5r      ,na.rm=T)
cm$LBWB5rc      <-cm$LBWB5r      -mean(cm$LBWB5r      ,na.rm=T)
cm$LBWH5rc      <-cm$LBWH5r      -mean(cm$LBWH5r      ,na.rm=T)
cm$PTBT5rc      <-cm$PTBT5r      -mean(cm$PTBT5r      ,na.rm=T)
cm$PTBM5rc      <-cm$PTBM5r      -mean(cm$PTBM5r      ,na.rm=T)
cm$PTBF5rc      <-cm$PTBF5r      -mean(cm$PTBF5r      ,na.rm=T)
cm$PTBW5rc      <-cm$PTBW5r      -mean(cm$PTBW5r      ,na.rm=T)
cm$PTBB5rc      <-cm$PTBB5r      -mean(cm$PTBB5r      ,na.rm=T)
cm$PTBH5rc      <-cm$PTBH5r      -mean(cm$PTBH5r      ,na.rm=T)
cm$PNCT5rc      <-cm$PNCT5r      -mean(cm$PNCT5r      ,na.rm=T)
cm$PNCM5rc      <-cm$PNCM5r      -mean(cm$PNCM5r      ,na.rm=T)
cm$PNCF5rc      <-cm$PNCF5r      -mean(cm$PNCF5r      ,na.rm=T)
cm$PNCW5rc      <-cm$PNCW5r      -mean(cm$PNCW5r      ,na.rm=T)
cm$PNCB5rc      <-cm$PNCB5r      -mean(cm$PNCB5r      ,na.rm=T)
cm$PNCH5rc      <-cm$PNCH5r      -mean(cm$PNCH5r      ,na.rm=T)
cm$TBBT5rc      <-cm$TBBT5r      -mean(cm$TBBT5r      ,na.rm=T)
cm$TBBM5rc      <-cm$TBBM5r      -mean(cm$TBBM5r      ,na.rm=T)
cm$TBBF5rc      <-cm$TBBF5r      -mean(cm$TBBF5r      ,na.rm=T)
cm$TBBW5rc      <-cm$TBBW5r      -mean(cm$TBBW5r      ,na.rm=T)
cm$TBBB5rc      <-cm$TBBB5r      -mean(cm$TBBB5r      ,na.rm=T)
cm$TBBH5rc      <-cm$TBBH5r      -mean(cm$TBBH5r      ,na.rm=T)
cm$TBTT5rc      <-cm$TBTT5r      -mean(cm$TBTT5r      ,na.rm=T)
cm$TBTM5rc      <-cm$TBTM5r      -mean(cm$TBTM5r      ,na.rm=T)
cm$TBTF5rc      <-cm$TBTF5r      -mean(cm$TBTF5r      ,na.rm=T)
cm$TBTW5rc      <-cm$TBTW5r      -mean(cm$TBTW5r      ,na.rm=T)
cm$TBTB5rc      <-cm$TBTB5r      -mean(cm$TBTB5r      ,na.rm=T)
cm$TBTH5rc      <-cm$TBTH5r      -mean(cm$TBTH5r      ,na.rm=T)
cm$Opioidc      <-cm$Opioid      -mean(cm$Opioid      ,na.rm=T)
cm$LifeExpc     <-cm$LifeExp     -mean(cm$LifeExp     ,na.rm=T)
cm$LifeExpBc    <-cm$LifeExpB    -mean(cm$LifeExpB    ,na.rm=T)
cm$LifeExpHc    <-cm$LifeExpH    -mean(cm$LifeExpH    ,na.rm=T)
cm$LifeExpWc    <-cm$LifeExpW    -mean(cm$LifeExpW    ,na.rm=T)
cm$ChdDeathc    <-cm$ChdDeath    -mean(cm$ChdDeath    ,na.rm=T)
cm$ChdDeathBc   <-cm$ChdDeathB   -mean(cm$ChdDeathB   ,na.rm=T)
cm$ChdDeathHc   <-cm$ChdDeathH   -mean(cm$ChdDeathH   ,na.rm=T)
cm$ChdDeathWc   <-cm$ChdDeathW   -mean(cm$ChdDeathW   ,na.rm=T)
cm$InfDeathc    <-cm$InfDeath    -mean(cm$InfDeath    ,na.rm=T)
cm$InfDeathBc   <-cm$InfDeathB   -mean(cm$InfDeathB   ,na.rm=T)
cm$InfDeathHc   <-cm$InfDeathH   -mean(cm$InfDeathH   ,na.rm=T)
cm$InfDeathWc   <-cm$InfDeathW   -mean(cm$InfDeathW   ,na.rm=T)
cm$Injuryc      <-cm$Injury      -mean(cm$Injury      ,na.rm=T)
cm$InjuryBc     <-cm$InjuryB     -mean(cm$InjuryB     ,na.rm=T)
cm$InjuryHc     <-cm$InjuryH     -mean(cm$InjuryH     ,na.rm=T)
cm$InjuryWc     <-cm$InjuryW     -mean(cm$InjuryW     ,na.rm=T)
cm$GunDeathc    <-cm$GunDeath    -mean(cm$GunDeath    ,na.rm=T)
cm$GunDeathBc   <-cm$GunDeathB   -mean(cm$GunDeathB   ,na.rm=T)
cm$GunDeathWc   <-cm$GunDeathW   -mean(cm$GunDeathW   ,na.rm=T)
cm$PrmDeath_c   <-cm$PrmDeath    -mean(cm$PrmDeath    ,na.rm=T)
cm$PrmDeathcc   <-cm$PrmDeathc   -mean(cm$PrmDeathc   ,na.rm=T)
cm$PrmDeathBc   <-cm$PrmDeathB   -mean(cm$PrmDeathB   ,na.rm=T)
cm$PrmDeathHc   <-cm$PrmDeathH   -mean(cm$PrmDeathH   ,na.rm=T)
cm$PrmDeathWc   <-cm$PrmDeathW   -mean(cm$PrmDeathW   ,na.rm=T)
cm$PrmDeath2_c  <-cm$PrmDeath2   -mean(cm$PrmDeath2   ,na.rm=T)
cm$PrmDeath2cc  <-cm$PrmDeath2c  -mean(cm$PrmDeath2c  ,na.rm=T)
cm$PrmDeath2Bc  <-cm$PrmDeath2B  -mean(cm$PrmDeath2B  ,na.rm=T)
cm$PrmDeath2Hc  <-cm$PrmDeath2H  -mean(cm$PrmDeath2H  ,na.rm=T)
cm$PrmDeath2Wc  <-cm$PrmDeath2W  -mean(cm$PrmDeath2W  ,na.rm=T)
cm$Suicidec     <-cm$Suicide     -mean(cm$Suicide     ,na.rm=T)
cm$Diabetc      <-cm$Diabet      -mean(cm$Diabet      ,na.rm=T)
cm$Obesityc     <-cm$Obesity     -mean(cm$Obesity     ,na.rm=T)
cm$Physicalc    <-cm$Physical    -mean(cm$Physical    ,na.rm=T)
cm$PoorHlthc    <-cm$PoorHlth    -mean(cm$PoorHlth    ,na.rm=T)
cm$PoorMHc      <-cm$PoorMH      -mean(cm$PoorMH      ,na.rm=T)
cm$PoorPhyc     <-cm$PoorPhy     -mean(cm$PoorPhy     ,na.rm=T)
cm$Sleepc       <-cm$Sleep       -mean(cm$Sleep       ,na.rm=T)
cm$DrugOdc      <-cm$DrugOd      -mean(cm$DrugOd      ,na.rm=T)
cm$DrugOdBc     <-cm$DrugOdB     -mean(cm$DrugOdB     ,na.rm=T)
cm$DrugOdHc     <-cm$DrugOdH     -mean(cm$DrugOdH     ,na.rm=T)
cm$DrugOdWc     <-cm$DrugOdW     -mean(cm$DrugOdW     ,na.rm=T)
cm$DWIDeathc    <-cm$DWIDeath    -mean(cm$DWIDeath    ,na.rm=T)
cm$EDrinkc      <-cm$EDrink      -mean(cm$EDrink      ,na.rm=T)
cm$Smokec       <-cm$Smoke       -mean(cm$Smoke       ,na.rm=T)
cm$FastFoodc    <-cm$FastFood    -mean(cm$FastFood    ,na.rm=T)
cm$FoodEnvc     <-cm$FoodEnv     -mean(cm$FoodEnv     ,na.rm=T)
cm$FoodInsc     <-cm$FoodIns     -mean(cm$FoodIns     ,na.rm=T)
cm$FrLunchc     <-cm$FrLunch     -mean(cm$FrLunch     ,na.rm=T)
cm$LAccFoodc    <-cm$LAccFood    -mean(cm$LAccFood    ,na.rm=T)
cm$Gymc         <-cm$Gym         -mean(cm$Gym         ,na.rm=T)
cm$Gym2c        <-cm$Gym2        -mean(cm$Gym2        ,na.rm=T)
cm$Inactivec    <-cm$Inactive    -mean(cm$Inactive    ,na.rm=T)
cm$HousCostc    <-cm$HousCost    -mean(cm$HousCost    ,na.rm=T)
cm$HousCostsc   <-cm$HousCosts   -mean(cm$HousCosts   ,na.rm=T)
cm$HousCrowdc   <-cm$HousCrowd   -mean(cm$HousCrowd   ,na.rm=T)
cm$Housingc     <-cm$Housing     -mean(cm$Housing     ,na.rm=T)
cm$HousPlumbc   <-cm$HousPlumb   -mean(cm$HousPlumb   ,na.rm=T)
cm$Insuredc     <-cm$Insured     -mean(cm$Insured     ,na.rm=T)
cm$InsuredAc    <-cm$InsuredA    -mean(cm$InsuredA    ,na.rm=T)
cm$InsuredCc    <-cm$InsuredC    -mean(cm$InsuredC    ,na.rm=T)
cm$JuvArrc      <-cm$JuvArr      -mean(cm$JuvArr      ,na.rm=T)
cm$Murderc      <-cm$Murder      -mean(cm$Murder      ,na.rm=T)
cm$Violentc     <-cm$Violent     -mean(cm$Violent     ,na.rm=T)
cm$LongCommc    <-cm$LongComm    -mean(cm$LongComm    ,na.rm=T)
cm$LowBWc       <-cm$LowBW       -mean(cm$LowBW       ,na.rm=T)
cm$LowBWBc      <-cm$LowBWB      -mean(cm$LowBWB      ,na.rm=T)
cm$LowBWHc      <-cm$LowBWH      -mean(cm$LowBWH      ,na.rm=T)
cm$LowBWWc      <-cm$LowBWW      -mean(cm$LowBWW      ,na.rm=T)
cm$TeenBthc     <-cm$TeenBth     -mean(cm$TeenBth     ,na.rm=T)
cm$TeenBthBc    <-cm$TeenBthB    -mean(cm$TeenBthB    ,na.rm=T)
cm$TeenBthHc    <-cm$TeenBthH    -mean(cm$TeenBthH    ,na.rm=T)
cm$TeenBthWc    <-cm$TeenBthW    -mean(cm$TeenBthW    ,na.rm=T)
cm$Mentalc      <-cm$Mental      -mean(cm$Mental      ,na.rm=T)
cm$MHPrvdc      <-cm$MHPrvd      -mean(cm$MHPrvd      ,na.rm=T)
cm$PCPc         <-cm$PCP         -mean(cm$PCP         ,na.rm=T)
cm$PCP2c        <-cm$PCP2        -mean(cm$PCP2        ,na.rm=T)
cm$Dentistc     <-cm$Dentist     -mean(cm$Dentist     ,na.rm=T)
cm$PrvtHospc    <-cm$PrvtHosp    -mean(cm$PrvtHosp    ,na.rm=T)
cm$PrvtHospBc   <-cm$PrvtHospB   -mean(cm$PrvtHospB   ,na.rm=T)
cm$PrvtHospHc   <-cm$PrvtHospH   -mean(cm$PrvtHospH   ,na.rm=T)
cm$PrvtHospWc   <-cm$PrvtHospW   -mean(cm$PrvtHospW   ,na.rm=T)
cm$SegBWc       <-cm$SegBW       -mean(cm$SegBW       ,na.rm=T)
cm$SegNWc       <-cm$SegNW       -mean(cm$SegNW       ,na.rm=T)
cm$SocAssoc     <-cm$SocAsso     -mean(cm$SocAsso     ,na.rm=T)
cm$SocSuppc     <-cm$SocSupp     -mean(cm$SocSupp     ,na.rm=T)
cm$MIECHVc      <-cm$MIECHV      -mean(cm$MIECHV      ,na.rm=T)
cm$NHVRCc       <-cm$NHVRC       -mean(cm$NHVRC       ,na.rm=T)
cm$FoodInsecurec<-cm$FoodInsecure-mean(cm$FoodInsecure,na.rm=T)
cm$PCPAllc      <-cm$PCPAll      -mean(cm$PCPAll      ,na.rm=T)
cm$MH_PCPc      <-cm$MH_PCP      -mean(cm$MH_PCP      ,na.rm=T)

cm<-cbind(cm,demean(cm,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cmm01<-lmer(RptMr~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
# Mental Health
cmm02<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm03<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm04<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
cmm05<-lmer(RptMr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm06<-lmer(RptMr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm07<-lmer(RptMr~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm08<-lmer(RptMr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
cmm09<-lmer(RptMr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm10<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm11<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm12<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm13<-lmer(RptMr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
BIC(cmm04,cmm05,cmm06,cmm07,cmm08,cmm09,cmm10,cmm11,cmm12,cmm13)
summary(cmm12)
# Physical Health
cmm22<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm23<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm24<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
cmm25<-lmer(RptMr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm26<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm27<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
cmm28<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
cmm29<-lmer(RptMr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=cm,control=lmerControl(optimizer="bobyqa"))
BIC(cmm24,cmm25,cmm26,cmm27,cmm28,cmm29)
summary(cmm24)
summary(cmm29)
# bootstrap confidence interval
cmm12CI<-confint(cmm12,method='boot',nsim=500,boot.type='perc')
cmm29CI<-confint(cmm29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cmm12)
check_collinearity(cmm29)
isSingular(cmm12)
isSingular(cmm29)





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cf$CPopBPc      <-cf$CPopBP      -mean(cf$CPopBP      ,na.rm=T)
cf$CPopHPc      <-cf$CPopHP      -mean(cf$CPopHP      ,na.rm=T)
cf$ChildPTc     <-cf$ChildPT     -mean(cf$ChildPT     ,na.rm=T)
cf$ChildPWc     <-cf$ChildPW     -mean(cf$ChildPW     ,na.rm=T)
cf$ChildPBc     <-cf$ChildPB     -mean(cf$ChildPB     ,na.rm=T)
cf$ChildPHc     <-cf$ChildPH     -mean(cf$ChildPH     ,na.rm=T)
cf$CARatioT100c <-cf$CARatioT100 -mean(cf$CARatioT100 ,na.rm=T)
cf$CARatioW100c <-cf$CARatioW100 -mean(cf$CARatioW100 ,na.rm=T)
cf$CARatioB100c <-cf$CARatioB100 -mean(cf$CARatioB100 ,na.rm=T)
cf$CARatioH100c <-cf$CARatioH100 -mean(cf$CARatioH100 ,na.rm=T)
cf$MalePTc      <-cf$MalePT      -mean(cf$MalePT      ,na.rm=T)
cf$MalePWc      <-cf$MalePW      -mean(cf$MalePW      ,na.rm=T)
cf$MalePBc      <-cf$MalePB      -mean(cf$MalePB      ,na.rm=T)
cf$MalePHc      <-cf$MalePH      -mean(cf$MalePH      ,na.rm=T)
cf$MFRatioT100c <-cf$MFRatioT100 -mean(cf$MFRatioT100 ,na.rm=T)
cf$MFRatioW100c <-cf$MFRatioW100 -mean(cf$MFRatioW100 ,na.rm=T)
cf$MFRatioB100c <-cf$MFRatioB100 -mean(cf$MFRatioB100 ,na.rm=T)
cf$MFRatioH100c <-cf$MFRatioH100 -mean(cf$MFRatioH100 ,na.rm=T)
cf$ElderTc      <-cf$ElderT      -mean(cf$ElderT      ,na.rm=T)
cf$ElderWc      <-cf$ElderW      -mean(cf$ElderW      ,na.rm=T)
cf$ElderBc      <-cf$ElderB      -mean(cf$ElderB      ,na.rm=T)
cf$ElderHc      <-cf$ElderH      -mean(cf$ElderH      ,na.rm=T)
cf$SingleTc     <-cf$SingleT     -mean(cf$SingleT     ,na.rm=T)
cf$SingleWc     <-cf$SingleW     -mean(cf$SingleW     ,na.rm=T)
cf$SingleBc     <-cf$SingleB     -mean(cf$SingleB     ,na.rm=T)
cf$SingleHc     <-cf$SingleH     -mean(cf$SingleH     ,na.rm=T)
cf$FHeadTc      <-cf$FHeadT      -mean(cf$FHeadT      ,na.rm=T)
cf$FHeadWc      <-cf$FHeadW      -mean(cf$FHeadW      ,na.rm=T)
cf$FHeadBc      <-cf$FHeadB      -mean(cf$FHeadB      ,na.rm=T)
cf$FHeadHc      <-cf$FHeadH      -mean(cf$FHeadH      ,na.rm=T)
cf$NoHighTc     <-cf$NoHighT     -mean(cf$NoHighT     ,na.rm=T)
cf$NoHighWc     <-cf$NoHighW     -mean(cf$NoHighW     ,na.rm=T)
cf$NoHighBc     <-cf$NoHighB     -mean(cf$NoHighB     ,na.rm=T)
cf$NoHighHc     <-cf$NoHighH     -mean(cf$NoHighH     ,na.rm=T)
cf$UnempTc      <-cf$UnempT      -mean(cf$UnempT      ,na.rm=T)
cf$UnempWc      <-cf$UnempW      -mean(cf$UnempW      ,na.rm=T)
cf$UnempBc      <-cf$UnempB      -mean(cf$UnempB      ,na.rm=T)
cf$UnempHc      <-cf$UnempH      -mean(cf$UnempH      ,na.rm=T)
cf$CPovTc       <-cf$CPovT       -mean(cf$CPovT       ,na.rm=T)
cf$CPovWc       <-cf$CPovW       -mean(cf$CPovW       ,na.rm=T)
cf$CPovBc       <-cf$CPovB       -mean(cf$CPovB       ,na.rm=T)
cf$CPovHc       <-cf$CPovH       -mean(cf$CPovH       ,na.rm=T)
cf$CPov1c       <-cf$CPov1       -mean(cf$CPov1       ,na.rm=T)
cf$CPov2c       <-cf$CPov2       -mean(cf$CPov2       ,na.rm=T)
cf$CPov3c       <-cf$CPov3       -mean(cf$CPov3       ,na.rm=T)
cf$PubAsTc      <-cf$PubAsT      -mean(cf$PubAsT      ,na.rm=T)
cf$WelfarTc     <-cf$WelfarT     -mean(cf$WelfarT     ,na.rm=T)
cf$SnapTc       <-cf$SnapT       -mean(cf$SnapT       ,na.rm=T)
cf$SnapWc       <-cf$SnapW       -mean(cf$SnapW       ,na.rm=T)
cf$SnapBc       <-cf$SnapB       -mean(cf$SnapB       ,na.rm=T)
cf$SnapHc       <-cf$SnapH       -mean(cf$SnapH       ,na.rm=T)
cf$IncomeT1kc   <-cf$IncomeT1k   -mean(cf$IncomeT1k   ,na.rm=T)
cf$IncomeW1kc   <-cf$IncomeW1k   -mean(cf$IncomeW1k   ,na.rm=T)
cf$IncomeB1kc   <-cf$IncomeB1k   -mean(cf$IncomeB1k   ,na.rm=T)
cf$IncomeH1kc   <-cf$IncomeH1k   -mean(cf$IncomeH1k   ,na.rm=T)
cf$GiniT100c    <-cf$GiniT100    -mean(cf$GiniT100    ,na.rm=T)
cf$HValueT10kc  <-cf$HValueT10k  -mean(cf$HValueT10k  ,na.rm=T)
cf$MCostT100c   <-cf$MCostT100   -mean(cf$MCostT100   ,na.rm=T)
cf$OCostDT100c  <-cf$OCostDT100  -mean(cf$OCostDT100  ,na.rm=T)
cf$MRentDT100c  <-cf$MRentDT100  -mean(cf$MRentDT100  ,na.rm=T)
cf$OCostPTc     <-cf$OCostPT     -mean(cf$OCostPT     ,na.rm=T)
cf$MRentPTc     <-cf$MRentPT     -mean(cf$MRentPT     ,na.rm=T)
cf$MortgTc      <-cf$MortgT      -mean(cf$MortgT      ,na.rm=T)
cf$LangAPTc     <-cf$LangAPT     -mean(cf$LangAPT     ,na.rm=T)
cf$LangAPWc     <-cf$LangAPW     -mean(cf$LangAPW     ,na.rm=T)
cf$LangAPBc     <-cf$LangAPB     -mean(cf$LangAPB     ,na.rm=T)
cf$LangAPHc     <-cf$LangAPH     -mean(cf$LangAPH     ,na.rm=T)
cf$LangBPTc     <-cf$LangBPT     -mean(cf$LangBPT     ,na.rm=T)
cf$LangBPWc     <-cf$LangBPW     -mean(cf$LangBPW     ,na.rm=T)
cf$LangBPBc     <-cf$LangBPB     -mean(cf$LangBPB     ,na.rm=T)
cf$LangBPHc     <-cf$LangBPH     -mean(cf$LangBPH     ,na.rm=T)
cf$LangCPTc     <-cf$LangCPT     -mean(cf$LangCPT     ,na.rm=T)
cf$OutUsTc      <-cf$OutUsT      -mean(cf$OutUsT      ,na.rm=T)
cf$OutUsWc      <-cf$OutUsW      -mean(cf$OutUsW      ,na.rm=T)
cf$OutUsBc      <-cf$OutUsB      -mean(cf$OutUsB      ,na.rm=T)
cf$OutUsHc      <-cf$OutUsH      -mean(cf$OutUsH      ,na.rm=T)
cf$FBornTc      <-cf$FBornT      -mean(cf$FBornT      ,na.rm=T)
cf$FBornWc      <-cf$FBornW      -mean(cf$FBornW      ,na.rm=T)
cf$FBornBc      <-cf$FBornB      -mean(cf$FBornB      ,na.rm=T)
cf$FBornHc      <-cf$FBornH      -mean(cf$FBornH      ,na.rm=T)
cf$NotCtzTc     <-cf$NotCtzT     -mean(cf$NotCtzT     ,na.rm=T)
cf$NotCtzWc     <-cf$NotCtzW     -mean(cf$NotCtzW     ,na.rm=T)
cf$NotCtzBc     <-cf$NotCtzB     -mean(cf$NotCtzB     ,na.rm=T)
cf$NotCtzHc     <-cf$NotCtzH     -mean(cf$NotCtzH     ,na.rm=T)
cf$MoveTc       <-cf$MoveT       -mean(cf$MoveT       ,na.rm=T)
cf$MoveWc       <-cf$MoveW       -mean(cf$MoveW       ,na.rm=T)
cf$MoveBc       <-cf$MoveB       -mean(cf$MoveB       ,na.rm=T)
cf$MoveHc       <-cf$MoveH       -mean(cf$MoveH       ,na.rm=T)
cf$VacantTc     <-cf$VacantT     -mean(cf$VacantT     ,na.rm=T)
cf$OwnerTc      <-cf$OwnerT      -mean(cf$OwnerT      ,na.rm=T)
cf$OwnerWc      <-cf$OwnerW      -mean(cf$OwnerW      ,na.rm=T)
cf$OwnerBc      <-cf$OwnerB      -mean(cf$OwnerB      ,na.rm=T)
cf$OwnerHc      <-cf$OwnerH      -mean(cf$OwnerH      ,na.rm=T)
cf$CrowdTc      <-cf$CrowdT      -mean(cf$CrowdT      ,na.rm=T)
cf$CrowdWc      <-cf$CrowdW      -mean(cf$CrowdW      ,na.rm=T)
cf$CrowdBc      <-cf$CrowdB      -mean(cf$CrowdB      ,na.rm=T)
cf$CrowdHc      <-cf$CrowdH      -mean(cf$CrowdH      ,na.rm=T)
cf$MobileTc     <-cf$MobileT     -mean(cf$MobileT     ,na.rm=T)
cf$MobileWc     <-cf$MobileW     -mean(cf$MobileW     ,na.rm=T)
cf$MobileBc     <-cf$MobileB     -mean(cf$MobileB     ,na.rm=T)
cf$MobileHc     <-cf$MobileH     -mean(cf$MobileH     ,na.rm=T)
cf$DisablTc     <-cf$DisablT     -mean(cf$DisablT     ,na.rm=T)
cf$DisablWc     <-cf$DisablW     -mean(cf$DisablW     ,na.rm=T)
cf$DisablBc     <-cf$DisablB     -mean(cf$DisablB     ,na.rm=T)
cf$DisablHc     <-cf$DisablH     -mean(cf$DisablH     ,na.rm=T)
cf$DisablTCc    <-cf$DisablTC    -mean(cf$DisablTC    ,na.rm=T)
cf$DisablWCc    <-cf$DisablWC    -mean(cf$DisablWC    ,na.rm=T)
cf$DisablBCc    <-cf$DisablBC    -mean(cf$DisablBC    ,na.rm=T)
cf$DisablHCc    <-cf$DisablHC    -mean(cf$DisablHC    ,na.rm=T)
cf$DisablTMc    <-cf$DisablTM    -mean(cf$DisablTM    ,na.rm=T)
cf$DisablTFc    <-cf$DisablTF    -mean(cf$DisablTF    ,na.rm=T)
cf$Urban1c      <-cf$Urban1      -mean(cf$Urban1      ,na.rm=T)
cf$Urban2c      <-cf$Urban2      -mean(cf$Urban2      ,na.rm=T)
cf$LBWT1rc      <-cf$LBWT1r      -mean(cf$LBWT1r      ,na.rm=T)
cf$LBWM1rc      <-cf$LBWM1r      -mean(cf$LBWM1r      ,na.rm=T)
cf$LBWF1rc      <-cf$LBWF1r      -mean(cf$LBWF1r      ,na.rm=T)
cf$LBWW1rc      <-cf$LBWW1r      -mean(cf$LBWW1r      ,na.rm=T)
cf$LBWB1rc      <-cf$LBWB1r      -mean(cf$LBWB1r      ,na.rm=T)
cf$LBWH1rc      <-cf$LBWH1r      -mean(cf$LBWH1r      ,na.rm=T)
cf$PTBT1rc      <-cf$PTBT1r      -mean(cf$PTBT1r      ,na.rm=T)
cf$PTBM1rc      <-cf$PTBM1r      -mean(cf$PTBM1r      ,na.rm=T)
cf$PTBF1rc      <-cf$PTBF1r      -mean(cf$PTBF1r      ,na.rm=T)
cf$PTBW1rc      <-cf$PTBW1r      -mean(cf$PTBW1r      ,na.rm=T)
cf$PTBB1rc      <-cf$PTBB1r      -mean(cf$PTBB1r      ,na.rm=T)
cf$PTBH1rc      <-cf$PTBH1r      -mean(cf$PTBH1r      ,na.rm=T)
cf$PNCT1rc      <-cf$PNCT1r      -mean(cf$PNCT1r      ,na.rm=T)
cf$PNCM1rc      <-cf$PNCM1r      -mean(cf$PNCM1r      ,na.rm=T)
cf$PNCF1rc      <-cf$PNCF1r      -mean(cf$PNCF1r      ,na.rm=T)
cf$PNCW1rc      <-cf$PNCW1r      -mean(cf$PNCW1r      ,na.rm=T)
cf$PNCB1rc      <-cf$PNCB1r      -mean(cf$PNCB1r      ,na.rm=T)
cf$PNCH1rc      <-cf$PNCH1r      -mean(cf$PNCH1r      ,na.rm=T)
cf$TBBT1rc      <-cf$TBBT1r      -mean(cf$TBBT1r      ,na.rm=T)
cf$TBBM1rc      <-cf$TBBM1r      -mean(cf$TBBM1r      ,na.rm=T)
cf$TBBF1rc      <-cf$TBBF1r      -mean(cf$TBBF1r      ,na.rm=T)
cf$TBBW1rc      <-cf$TBBW1r      -mean(cf$TBBW1r      ,na.rm=T)
cf$TBBB1rc      <-cf$TBBB1r      -mean(cf$TBBB1r      ,na.rm=T)
cf$TBBH1rc      <-cf$TBBH1r      -mean(cf$TBBH1r      ,na.rm=T)
cf$TBTT1rc      <-cf$TBTT1r      -mean(cf$TBTT1r      ,na.rm=T)
cf$TBTM1rc      <-cf$TBTM1r      -mean(cf$TBTM1r      ,na.rm=T)
cf$TBTF1rc      <-cf$TBTF1r      -mean(cf$TBTF1r      ,na.rm=T)
cf$TBTW1rc      <-cf$TBTW1r      -mean(cf$TBTW1r      ,na.rm=T)
cf$TBTB1rc      <-cf$TBTB1r      -mean(cf$TBTB1r      ,na.rm=T)
cf$TBTH1rc      <-cf$TBTH1r      -mean(cf$TBTH1r      ,na.rm=T)
cf$LBWT5rc      <-cf$LBWT5r      -mean(cf$LBWT5r      ,na.rm=T)
cf$LBWM5rc      <-cf$LBWM5r      -mean(cf$LBWM5r      ,na.rm=T)
cf$LBWF5rc      <-cf$LBWF5r      -mean(cf$LBWF5r      ,na.rm=T)
cf$LBWW5rc      <-cf$LBWW5r      -mean(cf$LBWW5r      ,na.rm=T)
cf$LBWB5rc      <-cf$LBWB5r      -mean(cf$LBWB5r      ,na.rm=T)
cf$LBWH5rc      <-cf$LBWH5r      -mean(cf$LBWH5r      ,na.rm=T)
cf$PTBT5rc      <-cf$PTBT5r      -mean(cf$PTBT5r      ,na.rm=T)
cf$PTBM5rc      <-cf$PTBM5r      -mean(cf$PTBM5r      ,na.rm=T)
cf$PTBF5rc      <-cf$PTBF5r      -mean(cf$PTBF5r      ,na.rm=T)
cf$PTBW5rc      <-cf$PTBW5r      -mean(cf$PTBW5r      ,na.rm=T)
cf$PTBB5rc      <-cf$PTBB5r      -mean(cf$PTBB5r      ,na.rm=T)
cf$PTBH5rc      <-cf$PTBH5r      -mean(cf$PTBH5r      ,na.rm=T)
cf$PNCT5rc      <-cf$PNCT5r      -mean(cf$PNCT5r      ,na.rm=T)
cf$PNCM5rc      <-cf$PNCM5r      -mean(cf$PNCM5r      ,na.rm=T)
cf$PNCF5rc      <-cf$PNCF5r      -mean(cf$PNCF5r      ,na.rm=T)
cf$PNCW5rc      <-cf$PNCW5r      -mean(cf$PNCW5r      ,na.rm=T)
cf$PNCB5rc      <-cf$PNCB5r      -mean(cf$PNCB5r      ,na.rm=T)
cf$PNCH5rc      <-cf$PNCH5r      -mean(cf$PNCH5r      ,na.rm=T)
cf$TBBT5rc      <-cf$TBBT5r      -mean(cf$TBBT5r      ,na.rm=T)
cf$TBBM5rc      <-cf$TBBM5r      -mean(cf$TBBM5r      ,na.rm=T)
cf$TBBF5rc      <-cf$TBBF5r      -mean(cf$TBBF5r      ,na.rm=T)
cf$TBBW5rc      <-cf$TBBW5r      -mean(cf$TBBW5r      ,na.rm=T)
cf$TBBB5rc      <-cf$TBBB5r      -mean(cf$TBBB5r      ,na.rm=T)
cf$TBBH5rc      <-cf$TBBH5r      -mean(cf$TBBH5r      ,na.rm=T)
cf$TBTT5rc      <-cf$TBTT5r      -mean(cf$TBTT5r      ,na.rm=T)
cf$TBTM5rc      <-cf$TBTM5r      -mean(cf$TBTM5r      ,na.rm=T)
cf$TBTF5rc      <-cf$TBTF5r      -mean(cf$TBTF5r      ,na.rm=T)
cf$TBTW5rc      <-cf$TBTW5r      -mean(cf$TBTW5r      ,na.rm=T)
cf$TBTB5rc      <-cf$TBTB5r      -mean(cf$TBTB5r      ,na.rm=T)
cf$TBTH5rc      <-cf$TBTH5r      -mean(cf$TBTH5r      ,na.rm=T)
cf$Opioidc      <-cf$Opioid      -mean(cf$Opioid      ,na.rm=T)
cf$LifeExpc     <-cf$LifeExp     -mean(cf$LifeExp     ,na.rm=T)
cf$LifeExpBc    <-cf$LifeExpB    -mean(cf$LifeExpB    ,na.rm=T)
cf$LifeExpHc    <-cf$LifeExpH    -mean(cf$LifeExpH    ,na.rm=T)
cf$LifeExpWc    <-cf$LifeExpW    -mean(cf$LifeExpW    ,na.rm=T)
cf$ChdDeathc    <-cf$ChdDeath    -mean(cf$ChdDeath    ,na.rm=T)
cf$ChdDeathBc   <-cf$ChdDeathB   -mean(cf$ChdDeathB   ,na.rm=T)
cf$ChdDeathHc   <-cf$ChdDeathH   -mean(cf$ChdDeathH   ,na.rm=T)
cf$ChdDeathWc   <-cf$ChdDeathW   -mean(cf$ChdDeathW   ,na.rm=T)
cf$InfDeathc    <-cf$InfDeath    -mean(cf$InfDeath    ,na.rm=T)
cf$InfDeathBc   <-cf$InfDeathB   -mean(cf$InfDeathB   ,na.rm=T)
cf$InfDeathHc   <-cf$InfDeathH   -mean(cf$InfDeathH   ,na.rm=T)
cf$InfDeathWc   <-cf$InfDeathW   -mean(cf$InfDeathW   ,na.rm=T)
cf$Injuryc      <-cf$Injury      -mean(cf$Injury      ,na.rm=T)
cf$InjuryBc     <-cf$InjuryB     -mean(cf$InjuryB     ,na.rm=T)
cf$InjuryHc     <-cf$InjuryH     -mean(cf$InjuryH     ,na.rm=T)
cf$InjuryWc     <-cf$InjuryW     -mean(cf$InjuryW     ,na.rm=T)
cf$GunDeathc    <-cf$GunDeath    -mean(cf$GunDeath    ,na.rm=T)
cf$GunDeathBc   <-cf$GunDeathB   -mean(cf$GunDeathB   ,na.rm=T)
cf$GunDeathWc   <-cf$GunDeathW   -mean(cf$GunDeathW   ,na.rm=T)
cf$PrmDeath_c   <-cf$PrmDeath    -mean(cf$PrmDeath    ,na.rm=T)
cf$PrmDeathcc   <-cf$PrmDeathc   -mean(cf$PrmDeathc   ,na.rm=T)
cf$PrmDeathBc   <-cf$PrmDeathB   -mean(cf$PrmDeathB   ,na.rm=T)
cf$PrmDeathHc   <-cf$PrmDeathH   -mean(cf$PrmDeathH   ,na.rm=T)
cf$PrmDeathWc   <-cf$PrmDeathW   -mean(cf$PrmDeathW   ,na.rm=T)
cf$PrmDeath2_c  <-cf$PrmDeath2   -mean(cf$PrmDeath2   ,na.rm=T)
cf$PrmDeath2cc  <-cf$PrmDeath2c  -mean(cf$PrmDeath2c  ,na.rm=T)
cf$PrmDeath2Bc  <-cf$PrmDeath2B  -mean(cf$PrmDeath2B  ,na.rm=T)
cf$PrmDeath2Hc  <-cf$PrmDeath2H  -mean(cf$PrmDeath2H  ,na.rm=T)
cf$PrmDeath2Wc  <-cf$PrmDeath2W  -mean(cf$PrmDeath2W  ,na.rm=T)
cf$Suicidec     <-cf$Suicide     -mean(cf$Suicide     ,na.rm=T)
cf$Diabetc      <-cf$Diabet      -mean(cf$Diabet      ,na.rm=T)
cf$Obesityc     <-cf$Obesity     -mean(cf$Obesity     ,na.rm=T)
cf$Physicalc    <-cf$Physical    -mean(cf$Physical    ,na.rm=T)
cf$PoorHlthc    <-cf$PoorHlth    -mean(cf$PoorHlth    ,na.rm=T)
cf$PoorMHc      <-cf$PoorMH      -mean(cf$PoorMH      ,na.rm=T)
cf$PoorPhyc     <-cf$PoorPhy     -mean(cf$PoorPhy     ,na.rm=T)
cf$Sleepc       <-cf$Sleep       -mean(cf$Sleep       ,na.rm=T)
cf$DrugOdc      <-cf$DrugOd      -mean(cf$DrugOd      ,na.rm=T)
cf$DrugOdBc     <-cf$DrugOdB     -mean(cf$DrugOdB     ,na.rm=T)
cf$DrugOdHc     <-cf$DrugOdH     -mean(cf$DrugOdH     ,na.rm=T)
cf$DrugOdWc     <-cf$DrugOdW     -mean(cf$DrugOdW     ,na.rm=T)
cf$DWIDeathc    <-cf$DWIDeath    -mean(cf$DWIDeath    ,na.rm=T)
cf$EDrinkc      <-cf$EDrink      -mean(cf$EDrink      ,na.rm=T)
cf$Smokec       <-cf$Smoke       -mean(cf$Smoke       ,na.rm=T)
cf$FastFoodc    <-cf$FastFood    -mean(cf$FastFood    ,na.rm=T)
cf$FoodEnvc     <-cf$FoodEnv     -mean(cf$FoodEnv     ,na.rm=T)
cf$FoodInsc     <-cf$FoodIns     -mean(cf$FoodIns     ,na.rm=T)
cf$FrLunchc     <-cf$FrLunch     -mean(cf$FrLunch     ,na.rm=T)
cf$LAccFoodc    <-cf$LAccFood    -mean(cf$LAccFood    ,na.rm=T)
cf$Gymc         <-cf$Gym         -mean(cf$Gym         ,na.rm=T)
cf$Gym2c        <-cf$Gym2        -mean(cf$Gym2        ,na.rm=T)
cf$Inactivec    <-cf$Inactive    -mean(cf$Inactive    ,na.rm=T)
cf$HousCostc    <-cf$HousCost    -mean(cf$HousCost    ,na.rm=T)
cf$HousCostsc   <-cf$HousCosts   -mean(cf$HousCosts   ,na.rm=T)
cf$HousCrowdc   <-cf$HousCrowd   -mean(cf$HousCrowd   ,na.rm=T)
cf$Housingc     <-cf$Housing     -mean(cf$Housing     ,na.rm=T)
cf$HousPlumbc   <-cf$HousPlumb   -mean(cf$HousPlumb   ,na.rm=T)
cf$Insuredc     <-cf$Insured     -mean(cf$Insured     ,na.rm=T)
cf$InsuredAc    <-cf$InsuredA    -mean(cf$InsuredA    ,na.rm=T)
cf$InsuredCc    <-cf$InsuredC    -mean(cf$InsuredC    ,na.rm=T)
cf$JuvArrc      <-cf$JuvArr      -mean(cf$JuvArr      ,na.rm=T)
cf$Murderc      <-cf$Murder      -mean(cf$Murder      ,na.rm=T)
cf$Violentc     <-cf$Violent     -mean(cf$Violent     ,na.rm=T)
cf$LongCommc    <-cf$LongComm    -mean(cf$LongComm    ,na.rm=T)
cf$LowBWc       <-cf$LowBW       -mean(cf$LowBW       ,na.rm=T)
cf$LowBWBc      <-cf$LowBWB      -mean(cf$LowBWB      ,na.rm=T)
cf$LowBWHc      <-cf$LowBWH      -mean(cf$LowBWH      ,na.rm=T)
cf$LowBWWc      <-cf$LowBWW      -mean(cf$LowBWW      ,na.rm=T)
cf$TeenBthc     <-cf$TeenBth     -mean(cf$TeenBth     ,na.rm=T)
cf$TeenBthBc    <-cf$TeenBthB    -mean(cf$TeenBthB    ,na.rm=T)
cf$TeenBthHc    <-cf$TeenBthH    -mean(cf$TeenBthH    ,na.rm=T)
cf$TeenBthWc    <-cf$TeenBthW    -mean(cf$TeenBthW    ,na.rm=T)
cf$Mentalc      <-cf$Mental      -mean(cf$Mental      ,na.rm=T)
cf$MHPrvdc      <-cf$MHPrvd      -mean(cf$MHPrvd      ,na.rm=T)
cf$PCPc         <-cf$PCP         -mean(cf$PCP         ,na.rm=T)
cf$PCP2c        <-cf$PCP2        -mean(cf$PCP2        ,na.rm=T)
cf$Dentistc     <-cf$Dentist     -mean(cf$Dentist     ,na.rm=T)
cf$PrvtHospc    <-cf$PrvtHosp    -mean(cf$PrvtHosp    ,na.rm=T)
cf$PrvtHospBc   <-cf$PrvtHospB   -mean(cf$PrvtHospB   ,na.rm=T)
cf$PrvtHospHc   <-cf$PrvtHospH   -mean(cf$PrvtHospH   ,na.rm=T)
cf$PrvtHospWc   <-cf$PrvtHospW   -mean(cf$PrvtHospW   ,na.rm=T)
cf$SegBWc       <-cf$SegBW       -mean(cf$SegBW       ,na.rm=T)
cf$SegNWc       <-cf$SegNW       -mean(cf$SegNW       ,na.rm=T)
cf$SocAssoc     <-cf$SocAsso     -mean(cf$SocAsso     ,na.rm=T)
cf$SocSuppc     <-cf$SocSupp     -mean(cf$SocSupp     ,na.rm=T)
cf$MIECHVc      <-cf$MIECHV      -mean(cf$MIECHV      ,na.rm=T)
cf$NHVRCc       <-cf$NHVRC       -mean(cf$NHVRC       ,na.rm=T)
cf$FoodInsecurec<-cf$FoodInsecure-mean(cf$FoodInsecure,na.rm=T)
cf$PCPAllc      <-cf$PCPAll      -mean(cf$PCPAll      ,na.rm=T)
cf$MH_PCPc      <-cf$MH_PCP      -mean(cf$MH_PCP      ,na.rm=T)

cf<-cbind(cf,demean(cf,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cfm01<-lmer(RptFr~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
# Mental Health
cfm02<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm03<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm04<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
cfm05<-lmer(RptFr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm06<-lmer(RptFr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm07<-lmer(RptFr~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm08<-lmer(RptFr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
cfm09<-lmer(RptFr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm10<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm11<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm12<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm13<-lmer(RptFr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
BIC(cfm04,cfm05,cfm06,cfm07,cfm08,cfm09,cfm10,cfm11,cfm12,cfm13)
summary(cfm12)
# Physical Health
cfm22<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm23<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm24<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
cfm25<-lmer(RptFr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm26<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm27<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
cfm28<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
cfm29<-lmer(RptFr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(Physicalc_between|StateFIPS),data=cf,control=lmerControl(optimizer="bobyqa"))
BIC(cfm24,cfm25,cfm26,cfm27,cfm28,cfm29)
summary(cfm24)
summary(cfm29)

# bootstrap confidence interval
cfm12CI<-confint(cfm12,method='boot',nsim=500,boot.type='perc')
cfm29CI<-confint(cfm29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cfm12)
check_collinearity(cfm29)
isSingular(cfm12)
isSingular(cfm29)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cn$CPopBPc      <-cn$CPopBP      -mean(cn$CPopBP      ,na.rm=T)
cn$CPopHPc      <-cn$CPopHP      -mean(cn$CPopHP      ,na.rm=T)
cn$ChildPTc     <-cn$ChildPT     -mean(cn$ChildPT     ,na.rm=T)
cn$ChildPWc     <-cn$ChildPW     -mean(cn$ChildPW     ,na.rm=T)
cn$ChildPBc     <-cn$ChildPB     -mean(cn$ChildPB     ,na.rm=T)
cn$ChildPHc     <-cn$ChildPH     -mean(cn$ChildPH     ,na.rm=T)
cn$CARatioT100c <-cn$CARatioT100 -mean(cn$CARatioT100 ,na.rm=T)
cn$CARatioW100c <-cn$CARatioW100 -mean(cn$CARatioW100 ,na.rm=T)
cn$CARatioB100c <-cn$CARatioB100 -mean(cn$CARatioB100 ,na.rm=T)
cn$CARatioH100c <-cn$CARatioH100 -mean(cn$CARatioH100 ,na.rm=T)
cn$MalePTc      <-cn$MalePT      -mean(cn$MalePT      ,na.rm=T)
cn$MalePWc      <-cn$MalePW      -mean(cn$MalePW      ,na.rm=T)
cn$MalePBc      <-cn$MalePB      -mean(cn$MalePB      ,na.rm=T)
cn$MalePHc      <-cn$MalePH      -mean(cn$MalePH      ,na.rm=T)
cn$MFRatioT100c <-cn$MFRatioT100 -mean(cn$MFRatioT100 ,na.rm=T)
cn$MFRatioW100c <-cn$MFRatioW100 -mean(cn$MFRatioW100 ,na.rm=T)
cn$MFRatioB100c <-cn$MFRatioB100 -mean(cn$MFRatioB100 ,na.rm=T)
cn$MFRatioH100c <-cn$MFRatioH100 -mean(cn$MFRatioH100 ,na.rm=T)
cn$ElderTc      <-cn$ElderT      -mean(cn$ElderT      ,na.rm=T)
cn$ElderWc      <-cn$ElderW      -mean(cn$ElderW      ,na.rm=T)
cn$ElderBc      <-cn$ElderB      -mean(cn$ElderB      ,na.rm=T)
cn$ElderHc      <-cn$ElderH      -mean(cn$ElderH      ,na.rm=T)
cn$SingleTc     <-cn$SingleT     -mean(cn$SingleT     ,na.rm=T)
cn$SingleWc     <-cn$SingleW     -mean(cn$SingleW     ,na.rm=T)
cn$SingleBc     <-cn$SingleB     -mean(cn$SingleB     ,na.rm=T)
cn$SingleHc     <-cn$SingleH     -mean(cn$SingleH     ,na.rm=T)
cn$FHeadTc      <-cn$FHeadT      -mean(cn$FHeadT      ,na.rm=T)
cn$FHeadWc      <-cn$FHeadW      -mean(cn$FHeadW      ,na.rm=T)
cn$FHeadBc      <-cn$FHeadB      -mean(cn$FHeadB      ,na.rm=T)
cn$FHeadHc      <-cn$FHeadH      -mean(cn$FHeadH      ,na.rm=T)
cn$NoHighTc     <-cn$NoHighT     -mean(cn$NoHighT     ,na.rm=T)
cn$NoHighWc     <-cn$NoHighW     -mean(cn$NoHighW     ,na.rm=T)
cn$NoHighBc     <-cn$NoHighB     -mean(cn$NoHighB     ,na.rm=T)
cn$NoHighHc     <-cn$NoHighH     -mean(cn$NoHighH     ,na.rm=T)
cn$UnempTc      <-cn$UnempT      -mean(cn$UnempT      ,na.rm=T)
cn$UnempWc      <-cn$UnempW      -mean(cn$UnempW      ,na.rm=T)
cn$UnempBc      <-cn$UnempB      -mean(cn$UnempB      ,na.rm=T)
cn$UnempHc      <-cn$UnempH      -mean(cn$UnempH      ,na.rm=T)
cn$CPovTc       <-cn$CPovT       -mean(cn$CPovT       ,na.rm=T)
cn$CPovWc       <-cn$CPovW       -mean(cn$CPovW       ,na.rm=T)
cn$CPovBc       <-cn$CPovB       -mean(cn$CPovB       ,na.rm=T)
cn$CPovHc       <-cn$CPovH       -mean(cn$CPovH       ,na.rm=T)
cn$CPov1c       <-cn$CPov1       -mean(cn$CPov1       ,na.rm=T)
cn$CPov2c       <-cn$CPov2       -mean(cn$CPov2       ,na.rm=T)
cn$CPov3c       <-cn$CPov3       -mean(cn$CPov3       ,na.rm=T)
cn$PubAsTc      <-cn$PubAsT      -mean(cn$PubAsT      ,na.rm=T)
cn$WelfarTc     <-cn$WelfarT     -mean(cn$WelfarT     ,na.rm=T)
cn$SnapTc       <-cn$SnapT       -mean(cn$SnapT       ,na.rm=T)
cn$SnapWc       <-cn$SnapW       -mean(cn$SnapW       ,na.rm=T)
cn$SnapBc       <-cn$SnapB       -mean(cn$SnapB       ,na.rm=T)
cn$SnapHc       <-cn$SnapH       -mean(cn$SnapH       ,na.rm=T)
cn$IncomeT1kc   <-cn$IncomeT1k   -mean(cn$IncomeT1k   ,na.rm=T)
cn$IncomeW1kc   <-cn$IncomeW1k   -mean(cn$IncomeW1k   ,na.rm=T)
cn$IncomeB1kc   <-cn$IncomeB1k   -mean(cn$IncomeB1k   ,na.rm=T)
cn$IncomeH1kc   <-cn$IncomeH1k   -mean(cn$IncomeH1k   ,na.rm=T)
cn$GiniT100c    <-cn$GiniT100    -mean(cn$GiniT100    ,na.rm=T)
cn$HValueT10kc  <-cn$HValueT10k  -mean(cn$HValueT10k  ,na.rm=T)
cn$MCostT100c   <-cn$MCostT100   -mean(cn$MCostT100   ,na.rm=T)
cn$OCostDT100c  <-cn$OCostDT100  -mean(cn$OCostDT100  ,na.rm=T)
cn$MRentDT100c  <-cn$MRentDT100  -mean(cn$MRentDT100  ,na.rm=T)
cn$OCostPTc     <-cn$OCostPT     -mean(cn$OCostPT     ,na.rm=T)
cn$MRentPTc     <-cn$MRentPT     -mean(cn$MRentPT     ,na.rm=T)
cn$MortgTc      <-cn$MortgT      -mean(cn$MortgT      ,na.rm=T)
cn$LangAPTc     <-cn$LangAPT     -mean(cn$LangAPT     ,na.rm=T)
cn$LangAPWc     <-cn$LangAPW     -mean(cn$LangAPW     ,na.rm=T)
cn$LangAPBc     <-cn$LangAPB     -mean(cn$LangAPB     ,na.rm=T)
cn$LangAPHc     <-cn$LangAPH     -mean(cn$LangAPH     ,na.rm=T)
cn$LangBPTc     <-cn$LangBPT     -mean(cn$LangBPT     ,na.rm=T)
cn$LangBPWc     <-cn$LangBPW     -mean(cn$LangBPW     ,na.rm=T)
cn$LangBPBc     <-cn$LangBPB     -mean(cn$LangBPB     ,na.rm=T)
cn$LangBPHc     <-cn$LangBPH     -mean(cn$LangBPH     ,na.rm=T)
cn$LangCPTc     <-cn$LangCPT     -mean(cn$LangCPT     ,na.rm=T)
cn$OutUsTc      <-cn$OutUsT      -mean(cn$OutUsT      ,na.rm=T)
cn$OutUsWc      <-cn$OutUsW      -mean(cn$OutUsW      ,na.rm=T)
cn$OutUsBc      <-cn$OutUsB      -mean(cn$OutUsB      ,na.rm=T)
cn$OutUsHc      <-cn$OutUsH      -mean(cn$OutUsH      ,na.rm=T)
cn$FBornTc      <-cn$FBornT      -mean(cn$FBornT      ,na.rm=T)
cn$FBornWc      <-cn$FBornW      -mean(cn$FBornW      ,na.rm=T)
cn$FBornBc      <-cn$FBornB      -mean(cn$FBornB      ,na.rm=T)
cn$FBornHc      <-cn$FBornH      -mean(cn$FBornH      ,na.rm=T)
cn$NotCtzTc     <-cn$NotCtzT     -mean(cn$NotCtzT     ,na.rm=T)
cn$NotCtzWc     <-cn$NotCtzW     -mean(cn$NotCtzW     ,na.rm=T)
cn$NotCtzBc     <-cn$NotCtzB     -mean(cn$NotCtzB     ,na.rm=T)
cn$NotCtzHc     <-cn$NotCtzH     -mean(cn$NotCtzH     ,na.rm=T)
cn$MoveTc       <-cn$MoveT       -mean(cn$MoveT       ,na.rm=T)
cn$MoveWc       <-cn$MoveW       -mean(cn$MoveW       ,na.rm=T)
cn$MoveBc       <-cn$MoveB       -mean(cn$MoveB       ,na.rm=T)
cn$MoveHc       <-cn$MoveH       -mean(cn$MoveH       ,na.rm=T)
cn$VacantTc     <-cn$VacantT     -mean(cn$VacantT     ,na.rm=T)
cn$OwnerTc      <-cn$OwnerT      -mean(cn$OwnerT      ,na.rm=T)
cn$OwnerWc      <-cn$OwnerW      -mean(cn$OwnerW      ,na.rm=T)
cn$OwnerBc      <-cn$OwnerB      -mean(cn$OwnerB      ,na.rm=T)
cn$OwnerHc      <-cn$OwnerH      -mean(cn$OwnerH      ,na.rm=T)
cn$CrowdTc      <-cn$CrowdT      -mean(cn$CrowdT      ,na.rm=T)
cn$CrowdWc      <-cn$CrowdW      -mean(cn$CrowdW      ,na.rm=T)
cn$CrowdBc      <-cn$CrowdB      -mean(cn$CrowdB      ,na.rm=T)
cn$CrowdHc      <-cn$CrowdH      -mean(cn$CrowdH      ,na.rm=T)
cn$MobileTc     <-cn$MobileT     -mean(cn$MobileT     ,na.rm=T)
cn$MobileWc     <-cn$MobileW     -mean(cn$MobileW     ,na.rm=T)
cn$MobileBc     <-cn$MobileB     -mean(cn$MobileB     ,na.rm=T)
cn$MobileHc     <-cn$MobileH     -mean(cn$MobileH     ,na.rm=T)
cn$DisablTc     <-cn$DisablT     -mean(cn$DisablT     ,na.rm=T)
cn$DisablWc     <-cn$DisablW     -mean(cn$DisablW     ,na.rm=T)
cn$DisablBc     <-cn$DisablB     -mean(cn$DisablB     ,na.rm=T)
cn$DisablHc     <-cn$DisablH     -mean(cn$DisablH     ,na.rm=T)
cn$DisablTCc    <-cn$DisablTC    -mean(cn$DisablTC    ,na.rm=T)
cn$DisablWCc    <-cn$DisablWC    -mean(cn$DisablWC    ,na.rm=T)
cn$DisablBCc    <-cn$DisablBC    -mean(cn$DisablBC    ,na.rm=T)
cn$DisablHCc    <-cn$DisablHC    -mean(cn$DisablHC    ,na.rm=T)
cn$DisablTMc    <-cn$DisablTM    -mean(cn$DisablTM    ,na.rm=T)
cn$DisablTFc    <-cn$DisablTF    -mean(cn$DisablTF    ,na.rm=T)
cn$Urban1c      <-cn$Urban1      -mean(cn$Urban1      ,na.rm=T)
cn$Urban2c      <-cn$Urban2      -mean(cn$Urban2      ,na.rm=T)
cn$LBWT1rc      <-cn$LBWT1r      -mean(cn$LBWT1r      ,na.rm=T)
cn$LBWM1rc      <-cn$LBWM1r      -mean(cn$LBWM1r      ,na.rm=T)
cn$LBWF1rc      <-cn$LBWF1r      -mean(cn$LBWF1r      ,na.rm=T)
cn$LBWW1rc      <-cn$LBWW1r      -mean(cn$LBWW1r      ,na.rm=T)
cn$LBWB1rc      <-cn$LBWB1r      -mean(cn$LBWB1r      ,na.rm=T)
cn$LBWH1rc      <-cn$LBWH1r      -mean(cn$LBWH1r      ,na.rm=T)
cn$PTBT1rc      <-cn$PTBT1r      -mean(cn$PTBT1r      ,na.rm=T)
cn$PTBM1rc      <-cn$PTBM1r      -mean(cn$PTBM1r      ,na.rm=T)
cn$PTBF1rc      <-cn$PTBF1r      -mean(cn$PTBF1r      ,na.rm=T)
cn$PTBW1rc      <-cn$PTBW1r      -mean(cn$PTBW1r      ,na.rm=T)
cn$PTBB1rc      <-cn$PTBB1r      -mean(cn$PTBB1r      ,na.rm=T)
cn$PTBH1rc      <-cn$PTBH1r      -mean(cn$PTBH1r      ,na.rm=T)
cn$PNCT1rc      <-cn$PNCT1r      -mean(cn$PNCT1r      ,na.rm=T)
cn$PNCM1rc      <-cn$PNCM1r      -mean(cn$PNCM1r      ,na.rm=T)
cn$PNCF1rc      <-cn$PNCF1r      -mean(cn$PNCF1r      ,na.rm=T)
cn$PNCW1rc      <-cn$PNCW1r      -mean(cn$PNCW1r      ,na.rm=T)
cn$PNCB1rc      <-cn$PNCB1r      -mean(cn$PNCB1r      ,na.rm=T)
cn$PNCH1rc      <-cn$PNCH1r      -mean(cn$PNCH1r      ,na.rm=T)
cn$TBBT1rc      <-cn$TBBT1r      -mean(cn$TBBT1r      ,na.rm=T)
cn$TBBM1rc      <-cn$TBBM1r      -mean(cn$TBBM1r      ,na.rm=T)
cn$TBBF1rc      <-cn$TBBF1r      -mean(cn$TBBF1r      ,na.rm=T)
cn$TBBW1rc      <-cn$TBBW1r      -mean(cn$TBBW1r      ,na.rm=T)
cn$TBBB1rc      <-cn$TBBB1r      -mean(cn$TBBB1r      ,na.rm=T)
cn$TBBH1rc      <-cn$TBBH1r      -mean(cn$TBBH1r      ,na.rm=T)
cn$TBTT1rc      <-cn$TBTT1r      -mean(cn$TBTT1r      ,na.rm=T)
cn$TBTM1rc      <-cn$TBTM1r      -mean(cn$TBTM1r      ,na.rm=T)
cn$TBTF1rc      <-cn$TBTF1r      -mean(cn$TBTF1r      ,na.rm=T)
cn$TBTW1rc      <-cn$TBTW1r      -mean(cn$TBTW1r      ,na.rm=T)
cn$TBTB1rc      <-cn$TBTB1r      -mean(cn$TBTB1r      ,na.rm=T)
cn$TBTH1rc      <-cn$TBTH1r      -mean(cn$TBTH1r      ,na.rm=T)
cn$LBWT5rc      <-cn$LBWT5r      -mean(cn$LBWT5r      ,na.rm=T)
cn$LBWM5rc      <-cn$LBWM5r      -mean(cn$LBWM5r      ,na.rm=T)
cn$LBWF5rc      <-cn$LBWF5r      -mean(cn$LBWF5r      ,na.rm=T)
cn$LBWW5rc      <-cn$LBWW5r      -mean(cn$LBWW5r      ,na.rm=T)
cn$LBWB5rc      <-cn$LBWB5r      -mean(cn$LBWB5r      ,na.rm=T)
cn$LBWH5rc      <-cn$LBWH5r      -mean(cn$LBWH5r      ,na.rm=T)
cn$PTBT5rc      <-cn$PTBT5r      -mean(cn$PTBT5r      ,na.rm=T)
cn$PTBM5rc      <-cn$PTBM5r      -mean(cn$PTBM5r      ,na.rm=T)
cn$PTBF5rc      <-cn$PTBF5r      -mean(cn$PTBF5r      ,na.rm=T)
cn$PTBW5rc      <-cn$PTBW5r      -mean(cn$PTBW5r      ,na.rm=T)
cn$PTBB5rc      <-cn$PTBB5r      -mean(cn$PTBB5r      ,na.rm=T)
cn$PTBH5rc      <-cn$PTBH5r      -mean(cn$PTBH5r      ,na.rm=T)
cn$PNCT5rc      <-cn$PNCT5r      -mean(cn$PNCT5r      ,na.rm=T)
cn$PNCM5rc      <-cn$PNCM5r      -mean(cn$PNCM5r      ,na.rm=T)
cn$PNCF5rc      <-cn$PNCF5r      -mean(cn$PNCF5r      ,na.rm=T)
cn$PNCW5rc      <-cn$PNCW5r      -mean(cn$PNCW5r      ,na.rm=T)
cn$PNCB5rc      <-cn$PNCB5r      -mean(cn$PNCB5r      ,na.rm=T)
cn$PNCH5rc      <-cn$PNCH5r      -mean(cn$PNCH5r      ,na.rm=T)
cn$TBBT5rc      <-cn$TBBT5r      -mean(cn$TBBT5r      ,na.rm=T)
cn$TBBM5rc      <-cn$TBBM5r      -mean(cn$TBBM5r      ,na.rm=T)
cn$TBBF5rc      <-cn$TBBF5r      -mean(cn$TBBF5r      ,na.rm=T)
cn$TBBW5rc      <-cn$TBBW5r      -mean(cn$TBBW5r      ,na.rm=T)
cn$TBBB5rc      <-cn$TBBB5r      -mean(cn$TBBB5r      ,na.rm=T)
cn$TBBH5rc      <-cn$TBBH5r      -mean(cn$TBBH5r      ,na.rm=T)
cn$TBTT5rc      <-cn$TBTT5r      -mean(cn$TBTT5r      ,na.rm=T)
cn$TBTM5rc      <-cn$TBTM5r      -mean(cn$TBTM5r      ,na.rm=T)
cn$TBTF5rc      <-cn$TBTF5r      -mean(cn$TBTF5r      ,na.rm=T)
cn$TBTW5rc      <-cn$TBTW5r      -mean(cn$TBTW5r      ,na.rm=T)
cn$TBTB5rc      <-cn$TBTB5r      -mean(cn$TBTB5r      ,na.rm=T)
cn$TBTH5rc      <-cn$TBTH5r      -mean(cn$TBTH5r      ,na.rm=T)
cn$Opioidc      <-cn$Opioid      -mean(cn$Opioid      ,na.rm=T)
cn$LifeExpc     <-cn$LifeExp     -mean(cn$LifeExp     ,na.rm=T)
cn$LifeExpBc    <-cn$LifeExpB    -mean(cn$LifeExpB    ,na.rm=T)
cn$LifeExpHc    <-cn$LifeExpH    -mean(cn$LifeExpH    ,na.rm=T)
cn$LifeExpWc    <-cn$LifeExpW    -mean(cn$LifeExpW    ,na.rm=T)
cn$ChdDeathc    <-cn$ChdDeath    -mean(cn$ChdDeath    ,na.rm=T)
cn$ChdDeathBc   <-cn$ChdDeathB   -mean(cn$ChdDeathB   ,na.rm=T)
cn$ChdDeathHc   <-cn$ChdDeathH   -mean(cn$ChdDeathH   ,na.rm=T)
cn$ChdDeathWc   <-cn$ChdDeathW   -mean(cn$ChdDeathW   ,na.rm=T)
cn$InfDeathc    <-cn$InfDeath    -mean(cn$InfDeath    ,na.rm=T)
cn$InfDeathBc   <-cn$InfDeathB   -mean(cn$InfDeathB   ,na.rm=T)
cn$InfDeathHc   <-cn$InfDeathH   -mean(cn$InfDeathH   ,na.rm=T)
cn$InfDeathWc   <-cn$InfDeathW   -mean(cn$InfDeathW   ,na.rm=T)
cn$Injuryc      <-cn$Injury      -mean(cn$Injury      ,na.rm=T)
cn$InjuryBc     <-cn$InjuryB     -mean(cn$InjuryB     ,na.rm=T)
cn$InjuryHc     <-cn$InjuryH     -mean(cn$InjuryH     ,na.rm=T)
cn$InjuryWc     <-cn$InjuryW     -mean(cn$InjuryW     ,na.rm=T)
cn$GunDeathc    <-cn$GunDeath    -mean(cn$GunDeath    ,na.rm=T)
cn$GunDeathBc   <-cn$GunDeathB   -mean(cn$GunDeathB   ,na.rm=T)
cn$GunDeathWc   <-cn$GunDeathW   -mean(cn$GunDeathW   ,na.rm=T)
cn$PrmDeath_c   <-cn$PrmDeath    -mean(cn$PrmDeath    ,na.rm=T)
cn$PrmDeathcc   <-cn$PrmDeathc   -mean(cn$PrmDeathc   ,na.rm=T)
cn$PrmDeathBc   <-cn$PrmDeathB   -mean(cn$PrmDeathB   ,na.rm=T)
cn$PrmDeathHc   <-cn$PrmDeathH   -mean(cn$PrmDeathH   ,na.rm=T)
cn$PrmDeathWc   <-cn$PrmDeathW   -mean(cn$PrmDeathW   ,na.rm=T)
cn$PrmDeath2_c  <-cn$PrmDeath2   -mean(cn$PrmDeath2   ,na.rm=T)
cn$PrmDeath2cc  <-cn$PrmDeath2c  -mean(cn$PrmDeath2c  ,na.rm=T)
cn$PrmDeath2Bc  <-cn$PrmDeath2B  -mean(cn$PrmDeath2B  ,na.rm=T)
cn$PrmDeath2Hc  <-cn$PrmDeath2H  -mean(cn$PrmDeath2H  ,na.rm=T)
cn$PrmDeath2Wc  <-cn$PrmDeath2W  -mean(cn$PrmDeath2W  ,na.rm=T)
cn$Suicidec     <-cn$Suicide     -mean(cn$Suicide     ,na.rm=T)
cn$Diabetc      <-cn$Diabet      -mean(cn$Diabet      ,na.rm=T)
cn$Obesityc     <-cn$Obesity     -mean(cn$Obesity     ,na.rm=T)
cn$Physicalc    <-cn$Physical    -mean(cn$Physical    ,na.rm=T)
cn$PoorHlthc    <-cn$PoorHlth    -mean(cn$PoorHlth    ,na.rm=T)
cn$PoorMHc      <-cn$PoorMH      -mean(cn$PoorMH      ,na.rm=T)
cn$PoorPhyc     <-cn$PoorPhy     -mean(cn$PoorPhy     ,na.rm=T)
cn$Sleepc       <-cn$Sleep       -mean(cn$Sleep       ,na.rm=T)
cn$DrugOdc      <-cn$DrugOd      -mean(cn$DrugOd      ,na.rm=T)
cn$DrugOdBc     <-cn$DrugOdB     -mean(cn$DrugOdB     ,na.rm=T)
cn$DrugOdHc     <-cn$DrugOdH     -mean(cn$DrugOdH     ,na.rm=T)
cn$DrugOdWc     <-cn$DrugOdW     -mean(cn$DrugOdW     ,na.rm=T)
cn$DWIDeathc    <-cn$DWIDeath    -mean(cn$DWIDeath    ,na.rm=T)
cn$EDrinkc      <-cn$EDrink      -mean(cn$EDrink      ,na.rm=T)
cn$Smokec       <-cn$Smoke       -mean(cn$Smoke       ,na.rm=T)
cn$FastFoodc    <-cn$FastFood    -mean(cn$FastFood    ,na.rm=T)
cn$FoodEnvc     <-cn$FoodEnv     -mean(cn$FoodEnv     ,na.rm=T)
cn$FoodInsc     <-cn$FoodIns     -mean(cn$FoodIns     ,na.rm=T)
cn$FrLunchc     <-cn$FrLunch     -mean(cn$FrLunch     ,na.rm=T)
cn$LAccFoodc    <-cn$LAccFood    -mean(cn$LAccFood    ,na.rm=T)
cn$Gymc         <-cn$Gym         -mean(cn$Gym         ,na.rm=T)
cn$Gym2c        <-cn$Gym2        -mean(cn$Gym2        ,na.rm=T)
cn$Inactivec    <-cn$Inactive    -mean(cn$Inactive    ,na.rm=T)
cn$HousCostc    <-cn$HousCost    -mean(cn$HousCost    ,na.rm=T)
cn$HousCostsc   <-cn$HousCosts   -mean(cn$HousCosts   ,na.rm=T)
cn$HousCrowdc   <-cn$HousCrowd   -mean(cn$HousCrowd   ,na.rm=T)
cn$Housingc     <-cn$Housing     -mean(cn$Housing     ,na.rm=T)
cn$HousPlumbc   <-cn$HousPlumb   -mean(cn$HousPlumb   ,na.rm=T)
cn$Insuredc     <-cn$Insured     -mean(cn$Insured     ,na.rm=T)
cn$InsuredAc    <-cn$InsuredA    -mean(cn$InsuredA    ,na.rm=T)
cn$InsuredCc    <-cn$InsuredC    -mean(cn$InsuredC    ,na.rm=T)
cn$JuvArrc      <-cn$JuvArr      -mean(cn$JuvArr      ,na.rm=T)
cn$Murderc      <-cn$Murder      -mean(cn$Murder      ,na.rm=T)
cn$Violentc     <-cn$Violent     -mean(cn$Violent     ,na.rm=T)
cn$LongCommc    <-cn$LongComm    -mean(cn$LongComm    ,na.rm=T)
cn$LowBWc       <-cn$LowBW       -mean(cn$LowBW       ,na.rm=T)
cn$LowBWBc      <-cn$LowBWB      -mean(cn$LowBWB      ,na.rm=T)
cn$LowBWHc      <-cn$LowBWH      -mean(cn$LowBWH      ,na.rm=T)
cn$LowBWWc      <-cn$LowBWW      -mean(cn$LowBWW      ,na.rm=T)
cn$TeenBthc     <-cn$TeenBth     -mean(cn$TeenBth     ,na.rm=T)
cn$TeenBthBc    <-cn$TeenBthB    -mean(cn$TeenBthB    ,na.rm=T)
cn$TeenBthHc    <-cn$TeenBthH    -mean(cn$TeenBthH    ,na.rm=T)
cn$TeenBthWc    <-cn$TeenBthW    -mean(cn$TeenBthW    ,na.rm=T)
cn$Mentalc      <-cn$Mental      -mean(cn$Mental      ,na.rm=T)
cn$MHPrvdc      <-cn$MHPrvd      -mean(cn$MHPrvd      ,na.rm=T)
cn$PCPc         <-cn$PCP         -mean(cn$PCP         ,na.rm=T)
cn$PCP2c        <-cn$PCP2        -mean(cn$PCP2        ,na.rm=T)
cn$Dentistc     <-cn$Dentist     -mean(cn$Dentist     ,na.rm=T)
cn$PrvtHospc    <-cn$PrvtHosp    -mean(cn$PrvtHosp    ,na.rm=T)
cn$PrvtHospBc   <-cn$PrvtHospB   -mean(cn$PrvtHospB   ,na.rm=T)
cn$PrvtHospHc   <-cn$PrvtHospH   -mean(cn$PrvtHospH   ,na.rm=T)
cn$PrvtHospWc   <-cn$PrvtHospW   -mean(cn$PrvtHospW   ,na.rm=T)
cn$SegBWc       <-cn$SegBW       -mean(cn$SegBW       ,na.rm=T)
cn$SegNWc       <-cn$SegNW       -mean(cn$SegNW       ,na.rm=T)
cn$SocAssoc     <-cn$SocAsso     -mean(cn$SocAsso     ,na.rm=T)
cn$SocSuppc     <-cn$SocSupp     -mean(cn$SocSupp     ,na.rm=T)
cn$MIECHVc      <-cn$MIECHV      -mean(cn$MIECHV      ,na.rm=T)
cn$NHVRCc       <-cn$NHVRC       -mean(cn$NHVRC       ,na.rm=T)
cn$FoodInsecurec<-cn$FoodInsecure-mean(cn$FoodInsecure,na.rm=T)
cn$PCPAllc      <-cn$PCPAll      -mean(cn$PCPAll      ,na.rm=T)
cn$MH_PCPc      <-cn$MH_PCP      -mean(cn$MH_PCP      ,na.rm=T)

cn<-cbind(cn,demean(cn,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cnm01<-lmer(NegTr~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
# Mental Health
cnm02<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm03<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm04<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
cnm05<-lmer(NegTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm06<-lmer(NegTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm07<-lmer(NegTr~Yearf+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm08<-lmer(NegTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
cnm09<-lmer(NegTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm10<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm11<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm12<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm13<-lmer(NegTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
BIC(cnm04,cnm05,cnm06,cnm07,cnm08,cnm09,cnm10,cnm11,cnm12,cnm13)
summary(cnm12)

# Physical Health
cnm22<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm23<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm24<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
cnm25<-lmer(NegTr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm26<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm27<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
cnm28<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
cnm29<-lmer(NegTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Physicalc_within|CountyFIPS)+(1|StateFIPS),data=cn,control=lmerControl(optimizer="bobyqa"))
BIC(cnm24,cnm25,cnm26,cnm27,cnm28,cnm29)
summary(cnm29)

# bootstrap confidence interval
cnm12CI<-confint(cnm12,method='boot',nsim=500,boot.type='perc')
cnm29CI<-confint(cnm29,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cnm12)
check_collinearity(cnm29)
isSingular(cnm12)
isSingular(cnm29)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cp$CPopBPc      <-cp$CPopBP      -mean(cp$CPopBP      ,na.rm=T)
cp$CPopHPc      <-cp$CPopHP      -mean(cp$CPopHP      ,na.rm=T)
cp$ChildPTc     <-cp$ChildPT     -mean(cp$ChildPT     ,na.rm=T)
cp$ChildPWc     <-cp$ChildPW     -mean(cp$ChildPW     ,na.rm=T)
cp$ChildPBc     <-cp$ChildPB     -mean(cp$ChildPB     ,na.rm=T)
cp$ChildPHc     <-cp$ChildPH     -mean(cp$ChildPH     ,na.rm=T)
cp$CARatioT100c <-cp$CARatioT100 -mean(cp$CARatioT100 ,na.rm=T)
cp$CARatioW100c <-cp$CARatioW100 -mean(cp$CARatioW100 ,na.rm=T)
cp$CARatioB100c <-cp$CARatioB100 -mean(cp$CARatioB100 ,na.rm=T)
cp$CARatioH100c <-cp$CARatioH100 -mean(cp$CARatioH100 ,na.rm=T)
cp$MalePTc      <-cp$MalePT      -mean(cp$MalePT      ,na.rm=T)
cp$MalePWc      <-cp$MalePW      -mean(cp$MalePW      ,na.rm=T)
cp$MalePBc      <-cp$MalePB      -mean(cp$MalePB      ,na.rm=T)
cp$MalePHc      <-cp$MalePH      -mean(cp$MalePH      ,na.rm=T)
cp$MFRatioT100c <-cp$MFRatioT100 -mean(cp$MFRatioT100 ,na.rm=T)
cp$MFRatioW100c <-cp$MFRatioW100 -mean(cp$MFRatioW100 ,na.rm=T)
cp$MFRatioB100c <-cp$MFRatioB100 -mean(cp$MFRatioB100 ,na.rm=T)
cp$MFRatioH100c <-cp$MFRatioH100 -mean(cp$MFRatioH100 ,na.rm=T)
cp$ElderTc      <-cp$ElderT      -mean(cp$ElderT      ,na.rm=T)
cp$ElderWc      <-cp$ElderW      -mean(cp$ElderW      ,na.rm=T)
cp$ElderBc      <-cp$ElderB      -mean(cp$ElderB      ,na.rm=T)
cp$ElderHc      <-cp$ElderH      -mean(cp$ElderH      ,na.rm=T)
cp$SingleTc     <-cp$SingleT     -mean(cp$SingleT     ,na.rm=T)
cp$SingleWc     <-cp$SingleW     -mean(cp$SingleW     ,na.rm=T)
cp$SingleBc     <-cp$SingleB     -mean(cp$SingleB     ,na.rm=T)
cp$SingleHc     <-cp$SingleH     -mean(cp$SingleH     ,na.rm=T)
cp$FHeadTc      <-cp$FHeadT      -mean(cp$FHeadT      ,na.rm=T)
cp$FHeadWc      <-cp$FHeadW      -mean(cp$FHeadW      ,na.rm=T)
cp$FHeadBc      <-cp$FHeadB      -mean(cp$FHeadB      ,na.rm=T)
cp$FHeadHc      <-cp$FHeadH      -mean(cp$FHeadH      ,na.rm=T)
cp$NoHighTc     <-cp$NoHighT     -mean(cp$NoHighT     ,na.rm=T)
cp$NoHighWc     <-cp$NoHighW     -mean(cp$NoHighW     ,na.rm=T)
cp$NoHighBc     <-cp$NoHighB     -mean(cp$NoHighB     ,na.rm=T)
cp$NoHighHc     <-cp$NoHighH     -mean(cp$NoHighH     ,na.rm=T)
cp$UnempTc      <-cp$UnempT      -mean(cp$UnempT      ,na.rm=T)
cp$UnempWc      <-cp$UnempW      -mean(cp$UnempW      ,na.rm=T)
cp$UnempBc      <-cp$UnempB      -mean(cp$UnempB      ,na.rm=T)
cp$UnempHc      <-cp$UnempH      -mean(cp$UnempH      ,na.rm=T)
cp$CPovTc       <-cp$CPovT       -mean(cp$CPovT       ,na.rm=T)
cp$CPovWc       <-cp$CPovW       -mean(cp$CPovW       ,na.rm=T)
cp$CPovBc       <-cp$CPovB       -mean(cp$CPovB       ,na.rm=T)
cp$CPovHc       <-cp$CPovH       -mean(cp$CPovH       ,na.rm=T)
cp$CPov1c       <-cp$CPov1       -mean(cp$CPov1       ,na.rm=T)
cp$CPov2c       <-cp$CPov2       -mean(cp$CPov2       ,na.rm=T)
cp$CPov3c       <-cp$CPov3       -mean(cp$CPov3       ,na.rm=T)
cp$PubAsTc      <-cp$PubAsT      -mean(cp$PubAsT      ,na.rm=T)
cp$WelfarTc     <-cp$WelfarT     -mean(cp$WelfarT     ,na.rm=T)
cp$SnapTc       <-cp$SnapT       -mean(cp$SnapT       ,na.rm=T)
cp$SnapWc       <-cp$SnapW       -mean(cp$SnapW       ,na.rm=T)
cp$SnapBc       <-cp$SnapB       -mean(cp$SnapB       ,na.rm=T)
cp$SnapHc       <-cp$SnapH       -mean(cp$SnapH       ,na.rm=T)
cp$IncomeT1kc   <-cp$IncomeT1k   -mean(cp$IncomeT1k   ,na.rm=T)
cp$IncomeW1kc   <-cp$IncomeW1k   -mean(cp$IncomeW1k   ,na.rm=T)
cp$IncomeB1kc   <-cp$IncomeB1k   -mean(cp$IncomeB1k   ,na.rm=T)
cp$IncomeH1kc   <-cp$IncomeH1k   -mean(cp$IncomeH1k   ,na.rm=T)
cp$GiniT100c    <-cp$GiniT100    -mean(cp$GiniT100    ,na.rm=T)
cp$HValueT10kc  <-cp$HValueT10k  -mean(cp$HValueT10k  ,na.rm=T)
cp$MCostT100c   <-cp$MCostT100   -mean(cp$MCostT100   ,na.rm=T)
cp$OCostDT100c  <-cp$OCostDT100  -mean(cp$OCostDT100  ,na.rm=T)
cp$MRentDT100c  <-cp$MRentDT100  -mean(cp$MRentDT100  ,na.rm=T)
cp$OCostPTc     <-cp$OCostPT     -mean(cp$OCostPT     ,na.rm=T)
cp$MRentPTc     <-cp$MRentPT     -mean(cp$MRentPT     ,na.rm=T)
cp$MortgTc      <-cp$MortgT      -mean(cp$MortgT      ,na.rm=T)
cp$LangAPTc     <-cp$LangAPT     -mean(cp$LangAPT     ,na.rm=T)
cp$LangAPWc     <-cp$LangAPW     -mean(cp$LangAPW     ,na.rm=T)
cp$LangAPBc     <-cp$LangAPB     -mean(cp$LangAPB     ,na.rm=T)
cp$LangAPHc     <-cp$LangAPH     -mean(cp$LangAPH     ,na.rm=T)
cp$LangBPTc     <-cp$LangBPT     -mean(cp$LangBPT     ,na.rm=T)
cp$LangBPWc     <-cp$LangBPW     -mean(cp$LangBPW     ,na.rm=T)
cp$LangBPBc     <-cp$LangBPB     -mean(cp$LangBPB     ,na.rm=T)
cp$LangBPHc     <-cp$LangBPH     -mean(cp$LangBPH     ,na.rm=T)
cp$LangCPTc     <-cp$LangCPT     -mean(cp$LangCPT     ,na.rm=T)
cp$OutUsTc      <-cp$OutUsT      -mean(cp$OutUsT      ,na.rm=T)
cp$OutUsWc      <-cp$OutUsW      -mean(cp$OutUsW      ,na.rm=T)
cp$OutUsBc      <-cp$OutUsB      -mean(cp$OutUsB      ,na.rm=T)
cp$OutUsHc      <-cp$OutUsH      -mean(cp$OutUsH      ,na.rm=T)
cp$FBornTc      <-cp$FBornT      -mean(cp$FBornT      ,na.rm=T)
cp$FBornWc      <-cp$FBornW      -mean(cp$FBornW      ,na.rm=T)
cp$FBornBc      <-cp$FBornB      -mean(cp$FBornB      ,na.rm=T)
cp$FBornHc      <-cp$FBornH      -mean(cp$FBornH      ,na.rm=T)
cp$NotCtzTc     <-cp$NotCtzT     -mean(cp$NotCtzT     ,na.rm=T)
cp$NotCtzWc     <-cp$NotCtzW     -mean(cp$NotCtzW     ,na.rm=T)
cp$NotCtzBc     <-cp$NotCtzB     -mean(cp$NotCtzB     ,na.rm=T)
cp$NotCtzHc     <-cp$NotCtzH     -mean(cp$NotCtzH     ,na.rm=T)
cp$MoveTc       <-cp$MoveT       -mean(cp$MoveT       ,na.rm=T)
cp$MoveWc       <-cp$MoveW       -mean(cp$MoveW       ,na.rm=T)
cp$MoveBc       <-cp$MoveB       -mean(cp$MoveB       ,na.rm=T)
cp$MoveHc       <-cp$MoveH       -mean(cp$MoveH       ,na.rm=T)
cp$VacantTc     <-cp$VacantT     -mean(cp$VacantT     ,na.rm=T)
cp$OwnerTc      <-cp$OwnerT      -mean(cp$OwnerT      ,na.rm=T)
cp$OwnerWc      <-cp$OwnerW      -mean(cp$OwnerW      ,na.rm=T)
cp$OwnerBc      <-cp$OwnerB      -mean(cp$OwnerB      ,na.rm=T)
cp$OwnerHc      <-cp$OwnerH      -mean(cp$OwnerH      ,na.rm=T)
cp$CrowdTc      <-cp$CrowdT      -mean(cp$CrowdT      ,na.rm=T)
cp$CrowdWc      <-cp$CrowdW      -mean(cp$CrowdW      ,na.rm=T)
cp$CrowdBc      <-cp$CrowdB      -mean(cp$CrowdB      ,na.rm=T)
cp$CrowdHc      <-cp$CrowdH      -mean(cp$CrowdH      ,na.rm=T)
cp$MobileTc     <-cp$MobileT     -mean(cp$MobileT     ,na.rm=T)
cp$MobileWc     <-cp$MobileW     -mean(cp$MobileW     ,na.rm=T)
cp$MobileBc     <-cp$MobileB     -mean(cp$MobileB     ,na.rm=T)
cp$MobileHc     <-cp$MobileH     -mean(cp$MobileH     ,na.rm=T)
cp$DisablTc     <-cp$DisablT     -mean(cp$DisablT     ,na.rm=T)
cp$DisablWc     <-cp$DisablW     -mean(cp$DisablW     ,na.rm=T)
cp$DisablBc     <-cp$DisablB     -mean(cp$DisablB     ,na.rm=T)
cp$DisablHc     <-cp$DisablH     -mean(cp$DisablH     ,na.rm=T)
cp$DisablTCc    <-cp$DisablTC    -mean(cp$DisablTC    ,na.rm=T)
cp$DisablWCc    <-cp$DisablWC    -mean(cp$DisablWC    ,na.rm=T)
cp$DisablBCc    <-cp$DisablBC    -mean(cp$DisablBC    ,na.rm=T)
cp$DisablHCc    <-cp$DisablHC    -mean(cp$DisablHC    ,na.rm=T)
cp$DisablTMc    <-cp$DisablTM    -mean(cp$DisablTM    ,na.rm=T)
cp$DisablTFc    <-cp$DisablTF    -mean(cp$DisablTF    ,na.rm=T)
cp$Urban1c      <-cp$Urban1      -mean(cp$Urban1      ,na.rm=T)
cp$Urban2c      <-cp$Urban2      -mean(cp$Urban2      ,na.rm=T)
cp$LBWT1rc      <-cp$LBWT1r      -mean(cp$LBWT1r      ,na.rm=T)
cp$LBWM1rc      <-cp$LBWM1r      -mean(cp$LBWM1r      ,na.rm=T)
cp$LBWF1rc      <-cp$LBWF1r      -mean(cp$LBWF1r      ,na.rm=T)
cp$LBWW1rc      <-cp$LBWW1r      -mean(cp$LBWW1r      ,na.rm=T)
cp$LBWB1rc      <-cp$LBWB1r      -mean(cp$LBWB1r      ,na.rm=T)
cp$LBWH1rc      <-cp$LBWH1r      -mean(cp$LBWH1r      ,na.rm=T)
cp$PTBT1rc      <-cp$PTBT1r      -mean(cp$PTBT1r      ,na.rm=T)
cp$PTBM1rc      <-cp$PTBM1r      -mean(cp$PTBM1r      ,na.rm=T)
cp$PTBF1rc      <-cp$PTBF1r      -mean(cp$PTBF1r      ,na.rm=T)
cp$PTBW1rc      <-cp$PTBW1r      -mean(cp$PTBW1r      ,na.rm=T)
cp$PTBB1rc      <-cp$PTBB1r      -mean(cp$PTBB1r      ,na.rm=T)
cp$PTBH1rc      <-cp$PTBH1r      -mean(cp$PTBH1r      ,na.rm=T)
cp$PNCT1rc      <-cp$PNCT1r      -mean(cp$PNCT1r      ,na.rm=T)
cp$PNCM1rc      <-cp$PNCM1r      -mean(cp$PNCM1r      ,na.rm=T)
cp$PNCF1rc      <-cp$PNCF1r      -mean(cp$PNCF1r      ,na.rm=T)
cp$PNCW1rc      <-cp$PNCW1r      -mean(cp$PNCW1r      ,na.rm=T)
cp$PNCB1rc      <-cp$PNCB1r      -mean(cp$PNCB1r      ,na.rm=T)
cp$PNCH1rc      <-cp$PNCH1r      -mean(cp$PNCH1r      ,na.rm=T)
cp$TBBT1rc      <-cp$TBBT1r      -mean(cp$TBBT1r      ,na.rm=T)
cp$TBBM1rc      <-cp$TBBM1r      -mean(cp$TBBM1r      ,na.rm=T)
cp$TBBF1rc      <-cp$TBBF1r      -mean(cp$TBBF1r      ,na.rm=T)
cp$TBBW1rc      <-cp$TBBW1r      -mean(cp$TBBW1r      ,na.rm=T)
cp$TBBB1rc      <-cp$TBBB1r      -mean(cp$TBBB1r      ,na.rm=T)
cp$TBBH1rc      <-cp$TBBH1r      -mean(cp$TBBH1r      ,na.rm=T)
cp$TBTT1rc      <-cp$TBTT1r      -mean(cp$TBTT1r      ,na.rm=T)
cp$TBTM1rc      <-cp$TBTM1r      -mean(cp$TBTM1r      ,na.rm=T)
cp$TBTF1rc      <-cp$TBTF1r      -mean(cp$TBTF1r      ,na.rm=T)
cp$TBTW1rc      <-cp$TBTW1r      -mean(cp$TBTW1r      ,na.rm=T)
cp$TBTB1rc      <-cp$TBTB1r      -mean(cp$TBTB1r      ,na.rm=T)
cp$TBTH1rc      <-cp$TBTH1r      -mean(cp$TBTH1r      ,na.rm=T)
cp$LBWT5rc      <-cp$LBWT5r      -mean(cp$LBWT5r      ,na.rm=T)
cp$LBWM5rc      <-cp$LBWM5r      -mean(cp$LBWM5r      ,na.rm=T)
cp$LBWF5rc      <-cp$LBWF5r      -mean(cp$LBWF5r      ,na.rm=T)
cp$LBWW5rc      <-cp$LBWW5r      -mean(cp$LBWW5r      ,na.rm=T)
cp$LBWB5rc      <-cp$LBWB5r      -mean(cp$LBWB5r      ,na.rm=T)
cp$LBWH5rc      <-cp$LBWH5r      -mean(cp$LBWH5r      ,na.rm=T)
cp$PTBT5rc      <-cp$PTBT5r      -mean(cp$PTBT5r      ,na.rm=T)
cp$PTBM5rc      <-cp$PTBM5r      -mean(cp$PTBM5r      ,na.rm=T)
cp$PTBF5rc      <-cp$PTBF5r      -mean(cp$PTBF5r      ,na.rm=T)
cp$PTBW5rc      <-cp$PTBW5r      -mean(cp$PTBW5r      ,na.rm=T)
cp$PTBB5rc      <-cp$PTBB5r      -mean(cp$PTBB5r      ,na.rm=T)
cp$PTBH5rc      <-cp$PTBH5r      -mean(cp$PTBH5r      ,na.rm=T)
cp$PNCT5rc      <-cp$PNCT5r      -mean(cp$PNCT5r      ,na.rm=T)
cp$PNCM5rc      <-cp$PNCM5r      -mean(cp$PNCM5r      ,na.rm=T)
cp$PNCF5rc      <-cp$PNCF5r      -mean(cp$PNCF5r      ,na.rm=T)
cp$PNCW5rc      <-cp$PNCW5r      -mean(cp$PNCW5r      ,na.rm=T)
cp$PNCB5rc      <-cp$PNCB5r      -mean(cp$PNCB5r      ,na.rm=T)
cp$PNCH5rc      <-cp$PNCH5r      -mean(cp$PNCH5r      ,na.rm=T)
cp$TBBT5rc      <-cp$TBBT5r      -mean(cp$TBBT5r      ,na.rm=T)
cp$TBBM5rc      <-cp$TBBM5r      -mean(cp$TBBM5r      ,na.rm=T)
cp$TBBF5rc      <-cp$TBBF5r      -mean(cp$TBBF5r      ,na.rm=T)
cp$TBBW5rc      <-cp$TBBW5r      -mean(cp$TBBW5r      ,na.rm=T)
cp$TBBB5rc      <-cp$TBBB5r      -mean(cp$TBBB5r      ,na.rm=T)
cp$TBBH5rc      <-cp$TBBH5r      -mean(cp$TBBH5r      ,na.rm=T)
cp$TBTT5rc      <-cp$TBTT5r      -mean(cp$TBTT5r      ,na.rm=T)
cp$TBTM5rc      <-cp$TBTM5r      -mean(cp$TBTM5r      ,na.rm=T)
cp$TBTF5rc      <-cp$TBTF5r      -mean(cp$TBTF5r      ,na.rm=T)
cp$TBTW5rc      <-cp$TBTW5r      -mean(cp$TBTW5r      ,na.rm=T)
cp$TBTB5rc      <-cp$TBTB5r      -mean(cp$TBTB5r      ,na.rm=T)
cp$TBTH5rc      <-cp$TBTH5r      -mean(cp$TBTH5r      ,na.rm=T)
cp$Opioidc      <-cp$Opioid      -mean(cp$Opioid      ,na.rm=T)
cp$LifeExpc     <-cp$LifeExp     -mean(cp$LifeExp     ,na.rm=T)
cp$LifeExpBc    <-cp$LifeExpB    -mean(cp$LifeExpB    ,na.rm=T)
cp$LifeExpHc    <-cp$LifeExpH    -mean(cp$LifeExpH    ,na.rm=T)
cp$LifeExpWc    <-cp$LifeExpW    -mean(cp$LifeExpW    ,na.rm=T)
cp$ChdDeathc    <-cp$ChdDeath    -mean(cp$ChdDeath    ,na.rm=T)
cp$ChdDeathBc   <-cp$ChdDeathB   -mean(cp$ChdDeathB   ,na.rm=T)
cp$ChdDeathHc   <-cp$ChdDeathH   -mean(cp$ChdDeathH   ,na.rm=T)
cp$ChdDeathWc   <-cp$ChdDeathW   -mean(cp$ChdDeathW   ,na.rm=T)
cp$InfDeathc    <-cp$InfDeath    -mean(cp$InfDeath    ,na.rm=T)
cp$InfDeathBc   <-cp$InfDeathB   -mean(cp$InfDeathB   ,na.rm=T)
cp$InfDeathHc   <-cp$InfDeathH   -mean(cp$InfDeathH   ,na.rm=T)
cp$InfDeathWc   <-cp$InfDeathW   -mean(cp$InfDeathW   ,na.rm=T)
cp$Injuryc      <-cp$Injury      -mean(cp$Injury      ,na.rm=T)
cp$InjuryBc     <-cp$InjuryB     -mean(cp$InjuryB     ,na.rm=T)
cp$InjuryHc     <-cp$InjuryH     -mean(cp$InjuryH     ,na.rm=T)
cp$InjuryWc     <-cp$InjuryW     -mean(cp$InjuryW     ,na.rm=T)
cp$GunDeathc    <-cp$GunDeath    -mean(cp$GunDeath    ,na.rm=T)
cp$GunDeathBc   <-cp$GunDeathB   -mean(cp$GunDeathB   ,na.rm=T)
cp$GunDeathWc   <-cp$GunDeathW   -mean(cp$GunDeathW   ,na.rm=T)
cp$PrmDeath_c   <-cp$PrmDeath    -mean(cp$PrmDeath    ,na.rm=T)
cp$PrmDeathcc   <-cp$PrmDeathc   -mean(cp$PrmDeathc   ,na.rm=T)
cp$PrmDeathBc   <-cp$PrmDeathB   -mean(cp$PrmDeathB   ,na.rm=T)
cp$PrmDeathHc   <-cp$PrmDeathH   -mean(cp$PrmDeathH   ,na.rm=T)
cp$PrmDeathWc   <-cp$PrmDeathW   -mean(cp$PrmDeathW   ,na.rm=T)
cp$PrmDeath2_c  <-cp$PrmDeath2   -mean(cp$PrmDeath2   ,na.rm=T)
cp$PrmDeath2cc  <-cp$PrmDeath2c  -mean(cp$PrmDeath2c  ,na.rm=T)
cp$PrmDeath2Bc  <-cp$PrmDeath2B  -mean(cp$PrmDeath2B  ,na.rm=T)
cp$PrmDeath2Hc  <-cp$PrmDeath2H  -mean(cp$PrmDeath2H  ,na.rm=T)
cp$PrmDeath2Wc  <-cp$PrmDeath2W  -mean(cp$PrmDeath2W  ,na.rm=T)
cp$Suicidec     <-cp$Suicide     -mean(cp$Suicide     ,na.rm=T)
cp$Diabetc      <-cp$Diabet      -mean(cp$Diabet      ,na.rm=T)
cp$Obesityc     <-cp$Obesity     -mean(cp$Obesity     ,na.rm=T)
cp$Physicalc    <-cp$Physical    -mean(cp$Physical    ,na.rm=T)
cp$PoorHlthc    <-cp$PoorHlth    -mean(cp$PoorHlth    ,na.rm=T)
cp$PoorMHc      <-cp$PoorMH      -mean(cp$PoorMH      ,na.rm=T)
cp$PoorPhyc     <-cp$PoorPhy     -mean(cp$PoorPhy     ,na.rm=T)
cp$Sleepc       <-cp$Sleep       -mean(cp$Sleep       ,na.rm=T)
cp$DrugOdc      <-cp$DrugOd      -mean(cp$DrugOd      ,na.rm=T)
cp$DrugOdBc     <-cp$DrugOdB     -mean(cp$DrugOdB     ,na.rm=T)
cp$DrugOdHc     <-cp$DrugOdH     -mean(cp$DrugOdH     ,na.rm=T)
cp$DrugOdWc     <-cp$DrugOdW     -mean(cp$DrugOdW     ,na.rm=T)
cp$DWIDeathc    <-cp$DWIDeath    -mean(cp$DWIDeath    ,na.rm=T)
cp$EDrinkc      <-cp$EDrink      -mean(cp$EDrink      ,na.rm=T)
cp$Smokec       <-cp$Smoke       -mean(cp$Smoke       ,na.rm=T)
cp$FastFoodc    <-cp$FastFood    -mean(cp$FastFood    ,na.rm=T)
cp$FoodEnvc     <-cp$FoodEnv     -mean(cp$FoodEnv     ,na.rm=T)
cp$FoodInsc     <-cp$FoodIns     -mean(cp$FoodIns     ,na.rm=T)
cp$FrLunchc     <-cp$FrLunch     -mean(cp$FrLunch     ,na.rm=T)
cp$LAccFoodc    <-cp$LAccFood    -mean(cp$LAccFood    ,na.rm=T)
cp$Gymc         <-cp$Gym         -mean(cp$Gym         ,na.rm=T)
cp$Gym2c        <-cp$Gym2        -mean(cp$Gym2        ,na.rm=T)
cp$Inactivec    <-cp$Inactive    -mean(cp$Inactive    ,na.rm=T)
cp$HousCostc    <-cp$HousCost    -mean(cp$HousCost    ,na.rm=T)
cp$HousCostsc   <-cp$HousCosts   -mean(cp$HousCosts   ,na.rm=T)
cp$HousCrowdc   <-cp$HousCrowd   -mean(cp$HousCrowd   ,na.rm=T)
cp$Housingc     <-cp$Housing     -mean(cp$Housing     ,na.rm=T)
cp$HousPlumbc   <-cp$HousPlumb   -mean(cp$HousPlumb   ,na.rm=T)
cp$Insuredc     <-cp$Insured     -mean(cp$Insured     ,na.rm=T)
cp$InsuredAc    <-cp$InsuredA    -mean(cp$InsuredA    ,na.rm=T)
cp$InsuredCc    <-cp$InsuredC    -mean(cp$InsuredC    ,na.rm=T)
cp$JuvArrc      <-cp$JuvArr      -mean(cp$JuvArr      ,na.rm=T)
cp$Murderc      <-cp$Murder      -mean(cp$Murder      ,na.rm=T)
cp$Violentc     <-cp$Violent     -mean(cp$Violent     ,na.rm=T)
cp$LongCommc    <-cp$LongComm    -mean(cp$LongComm    ,na.rm=T)
cp$LowBWc       <-cp$LowBW       -mean(cp$LowBW       ,na.rm=T)
cp$LowBWBc      <-cp$LowBWB      -mean(cp$LowBWB      ,na.rm=T)
cp$LowBWHc      <-cp$LowBWH      -mean(cp$LowBWH      ,na.rm=T)
cp$LowBWWc      <-cp$LowBWW      -mean(cp$LowBWW      ,na.rm=T)
cp$TeenBthc     <-cp$TeenBth     -mean(cp$TeenBth     ,na.rm=T)
cp$TeenBthBc    <-cp$TeenBthB    -mean(cp$TeenBthB    ,na.rm=T)
cp$TeenBthHc    <-cp$TeenBthH    -mean(cp$TeenBthH    ,na.rm=T)
cp$TeenBthWc    <-cp$TeenBthW    -mean(cp$TeenBthW    ,na.rm=T)
cp$Mentalc      <-cp$Mental      -mean(cp$Mental      ,na.rm=T)
cp$MHPrvdc      <-cp$MHPrvd      -mean(cp$MHPrvd      ,na.rm=T)
cp$PCPc         <-cp$PCP         -mean(cp$PCP         ,na.rm=T)
cp$PCP2c        <-cp$PCP2        -mean(cp$PCP2        ,na.rm=T)
cp$Dentistc     <-cp$Dentist     -mean(cp$Dentist     ,na.rm=T)
cp$PrvtHospc    <-cp$PrvtHosp    -mean(cp$PrvtHosp    ,na.rm=T)
cp$PrvtHospBc   <-cp$PrvtHospB   -mean(cp$PrvtHospB   ,na.rm=T)
cp$PrvtHospHc   <-cp$PrvtHospH   -mean(cp$PrvtHospH   ,na.rm=T)
cp$PrvtHospWc   <-cp$PrvtHospW   -mean(cp$PrvtHospW   ,na.rm=T)
cp$SegBWc       <-cp$SegBW       -mean(cp$SegBW       ,na.rm=T)
cp$SegNWc       <-cp$SegNW       -mean(cp$SegNW       ,na.rm=T)
cp$SocAssoc     <-cp$SocAsso     -mean(cp$SocAsso     ,na.rm=T)
cp$SocSuppc     <-cp$SocSupp     -mean(cp$SocSupp     ,na.rm=T)
cp$MIECHVc      <-cp$MIECHV      -mean(cp$MIECHV      ,na.rm=T)
cp$NHVRCc       <-cp$NHVRC       -mean(cp$NHVRC       ,na.rm=T)
cp$FoodInsecurec<-cp$FoodInsecure-mean(cp$FoodInsecure,na.rm=T)
cp$PCPAllc      <-cp$PCPAll      -mean(cp$PCPAll      ,na.rm=T)
cp$MH_PCPc      <-cp$MH_PCP      -mean(cp$MH_PCP      ,na.rm=T)

cp<-cbind(cp,demean(cp,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cpm01<-lmer(PhyTr~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
# Mental Health
cpm02<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm03<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm04<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
cpm05<-lmer(PhyTr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm06<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm07<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm08<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
cpm09<-lmer(PhyTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm10<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm11<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm12<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm13<-lmer(PhyTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within+MHPrvdc_within|CountyFIPS)+(Mentalc_between+MHPrvdc_between|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
BIC(cpm04,cpm05,cpm06,cpm07,cpm08,cpm09,cpm10,cpm11,cpm12,cpm13)
summary(cpm12)

# Physical Health
cpm22<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm23<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm24<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
cpm25<-lmer(PhyTr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm26<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm27<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm28<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
# Physical Health Random Slope
cpm29<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Physicalc_within|CountyFIPS)+(1|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
cpm30<-lmer(PhyTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Physicalc_within|CountyFIPS)+(PCPc_between|StateFIPS),data=cp,control=lmerControl(optimizer="bobyqa"))
BIC(cpm24,cpm25,cpm26,cpm27,cpm28,cpm29,cpm30)
summary(cpm30)

# bootstrap confidence interval
cpm12CI<-confint(cpm12,method='boot',nsim=500,boot.type='perc')
cpm30CI<-confint(cpm30,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(cpm12)
check_collinearity(cpm30)
isSingular(cpm12)
isSingular(cpm30)





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cs$CPopBPc      <-cs$CPopBP      -mean(cs$CPopBP      ,na.rm=T)
cs$CPopHPc      <-cs$CPopHP      -mean(cs$CPopHP      ,na.rm=T)
cs$ChildPTc     <-cs$ChildPT     -mean(cs$ChildPT     ,na.rm=T)
cs$ChildPWc     <-cs$ChildPW     -mean(cs$ChildPW     ,na.rm=T)
cs$ChildPBc     <-cs$ChildPB     -mean(cs$ChildPB     ,na.rm=T)
cs$ChildPHc     <-cs$ChildPH     -mean(cs$ChildPH     ,na.rm=T)
cs$CARatioT100c <-cs$CARatioT100 -mean(cs$CARatioT100 ,na.rm=T)
cs$CARatioW100c <-cs$CARatioW100 -mean(cs$CARatioW100 ,na.rm=T)
cs$CARatioB100c <-cs$CARatioB100 -mean(cs$CARatioB100 ,na.rm=T)
cs$CARatioH100c <-cs$CARatioH100 -mean(cs$CARatioH100 ,na.rm=T)
cs$MalePTc      <-cs$MalePT      -mean(cs$MalePT      ,na.rm=T)
cs$MalePWc      <-cs$MalePW      -mean(cs$MalePW      ,na.rm=T)
cs$MalePBc      <-cs$MalePB      -mean(cs$MalePB      ,na.rm=T)
cs$MalePHc      <-cs$MalePH      -mean(cs$MalePH      ,na.rm=T)
cs$MFRatioT100c <-cs$MFRatioT100 -mean(cs$MFRatioT100 ,na.rm=T)
cs$MFRatioW100c <-cs$MFRatioW100 -mean(cs$MFRatioW100 ,na.rm=T)
cs$MFRatioB100c <-cs$MFRatioB100 -mean(cs$MFRatioB100 ,na.rm=T)
cs$MFRatioH100c <-cs$MFRatioH100 -mean(cs$MFRatioH100 ,na.rm=T)
cs$ElderTc      <-cs$ElderT      -mean(cs$ElderT      ,na.rm=T)
cs$ElderWc      <-cs$ElderW      -mean(cs$ElderW      ,na.rm=T)
cs$ElderBc      <-cs$ElderB      -mean(cs$ElderB      ,na.rm=T)
cs$ElderHc      <-cs$ElderH      -mean(cs$ElderH      ,na.rm=T)
cs$SingleTc     <-cs$SingleT     -mean(cs$SingleT     ,na.rm=T)
cs$SingleWc     <-cs$SingleW     -mean(cs$SingleW     ,na.rm=T)
cs$SingleBc     <-cs$SingleB     -mean(cs$SingleB     ,na.rm=T)
cs$SingleHc     <-cs$SingleH     -mean(cs$SingleH     ,na.rm=T)
cs$FHeadTc      <-cs$FHeadT      -mean(cs$FHeadT      ,na.rm=T)
cs$FHeadWc      <-cs$FHeadW      -mean(cs$FHeadW      ,na.rm=T)
cs$FHeadBc      <-cs$FHeadB      -mean(cs$FHeadB      ,na.rm=T)
cs$FHeadHc      <-cs$FHeadH      -mean(cs$FHeadH      ,na.rm=T)
cs$NoHighTc     <-cs$NoHighT     -mean(cs$NoHighT     ,na.rm=T)
cs$NoHighWc     <-cs$NoHighW     -mean(cs$NoHighW     ,na.rm=T)
cs$NoHighBc     <-cs$NoHighB     -mean(cs$NoHighB     ,na.rm=T)
cs$NoHighHc     <-cs$NoHighH     -mean(cs$NoHighH     ,na.rm=T)
cs$UnempTc      <-cs$UnempT      -mean(cs$UnempT      ,na.rm=T)
cs$UnempWc      <-cs$UnempW      -mean(cs$UnempW      ,na.rm=T)
cs$UnempBc      <-cs$UnempB      -mean(cs$UnempB      ,na.rm=T)
cs$UnempHc      <-cs$UnempH      -mean(cs$UnempH      ,na.rm=T)
cs$CPovTc       <-cs$CPovT       -mean(cs$CPovT       ,na.rm=T)
cs$CPovWc       <-cs$CPovW       -mean(cs$CPovW       ,na.rm=T)
cs$CPovBc       <-cs$CPovB       -mean(cs$CPovB       ,na.rm=T)
cs$CPovHc       <-cs$CPovH       -mean(cs$CPovH       ,na.rm=T)
cs$CPov1c       <-cs$CPov1       -mean(cs$CPov1       ,na.rm=T)
cs$CPov2c       <-cs$CPov2       -mean(cs$CPov2       ,na.rm=T)
cs$CPov3c       <-cs$CPov3       -mean(cs$CPov3       ,na.rm=T)
cs$PubAsTc      <-cs$PubAsT      -mean(cs$PubAsT      ,na.rm=T)
cs$WelfarTc     <-cs$WelfarT     -mean(cs$WelfarT     ,na.rm=T)
cs$SnapTc       <-cs$SnapT       -mean(cs$SnapT       ,na.rm=T)
cs$SnapWc       <-cs$SnapW       -mean(cs$SnapW       ,na.rm=T)
cs$SnapBc       <-cs$SnapB       -mean(cs$SnapB       ,na.rm=T)
cs$SnapHc       <-cs$SnapH       -mean(cs$SnapH       ,na.rm=T)
cs$IncomeT1kc   <-cs$IncomeT1k   -mean(cs$IncomeT1k   ,na.rm=T)
cs$IncomeW1kc   <-cs$IncomeW1k   -mean(cs$IncomeW1k   ,na.rm=T)
cs$IncomeB1kc   <-cs$IncomeB1k   -mean(cs$IncomeB1k   ,na.rm=T)
cs$IncomeH1kc   <-cs$IncomeH1k   -mean(cs$IncomeH1k   ,na.rm=T)
cs$GiniT100c    <-cs$GiniT100    -mean(cs$GiniT100    ,na.rm=T)
cs$HValueT10kc  <-cs$HValueT10k  -mean(cs$HValueT10k  ,na.rm=T)
cs$MCostT100c   <-cs$MCostT100   -mean(cs$MCostT100   ,na.rm=T)
cs$OCostDT100c  <-cs$OCostDT100  -mean(cs$OCostDT100  ,na.rm=T)
cs$MRentDT100c  <-cs$MRentDT100  -mean(cs$MRentDT100  ,na.rm=T)
cs$OCostPTc     <-cs$OCostPT     -mean(cs$OCostPT     ,na.rm=T)
cs$MRentPTc     <-cs$MRentPT     -mean(cs$MRentPT     ,na.rm=T)
cs$MortgTc      <-cs$MortgT      -mean(cs$MortgT      ,na.rm=T)
cs$LangAPTc     <-cs$LangAPT     -mean(cs$LangAPT     ,na.rm=T)
cs$LangAPWc     <-cs$LangAPW     -mean(cs$LangAPW     ,na.rm=T)
cs$LangAPBc     <-cs$LangAPB     -mean(cs$LangAPB     ,na.rm=T)
cs$LangAPHc     <-cs$LangAPH     -mean(cs$LangAPH     ,na.rm=T)
cs$LangBPTc     <-cs$LangBPT     -mean(cs$LangBPT     ,na.rm=T)
cs$LangBPWc     <-cs$LangBPW     -mean(cs$LangBPW     ,na.rm=T)
cs$LangBPBc     <-cs$LangBPB     -mean(cs$LangBPB     ,na.rm=T)
cs$LangBPHc     <-cs$LangBPH     -mean(cs$LangBPH     ,na.rm=T)
cs$LangCPTc     <-cs$LangCPT     -mean(cs$LangCPT     ,na.rm=T)
cs$OutUsTc      <-cs$OutUsT      -mean(cs$OutUsT      ,na.rm=T)
cs$OutUsWc      <-cs$OutUsW      -mean(cs$OutUsW      ,na.rm=T)
cs$OutUsBc      <-cs$OutUsB      -mean(cs$OutUsB      ,na.rm=T)
cs$OutUsHc      <-cs$OutUsH      -mean(cs$OutUsH      ,na.rm=T)
cs$FBornTc      <-cs$FBornT      -mean(cs$FBornT      ,na.rm=T)
cs$FBornWc      <-cs$FBornW      -mean(cs$FBornW      ,na.rm=T)
cs$FBornBc      <-cs$FBornB      -mean(cs$FBornB      ,na.rm=T)
cs$FBornHc      <-cs$FBornH      -mean(cs$FBornH      ,na.rm=T)
cs$NotCtzTc     <-cs$NotCtzT     -mean(cs$NotCtzT     ,na.rm=T)
cs$NotCtzWc     <-cs$NotCtzW     -mean(cs$NotCtzW     ,na.rm=T)
cs$NotCtzBc     <-cs$NotCtzB     -mean(cs$NotCtzB     ,na.rm=T)
cs$NotCtzHc     <-cs$NotCtzH     -mean(cs$NotCtzH     ,na.rm=T)
cs$MoveTc       <-cs$MoveT       -mean(cs$MoveT       ,na.rm=T)
cs$MoveWc       <-cs$MoveW       -mean(cs$MoveW       ,na.rm=T)
cs$MoveBc       <-cs$MoveB       -mean(cs$MoveB       ,na.rm=T)
cs$MoveHc       <-cs$MoveH       -mean(cs$MoveH       ,na.rm=T)
cs$VacantTc     <-cs$VacantT     -mean(cs$VacantT     ,na.rm=T)
cs$OwnerTc      <-cs$OwnerT      -mean(cs$OwnerT      ,na.rm=T)
cs$OwnerWc      <-cs$OwnerW      -mean(cs$OwnerW      ,na.rm=T)
cs$OwnerBc      <-cs$OwnerB      -mean(cs$OwnerB      ,na.rm=T)
cs$OwnerHc      <-cs$OwnerH      -mean(cs$OwnerH      ,na.rm=T)
cs$CrowdTc      <-cs$CrowdT      -mean(cs$CrowdT      ,na.rm=T)
cs$CrowdWc      <-cs$CrowdW      -mean(cs$CrowdW      ,na.rm=T)
cs$CrowdBc      <-cs$CrowdB      -mean(cs$CrowdB      ,na.rm=T)
cs$CrowdHc      <-cs$CrowdH      -mean(cs$CrowdH      ,na.rm=T)
cs$MobileTc     <-cs$MobileT     -mean(cs$MobileT     ,na.rm=T)
cs$MobileWc     <-cs$MobileW     -mean(cs$MobileW     ,na.rm=T)
cs$MobileBc     <-cs$MobileB     -mean(cs$MobileB     ,na.rm=T)
cs$MobileHc     <-cs$MobileH     -mean(cs$MobileH     ,na.rm=T)
cs$DisablTc     <-cs$DisablT     -mean(cs$DisablT     ,na.rm=T)
cs$DisablWc     <-cs$DisablW     -mean(cs$DisablW     ,na.rm=T)
cs$DisablBc     <-cs$DisablB     -mean(cs$DisablB     ,na.rm=T)
cs$DisablHc     <-cs$DisablH     -mean(cs$DisablH     ,na.rm=T)
cs$DisablTCc    <-cs$DisablTC    -mean(cs$DisablTC    ,na.rm=T)
cs$DisablWCc    <-cs$DisablWC    -mean(cs$DisablWC    ,na.rm=T)
cs$DisablBCc    <-cs$DisablBC    -mean(cs$DisablBC    ,na.rm=T)
cs$DisablHCc    <-cs$DisablHC    -mean(cs$DisablHC    ,na.rm=T)
cs$DisablTMc    <-cs$DisablTM    -mean(cs$DisablTM    ,na.rm=T)
cs$DisablTFc    <-cs$DisablTF    -mean(cs$DisablTF    ,na.rm=T)
cs$Urban1c      <-cs$Urban1      -mean(cs$Urban1      ,na.rm=T)
cs$Urban2c      <-cs$Urban2      -mean(cs$Urban2      ,na.rm=T)
cs$LBWT1rc      <-cs$LBWT1r      -mean(cs$LBWT1r      ,na.rm=T)
cs$LBWM1rc      <-cs$LBWM1r      -mean(cs$LBWM1r      ,na.rm=T)
cs$LBWF1rc      <-cs$LBWF1r      -mean(cs$LBWF1r      ,na.rm=T)
cs$LBWW1rc      <-cs$LBWW1r      -mean(cs$LBWW1r      ,na.rm=T)
cs$LBWB1rc      <-cs$LBWB1r      -mean(cs$LBWB1r      ,na.rm=T)
cs$LBWH1rc      <-cs$LBWH1r      -mean(cs$LBWH1r      ,na.rm=T)
cs$PTBT1rc      <-cs$PTBT1r      -mean(cs$PTBT1r      ,na.rm=T)
cs$PTBM1rc      <-cs$PTBM1r      -mean(cs$PTBM1r      ,na.rm=T)
cs$PTBF1rc      <-cs$PTBF1r      -mean(cs$PTBF1r      ,na.rm=T)
cs$PTBW1rc      <-cs$PTBW1r      -mean(cs$PTBW1r      ,na.rm=T)
cs$PTBB1rc      <-cs$PTBB1r      -mean(cs$PTBB1r      ,na.rm=T)
cs$PTBH1rc      <-cs$PTBH1r      -mean(cs$PTBH1r      ,na.rm=T)
cs$PNCT1rc      <-cs$PNCT1r      -mean(cs$PNCT1r      ,na.rm=T)
cs$PNCM1rc      <-cs$PNCM1r      -mean(cs$PNCM1r      ,na.rm=T)
cs$PNCF1rc      <-cs$PNCF1r      -mean(cs$PNCF1r      ,na.rm=T)
cs$PNCW1rc      <-cs$PNCW1r      -mean(cs$PNCW1r      ,na.rm=T)
cs$PNCB1rc      <-cs$PNCB1r      -mean(cs$PNCB1r      ,na.rm=T)
cs$PNCH1rc      <-cs$PNCH1r      -mean(cs$PNCH1r      ,na.rm=T)
cs$TBBT1rc      <-cs$TBBT1r      -mean(cs$TBBT1r      ,na.rm=T)
cs$TBBM1rc      <-cs$TBBM1r      -mean(cs$TBBM1r      ,na.rm=T)
cs$TBBF1rc      <-cs$TBBF1r      -mean(cs$TBBF1r      ,na.rm=T)
cs$TBBW1rc      <-cs$TBBW1r      -mean(cs$TBBW1r      ,na.rm=T)
cs$TBBB1rc      <-cs$TBBB1r      -mean(cs$TBBB1r      ,na.rm=T)
cs$TBBH1rc      <-cs$TBBH1r      -mean(cs$TBBH1r      ,na.rm=T)
cs$TBTT1rc      <-cs$TBTT1r      -mean(cs$TBTT1r      ,na.rm=T)
cs$TBTM1rc      <-cs$TBTM1r      -mean(cs$TBTM1r      ,na.rm=T)
cs$TBTF1rc      <-cs$TBTF1r      -mean(cs$TBTF1r      ,na.rm=T)
cs$TBTW1rc      <-cs$TBTW1r      -mean(cs$TBTW1r      ,na.rm=T)
cs$TBTB1rc      <-cs$TBTB1r      -mean(cs$TBTB1r      ,na.rm=T)
cs$TBTH1rc      <-cs$TBTH1r      -mean(cs$TBTH1r      ,na.rm=T)
cs$LBWT5rc      <-cs$LBWT5r      -mean(cs$LBWT5r      ,na.rm=T)
cs$LBWM5rc      <-cs$LBWM5r      -mean(cs$LBWM5r      ,na.rm=T)
cs$LBWF5rc      <-cs$LBWF5r      -mean(cs$LBWF5r      ,na.rm=T)
cs$LBWW5rc      <-cs$LBWW5r      -mean(cs$LBWW5r      ,na.rm=T)
cs$LBWB5rc      <-cs$LBWB5r      -mean(cs$LBWB5r      ,na.rm=T)
cs$LBWH5rc      <-cs$LBWH5r      -mean(cs$LBWH5r      ,na.rm=T)
cs$PTBT5rc      <-cs$PTBT5r      -mean(cs$PTBT5r      ,na.rm=T)
cs$PTBM5rc      <-cs$PTBM5r      -mean(cs$PTBM5r      ,na.rm=T)
cs$PTBF5rc      <-cs$PTBF5r      -mean(cs$PTBF5r      ,na.rm=T)
cs$PTBW5rc      <-cs$PTBW5r      -mean(cs$PTBW5r      ,na.rm=T)
cs$PTBB5rc      <-cs$PTBB5r      -mean(cs$PTBB5r      ,na.rm=T)
cs$PTBH5rc      <-cs$PTBH5r      -mean(cs$PTBH5r      ,na.rm=T)
cs$PNCT5rc      <-cs$PNCT5r      -mean(cs$PNCT5r      ,na.rm=T)
cs$PNCM5rc      <-cs$PNCM5r      -mean(cs$PNCM5r      ,na.rm=T)
cs$PNCF5rc      <-cs$PNCF5r      -mean(cs$PNCF5r      ,na.rm=T)
cs$PNCW5rc      <-cs$PNCW5r      -mean(cs$PNCW5r      ,na.rm=T)
cs$PNCB5rc      <-cs$PNCB5r      -mean(cs$PNCB5r      ,na.rm=T)
cs$PNCH5rc      <-cs$PNCH5r      -mean(cs$PNCH5r      ,na.rm=T)
cs$TBBT5rc      <-cs$TBBT5r      -mean(cs$TBBT5r      ,na.rm=T)
cs$TBBM5rc      <-cs$TBBM5r      -mean(cs$TBBM5r      ,na.rm=T)
cs$TBBF5rc      <-cs$TBBF5r      -mean(cs$TBBF5r      ,na.rm=T)
cs$TBBW5rc      <-cs$TBBW5r      -mean(cs$TBBW5r      ,na.rm=T)
cs$TBBB5rc      <-cs$TBBB5r      -mean(cs$TBBB5r      ,na.rm=T)
cs$TBBH5rc      <-cs$TBBH5r      -mean(cs$TBBH5r      ,na.rm=T)
cs$TBTT5rc      <-cs$TBTT5r      -mean(cs$TBTT5r      ,na.rm=T)
cs$TBTM5rc      <-cs$TBTM5r      -mean(cs$TBTM5r      ,na.rm=T)
cs$TBTF5rc      <-cs$TBTF5r      -mean(cs$TBTF5r      ,na.rm=T)
cs$TBTW5rc      <-cs$TBTW5r      -mean(cs$TBTW5r      ,na.rm=T)
cs$TBTB5rc      <-cs$TBTB5r      -mean(cs$TBTB5r      ,na.rm=T)
cs$TBTH5rc      <-cs$TBTH5r      -mean(cs$TBTH5r      ,na.rm=T)
cs$Opioidc      <-cs$Opioid      -mean(cs$Opioid      ,na.rm=T)
cs$LifeExpc     <-cs$LifeExp     -mean(cs$LifeExp     ,na.rm=T)
cs$LifeExpBc    <-cs$LifeExpB    -mean(cs$LifeExpB    ,na.rm=T)
cs$LifeExpHc    <-cs$LifeExpH    -mean(cs$LifeExpH    ,na.rm=T)
cs$LifeExpWc    <-cs$LifeExpW    -mean(cs$LifeExpW    ,na.rm=T)
cs$ChdDeathc    <-cs$ChdDeath    -mean(cs$ChdDeath    ,na.rm=T)
cs$ChdDeathBc   <-cs$ChdDeathB   -mean(cs$ChdDeathB   ,na.rm=T)
cs$ChdDeathHc   <-cs$ChdDeathH   -mean(cs$ChdDeathH   ,na.rm=T)
cs$ChdDeathWc   <-cs$ChdDeathW   -mean(cs$ChdDeathW   ,na.rm=T)
cs$InfDeathc    <-cs$InfDeath    -mean(cs$InfDeath    ,na.rm=T)
cs$InfDeathBc   <-cs$InfDeathB   -mean(cs$InfDeathB   ,na.rm=T)
cs$InfDeathHc   <-cs$InfDeathH   -mean(cs$InfDeathH   ,na.rm=T)
cs$InfDeathWc   <-cs$InfDeathW   -mean(cs$InfDeathW   ,na.rm=T)
cs$Injuryc      <-cs$Injury      -mean(cs$Injury      ,na.rm=T)
cs$InjuryBc     <-cs$InjuryB     -mean(cs$InjuryB     ,na.rm=T)
cs$InjuryHc     <-cs$InjuryH     -mean(cs$InjuryH     ,na.rm=T)
cs$InjuryWc     <-cs$InjuryW     -mean(cs$InjuryW     ,na.rm=T)
cs$GunDeathc    <-cs$GunDeath    -mean(cs$GunDeath    ,na.rm=T)
cs$GunDeathBc   <-cs$GunDeathB   -mean(cs$GunDeathB   ,na.rm=T)
cs$GunDeathWc   <-cs$GunDeathW   -mean(cs$GunDeathW   ,na.rm=T)
cs$PrmDeath_c   <-cs$PrmDeath    -mean(cs$PrmDeath    ,na.rm=T)
cs$PrmDeathcc   <-cs$PrmDeathc   -mean(cs$PrmDeathc   ,na.rm=T)
cs$PrmDeathBc   <-cs$PrmDeathB   -mean(cs$PrmDeathB   ,na.rm=T)
cs$PrmDeathHc   <-cs$PrmDeathH   -mean(cs$PrmDeathH   ,na.rm=T)
cs$PrmDeathWc   <-cs$PrmDeathW   -mean(cs$PrmDeathW   ,na.rm=T)
cs$PrmDeath2_c  <-cs$PrmDeath2   -mean(cs$PrmDeath2   ,na.rm=T)
cs$PrmDeath2cc  <-cs$PrmDeath2c  -mean(cs$PrmDeath2c  ,na.rm=T)
cs$PrmDeath2Bc  <-cs$PrmDeath2B  -mean(cs$PrmDeath2B  ,na.rm=T)
cs$PrmDeath2Hc  <-cs$PrmDeath2H  -mean(cs$PrmDeath2H  ,na.rm=T)
cs$PrmDeath2Wc  <-cs$PrmDeath2W  -mean(cs$PrmDeath2W  ,na.rm=T)
cs$Suicidec     <-cs$Suicide     -mean(cs$Suicide     ,na.rm=T)
cs$Diabetc      <-cs$Diabet      -mean(cs$Diabet      ,na.rm=T)
cs$Obesityc     <-cs$Obesity     -mean(cs$Obesity     ,na.rm=T)
cs$Physicalc    <-cs$Physical    -mean(cs$Physical    ,na.rm=T)
cs$PoorHlthc    <-cs$PoorHlth    -mean(cs$PoorHlth    ,na.rm=T)
cs$PoorMHc      <-cs$PoorMH      -mean(cs$PoorMH      ,na.rm=T)
cs$PoorPhyc     <-cs$PoorPhy     -mean(cs$PoorPhy     ,na.rm=T)
cs$Sleepc       <-cs$Sleep       -mean(cs$Sleep       ,na.rm=T)
cs$DrugOdc      <-cs$DrugOd      -mean(cs$DrugOd      ,na.rm=T)
cs$DrugOdBc     <-cs$DrugOdB     -mean(cs$DrugOdB     ,na.rm=T)
cs$DrugOdHc     <-cs$DrugOdH     -mean(cs$DrugOdH     ,na.rm=T)
cs$DrugOdWc     <-cs$DrugOdW     -mean(cs$DrugOdW     ,na.rm=T)
cs$DWIDeathc    <-cs$DWIDeath    -mean(cs$DWIDeath    ,na.rm=T)
cs$EDrinkc      <-cs$EDrink      -mean(cs$EDrink      ,na.rm=T)
cs$Smokec       <-cs$Smoke       -mean(cs$Smoke       ,na.rm=T)
cs$FastFoodc    <-cs$FastFood    -mean(cs$FastFood    ,na.rm=T)
cs$FoodEnvc     <-cs$FoodEnv     -mean(cs$FoodEnv     ,na.rm=T)
cs$FoodInsc     <-cs$FoodIns     -mean(cs$FoodIns     ,na.rm=T)
cs$FrLunchc     <-cs$FrLunch     -mean(cs$FrLunch     ,na.rm=T)
cs$LAccFoodc    <-cs$LAccFood    -mean(cs$LAccFood    ,na.rm=T)
cs$Gymc         <-cs$Gym         -mean(cs$Gym         ,na.rm=T)
cs$Gym2c        <-cs$Gym2        -mean(cs$Gym2        ,na.rm=T)
cs$Inactivec    <-cs$Inactive    -mean(cs$Inactive    ,na.rm=T)
cs$HousCostc    <-cs$HousCost    -mean(cs$HousCost    ,na.rm=T)
cs$HousCostsc   <-cs$HousCosts   -mean(cs$HousCosts   ,na.rm=T)
cs$HousCrowdc   <-cs$HousCrowd   -mean(cs$HousCrowd   ,na.rm=T)
cs$Housingc     <-cs$Housing     -mean(cs$Housing     ,na.rm=T)
cs$HousPlumbc   <-cs$HousPlumb   -mean(cs$HousPlumb   ,na.rm=T)
cs$Insuredc     <-cs$Insured     -mean(cs$Insured     ,na.rm=T)
cs$InsuredAc    <-cs$InsuredA    -mean(cs$InsuredA    ,na.rm=T)
cs$InsuredCc    <-cs$InsuredC    -mean(cs$InsuredC    ,na.rm=T)
cs$JuvArrc      <-cs$JuvArr      -mean(cs$JuvArr      ,na.rm=T)
cs$Murderc      <-cs$Murder      -mean(cs$Murder      ,na.rm=T)
cs$Violentc     <-cs$Violent     -mean(cs$Violent     ,na.rm=T)
cs$LongCommc    <-cs$LongComm    -mean(cs$LongComm    ,na.rm=T)
cs$LowBWc       <-cs$LowBW       -mean(cs$LowBW       ,na.rm=T)
cs$LowBWBc      <-cs$LowBWB      -mean(cs$LowBWB      ,na.rm=T)
cs$LowBWHc      <-cs$LowBWH      -mean(cs$LowBWH      ,na.rm=T)
cs$LowBWWc      <-cs$LowBWW      -mean(cs$LowBWW      ,na.rm=T)
cs$TeenBthc     <-cs$TeenBth     -mean(cs$TeenBth     ,na.rm=T)
cs$TeenBthBc    <-cs$TeenBthB    -mean(cs$TeenBthB    ,na.rm=T)
cs$TeenBthHc    <-cs$TeenBthH    -mean(cs$TeenBthH    ,na.rm=T)
cs$TeenBthWc    <-cs$TeenBthW    -mean(cs$TeenBthW    ,na.rm=T)
cs$Mentalc      <-cs$Mental      -mean(cs$Mental      ,na.rm=T)
cs$MHPrvdc      <-cs$MHPrvd      -mean(cs$MHPrvd      ,na.rm=T)
cs$PCPc         <-cs$PCP         -mean(cs$PCP         ,na.rm=T)
cs$PCP2c        <-cs$PCP2        -mean(cs$PCP2        ,na.rm=T)
cs$Dentistc     <-cs$Dentist     -mean(cs$Dentist     ,na.rm=T)
cs$PrvtHospc    <-cs$PrvtHosp    -mean(cs$PrvtHosp    ,na.rm=T)
cs$PrvtHospBc   <-cs$PrvtHospB   -mean(cs$PrvtHospB   ,na.rm=T)
cs$PrvtHospHc   <-cs$PrvtHospH   -mean(cs$PrvtHospH   ,na.rm=T)
cs$PrvtHospWc   <-cs$PrvtHospW   -mean(cs$PrvtHospW   ,na.rm=T)
cs$SegBWc       <-cs$SegBW       -mean(cs$SegBW       ,na.rm=T)
cs$SegNWc       <-cs$SegNW       -mean(cs$SegNW       ,na.rm=T)
cs$SocAssoc     <-cs$SocAsso     -mean(cs$SocAsso     ,na.rm=T)
cs$SocSuppc     <-cs$SocSupp     -mean(cs$SocSupp     ,na.rm=T)
cs$MIECHVc      <-cs$MIECHV      -mean(cs$MIECHV      ,na.rm=T)
cs$NHVRCc       <-cs$NHVRC       -mean(cs$NHVRC       ,na.rm=T)
cs$FoodInsecurec<-cs$FoodInsecure-mean(cs$FoodInsecure,na.rm=T)
cs$PCPAllc      <-cs$PCPAll      -mean(cs$PCPAll      ,na.rm=T)
cs$MH_PCPc      <-cs$MH_PCP      -mean(cs$MH_PCP      ,na.rm=T)

cs<-cbind(cs,demean(cs,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
csm01<-lmer(SexTr~Yearf+USDA_RUC+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
# Mental Health
csm02<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm03<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm04<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
# Mental Health Interaction
csm05<-lmer(SexTr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm06<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+USDA_RUC*MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm07<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm08<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+USDA_RUC*MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
# Mental Health Random Slope
csm09<-lmer(SexTr~Yearf+USDA_RUC*Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm10<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm11<-lmer(SexTr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(Mentalc_within|CountyFIPS)+(MHPrvdc_between|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
BIC(csm04,csm05,csm06,csm07,csm08,csm09,csm10,csm11)
summary(csm10)
summary(csm11) # Singular
# Physical Health
csm22<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm23<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm24<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
# Physical Health Interaction
csm25<-lmer(SexTr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm26<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+USDA_RUC*PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm27<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
csm28<-lmer(SexTr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+USDA_RUC*PCPc_between+IncomeT1kc+SingleTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+DisablTc+MoveTc+(1|CountyFIPS)+(1|StateFIPS),data=cs,control=lmerControl(optimizer="bobyqa"))
BIC(csm24,csm25,csm26,csm27,csm28)
summary(csm24)

# bootstrap confidence interval
csm10CI<-confint(csm10,method='boot',nsim=500,boot.type='perc')
csm24CI<-confint(csm24,method='boot',nsim=500,boot.type='perc')

# Model Check
check_collinearity(csm10)
check_collinearity(csm24)
isSingular(csm10)
isSingular(csm24)





save.image("Z:/CDCK01/Analysis/County/Service/Service3.RData")





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Table1

Table1<-data.table(
  Name=c("Total","Young","Middle","Old","Male","Female","Neglect","Physical","Sexual","Mental Distress","MH Provider","Physical Distress","PCP","Income","Single","% Black","% Latino","Foreign-born","% Child","Disability","Mobility","Large Urban","Small Urban","Rural","2014","2015","2016","2017"),
  N1=c(nrow(ct),nrow(c1),nrow(c2),nrow(c3),nrow(cm),nrow(cf),nrow(cn),nrow(cp),nrow(cs),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  N2=c(length(unique(ct$CountyFIPS)),length(unique(c1$CountyFIPS)),length(unique(c2$CountyFIPS)),length(unique(c3$CountyFIPS)),length(unique(cm$CountyFIPS)),length(unique(cf$CountyFIPS)),length(unique(cn$CountyFIPS)),length(unique(cp$CountyFIPS)),length(unique(cs$CountyFIPS)),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  N3=c(length(unique(ct$StateFIPS)),length(unique(c1$StateFIPS)),length(unique(c2$StateFIPS)),length(unique(c3$StateFIPS)),length(unique(cm$StateFIPS)),length(unique(cf$StateFIPS)),length(unique(cn$StateFIPS)),length(unique(cp$StateFIPS)),length(unique(cs$StateFIPS)),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  Mean=c(mean(ct$RptTr),mean(c1$Rpt1r),mean(c2$Rpt2r),mean(c3$Rpt3r),mean(cm$RptMr),mean(cf$RptFr),mean(cn$NegTr),mean(cp$PhyTr),mean(cs$SexTr),mean(ct$Mental),mean(ct$MHPrvd),mean(ct$Physical),mean(ct$PCP),mean(ct$IncomeT1k),mean(ct$SingleT),mean(ct$CPopBP),mean(ct$CPopHP),mean(ct$FBornT),mean(ct$ChildPT),mean(ct$DisablT),mean(ct$MoveT),prop.table(table(ct$USDA_RUC))*100,prop.table(table(ct$Yearf))*100),
  SD=c(sd(ct$RptTr),sd(c1$Rpt1r),sd(c2$Rpt2r),sd(c3$Rpt3r),sd(cm$RptMr),sd(cf$RptFr),sd(cn$NegTr),sd(cp$PhyTr),sd(cs$SexTr),sd(ct$Mental),sd(ct$MHPrvd),sd(ct$Physical),sd(ct$PCP),sd(ct$IncomeT1k),sd(ct$SingleT),sd(ct$CPopBP),sd(ct$CPopHP),sd(ct$FBornT),sd(ct$ChildPT),sd(ct$DisablT),sd(ct$MoveT),NA,NA,NA,NA,NA,NA,NA))
Table1





# Table2

AIC1<-anova(ctm02,ctm04,ctm12)$AIC
BIC1<-anova(ctm02,ctm04,ctm12)$BIC
RE1<-as.data.table(VarCorr(ctm12))

AIC2<-anova(ctm22,ctm24,ctm29)$AIC
BIC2<-anova(ctm22,ctm24,ctm29)$BIC
RE2<-as.data.table(VarCorr(ctm29))

Table2<-data.table(
  Name=c("N1","N2","N3","FixedEffects","Mentalc_within","Mentalc_between","MHPrvdc_within","MHPrvdc_between","Physicalc_within","Physicalc_between","PCPc_within","PCPc_between","RandomEffects","Mentalc_within","Mentalc_between","MHPrvdc_within","MHPrvdc_between","Physicalc_within","Physicalc_between","PCPc_within","PCPc_between","ModelFit","AIC","BIC"),
  M11 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,fixef(ctm02)["Mentalc_within"],fixef(ctm02)["Mentalc_between"],fixef(ctm02)["MHPrvdc_within"],fixef(ctm02)["MHPrvdc_between"],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,AIC1[1],BIC1[1]),
  M11L=c(NA,NA,NA,NA,ctm02CI["Mentalc_within",1],ctm02CI["Mentalc_between",1],ctm02CI["MHPrvdc_within",1],ctm02CI["MHPrvdc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M11U=c(NA,NA,NA,NA,ctm02CI["Mentalc_within",2],ctm02CI["Mentalc_between",2],ctm02CI["MHPrvdc_within",2],ctm02CI["MHPrvdc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M11P=c(NA,NA,NA,NA,summary(ctm02)$coef["Mentalc_within",5],summary(ctm02)$coef["Mentalc_between",5],summary(ctm02)$coef["MHPrvdc_within",5],summary(ctm02)$coef["MHPrvdc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M12 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,fixef(ctm04)["Mentalc_within"],fixef(ctm04)["Mentalc_between"],fixef(ctm04)["MHPrvdc_within"],fixef(ctm04)["MHPrvdc_between"],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,AIC1[2],BIC1[2]),
  M12L=c(NA,NA,NA,NA,ctm04CI["Mentalc_within",1],ctm04CI["Mentalc_between",1],ctm04CI["MHPrvdc_within",1],ctm04CI["MHPrvdc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M12U=c(NA,NA,NA,NA,ctm04CI["Mentalc_within",2],ctm04CI["Mentalc_between",2],ctm04CI["MHPrvdc_within",2],ctm04CI["MHPrvdc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M12P=c(NA,NA,NA,NA,summary(ctm04)$coef["Mentalc_within",5],summary(ctm04)$coef["Mentalc_between",5],summary(ctm04)$coef["MHPrvdc_within",5],summary(ctm04)$coef["MHPrvdc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M13 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,fixef(ctm12)["Mentalc_within"],fixef(ctm12)["Mentalc_between"],fixef(ctm12)["MHPrvdc_within"],fixef(ctm12)["MHPrvdc_between"],NA,NA,NA,NA,NA,RE1$vcov[2],RE1$vcov[3],RE1$vcov[8],NA,NA,NA,NA,NA,NA,AIC1[3],BIC1[3]),
  M13L=c(NA,NA,NA,NA,ctm12CI["Mentalc_within",1],ctm12CI["Mentalc_between",1],ctm12CI["MHPrvdc_within",1],ctm12CI["MHPrvdc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M13U=c(NA,NA,NA,NA,ctm12CI["Mentalc_within",2],ctm12CI["Mentalc_between",2],ctm12CI["MHPrvdc_within",2],ctm12CI["MHPrvdc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M13P=c(NA,NA,NA,NA,summary(ctm12)$coef["Mentalc_within",5],summary(ctm12)$coef["Mentalc_between",5],summary(ctm12)$coef["MHPrvdc_within",5],summary(ctm12)$coef["MHPrvdc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M21 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,NA,NA,NA,NA,fixef(ctm22)["Physicalc_within"],fixef(ctm22)["Physicalc_between"],fixef(ctm22)["PCPc_within"],fixef(ctm22)["PCPc_between"],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,AIC2[1],BIC2[1]),
  M21L=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm22CI["Physicalc_within",1],ctm22CI["Physicalc_between",1],ctm22CI["PCPc_within",1],ctm22CI["PCPc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M21U=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm22CI["Physicalc_within",2],ctm22CI["Physicalc_between",2],ctm22CI["PCPc_within",2],ctm22CI["PCPc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M21P=c(NA,NA,NA,NA,NA,NA,NA,NA,summary(ctm22)$coef["Physicalc_within",5],summary(ctm22)$coef["Physicalc_between",5],summary(ctm22)$coef["PCPc_within",5],summary(ctm22)$coef["PCPc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M22 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,NA,NA,NA,NA,fixef(ctm24)["Physicalc_within"],fixef(ctm24)["Physicalc_between"],fixef(ctm24)["PCPc_within"],fixef(ctm24)["PCPc_between"],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,AIC2[2],BIC2[2]),
  M22L=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm24CI["Physicalc_within",1],ctm24CI["Physicalc_between",1],ctm24CI["PCPc_within",1],ctm24CI["PCPc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M22U=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm24CI["Physicalc_within",2],ctm24CI["Physicalc_between",2],ctm24CI["PCPc_within",2],ctm24CI["PCPc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M22P=c(NA,NA,NA,NA,NA,NA,NA,NA,summary(ctm24)$coef["Physicalc_within",5],summary(ctm24)$coef["Physicalc_between",5],summary(ctm24)$coef["PCPc_within",5],summary(ctm24)$coef["PCPc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M23 =c(nrow(ct),length(unique(ct$CountyFIPS)),length(unique(ct$StateFIPS)),NA,NA,NA,NA,NA,fixef(ctm29)["Physicalc_within"],fixef(ctm29)["Physicalc_between"],fixef(ctm29)["PCPc_within"],fixef(ctm29)["PCPc_between"],NA,NA,NA,NA,NA,NA,RE2$vcov[3],NA,NA,NA,AIC2[3],BIC2[3]),
  M23L=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm29CI["Physicalc_within",1],ctm29CI["Physicalc_between",1],ctm29CI["PCPc_within",1],ctm29CI["PCPc_between",1],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M23U=c(NA,NA,NA,NA,NA,NA,NA,NA,ctm29CI["Physicalc_within",2],ctm29CI["Physicalc_between",2],ctm29CI["PCPc_within",2],ctm29CI["PCPc_between",2],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
  M23P=c(NA,NA,NA,NA,NA,NA,NA,NA,summary(ctm29)$coef["Physicalc_within",5],summary(ctm29)$coef["Physicalc_between",5],summary(ctm29)$coef["PCPc_within",5],summary(ctm29)$coef["PCPc_between",5],NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA))
Table2



# Table3.1

Table3.1<-data.table(
  Name=c("N1","N2","N3","Mentalc_within","Mentalc_between","MHPrvdc_within","MHPrvdc_between"),
  Age1c=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),fixef(c1m12)["Mentalc_within"],fixef(c1m12)["Mentalc_between"],fixef(c1m12)["MHPrvdc_within"],fixef(c1m12)["MHPrvdc_between"]  ),
  Age1l=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),     c1m12CI["Mentalc_within",1],   c1m12CI["Mentalc_between",1],   c1m12CI["MHPrvdc_within",1],   c1m12CI["MHPrvdc_between",1]),
  Age1u=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),     c1m12CI["Mentalc_within",2],   c1m12CI["Mentalc_between",2],   c1m12CI["MHPrvdc_within",2],   c1m12CI["MHPrvdc_between",2]),
  Age1p=c(NA,NA,NA,summary(c1m12)$coef["Mentalc_within",5],summary(c1m12)$coef["Mentalc_between",5],summary(c1m12)$coef["MHPrvdc_within",5],summary(c1m12)$coef["MHPrvdc_between",5]),
  Age2c=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),fixef(c2m12)["Mentalc_within"],fixef(c2m12)["Mentalc_between"],fixef(c2m12)["MHPrvdc_within"],fixef(c2m12)["MHPrvdc_between"]  ),
  Age2l=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),     c2m12CI["Mentalc_within",1],   c2m12CI["Mentalc_between",1],   c2m12CI["MHPrvdc_within",1],   c2m12CI["MHPrvdc_between",1]),
  Age2u=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),     c2m12CI["Mentalc_within",2],   c2m12CI["Mentalc_between",2],   c2m12CI["MHPrvdc_within",2],   c2m12CI["MHPrvdc_between",2]),
  Age2p=c(NA,NA,NA,summary(c2m12)$coef["Mentalc_within",5],summary(c2m12)$coef["Mentalc_between",5],summary(c2m12)$coef["MHPrvdc_within",5],summary(c2m12)$coef["MHPrvdc_between",5]),
  Age3c=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),fixef(c3m12)["Mentalc_within"],fixef(c3m12)["Mentalc_between"],fixef(c3m12)["MHPrvdc_within"],fixef(c3m12)["MHPrvdc_between"]),
  Age3l=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),     c3m12CI["Mentalc_within",1],   c3m12CI["Mentalc_between",1],   c3m12CI["MHPrvdc_within",1],   c3m12CI["MHPrvdc_between",1]),
  Age3u=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),     c3m12CI["Mentalc_within",2],   c3m12CI["Mentalc_between",2],   c3m12CI["MHPrvdc_within",2],   c3m12CI["MHPrvdc_between",2]),
  Age3p=c(NA,NA,NA,summary(c3m12)$coef["Mentalc_within",5],summary(c3m12)$coef["Mentalc_between",5],summary(c3m12)$coef["MHPrvdc_within",5],summary(c3m12)$coef["MHPrvdc_between",5]),
  SexMc=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),fixef(cmm12)["Mentalc_within"],fixef(cmm12)["Mentalc_between"],fixef(cmm12)["MHPrvdc_within"],fixef(cmm12)["MHPrvdc_between"]),
  SexMl=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),     cmm12CI["Mentalc_within",1],   cmm12CI["Mentalc_between",1],   cmm12CI["MHPrvdc_within",1],   cmm12CI["MHPrvdc_between",1]),
  SexMu=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),     cmm12CI["Mentalc_within",2],   cmm12CI["Mentalc_between",2],   cmm12CI["MHPrvdc_within",2],   cmm12CI["MHPrvdc_between",2]),
  SexMp=c(NA,NA,NA,summary(cmm12)$coef["Mentalc_within",5],summary(cmm12)$coef["Mentalc_between",5],summary(cmm12)$coef["MHPrvdc_within",5],summary(cmm12)$coef["MHPrvdc_between",5]),
  SexFc=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),fixef(cfm12)["Mentalc_within"],fixef(cfm12)["Mentalc_between"],fixef(cfm12)["MHPrvdc_within"],fixef(cfm12)["MHPrvdc_between"]),
  SexFl=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),     cfm12CI["Mentalc_within",1],   cfm12CI["Mentalc_between",1],   cfm12CI["MHPrvdc_within",1],   cfm12CI["MHPrvdc_between",1]),
  SexFu=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),     cfm12CI["Mentalc_within",2],   cfm12CI["Mentalc_between",2],   cfm12CI["MHPrvdc_within",2],   cfm12CI["MHPrvdc_between",2]),
  SexFp=c(NA,NA,NA,summary(cfm12)$coef["Mentalc_within",5],summary(cfm12)$coef["Mentalc_between",5],summary(cfm12)$coef["MHPrvdc_within",5],summary(cfm12)$coef["MHPrvdc_between",5]),
  TNegc=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),fixef(cnm12)["Mentalc_within"],fixef(cnm12)["Mentalc_between"],fixef(cnm12)["MHPrvdc_within"],fixef(cnm12)["MHPrvdc_between"]),
  TNegl=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),     cnm12CI["Mentalc_within",1],   cnm12CI["Mentalc_between",1],   cnm12CI["MHPrvdc_within",1],   cnm12CI["MHPrvdc_between",1]),
  TNegu=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),     cnm12CI["Mentalc_within",2],   cnm12CI["Mentalc_between",2],   cnm12CI["MHPrvdc_within",2],   cnm12CI["MHPrvdc_between",2]),
  TNegp=c(NA,NA,NA,summary(cnm12)$coef["Mentalc_within",5],summary(cnm12)$coef["Mentalc_between",5],summary(cnm12)$coef["MHPrvdc_within",5],summary(cnm12)$coef["MHPrvdc_between",5]),
  TPhyc=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),fixef(cpm12)["Mentalc_within"],fixef(cpm12)["Mentalc_between"],fixef(cpm12)["MHPrvdc_within"],fixef(cpm12)["MHPrvdc_between"]),
  TPhyl=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),     cpm12CI["Mentalc_within",1],   cpm12CI["Mentalc_between",1],   cpm12CI["MHPrvdc_within",1],   cpm12CI["MHPrvdc_between",1]),
  TPhyu=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),     cpm12CI["Mentalc_within",2],   cpm12CI["Mentalc_between",2],   cpm12CI["MHPrvdc_within",2],   cpm12CI["MHPrvdc_between",2]),
  TPhyp=c(NA,NA,NA,summary(cpm12)$coef["Mentalc_within",5],summary(cpm12)$coef["Mentalc_between",5],summary(cpm12)$coef["MHPrvdc_within",5],summary(cpm12)$coef["MHPrvdc_between",5]),
  TSexc=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),fixef(csm10)["Mentalc_within"],fixef(csm10)["Mentalc_between"],fixef(csm10)["MHPrvdc_within"],fixef(csm10)["MHPrvdc_between"]),
  TSexl=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),     csm10CI["Mentalc_within",1],   csm10CI["Mentalc_between",1],   csm10CI["MHPrvdc_within",1],   csm10CI["MHPrvdc_between",1]),
  TSexu=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),     csm10CI["Mentalc_within",2],   csm10CI["Mentalc_between",2],   csm10CI["MHPrvdc_within",2],   csm10CI["MHPrvdc_between",2]),
  TSexp=c(NA,NA,NA,summary(csm10)$coef["Mentalc_within",5],summary(csm10)$coef["Mentalc_between",5],summary(csm10)$coef["MHPrvdc_within",5],summary(csm10)$coef["MHPrvdc_between",5]))
Table3.1



# Table3.2

Table3.2<-data.table(
  Name=c("N1","N2","N3","Physicalc_within","Physicalc_between","PCPc_within","PCPc_between"),
  Age1c=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),fixef(c1m29)["Physicalc_within"],fixef(c1m29)["Physicalc_between"],fixef(c1m29)["PCPc_within"],fixef(c1m29)["PCPc_between"]  ),
  Age1l=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),     c1m29CI["Physicalc_within",1],   c1m29CI["Physicalc_between",1],   c1m29CI["PCPc_within",1],   c1m29CI["PCPc_between",1]),
  Age1u=c(nrow(c1),length(unique(c1$CountyFIPS)),length(unique(c1$StateFIPS)),     c1m29CI["Physicalc_within",2],   c1m29CI["Physicalc_between",2],   c1m29CI["PCPc_within",2],   c1m29CI["PCPc_between",2]),
  Age1p=c(NA,NA,NA,summary(c1m29)$coef["Physicalc_within",5],summary(c1m29)$coef["Physicalc_between",5],summary(c1m29)$coef["PCPc_within",5],summary(c1m29)$coef["PCPc_between",5]),
  Age2c=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),fixef(c2m29)["Physicalc_within"],fixef(c2m29)["Physicalc_between"],fixef(c2m29)["PCPc_within"],fixef(c2m29)["PCPc_between"]  ),
  Age2l=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),     c2m29CI["Physicalc_within",1],   c2m29CI["Physicalc_between",1],   c2m29CI["PCPc_within",1],   c2m29CI["PCPc_between",1]),
  Age2u=c(nrow(c2),length(unique(c2$CountyFIPS)),length(unique(c2$StateFIPS)),     c2m29CI["Physicalc_within",2],   c2m29CI["Physicalc_between",2],   c2m29CI["PCPc_within",2],   c2m29CI["PCPc_between",2]),
  Age2p=c(NA,NA,NA,summary(c2m29)$coef["Physicalc_within",5],summary(c2m29)$coef["Physicalc_between",5],summary(c2m29)$coef["PCPc_within",5],summary(c2m29)$coef["PCPc_between",5]),
  Age3c=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),fixef(c3m29)["Physicalc_within"],fixef(c3m29)["Physicalc_between"],fixef(c3m29)["PCPc_within"],fixef(c3m29)["PCPc_between"]),
  Age3l=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),     c3m29CI["Physicalc_within",1],   c3m29CI["Physicalc_between",1],   c3m29CI["PCPc_within",1],   c3m29CI["PCPc_between",1]),
  Age3u=c(nrow(c3),length(unique(c3$CountyFIPS)),length(unique(c3$StateFIPS)),     c3m29CI["Physicalc_within",2],   c3m29CI["Physicalc_between",2],   c3m29CI["PCPc_within",2],   c3m29CI["PCPc_between",2]),
  Age3p=c(NA,NA,NA,summary(c3m29)$coef["Physicalc_within",5],summary(c3m29)$coef["Physicalc_between",5],summary(c3m29)$coef["PCPc_within",5],summary(c3m29)$coef["PCPc_between",5]),
  SexMc=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),fixef(cmm29)["Physicalc_within"],fixef(cmm29)["Physicalc_between"],fixef(cmm29)["PCPc_within"],fixef(cmm29)["PCPc_between"]),
  SexMl=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),     cmm29CI["Physicalc_within",1],   cmm29CI["Physicalc_between",1],   cmm29CI["PCPc_within",1],   cmm29CI["PCPc_between",1]),
  SexMu=c(nrow(cm),length(unique(cm$CountyFIPS)),length(unique(cm$StateFIPS)),     cmm29CI["Physicalc_within",2],   cmm29CI["Physicalc_between",2],   cmm29CI["PCPc_within",2],   cmm29CI["PCPc_between",2]),
  SexMp=c(NA,NA,NA,summary(cmm29)$coef["Physicalc_within",5],summary(cmm29)$coef["Physicalc_between",5],summary(cmm29)$coef["PCPc_within",5],summary(cmm29)$coef["PCPc_between",5]),
  SexFc=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),fixef(cfm29)["Physicalc_within"],fixef(cfm29)["Physicalc_between"],fixef(cfm29)["PCPc_within"],fixef(cfm29)["PCPc_between"]),
  SexFl=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),     cfm29CI["Physicalc_within",1],   cfm29CI["Physicalc_between",1],   cfm29CI["PCPc_within",1],   cfm29CI["PCPc_between",1]),
  SexFu=c(nrow(cf),length(unique(cf$CountyFIPS)),length(unique(cf$StateFIPS)),     cfm29CI["Physicalc_within",2],   cfm29CI["Physicalc_between",2],   cfm29CI["PCPc_within",2],   cfm29CI["PCPc_between",2]),
  SexFp=c(NA,NA,NA,summary(cfm29)$coef["Physicalc_within",5],summary(cfm29)$coef["Physicalc_between",5],summary(cfm29)$coef["PCPc_within",5],summary(cfm29)$coef["PCPc_between",5]),
  TNegc=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),fixef(cnm29)["Physicalc_within"],fixef(cnm29)["Physicalc_between"],fixef(cnm29)["PCPc_within"],fixef(cnm29)["PCPc_between"]),
  TNegl=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),     cnm29CI["Physicalc_within",1],   cnm29CI["Physicalc_between",1],   cnm29CI["PCPc_within",1],   cnm29CI["PCPc_between",1]),
  TNegu=c(nrow(cn),length(unique(cn$CountyFIPS)),length(unique(cn$StateFIPS)),     cnm29CI["Physicalc_within",2],   cnm29CI["Physicalc_between",2],   cnm29CI["PCPc_within",2],   cnm29CI["PCPc_between",2]),
  TNegp=c(NA,NA,NA,summary(cnm29)$coef["Physicalc_within",5],summary(cnm29)$coef["Physicalc_between",5],summary(cnm29)$coef["PCPc_within",5],summary(cnm29)$coef["PCPc_between",5]),
  TPhyc=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),fixef(cpm30)["Physicalc_within"],fixef(cpm30)["Physicalc_between"],fixef(cpm30)["PCPc_within"],fixef(cpm30)["PCPc_between"]),
  TPhyl=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),     cpm30CI["Physicalc_within",1],   cpm30CI["Physicalc_between",1],   cpm30CI["PCPc_within",1],   cpm30CI["PCPc_between",1]),
  TPhyu=c(nrow(cp),length(unique(cp$CountyFIPS)),length(unique(cp$StateFIPS)),     cpm30CI["Physicalc_within",2],   cpm30CI["Physicalc_between",2],   cpm30CI["PCPc_within",2],   cpm30CI["PCPc_between",2]),
  TPhyp=c(NA,NA,NA,summary(cpm30)$coef["Physicalc_within",5],summary(cpm30)$coef["Physicalc_between",5],summary(cpm30)$coef["PCPc_within",5],summary(cpm30)$coef["PCPc_between",5]),
  TSexc=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),fixef(csm24)["Physicalc_within"],fixef(csm24)["Physicalc_between"],fixef(csm24)["PCPc_within"],fixef(csm24)["PCPc_between"]),
  TSexl=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),     csm24CI["Physicalc_within",1],   csm24CI["Physicalc_between",1],   csm24CI["PCPc_within",1],   csm24CI["PCPc_between",1]),
  TSexu=c(nrow(cs),length(unique(cs$CountyFIPS)),length(unique(cs$StateFIPS)),     csm24CI["Physicalc_within",2],   csm24CI["Physicalc_between",2],   csm24CI["PCPc_within",2],   csm24CI["PCPc_between",2]),
  TSexp=c(NA,NA,NA,summary(csm24)$coef["Physicalc_within",5],summary(csm24)$coef["Physicalc_between",5],summary(csm24)$coef["PCPc_within",5],summary(csm24)$coef["PCPc_between",5]))
Table3.2





write.csv(Table1,"Z:/CDCK01/Analysis/County/Service/Table1_3.csv")
write.csv(Table2,"Z:/CDCK01/Analysis/County/Service/Table2_3.csv")
write.csv(Table3.1,"Z:/CDCK01/Analysis/County/Service/Table3.1_3.csv")
write.csv(Table3.2,"Z:/CDCK01/Analysis/County/Service/Table3.2_3.csv")

























###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cw$CPopBPc      <-cw$CPopBP      -mean(cw$CPopBP      ,na.rm=T)
cw$CPopHPc      <-cw$CPopHP      -mean(cw$CPopHP      ,na.rm=T)
cw$ChildPTc     <-cw$ChildPT     -mean(cw$ChildPT     ,na.rm=T)
cw$ChildPWc     <-cw$ChildPW     -mean(cw$ChildPW     ,na.rm=T)
cw$ChildPBc     <-cw$ChildPB     -mean(cw$ChildPB     ,na.rm=T)
cw$ChildPHc     <-cw$ChildPH     -mean(cw$ChildPH     ,na.rm=T)
cw$CARatioT100c <-cw$CARatioT100 -mean(cw$CARatioT100 ,na.rm=T)
cw$CARatioW100c <-cw$CARatioW100 -mean(cw$CARatioW100 ,na.rm=T)
cw$CARatioB100c <-cw$CARatioB100 -mean(cw$CARatioB100 ,na.rm=T)
cw$CARatioH100c <-cw$CARatioH100 -mean(cw$CARatioH100 ,na.rm=T)
cw$MalePTc      <-cw$MalePT      -mean(cw$MalePT      ,na.rm=T)
cw$MalePWc      <-cw$MalePW      -mean(cw$MalePW      ,na.rm=T)
cw$MalePBc      <-cw$MalePB      -mean(cw$MalePB      ,na.rm=T)
cw$MalePHc      <-cw$MalePH      -mean(cw$MalePH      ,na.rm=T)
cw$MFRatioT100c <-cw$MFRatioT100 -mean(cw$MFRatioT100 ,na.rm=T)
cw$MFRatioW100c <-cw$MFRatioW100 -mean(cw$MFRatioW100 ,na.rm=T)
cw$MFRatioB100c <-cw$MFRatioB100 -mean(cw$MFRatioB100 ,na.rm=T)
cw$MFRatioH100c <-cw$MFRatioH100 -mean(cw$MFRatioH100 ,na.rm=T)
cw$ElderTc      <-cw$ElderT      -mean(cw$ElderT      ,na.rm=T)
cw$ElderWc      <-cw$ElderW      -mean(cw$ElderW      ,na.rm=T)
cw$ElderBc      <-cw$ElderB      -mean(cw$ElderB      ,na.rm=T)
cw$ElderHc      <-cw$ElderH      -mean(cw$ElderH      ,na.rm=T)
cw$SingleTc     <-cw$SingleT     -mean(cw$SingleT     ,na.rm=T)
cw$SingleWc     <-cw$SingleW     -mean(cw$SingleW     ,na.rm=T)
cw$SingleBc     <-cw$SingleB     -mean(cw$SingleB     ,na.rm=T)
cw$SingleHc     <-cw$SingleH     -mean(cw$SingleH     ,na.rm=T)
cw$FHeadTc      <-cw$FHeadT      -mean(cw$FHeadT      ,na.rm=T)
cw$FHeadWc      <-cw$FHeadW      -mean(cw$FHeadW      ,na.rm=T)
cw$FHeadBc      <-cw$FHeadB      -mean(cw$FHeadB      ,na.rm=T)
cw$FHeadHc      <-cw$FHeadH      -mean(cw$FHeadH      ,na.rm=T)
cw$NoHighTc     <-cw$NoHighT     -mean(cw$NoHighT     ,na.rm=T)
cw$NoHighWc     <-cw$NoHighW     -mean(cw$NoHighW     ,na.rm=T)
cw$NoHighBc     <-cw$NoHighB     -mean(cw$NoHighB     ,na.rm=T)
cw$NoHighHc     <-cw$NoHighH     -mean(cw$NoHighH     ,na.rm=T)
cw$UnempTc      <-cw$UnempT      -mean(cw$UnempT      ,na.rm=T)
cw$UnempWc      <-cw$UnempW      -mean(cw$UnempW      ,na.rm=T)
cw$UnempBc      <-cw$UnempB      -mean(cw$UnempB      ,na.rm=T)
cw$UnempHc      <-cw$UnempH      -mean(cw$UnempH      ,na.rm=T)
cw$CPovTc       <-cw$CPovT       -mean(cw$CPovT       ,na.rm=T)
cw$CPovWc       <-cw$CPovW       -mean(cw$CPovW       ,na.rm=T)
cw$CPovBc       <-cw$CPovB       -mean(cw$CPovB       ,na.rm=T)
cw$CPovHc       <-cw$CPovH       -mean(cw$CPovH       ,na.rm=T)
cw$CPov1c       <-cw$CPov1       -mean(cw$CPov1       ,na.rm=T)
cw$CPov2c       <-cw$CPov2       -mean(cw$CPov2       ,na.rm=T)
cw$CPov3c       <-cw$CPov3       -mean(cw$CPov3       ,na.rm=T)
cw$PubAsTc      <-cw$PubAsT      -mean(cw$PubAsT      ,na.rm=T)
cw$WelfarTc     <-cw$WelfarT     -mean(cw$WelfarT     ,na.rm=T)
cw$SnapTc       <-cw$SnapT       -mean(cw$SnapT       ,na.rm=T)
cw$SnapWc       <-cw$SnapW       -mean(cw$SnapW       ,na.rm=T)
cw$SnapBc       <-cw$SnapB       -mean(cw$SnapB       ,na.rm=T)
cw$SnapHc       <-cw$SnapH       -mean(cw$SnapH       ,na.rm=T)
cw$IncomeT1kc   <-cw$IncomeT1k   -mean(cw$IncomeT1k   ,na.rm=T)
cw$IncomeW1kc   <-cw$IncomeW1k   -mean(cw$IncomeW1k   ,na.rm=T)
cw$IncomeB1kc   <-cw$IncomeB1k   -mean(cw$IncomeB1k   ,na.rm=T)
cw$IncomeH1kc   <-cw$IncomeH1k   -mean(cw$IncomeH1k   ,na.rm=T)
cw$GiniT100c    <-cw$GiniT100    -mean(cw$GiniT100    ,na.rm=T)
cw$HValueT10kc  <-cw$HValueT10k  -mean(cw$HValueT10k  ,na.rm=T)
cw$MCostT100c   <-cw$MCostT100   -mean(cw$MCostT100   ,na.rm=T)
cw$OCostDT100c  <-cw$OCostDT100  -mean(cw$OCostDT100  ,na.rm=T)
cw$MRentDT100c  <-cw$MRentDT100  -mean(cw$MRentDT100  ,na.rm=T)
cw$OCostPTc     <-cw$OCostPT     -mean(cw$OCostPT     ,na.rm=T)
cw$MRentPTc     <-cw$MRentPT     -mean(cw$MRentPT     ,na.rm=T)
cw$MortgTc      <-cw$MortgT      -mean(cw$MortgT      ,na.rm=T)
cw$LangAPTc     <-cw$LangAPT     -mean(cw$LangAPT     ,na.rm=T)
cw$LangAPWc     <-cw$LangAPW     -mean(cw$LangAPW     ,na.rm=T)
cw$LangAPBc     <-cw$LangAPB     -mean(cw$LangAPB     ,na.rm=T)
cw$LangAPHc     <-cw$LangAPH     -mean(cw$LangAPH     ,na.rm=T)
cw$LangBPTc     <-cw$LangBPT     -mean(cw$LangBPT     ,na.rm=T)
cw$LangBPWc     <-cw$LangBPW     -mean(cw$LangBPW     ,na.rm=T)
cw$LangBPBc     <-cw$LangBPB     -mean(cw$LangBPB     ,na.rm=T)
cw$LangBPHc     <-cw$LangBPH     -mean(cw$LangBPH     ,na.rm=T)
cw$LangCPTc     <-cw$LangCPT     -mean(cw$LangCPT     ,na.rm=T)
cw$OutUsTc      <-cw$OutUsT      -mean(cw$OutUsT      ,na.rm=T)
cw$OutUsWc      <-cw$OutUsW      -mean(cw$OutUsW      ,na.rm=T)
cw$OutUsBc      <-cw$OutUsB      -mean(cw$OutUsB      ,na.rm=T)
cw$OutUsHc      <-cw$OutUsH      -mean(cw$OutUsH      ,na.rm=T)
cw$FBornTc      <-cw$FBornT      -mean(cw$FBornT      ,na.rm=T)
cw$FBornWc      <-cw$FBornW      -mean(cw$FBornW      ,na.rm=T)
cw$FBornBc      <-cw$FBornB      -mean(cw$FBornB      ,na.rm=T)
cw$FBornHc      <-cw$FBornH      -mean(cw$FBornH      ,na.rm=T)
cw$NotCtzTc     <-cw$NotCtzT     -mean(cw$NotCtzT     ,na.rm=T)
cw$NotCtzWc     <-cw$NotCtzW     -mean(cw$NotCtzW     ,na.rm=T)
cw$NotCtzBc     <-cw$NotCtzB     -mean(cw$NotCtzB     ,na.rm=T)
cw$NotCtzHc     <-cw$NotCtzH     -mean(cw$NotCtzH     ,na.rm=T)
cw$MoveTc       <-cw$MoveT       -mean(cw$MoveT       ,na.rm=T)
cw$MoveWc       <-cw$MoveW       -mean(cw$MoveW       ,na.rm=T)
cw$MoveBc       <-cw$MoveB       -mean(cw$MoveB       ,na.rm=T)
cw$MoveHc       <-cw$MoveH       -mean(cw$MoveH       ,na.rm=T)
cw$VacantTc     <-cw$VacantT     -mean(cw$VacantT     ,na.rm=T)
cw$OwnerTc      <-cw$OwnerT      -mean(cw$OwnerT      ,na.rm=T)
cw$OwnerWc      <-cw$OwnerW      -mean(cw$OwnerW      ,na.rm=T)
cw$OwnerBc      <-cw$OwnerB      -mean(cw$OwnerB      ,na.rm=T)
cw$OwnerHc      <-cw$OwnerH      -mean(cw$OwnerH      ,na.rm=T)
cw$CrowdTc      <-cw$CrowdT      -mean(cw$CrowdT      ,na.rm=T)
cw$CrowdWc      <-cw$CrowdW      -mean(cw$CrowdW      ,na.rm=T)
cw$CrowdBc      <-cw$CrowdB      -mean(cw$CrowdB      ,na.rm=T)
cw$CrowdHc      <-cw$CrowdH      -mean(cw$CrowdH      ,na.rm=T)
cw$MobileTc     <-cw$MobileT     -mean(cw$MobileT     ,na.rm=T)
cw$MobileWc     <-cw$MobileW     -mean(cw$MobileW     ,na.rm=T)
cw$MobileBc     <-cw$MobileB     -mean(cw$MobileB     ,na.rm=T)
cw$MobileHc     <-cw$MobileH     -mean(cw$MobileH     ,na.rm=T)
cw$DisablTc     <-cw$DisablT     -mean(cw$DisablT     ,na.rm=T)
cw$DisablWc     <-cw$DisablW     -mean(cw$DisablW     ,na.rm=T)
cw$DisablBc     <-cw$DisablB     -mean(cw$DisablB     ,na.rm=T)
cw$DisablHc     <-cw$DisablH     -mean(cw$DisablH     ,na.rm=T)
cw$DisablTCc    <-cw$DisablTC    -mean(cw$DisablTC    ,na.rm=T)
cw$DisablWCc    <-cw$DisablWC    -mean(cw$DisablWC    ,na.rm=T)
cw$DisablBCc    <-cw$DisablBC    -mean(cw$DisablBC    ,na.rm=T)
cw$DisablHCc    <-cw$DisablHC    -mean(cw$DisablHC    ,na.rm=T)
cw$DisablTMc    <-cw$DisablTM    -mean(cw$DisablTM    ,na.rm=T)
cw$DisablTFc    <-cw$DisablTF    -mean(cw$DisablTF    ,na.rm=T)
cw$Urban1c      <-cw$Urban1      -mean(cw$Urban1      ,na.rm=T)
cw$Urban2c      <-cw$Urban2      -mean(cw$Urban2      ,na.rm=T)
cw$LBWT1rc      <-cw$LBWT1r      -mean(cw$LBWT1r      ,na.rm=T)
cw$LBWM1rc      <-cw$LBWM1r      -mean(cw$LBWM1r      ,na.rm=T)
cw$LBWF1rc      <-cw$LBWF1r      -mean(cw$LBWF1r      ,na.rm=T)
cw$LBWW1rc      <-cw$LBWW1r      -mean(cw$LBWW1r      ,na.rm=T)
cw$LBWB1rc      <-cw$LBWB1r      -mean(cw$LBWB1r      ,na.rm=T)
cw$LBWH1rc      <-cw$LBWH1r      -mean(cw$LBWH1r      ,na.rm=T)
cw$PTBT1rc      <-cw$PTBT1r      -mean(cw$PTBT1r      ,na.rm=T)
cw$PTBM1rc      <-cw$PTBM1r      -mean(cw$PTBM1r      ,na.rm=T)
cw$PTBF1rc      <-cw$PTBF1r      -mean(cw$PTBF1r      ,na.rm=T)
cw$PTBW1rc      <-cw$PTBW1r      -mean(cw$PTBW1r      ,na.rm=T)
cw$PTBB1rc      <-cw$PTBB1r      -mean(cw$PTBB1r      ,na.rm=T)
cw$PTBH1rc      <-cw$PTBH1r      -mean(cw$PTBH1r      ,na.rm=T)
cw$PNCT1rc      <-cw$PNCT1r      -mean(cw$PNCT1r      ,na.rm=T)
cw$PNCM1rc      <-cw$PNCM1r      -mean(cw$PNCM1r      ,na.rm=T)
cw$PNCF1rc      <-cw$PNCF1r      -mean(cw$PNCF1r      ,na.rm=T)
cw$PNCW1rc      <-cw$PNCW1r      -mean(cw$PNCW1r      ,na.rm=T)
cw$PNCB1rc      <-cw$PNCB1r      -mean(cw$PNCB1r      ,na.rm=T)
cw$PNCH1rc      <-cw$PNCH1r      -mean(cw$PNCH1r      ,na.rm=T)
cw$TBBT1rc      <-cw$TBBT1r      -mean(cw$TBBT1r      ,na.rm=T)
cw$TBBM1rc      <-cw$TBBM1r      -mean(cw$TBBM1r      ,na.rm=T)
cw$TBBF1rc      <-cw$TBBF1r      -mean(cw$TBBF1r      ,na.rm=T)
cw$TBBW1rc      <-cw$TBBW1r      -mean(cw$TBBW1r      ,na.rm=T)
cw$TBBB1rc      <-cw$TBBB1r      -mean(cw$TBBB1r      ,na.rm=T)
cw$TBBH1rc      <-cw$TBBH1r      -mean(cw$TBBH1r      ,na.rm=T)
cw$TBTT1rc      <-cw$TBTT1r      -mean(cw$TBTT1r      ,na.rm=T)
cw$TBTM1rc      <-cw$TBTM1r      -mean(cw$TBTM1r      ,na.rm=T)
cw$TBTF1rc      <-cw$TBTF1r      -mean(cw$TBTF1r      ,na.rm=T)
cw$TBTW1rc      <-cw$TBTW1r      -mean(cw$TBTW1r      ,na.rm=T)
cw$TBTB1rc      <-cw$TBTB1r      -mean(cw$TBTB1r      ,na.rm=T)
cw$TBTH1rc      <-cw$TBTH1r      -mean(cw$TBTH1r      ,na.rm=T)
cw$LBWT5rc      <-cw$LBWT5r      -mean(cw$LBWT5r      ,na.rm=T)
cw$LBWM5rc      <-cw$LBWM5r      -mean(cw$LBWM5r      ,na.rm=T)
cw$LBWF5rc      <-cw$LBWF5r      -mean(cw$LBWF5r      ,na.rm=T)
cw$LBWW5rc      <-cw$LBWW5r      -mean(cw$LBWW5r      ,na.rm=T)
cw$LBWB5rc      <-cw$LBWB5r      -mean(cw$LBWB5r      ,na.rm=T)
cw$LBWH5rc      <-cw$LBWH5r      -mean(cw$LBWH5r      ,na.rm=T)
cw$PTBT5rc      <-cw$PTBT5r      -mean(cw$PTBT5r      ,na.rm=T)
cw$PTBM5rc      <-cw$PTBM5r      -mean(cw$PTBM5r      ,na.rm=T)
cw$PTBF5rc      <-cw$PTBF5r      -mean(cw$PTBF5r      ,na.rm=T)
cw$PTBW5rc      <-cw$PTBW5r      -mean(cw$PTBW5r      ,na.rm=T)
cw$PTBB5rc      <-cw$PTBB5r      -mean(cw$PTBB5r      ,na.rm=T)
cw$PTBH5rc      <-cw$PTBH5r      -mean(cw$PTBH5r      ,na.rm=T)
cw$PNCT5rc      <-cw$PNCT5r      -mean(cw$PNCT5r      ,na.rm=T)
cw$PNCM5rc      <-cw$PNCM5r      -mean(cw$PNCM5r      ,na.rm=T)
cw$PNCF5rc      <-cw$PNCF5r      -mean(cw$PNCF5r      ,na.rm=T)
cw$PNCW5rc      <-cw$PNCW5r      -mean(cw$PNCW5r      ,na.rm=T)
cw$PNCB5rc      <-cw$PNCB5r      -mean(cw$PNCB5r      ,na.rm=T)
cw$PNCH5rc      <-cw$PNCH5r      -mean(cw$PNCH5r      ,na.rm=T)
cw$TBBT5rc      <-cw$TBBT5r      -mean(cw$TBBT5r      ,na.rm=T)
cw$TBBM5rc      <-cw$TBBM5r      -mean(cw$TBBM5r      ,na.rm=T)
cw$TBBF5rc      <-cw$TBBF5r      -mean(cw$TBBF5r      ,na.rm=T)
cw$TBBW5rc      <-cw$TBBW5r      -mean(cw$TBBW5r      ,na.rm=T)
cw$TBBB5rc      <-cw$TBBB5r      -mean(cw$TBBB5r      ,na.rm=T)
cw$TBBH5rc      <-cw$TBBH5r      -mean(cw$TBBH5r      ,na.rm=T)
cw$TBTT5rc      <-cw$TBTT5r      -mean(cw$TBTT5r      ,na.rm=T)
cw$TBTM5rc      <-cw$TBTM5r      -mean(cw$TBTM5r      ,na.rm=T)
cw$TBTF5rc      <-cw$TBTF5r      -mean(cw$TBTF5r      ,na.rm=T)
cw$TBTW5rc      <-cw$TBTW5r      -mean(cw$TBTW5r      ,na.rm=T)
cw$TBTB5rc      <-cw$TBTB5r      -mean(cw$TBTB5r      ,na.rm=T)
cw$TBTH5rc      <-cw$TBTH5r      -mean(cw$TBTH5r      ,na.rm=T)
cw$Opioidc      <-cw$Opioid      -mean(cw$Opioid      ,na.rm=T)
cw$LifeExpc     <-cw$LifeExp     -mean(cw$LifeExp     ,na.rm=T)
cw$LifeExpBc    <-cw$LifeExpB    -mean(cw$LifeExpB    ,na.rm=T)
cw$LifeExpHc    <-cw$LifeExpH    -mean(cw$LifeExpH    ,na.rm=T)
cw$LifeExpWc    <-cw$LifeExpW    -mean(cw$LifeExpW    ,na.rm=T)
cw$ChdDeathc    <-cw$ChdDeath    -mean(cw$ChdDeath    ,na.rm=T)
cw$ChdDeathBc   <-cw$ChdDeathB   -mean(cw$ChdDeathB   ,na.rm=T)
cw$ChdDeathHc   <-cw$ChdDeathH   -mean(cw$ChdDeathH   ,na.rm=T)
cw$ChdDeathWc   <-cw$ChdDeathW   -mean(cw$ChdDeathW   ,na.rm=T)
cw$InfDeathc    <-cw$InfDeath    -mean(cw$InfDeath    ,na.rm=T)
cw$InfDeathBc   <-cw$InfDeathB   -mean(cw$InfDeathB   ,na.rm=T)
cw$InfDeathHc   <-cw$InfDeathH   -mean(cw$InfDeathH   ,na.rm=T)
cw$InfDeathWc   <-cw$InfDeathW   -mean(cw$InfDeathW   ,na.rm=T)
cw$Injuryc      <-cw$Injury      -mean(cw$Injury      ,na.rm=T)
cw$InjuryBc     <-cw$InjuryB     -mean(cw$InjuryB     ,na.rm=T)
cw$InjuryHc     <-cw$InjuryH     -mean(cw$InjuryH     ,na.rm=T)
cw$InjuryWc     <-cw$InjuryW     -mean(cw$InjuryW     ,na.rm=T)
cw$GunDeathc    <-cw$GunDeath    -mean(cw$GunDeath    ,na.rm=T)
cw$GunDeathBc   <-cw$GunDeathB   -mean(cw$GunDeathB   ,na.rm=T)
cw$GunDeathWc   <-cw$GunDeathW   -mean(cw$GunDeathW   ,na.rm=T)
cw$PrmDeath_c   <-cw$PrmDeath    -mean(cw$PrmDeath    ,na.rm=T)
cw$PrmDeathcc   <-cw$PrmDeathc   -mean(cw$PrmDeathc   ,na.rm=T)
cw$PrmDeathBc   <-cw$PrmDeathB   -mean(cw$PrmDeathB   ,na.rm=T)
cw$PrmDeathHc   <-cw$PrmDeathH   -mean(cw$PrmDeathH   ,na.rm=T)
cw$PrmDeathWc   <-cw$PrmDeathW   -mean(cw$PrmDeathW   ,na.rm=T)
cw$PrmDeath2_c  <-cw$PrmDeath2   -mean(cw$PrmDeath2   ,na.rm=T)
cw$PrmDeath2cc  <-cw$PrmDeath2c  -mean(cw$PrmDeath2c  ,na.rm=T)
cw$PrmDeath2Bc  <-cw$PrmDeath2B  -mean(cw$PrmDeath2B  ,na.rm=T)
cw$PrmDeath2Hc  <-cw$PrmDeath2H  -mean(cw$PrmDeath2H  ,na.rm=T)
cw$PrmDeath2Wc  <-cw$PrmDeath2W  -mean(cw$PrmDeath2W  ,na.rm=T)
cw$Suicidec     <-cw$Suicide     -mean(cw$Suicide     ,na.rm=T)
cw$Diabetc      <-cw$Diabet      -mean(cw$Diabet      ,na.rm=T)
cw$Obesityc     <-cw$Obesity     -mean(cw$Obesity     ,na.rm=T)
cw$Physicalc    <-cw$Physical    -mean(cw$Physical    ,na.rm=T)
cw$PoorHlthc    <-cw$PoorHlth    -mean(cw$PoorHlth    ,na.rm=T)
cw$PoorMHc      <-cw$PoorMH      -mean(cw$PoorMH      ,na.rm=T)
cw$PoorPhyc     <-cw$PoorPhy     -mean(cw$PoorPhy     ,na.rm=T)
cw$Sleepc       <-cw$Sleep       -mean(cw$Sleep       ,na.rm=T)
cw$DrugOdc      <-cw$DrugOd      -mean(cw$DrugOd      ,na.rm=T)
cw$DrugOdBc     <-cw$DrugOdB     -mean(cw$DrugOdB     ,na.rm=T)
cw$DrugOdHc     <-cw$DrugOdH     -mean(cw$DrugOdH     ,na.rm=T)
cw$DrugOdWc     <-cw$DrugOdW     -mean(cw$DrugOdW     ,na.rm=T)
cw$DWIDeathc    <-cw$DWIDeath    -mean(cw$DWIDeath    ,na.rm=T)
cw$EDrinkc      <-cw$EDrink      -mean(cw$EDrink      ,na.rm=T)
cw$Smokec       <-cw$Smoke       -mean(cw$Smoke       ,na.rm=T)
cw$FastFoodc    <-cw$FastFood    -mean(cw$FastFood    ,na.rm=T)
cw$FoodEnvc     <-cw$FoodEnv     -mean(cw$FoodEnv     ,na.rm=T)
cw$FoodInsc     <-cw$FoodIns     -mean(cw$FoodIns     ,na.rm=T)
cw$FrLunchc     <-cw$FrLunch     -mean(cw$FrLunch     ,na.rm=T)
cw$LAccFoodc    <-cw$LAccFood    -mean(cw$LAccFood    ,na.rm=T)
cw$Gymc         <-cw$Gym         -mean(cw$Gym         ,na.rm=T)
cw$Gym2c        <-cw$Gym2        -mean(cw$Gym2        ,na.rm=T)
cw$Inactivec    <-cw$Inactive    -mean(cw$Inactive    ,na.rm=T)
cw$HousCostc    <-cw$HousCost    -mean(cw$HousCost    ,na.rm=T)
cw$HousCostsc   <-cw$HousCosts   -mean(cw$HousCosts   ,na.rm=T)
cw$HousCrowdc   <-cw$HousCrowd   -mean(cw$HousCrowd   ,na.rm=T)
cw$Housingc     <-cw$Housing     -mean(cw$Housing     ,na.rm=T)
cw$HousPlumbc   <-cw$HousPlumb   -mean(cw$HousPlumb   ,na.rm=T)
cw$Insuredc     <-cw$Insured     -mean(cw$Insured     ,na.rm=T)
cw$InsuredAc    <-cw$InsuredA    -mean(cw$InsuredA    ,na.rm=T)
cw$InsuredCc    <-cw$InsuredC    -mean(cw$InsuredC    ,na.rm=T)
cw$JuvArrc      <-cw$JuvArr      -mean(cw$JuvArr      ,na.rm=T)
cw$Murderc      <-cw$Murder      -mean(cw$Murder      ,na.rm=T)
cw$Violentc     <-cw$Violent     -mean(cw$Violent     ,na.rm=T)
cw$LongCommc    <-cw$LongComm    -mean(cw$LongComm    ,na.rm=T)
cw$LowBWc       <-cw$LowBW       -mean(cw$LowBW       ,na.rm=T)
cw$LowBWBc      <-cw$LowBWB      -mean(cw$LowBWB      ,na.rm=T)
cw$LowBWHc      <-cw$LowBWH      -mean(cw$LowBWH      ,na.rm=T)
cw$LowBWWc      <-cw$LowBWW      -mean(cw$LowBWW      ,na.rm=T)
cw$TeenBthc     <-cw$TeenBth     -mean(cw$TeenBth     ,na.rm=T)
cw$TeenBthBc    <-cw$TeenBthB    -mean(cw$TeenBthB    ,na.rm=T)
cw$TeenBthHc    <-cw$TeenBthH    -mean(cw$TeenBthH    ,na.rm=T)
cw$TeenBthWc    <-cw$TeenBthW    -mean(cw$TeenBthW    ,na.rm=T)
cw$Mentalc      <-cw$Mental      -mean(cw$Mental      ,na.rm=T)
cw$MHPrvdc      <-cw$MHPrvd      -mean(cw$MHPrvd      ,na.rm=T)
cw$PCPc         <-cw$PCP         -mean(cw$PCP         ,na.rm=T)
cw$PCP2c        <-cw$PCP2        -mean(cw$PCP2        ,na.rm=T)
cw$Dentistc     <-cw$Dentist     -mean(cw$Dentist     ,na.rm=T)
cw$PrvtHospc    <-cw$PrvtHosp    -mean(cw$PrvtHosp    ,na.rm=T)
cw$PrvtHospBc   <-cw$PrvtHospB   -mean(cw$PrvtHospB   ,na.rm=T)
cw$PrvtHospHc   <-cw$PrvtHospH   -mean(cw$PrvtHospH   ,na.rm=T)
cw$PrvtHospWc   <-cw$PrvtHospW   -mean(cw$PrvtHospW   ,na.rm=T)
cw$SegBWc       <-cw$SegBW       -mean(cw$SegBW       ,na.rm=T)
cw$SegNWc       <-cw$SegNW       -mean(cw$SegNW       ,na.rm=T)
cw$SocAssoc     <-cw$SocAsso     -mean(cw$SocAsso     ,na.rm=T)
cw$SocSuppc     <-cw$SocSupp     -mean(cw$SocSupp     ,na.rm=T)
cw$MIECHVc      <-cw$MIECHV      -mean(cw$MIECHV      ,na.rm=T)
cw$NHVRCc       <-cw$NHVRC       -mean(cw$NHVRC       ,na.rm=T)
cw$FoodInsecurec<-cw$FoodInsecure-mean(cw$FoodInsecure,na.rm=T)
cw$PCPAllc      <-cw$PCPAll      -mean(cw$PCPAll      ,na.rm=T)
cw$MH_PCPc      <-cw$MH_PCP      -mean(cw$MH_PCP      ,na.rm=T)

cw<-cbind(cw,demean(cw,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cwm01<-lmer(RptWr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
# Mental Health
cwm02<-lmer(RptWr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm03<-lmer(RptWr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm04<-lmer(RptWr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
# Mental Health Interaction
cwm05<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm06<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+USDA_RUC*MHPrvdc_within+USDA_RUC*MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
# Mental Health Random Slope
cwm07<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cw)
cwm08<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Mentalc_within|CountyFIPS)+(Mentalc_within|StateFIPS),data=cw)
# Physical Health
cwm12<-lmer(RptWr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm13<-lmer(RptWr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm14<-lmer(RptWr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
# Physical Health Interaction
cwm15<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
cwm16<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+USDA_RUC*PCPc_within+USDA_RUC*PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cw)
# Physical Health Random Slope
cwm17<-lmer(RptWr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Physicalc_within|CountyFIPS)+(1|StateFIPS),data=cw)
cwm18<-lmer(RptWr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Physicalc_within|CountyFIPS)+(Physicalc_within|StateFIPS),data=cw)
cwm17a<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Physicalc_within|CountyFIPS)+(1|StateFIPS),data=cw)
cwm18a<-lmer(RptWr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+
              IncomeW1kc_within+IncomeW1kc_between+SingleWc_within+SingleWc_between+
              CPopBPc+CPopHPc+FBornWc_within+FBornWc_between+
              ChildPWc_within+ChildPWc_between+DisablWc_within+DisablWc_between+MoveWc_within+MoveWc_between+
              (Physicalc_within|CountyFIPS)+(Physicalc_within|StateFIPS),data=cw)

# bootstrap confidence interval
cwm01CI<-confint(cwm01,method='boot',nsim=500,boot.type='perc')
cwm02CI<-confint(cwm02,method='boot',nsim=500,boot.type='perc')
cwm03CI<-confint(cwm03,method='boot',nsim=500,boot.type='perc')
cwm04CI<-confint(cwm04,method='boot',nsim=500,boot.type='perc')
cwm05CI<-confint(cwm05,method='boot',nsim=500,boot.type='perc')
cwm06CI<-confint(cwm06,method='boot',nsim=500,boot.type='perc')
cwm07CI<-confint(cwm07,method='boot',nsim=500,boot.type='perc')
cwm08CI<-confint(cwm08,method='boot',nsim=500,boot.type='perc')
cwm12CI<-confint(cwm12,method='boot',nsim=500,boot.type='perc')
cwm13CI<-confint(cwm13,method='boot',nsim=500,boot.type='perc')
cwm14CI<-confint(cwm14,method='boot',nsim=500,boot.type='perc')
cwm15CI<-confint(cwm15,method='boot',nsim=500,boot.type='perc')
cwm16CI<-confint(cwm16,method='boot',nsim=500,boot.type='perc')
cwm17CI<-confint(cwm17,method='boot',nsim=500,boot.type='perc')
cwm18CI<-confint(cwm18,method='boot',nsim=500,boot.type='perc')
cwm17aCI<-confint(cwm17a,method='boot',nsim=500,boot.type='perc')
cwm18aCI<-confint(cwm18a,method='boot',nsim=500,boot.type='perc')

AIC(cwm01,cwm02,cwm03,cwm04,cwm05,cwm06,cwm07,cwm08)
anova(cwm04,cwm05,cwm06)
anova(cwm04,cwm05,cwm07,cwm08)
AIC(cwm01,cwm12,cwm13,cwm14,cwm15,cwm16,cwm17,cwm18)
anova(cwm14,cwm15,cwm16)
anova(cwm14,cwm15,cwm17a,cwm18a)
anova(cwm17,cwm17a)
anova(cwm18,cwm18a)

tab_model(cwm01,cwm02,cwm03,cwm04,cwm05,cwm06,cwm07,cwm08,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm01,cwm12,cwm13,cwm14,cwm15,cwm16,cwm17a,cwm18a,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cwm01,cwm12,cwm13,cwm14,cwm15,cwm16,cwm17,cwm18,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# Model Check
check_collinearity(cwm01)
check_collinearity(cwm02)
check_collinearity(cwm03)
check_collinearity(cwm04)
check_collinearity(cwm05)
check_collinearity(cwm06)
check_collinearity(cwm07)
isSingular(cwm01)
isSingular(cwm02)
isSingular(cwm03)
isSingular(cwm04)
isSingular(cwm05)
isSingular(cwm06)
isSingular(cwm07)
isSingular(cwm08)
isSingular(cwm14)
isSingular(cwm15)
isSingular(cwm16)
isSingular(cwm17)
isSingular(cwm18)
isSingular(cwm17a)
isSingular(cwm18a)





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
cb$CPopBPc      <-cb$CPopBP      -mean(cb$CPopBP      ,na.rm=T)
cb$CPopHPc      <-cb$CPopHP      -mean(cb$CPopHP      ,na.rm=T)
cb$ChildPTc     <-cb$ChildPT     -mean(cb$ChildPT     ,na.rm=T)
cb$ChildPWc     <-cb$ChildPW     -mean(cb$ChildPW     ,na.rm=T)
cb$ChildPBc     <-cb$ChildPB     -mean(cb$ChildPB     ,na.rm=T)
cb$ChildPHc     <-cb$ChildPH     -mean(cb$ChildPH     ,na.rm=T)
cb$CARatioT100c <-cb$CARatioT100 -mean(cb$CARatioT100 ,na.rm=T)
cb$CARatioW100c <-cb$CARatioW100 -mean(cb$CARatioW100 ,na.rm=T)
cb$CARatioB100c <-cb$CARatioB100 -mean(cb$CARatioB100 ,na.rm=T)
cb$CARatioH100c <-cb$CARatioH100 -mean(cb$CARatioH100 ,na.rm=T)
cb$MalePTc      <-cb$MalePT      -mean(cb$MalePT      ,na.rm=T)
cb$MalePWc      <-cb$MalePW      -mean(cb$MalePW      ,na.rm=T)
cb$MalePBc      <-cb$MalePB      -mean(cb$MalePB      ,na.rm=T)
cb$MalePHc      <-cb$MalePH      -mean(cb$MalePH      ,na.rm=T)
cb$MFRatioT100c <-cb$MFRatioT100 -mean(cb$MFRatioT100 ,na.rm=T)
cb$MFRatioW100c <-cb$MFRatioW100 -mean(cb$MFRatioW100 ,na.rm=T)
cb$MFRatioB100c <-cb$MFRatioB100 -mean(cb$MFRatioB100 ,na.rm=T)
cb$MFRatioH100c <-cb$MFRatioH100 -mean(cb$MFRatioH100 ,na.rm=T)
cb$ElderTc      <-cb$ElderT      -mean(cb$ElderT      ,na.rm=T)
cb$ElderWc      <-cb$ElderW      -mean(cb$ElderW      ,na.rm=T)
cb$ElderBc      <-cb$ElderB      -mean(cb$ElderB      ,na.rm=T)
cb$ElderHc      <-cb$ElderH      -mean(cb$ElderH      ,na.rm=T)
cb$SingleTc     <-cb$SingleT     -mean(cb$SingleT     ,na.rm=T)
cb$SingleWc     <-cb$SingleW     -mean(cb$SingleW     ,na.rm=T)
cb$SingleBc     <-cb$SingleB     -mean(cb$SingleB     ,na.rm=T)
cb$SingleHc     <-cb$SingleH     -mean(cb$SingleH     ,na.rm=T)
cb$FHeadTc      <-cb$FHeadT      -mean(cb$FHeadT      ,na.rm=T)
cb$FHeadWc      <-cb$FHeadW      -mean(cb$FHeadW      ,na.rm=T)
cb$FHeadBc      <-cb$FHeadB      -mean(cb$FHeadB      ,na.rm=T)
cb$FHeadHc      <-cb$FHeadH      -mean(cb$FHeadH      ,na.rm=T)
cb$NoHighTc     <-cb$NoHighT     -mean(cb$NoHighT     ,na.rm=T)
cb$NoHighWc     <-cb$NoHighW     -mean(cb$NoHighW     ,na.rm=T)
cb$NoHighBc     <-cb$NoHighB     -mean(cb$NoHighB     ,na.rm=T)
cb$NoHighHc     <-cb$NoHighH     -mean(cb$NoHighH     ,na.rm=T)
cb$UnempTc      <-cb$UnempT      -mean(cb$UnempT      ,na.rm=T)
cb$UnempWc      <-cb$UnempW      -mean(cb$UnempW      ,na.rm=T)
cb$UnempBc      <-cb$UnempB      -mean(cb$UnempB      ,na.rm=T)
cb$UnempHc      <-cb$UnempH      -mean(cb$UnempH      ,na.rm=T)
cb$CPovTc       <-cb$CPovT       -mean(cb$CPovT       ,na.rm=T)
cb$CPovWc       <-cb$CPovW       -mean(cb$CPovW       ,na.rm=T)
cb$CPovBc       <-cb$CPovB       -mean(cb$CPovB       ,na.rm=T)
cb$CPovHc       <-cb$CPovH       -mean(cb$CPovH       ,na.rm=T)
cb$CPov1c       <-cb$CPov1       -mean(cb$CPov1       ,na.rm=T)
cb$CPov2c       <-cb$CPov2       -mean(cb$CPov2       ,na.rm=T)
cb$CPov3c       <-cb$CPov3       -mean(cb$CPov3       ,na.rm=T)
cb$PubAsTc      <-cb$PubAsT      -mean(cb$PubAsT      ,na.rm=T)
cb$WelfarTc     <-cb$WelfarT     -mean(cb$WelfarT     ,na.rm=T)
cb$SnapTc       <-cb$SnapT       -mean(cb$SnapT       ,na.rm=T)
cb$SnapWc       <-cb$SnapW       -mean(cb$SnapW       ,na.rm=T)
cb$SnapBc       <-cb$SnapB       -mean(cb$SnapB       ,na.rm=T)
cb$SnapHc       <-cb$SnapH       -mean(cb$SnapH       ,na.rm=T)
cb$IncomeT1kc   <-cb$IncomeT1k   -mean(cb$IncomeT1k   ,na.rm=T)
cb$IncomeW1kc   <-cb$IncomeW1k   -mean(cb$IncomeW1k   ,na.rm=T)
cb$IncomeB1kc   <-cb$IncomeB1k   -mean(cb$IncomeB1k   ,na.rm=T)
cb$IncomeH1kc   <-cb$IncomeH1k   -mean(cb$IncomeH1k   ,na.rm=T)
cb$GiniT100c    <-cb$GiniT100    -mean(cb$GiniT100    ,na.rm=T)
cb$HValueT10kc  <-cb$HValueT10k  -mean(cb$HValueT10k  ,na.rm=T)
cb$MCostT100c   <-cb$MCostT100   -mean(cb$MCostT100   ,na.rm=T)
cb$OCostDT100c  <-cb$OCostDT100  -mean(cb$OCostDT100  ,na.rm=T)
cb$MRentDT100c  <-cb$MRentDT100  -mean(cb$MRentDT100  ,na.rm=T)
cb$OCostPTc     <-cb$OCostPT     -mean(cb$OCostPT     ,na.rm=T)
cb$MRentPTc     <-cb$MRentPT     -mean(cb$MRentPT     ,na.rm=T)
cb$MortgTc      <-cb$MortgT      -mean(cb$MortgT      ,na.rm=T)
cb$LangAPTc     <-cb$LangAPT     -mean(cb$LangAPT     ,na.rm=T)
cb$LangAPWc     <-cb$LangAPW     -mean(cb$LangAPW     ,na.rm=T)
cb$LangAPBc     <-cb$LangAPB     -mean(cb$LangAPB     ,na.rm=T)
cb$LangAPHc     <-cb$LangAPH     -mean(cb$LangAPH     ,na.rm=T)
cb$LangBPTc     <-cb$LangBPT     -mean(cb$LangBPT     ,na.rm=T)
cb$LangBPWc     <-cb$LangBPW     -mean(cb$LangBPW     ,na.rm=T)
cb$LangBPBc     <-cb$LangBPB     -mean(cb$LangBPB     ,na.rm=T)
cb$LangBPHc     <-cb$LangBPH     -mean(cb$LangBPH     ,na.rm=T)
cb$LangCPTc     <-cb$LangCPT     -mean(cb$LangCPT     ,na.rm=T)
cb$OutUsTc      <-cb$OutUsT      -mean(cb$OutUsT      ,na.rm=T)
cb$OutUsWc      <-cb$OutUsW      -mean(cb$OutUsW      ,na.rm=T)
cb$OutUsBc      <-cb$OutUsB      -mean(cb$OutUsB      ,na.rm=T)
cb$OutUsHc      <-cb$OutUsH      -mean(cb$OutUsH      ,na.rm=T)
cb$FBornTc      <-cb$FBornT      -mean(cb$FBornT      ,na.rm=T)
cb$FBornWc      <-cb$FBornW      -mean(cb$FBornW      ,na.rm=T)
cb$FBornBc      <-cb$FBornB      -mean(cb$FBornB      ,na.rm=T)
cb$FBornHc      <-cb$FBornH      -mean(cb$FBornH      ,na.rm=T)
cb$NotCtzTc     <-cb$NotCtzT     -mean(cb$NotCtzT     ,na.rm=T)
cb$NotCtzWc     <-cb$NotCtzW     -mean(cb$NotCtzW     ,na.rm=T)
cb$NotCtzBc     <-cb$NotCtzB     -mean(cb$NotCtzB     ,na.rm=T)
cb$NotCtzHc     <-cb$NotCtzH     -mean(cb$NotCtzH     ,na.rm=T)
cb$MoveTc       <-cb$MoveT       -mean(cb$MoveT       ,na.rm=T)
cb$MoveWc       <-cb$MoveW       -mean(cb$MoveW       ,na.rm=T)
cb$MoveBc       <-cb$MoveB       -mean(cb$MoveB       ,na.rm=T)
cb$MoveHc       <-cb$MoveH       -mean(cb$MoveH       ,na.rm=T)
cb$VacantTc     <-cb$VacantT     -mean(cb$VacantT     ,na.rm=T)
cb$OwnerTc      <-cb$OwnerT      -mean(cb$OwnerT      ,na.rm=T)
cb$OwnerWc      <-cb$OwnerW      -mean(cb$OwnerW      ,na.rm=T)
cb$OwnerBc      <-cb$OwnerB      -mean(cb$OwnerB      ,na.rm=T)
cb$OwnerHc      <-cb$OwnerH      -mean(cb$OwnerH      ,na.rm=T)
cb$CrowdTc      <-cb$CrowdT      -mean(cb$CrowdT      ,na.rm=T)
cb$CrowdWc      <-cb$CrowdW      -mean(cb$CrowdW      ,na.rm=T)
cb$CrowdBc      <-cb$CrowdB      -mean(cb$CrowdB      ,na.rm=T)
cb$CrowdHc      <-cb$CrowdH      -mean(cb$CrowdH      ,na.rm=T)
cb$MobileTc     <-cb$MobileT     -mean(cb$MobileT     ,na.rm=T)
cb$MobileWc     <-cb$MobileW     -mean(cb$MobileW     ,na.rm=T)
cb$MobileBc     <-cb$MobileB     -mean(cb$MobileB     ,na.rm=T)
cb$MobileHc     <-cb$MobileH     -mean(cb$MobileH     ,na.rm=T)
cb$DisablTc     <-cb$DisablT     -mean(cb$DisablT     ,na.rm=T)
cb$DisablWc     <-cb$DisablW     -mean(cb$DisablW     ,na.rm=T)
cb$DisablBc     <-cb$DisablB     -mean(cb$DisablB     ,na.rm=T)
cb$DisablHc     <-cb$DisablH     -mean(cb$DisablH     ,na.rm=T)
cb$DisablTCc    <-cb$DisablTC    -mean(cb$DisablTC    ,na.rm=T)
cb$DisablWCc    <-cb$DisablWC    -mean(cb$DisablWC    ,na.rm=T)
cb$DisablBCc    <-cb$DisablBC    -mean(cb$DisablBC    ,na.rm=T)
cb$DisablHCc    <-cb$DisablHC    -mean(cb$DisablHC    ,na.rm=T)
cb$DisablTMc    <-cb$DisablTM    -mean(cb$DisablTM    ,na.rm=T)
cb$DisablTFc    <-cb$DisablTF    -mean(cb$DisablTF    ,na.rm=T)
cb$Urban1c      <-cb$Urban1      -mean(cb$Urban1      ,na.rm=T)
cb$Urban2c      <-cb$Urban2      -mean(cb$Urban2      ,na.rm=T)
cb$LBWT1rc      <-cb$LBWT1r      -mean(cb$LBWT1r      ,na.rm=T)
cb$LBWM1rc      <-cb$LBWM1r      -mean(cb$LBWM1r      ,na.rm=T)
cb$LBWF1rc      <-cb$LBWF1r      -mean(cb$LBWF1r      ,na.rm=T)
cb$LBWW1rc      <-cb$LBWW1r      -mean(cb$LBWW1r      ,na.rm=T)
cb$LBWB1rc      <-cb$LBWB1r      -mean(cb$LBWB1r      ,na.rm=T)
cb$LBWH1rc      <-cb$LBWH1r      -mean(cb$LBWH1r      ,na.rm=T)
cb$PTBT1rc      <-cb$PTBT1r      -mean(cb$PTBT1r      ,na.rm=T)
cb$PTBM1rc      <-cb$PTBM1r      -mean(cb$PTBM1r      ,na.rm=T)
cb$PTBF1rc      <-cb$PTBF1r      -mean(cb$PTBF1r      ,na.rm=T)
cb$PTBW1rc      <-cb$PTBW1r      -mean(cb$PTBW1r      ,na.rm=T)
cb$PTBB1rc      <-cb$PTBB1r      -mean(cb$PTBB1r      ,na.rm=T)
cb$PTBH1rc      <-cb$PTBH1r      -mean(cb$PTBH1r      ,na.rm=T)
cb$PNCT1rc      <-cb$PNCT1r      -mean(cb$PNCT1r      ,na.rm=T)
cb$PNCM1rc      <-cb$PNCM1r      -mean(cb$PNCM1r      ,na.rm=T)
cb$PNCF1rc      <-cb$PNCF1r      -mean(cb$PNCF1r      ,na.rm=T)
cb$PNCW1rc      <-cb$PNCW1r      -mean(cb$PNCW1r      ,na.rm=T)
cb$PNCB1rc      <-cb$PNCB1r      -mean(cb$PNCB1r      ,na.rm=T)
cb$PNCH1rc      <-cb$PNCH1r      -mean(cb$PNCH1r      ,na.rm=T)
cb$TBBT1rc      <-cb$TBBT1r      -mean(cb$TBBT1r      ,na.rm=T)
cb$TBBM1rc      <-cb$TBBM1r      -mean(cb$TBBM1r      ,na.rm=T)
cb$TBBF1rc      <-cb$TBBF1r      -mean(cb$TBBF1r      ,na.rm=T)
cb$TBBW1rc      <-cb$TBBW1r      -mean(cb$TBBW1r      ,na.rm=T)
cb$TBBB1rc      <-cb$TBBB1r      -mean(cb$TBBB1r      ,na.rm=T)
cb$TBBH1rc      <-cb$TBBH1r      -mean(cb$TBBH1r      ,na.rm=T)
cb$TBTT1rc      <-cb$TBTT1r      -mean(cb$TBTT1r      ,na.rm=T)
cb$TBTM1rc      <-cb$TBTM1r      -mean(cb$TBTM1r      ,na.rm=T)
cb$TBTF1rc      <-cb$TBTF1r      -mean(cb$TBTF1r      ,na.rm=T)
cb$TBTW1rc      <-cb$TBTW1r      -mean(cb$TBTW1r      ,na.rm=T)
cb$TBTB1rc      <-cb$TBTB1r      -mean(cb$TBTB1r      ,na.rm=T)
cb$TBTH1rc      <-cb$TBTH1r      -mean(cb$TBTH1r      ,na.rm=T)
cb$LBWT5rc      <-cb$LBWT5r      -mean(cb$LBWT5r      ,na.rm=T)
cb$LBWM5rc      <-cb$LBWM5r      -mean(cb$LBWM5r      ,na.rm=T)
cb$LBWF5rc      <-cb$LBWF5r      -mean(cb$LBWF5r      ,na.rm=T)
cb$LBWW5rc      <-cb$LBWW5r      -mean(cb$LBWW5r      ,na.rm=T)
cb$LBWB5rc      <-cb$LBWB5r      -mean(cb$LBWB5r      ,na.rm=T)
cb$LBWH5rc      <-cb$LBWH5r      -mean(cb$LBWH5r      ,na.rm=T)
cb$PTBT5rc      <-cb$PTBT5r      -mean(cb$PTBT5r      ,na.rm=T)
cb$PTBM5rc      <-cb$PTBM5r      -mean(cb$PTBM5r      ,na.rm=T)
cb$PTBF5rc      <-cb$PTBF5r      -mean(cb$PTBF5r      ,na.rm=T)
cb$PTBW5rc      <-cb$PTBW5r      -mean(cb$PTBW5r      ,na.rm=T)
cb$PTBB5rc      <-cb$PTBB5r      -mean(cb$PTBB5r      ,na.rm=T)
cb$PTBH5rc      <-cb$PTBH5r      -mean(cb$PTBH5r      ,na.rm=T)
cb$PNCT5rc      <-cb$PNCT5r      -mean(cb$PNCT5r      ,na.rm=T)
cb$PNCM5rc      <-cb$PNCM5r      -mean(cb$PNCM5r      ,na.rm=T)
cb$PNCF5rc      <-cb$PNCF5r      -mean(cb$PNCF5r      ,na.rm=T)
cb$PNCW5rc      <-cb$PNCW5r      -mean(cb$PNCW5r      ,na.rm=T)
cb$PNCB5rc      <-cb$PNCB5r      -mean(cb$PNCB5r      ,na.rm=T)
cb$PNCH5rc      <-cb$PNCH5r      -mean(cb$PNCH5r      ,na.rm=T)
cb$TBBT5rc      <-cb$TBBT5r      -mean(cb$TBBT5r      ,na.rm=T)
cb$TBBM5rc      <-cb$TBBM5r      -mean(cb$TBBM5r      ,na.rm=T)
cb$TBBF5rc      <-cb$TBBF5r      -mean(cb$TBBF5r      ,na.rm=T)
cb$TBBW5rc      <-cb$TBBW5r      -mean(cb$TBBW5r      ,na.rm=T)
cb$TBBB5rc      <-cb$TBBB5r      -mean(cb$TBBB5r      ,na.rm=T)
cb$TBBH5rc      <-cb$TBBH5r      -mean(cb$TBBH5r      ,na.rm=T)
cb$TBTT5rc      <-cb$TBTT5r      -mean(cb$TBTT5r      ,na.rm=T)
cb$TBTM5rc      <-cb$TBTM5r      -mean(cb$TBTM5r      ,na.rm=T)
cb$TBTF5rc      <-cb$TBTF5r      -mean(cb$TBTF5r      ,na.rm=T)
cb$TBTW5rc      <-cb$TBTW5r      -mean(cb$TBTW5r      ,na.rm=T)
cb$TBTB5rc      <-cb$TBTB5r      -mean(cb$TBTB5r      ,na.rm=T)
cb$TBTH5rc      <-cb$TBTH5r      -mean(cb$TBTH5r      ,na.rm=T)
cb$Opioidc      <-cb$Opioid      -mean(cb$Opioid      ,na.rm=T)
cb$LifeExpc     <-cb$LifeExp     -mean(cb$LifeExp     ,na.rm=T)
cb$LifeExpBc    <-cb$LifeExpB    -mean(cb$LifeExpB    ,na.rm=T)
cb$LifeExpHc    <-cb$LifeExpH    -mean(cb$LifeExpH    ,na.rm=T)
cb$LifeExpWc    <-cb$LifeExpW    -mean(cb$LifeExpW    ,na.rm=T)
cb$ChdDeathc    <-cb$ChdDeath    -mean(cb$ChdDeath    ,na.rm=T)
cb$ChdDeathBc   <-cb$ChdDeathB   -mean(cb$ChdDeathB   ,na.rm=T)
cb$ChdDeathHc   <-cb$ChdDeathH   -mean(cb$ChdDeathH   ,na.rm=T)
cb$ChdDeathWc   <-cb$ChdDeathW   -mean(cb$ChdDeathW   ,na.rm=T)
cb$InfDeathc    <-cb$InfDeath    -mean(cb$InfDeath    ,na.rm=T)
cb$InfDeathBc   <-cb$InfDeathB   -mean(cb$InfDeathB   ,na.rm=T)
cb$InfDeathHc   <-cb$InfDeathH   -mean(cb$InfDeathH   ,na.rm=T)
cb$InfDeathWc   <-cb$InfDeathW   -mean(cb$InfDeathW   ,na.rm=T)
cb$Injuryc      <-cb$Injury      -mean(cb$Injury      ,na.rm=T)
cb$InjuryBc     <-cb$InjuryB     -mean(cb$InjuryB     ,na.rm=T)
cb$InjuryHc     <-cb$InjuryH     -mean(cb$InjuryH     ,na.rm=T)
cb$InjuryWc     <-cb$InjuryW     -mean(cb$InjuryW     ,na.rm=T)
cb$GunDeathc    <-cb$GunDeath    -mean(cb$GunDeath    ,na.rm=T)
cb$GunDeathBc   <-cb$GunDeathB   -mean(cb$GunDeathB   ,na.rm=T)
cb$GunDeathWc   <-cb$GunDeathW   -mean(cb$GunDeathW   ,na.rm=T)
cb$PrmDeath_c   <-cb$PrmDeath    -mean(cb$PrmDeath    ,na.rm=T)
cb$PrmDeathcc   <-cb$PrmDeathc   -mean(cb$PrmDeathc   ,na.rm=T)
cb$PrmDeathBc   <-cb$PrmDeathB   -mean(cb$PrmDeathB   ,na.rm=T)
cb$PrmDeathHc   <-cb$PrmDeathH   -mean(cb$PrmDeathH   ,na.rm=T)
cb$PrmDeathWc   <-cb$PrmDeathW   -mean(cb$PrmDeathW   ,na.rm=T)
cb$PrmDeath2_c  <-cb$PrmDeath2   -mean(cb$PrmDeath2   ,na.rm=T)
cb$PrmDeath2cc  <-cb$PrmDeath2c  -mean(cb$PrmDeath2c  ,na.rm=T)
cb$PrmDeath2Bc  <-cb$PrmDeath2B  -mean(cb$PrmDeath2B  ,na.rm=T)
cb$PrmDeath2Hc  <-cb$PrmDeath2H  -mean(cb$PrmDeath2H  ,na.rm=T)
cb$PrmDeath2Wc  <-cb$PrmDeath2W  -mean(cb$PrmDeath2W  ,na.rm=T)
cb$Suicidec     <-cb$Suicide     -mean(cb$Suicide     ,na.rm=T)
cb$Diabetc      <-cb$Diabet      -mean(cb$Diabet      ,na.rm=T)
cb$Obesityc     <-cb$Obesity     -mean(cb$Obesity     ,na.rm=T)
cb$Physicalc    <-cb$Physical    -mean(cb$Physical    ,na.rm=T)
cb$PoorHlthc    <-cb$PoorHlth    -mean(cb$PoorHlth    ,na.rm=T)
cb$PoorMHc      <-cb$PoorMH      -mean(cb$PoorMH      ,na.rm=T)
cb$PoorPhyc     <-cb$PoorPhy     -mean(cb$PoorPhy     ,na.rm=T)
cb$Sleepc       <-cb$Sleep       -mean(cb$Sleep       ,na.rm=T)
cb$DrugOdc      <-cb$DrugOd      -mean(cb$DrugOd      ,na.rm=T)
cb$DrugOdBc     <-cb$DrugOdB     -mean(cb$DrugOdB     ,na.rm=T)
cb$DrugOdHc     <-cb$DrugOdH     -mean(cb$DrugOdH     ,na.rm=T)
cb$DrugOdWc     <-cb$DrugOdW     -mean(cb$DrugOdW     ,na.rm=T)
cb$DWIDeathc    <-cb$DWIDeath    -mean(cb$DWIDeath    ,na.rm=T)
cb$EDrinkc      <-cb$EDrink      -mean(cb$EDrink      ,na.rm=T)
cb$Smokec       <-cb$Smoke       -mean(cb$Smoke       ,na.rm=T)
cb$FastFoodc    <-cb$FastFood    -mean(cb$FastFood    ,na.rm=T)
cb$FoodEnvc     <-cb$FoodEnv     -mean(cb$FoodEnv     ,na.rm=T)
cb$FoodInsc     <-cb$FoodIns     -mean(cb$FoodIns     ,na.rm=T)
cb$FrLunchc     <-cb$FrLunch     -mean(cb$FrLunch     ,na.rm=T)
cb$LAccFoodc    <-cb$LAccFood    -mean(cb$LAccFood    ,na.rm=T)
cb$Gymc         <-cb$Gym         -mean(cb$Gym         ,na.rm=T)
cb$Gym2c        <-cb$Gym2        -mean(cb$Gym2        ,na.rm=T)
cb$Inactivec    <-cb$Inactive    -mean(cb$Inactive    ,na.rm=T)
cb$HousCostc    <-cb$HousCost    -mean(cb$HousCost    ,na.rm=T)
cb$HousCostsc   <-cb$HousCosts   -mean(cb$HousCosts   ,na.rm=T)
cb$HousCrowdc   <-cb$HousCrowd   -mean(cb$HousCrowd   ,na.rm=T)
cb$Housingc     <-cb$Housing     -mean(cb$Housing     ,na.rm=T)
cb$HousPlumbc   <-cb$HousPlumb   -mean(cb$HousPlumb   ,na.rm=T)
cb$Insuredc     <-cb$Insured     -mean(cb$Insured     ,na.rm=T)
cb$InsuredAc    <-cb$InsuredA    -mean(cb$InsuredA    ,na.rm=T)
cb$InsuredCc    <-cb$InsuredC    -mean(cb$InsuredC    ,na.rm=T)
cb$JuvArrc      <-cb$JuvArr      -mean(cb$JuvArr      ,na.rm=T)
cb$Murderc      <-cb$Murder      -mean(cb$Murder      ,na.rm=T)
cb$Violentc     <-cb$Violent     -mean(cb$Violent     ,na.rm=T)
cb$LongCommc    <-cb$LongComm    -mean(cb$LongComm    ,na.rm=T)
cb$LowBWc       <-cb$LowBW       -mean(cb$LowBW       ,na.rm=T)
cb$LowBWBc      <-cb$LowBWB      -mean(cb$LowBWB      ,na.rm=T)
cb$LowBWHc      <-cb$LowBWH      -mean(cb$LowBWH      ,na.rm=T)
cb$LowBWWc      <-cb$LowBWW      -mean(cb$LowBWW      ,na.rm=T)
cb$TeenBthc     <-cb$TeenBth     -mean(cb$TeenBth     ,na.rm=T)
cb$TeenBthBc    <-cb$TeenBthB    -mean(cb$TeenBthB    ,na.rm=T)
cb$TeenBthHc    <-cb$TeenBthH    -mean(cb$TeenBthH    ,na.rm=T)
cb$TeenBthWc    <-cb$TeenBthW    -mean(cb$TeenBthW    ,na.rm=T)
cb$Mentalc      <-cb$Mental      -mean(cb$Mental      ,na.rm=T)
cb$MHPrvdc      <-cb$MHPrvd      -mean(cb$MHPrvd      ,na.rm=T)
cb$PCPc         <-cb$PCP         -mean(cb$PCP         ,na.rm=T)
cb$PCP2c        <-cb$PCP2        -mean(cb$PCP2        ,na.rm=T)
cb$Dentistc     <-cb$Dentist     -mean(cb$Dentist     ,na.rm=T)
cb$PrvtHospc    <-cb$PrvtHosp    -mean(cb$PrvtHosp    ,na.rm=T)
cb$PrvtHospBc   <-cb$PrvtHospB   -mean(cb$PrvtHospB   ,na.rm=T)
cb$PrvtHospHc   <-cb$PrvtHospH   -mean(cb$PrvtHospH   ,na.rm=T)
cb$PrvtHospWc   <-cb$PrvtHospW   -mean(cb$PrvtHospW   ,na.rm=T)
cb$SegBWc       <-cb$SegBW       -mean(cb$SegBW       ,na.rm=T)
cb$SegNWc       <-cb$SegNW       -mean(cb$SegNW       ,na.rm=T)
cb$SocAssoc     <-cb$SocAsso     -mean(cb$SocAsso     ,na.rm=T)
cb$SocSuppc     <-cb$SocSupp     -mean(cb$SocSupp     ,na.rm=T)
cb$MIECHVc      <-cb$MIECHV      -mean(cb$MIECHV      ,na.rm=T)
cb$NHVRCc       <-cb$NHVRC       -mean(cb$NHVRC       ,na.rm=T)
cb$FoodInsecurec<-cb$FoodInsecure-mean(cb$FoodInsecure,na.rm=T)
cb$PCPAllc      <-cb$PCPAll      -mean(cb$PCPAll      ,na.rm=T)
cb$MH_PCPc      <-cb$MH_PCP      -mean(cb$MH_PCP      ,na.rm=T)

cb<-cbind(cb,demean(cb,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
cbm01<-lmer(RptBr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
# Mental Health
cbm02<-lmer(RptBr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm03<-lmer(RptBr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm04<-lmer(RptBr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
# Mental Health Interaction
cbm05<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm06<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+USDA_RUC*MHPrvdc_within+USDA_RUC*MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
# Mental Health Random Slope
cbm07<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (Mentalc_within|CountyFIPS)+(1|StateFIPS),data=cb)
cbm08<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (Mentalc_within|CountyFIPS)+(Mentalc_within|StateFIPS),data=cb)
# Physical Health
cbm12<-lmer(RptBr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm13<-lmer(RptBr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm14<-lmer(RptBr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
# Physical Health Interaction
cbm15<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
cbm16<-lmer(RptBr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+USDA_RUC*PCPc_within+USDA_RUC*PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=cb)
# Physical Health Random Slope
cbm17<-lmer(RptBr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (Physicalc_within|CountyFIPS)+(1|StateFIPS),data=cb)
cbm18<-lmer(RptBr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeB1kc_within+IncomeB1kc_between+SingleBc_within+SingleBc_between+
              CPopBPc+CPopHPc+FBornBc_within+FBornBc_between+
              ChildPBc_within+ChildPBc_between+DisablBc_within+DisablBc_between+MoveBc_within+MoveBc_between+
              (1|CountyFIPS)+(Physicalc_within|StateFIPS),data=cb)

# bootstrap confidence interval
cbm01CI<-confint(cbm01,method='boot',nsim=500,boot.type='perc')
cbm02CI<-confint(cbm02,method='boot',nsim=500,boot.type='perc')
cbm03CI<-confint(cbm03,method='boot',nsim=500,boot.type='perc')
cbm04CI<-confint(cbm04,method='boot',nsim=500,boot.type='perc')
cbm05CI<-confint(cbm05,method='boot',nsim=500,boot.type='perc')
cbm06CI<-confint(cbm06,method='boot',nsim=500,boot.type='perc')
cbm07CI<-confint(cbm07,method='boot',nsim=500,boot.type='perc')
cbm08CI<-confint(cbm08,method='boot',nsim=500,boot.type='perc')
cbm12CI<-confint(cbm12,method='boot',nsim=500,boot.type='perc')
cbm13CI<-confint(cbm13,method='boot',nsim=500,boot.type='perc')
cbm14CI<-confint(cbm14,method='boot',nsim=500,boot.type='perc')
cbm15CI<-confint(cbm15,method='boot',nsim=500,boot.type='perc')
cbm16CI<-confint(cbm16,method='boot',nsim=500,boot.type='perc')
cbm17CI<-confint(cbm17,method='boot',nsim=500,boot.type='perc')
cbm18CI<-confint(cbm18,method='boot',nsim=500,boot.type='perc')

AIC(cbm01,cbm02,cbm03,cbm04,cbm05,cbm06,cbm07,cbm08)
anova(cbm04,cbm05,cbm06)
anova(cbm04,cbm05,cbm07,cbm08)
AIC(cbm01,cbm12,cbm13,cbm14,cbm15,cbm16,cbm17,cbm18)
anova(cbm14,cbm15,cbm16)
anova(cbm14,cbm17)
anova(cbm14,cbm18)

tab_model(cbm01,cbm02,cbm03,cbm04,cbm05,cbm06,cbm07,cbm08,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(cbm01,cbm12,cbm13,cbm14,cbm15,cbm16,cbm17,cbm18,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# Model Check
check_collinearity(cbm01)
check_collinearity(cbm02)
check_collinearity(cbm03)
check_collinearity(cbm04)
check_collinearity(cbm05)
check_collinearity(cbm06)
check_collinearity(cbm07)
isSingular(cbm01)
isSingular(cbm02)
isSingular(cbm03)
isSingular(cbm04)
isSingular(cbm05)
isSingular(cbm06)
isSingular(cbm18)






###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Managing Variables & Creating Between- and Within-Variables
ch$CPopBPc      <-ch$CPopBP      -mean(ch$CPopBP      ,na.rm=T)
ch$CPopHPc      <-ch$CPopHP      -mean(ch$CPopHP      ,na.rm=T)
ch$ChildPTc     <-ch$ChildPT     -mean(ch$ChildPT     ,na.rm=T)
ch$ChildPWc     <-ch$ChildPW     -mean(ch$ChildPW     ,na.rm=T)
ch$ChildPBc     <-ch$ChildPB     -mean(ch$ChildPB     ,na.rm=T)
ch$ChildPHc     <-ch$ChildPH     -mean(ch$ChildPH     ,na.rm=T)
ch$CARatioT100c <-ch$CARatioT100 -mean(ch$CARatioT100 ,na.rm=T)
ch$CARatioW100c <-ch$CARatioW100 -mean(ch$CARatioW100 ,na.rm=T)
ch$CARatioB100c <-ch$CARatioB100 -mean(ch$CARatioB100 ,na.rm=T)
ch$CARatioH100c <-ch$CARatioH100 -mean(ch$CARatioH100 ,na.rm=T)
ch$MalePTc      <-ch$MalePT      -mean(ch$MalePT      ,na.rm=T)
ch$MalePWc      <-ch$MalePW      -mean(ch$MalePW      ,na.rm=T)
ch$MalePBc      <-ch$MalePB      -mean(ch$MalePB      ,na.rm=T)
ch$MalePHc      <-ch$MalePH      -mean(ch$MalePH      ,na.rm=T)
ch$MFRatioT100c <-ch$MFRatioT100 -mean(ch$MFRatioT100 ,na.rm=T)
ch$MFRatioW100c <-ch$MFRatioW100 -mean(ch$MFRatioW100 ,na.rm=T)
ch$MFRatioB100c <-ch$MFRatioB100 -mean(ch$MFRatioB100 ,na.rm=T)
ch$MFRatioH100c <-ch$MFRatioH100 -mean(ch$MFRatioH100 ,na.rm=T)
ch$ElderTc      <-ch$ElderT      -mean(ch$ElderT      ,na.rm=T)
ch$ElderWc      <-ch$ElderW      -mean(ch$ElderW      ,na.rm=T)
ch$ElderBc      <-ch$ElderB      -mean(ch$ElderB      ,na.rm=T)
ch$ElderHc      <-ch$ElderH      -mean(ch$ElderH      ,na.rm=T)
ch$SingleTc     <-ch$SingleT     -mean(ch$SingleT     ,na.rm=T)
ch$SingleWc     <-ch$SingleW     -mean(ch$SingleW     ,na.rm=T)
ch$SingleBc     <-ch$SingleB     -mean(ch$SingleB     ,na.rm=T)
ch$SingleHc     <-ch$SingleH     -mean(ch$SingleH     ,na.rm=T)
ch$FHeadTc      <-ch$FHeadT      -mean(ch$FHeadT      ,na.rm=T)
ch$FHeadWc      <-ch$FHeadW      -mean(ch$FHeadW      ,na.rm=T)
ch$FHeadBc      <-ch$FHeadB      -mean(ch$FHeadB      ,na.rm=T)
ch$FHeadHc      <-ch$FHeadH      -mean(ch$FHeadH      ,na.rm=T)
ch$NoHighTc     <-ch$NoHighT     -mean(ch$NoHighT     ,na.rm=T)
ch$NoHighWc     <-ch$NoHighW     -mean(ch$NoHighW     ,na.rm=T)
ch$NoHighBc     <-ch$NoHighB     -mean(ch$NoHighB     ,na.rm=T)
ch$NoHighHc     <-ch$NoHighH     -mean(ch$NoHighH     ,na.rm=T)
ch$UnempTc      <-ch$UnempT      -mean(ch$UnempT      ,na.rm=T)
ch$UnempWc      <-ch$UnempW      -mean(ch$UnempW      ,na.rm=T)
ch$UnempBc      <-ch$UnempB      -mean(ch$UnempB      ,na.rm=T)
ch$UnempHc      <-ch$UnempH      -mean(ch$UnempH      ,na.rm=T)
ch$CPovTc       <-ch$CPovT       -mean(ch$CPovT       ,na.rm=T)
ch$CPovWc       <-ch$CPovW       -mean(ch$CPovW       ,na.rm=T)
ch$CPovBc       <-ch$CPovB       -mean(ch$CPovB       ,na.rm=T)
ch$CPovHc       <-ch$CPovH       -mean(ch$CPovH       ,na.rm=T)
ch$CPov1c       <-ch$CPov1       -mean(ch$CPov1       ,na.rm=T)
ch$CPov2c       <-ch$CPov2       -mean(ch$CPov2       ,na.rm=T)
ch$CPov3c       <-ch$CPov3       -mean(ch$CPov3       ,na.rm=T)
ch$PubAsTc      <-ch$PubAsT      -mean(ch$PubAsT      ,na.rm=T)
ch$WelfarTc     <-ch$WelfarT     -mean(ch$WelfarT     ,na.rm=T)
ch$SnapTc       <-ch$SnapT       -mean(ch$SnapT       ,na.rm=T)
ch$SnapWc       <-ch$SnapW       -mean(ch$SnapW       ,na.rm=T)
ch$SnapBc       <-ch$SnapB       -mean(ch$SnapB       ,na.rm=T)
ch$SnapHc       <-ch$SnapH       -mean(ch$SnapH       ,na.rm=T)
ch$IncomeT1kc   <-ch$IncomeT1k   -mean(ch$IncomeT1k   ,na.rm=T)
ch$IncomeW1kc   <-ch$IncomeW1k   -mean(ch$IncomeW1k   ,na.rm=T)
ch$IncomeB1kc   <-ch$IncomeB1k   -mean(ch$IncomeB1k   ,na.rm=T)
ch$IncomeH1kc   <-ch$IncomeH1k   -mean(ch$IncomeH1k   ,na.rm=T)
ch$GiniT100c    <-ch$GiniT100    -mean(ch$GiniT100    ,na.rm=T)
ch$HValueT10kc  <-ch$HValueT10k  -mean(ch$HValueT10k  ,na.rm=T)
ch$MCostT100c   <-ch$MCostT100   -mean(ch$MCostT100   ,na.rm=T)
ch$OCostDT100c  <-ch$OCostDT100  -mean(ch$OCostDT100  ,na.rm=T)
ch$MRentDT100c  <-ch$MRentDT100  -mean(ch$MRentDT100  ,na.rm=T)
ch$OCostPTc     <-ch$OCostPT     -mean(ch$OCostPT     ,na.rm=T)
ch$MRentPTc     <-ch$MRentPT     -mean(ch$MRentPT     ,na.rm=T)
ch$MortgTc      <-ch$MortgT      -mean(ch$MortgT      ,na.rm=T)
ch$LangAPTc     <-ch$LangAPT     -mean(ch$LangAPT     ,na.rm=T)
ch$LangAPWc     <-ch$LangAPW     -mean(ch$LangAPW     ,na.rm=T)
ch$LangAPBc     <-ch$LangAPB     -mean(ch$LangAPB     ,na.rm=T)
ch$LangAPHc     <-ch$LangAPH     -mean(ch$LangAPH     ,na.rm=T)
ch$LangBPTc     <-ch$LangBPT     -mean(ch$LangBPT     ,na.rm=T)
ch$LangBPWc     <-ch$LangBPW     -mean(ch$LangBPW     ,na.rm=T)
ch$LangBPBc     <-ch$LangBPB     -mean(ch$LangBPB     ,na.rm=T)
ch$LangBPHc     <-ch$LangBPH     -mean(ch$LangBPH     ,na.rm=T)
ch$LangCPTc     <-ch$LangCPT     -mean(ch$LangCPT     ,na.rm=T)
ch$OutUsTc      <-ch$OutUsT      -mean(ch$OutUsT      ,na.rm=T)
ch$OutUsWc      <-ch$OutUsW      -mean(ch$OutUsW      ,na.rm=T)
ch$OutUsBc      <-ch$OutUsB      -mean(ch$OutUsB      ,na.rm=T)
ch$OutUsHc      <-ch$OutUsH      -mean(ch$OutUsH      ,na.rm=T)
ch$FBornTc      <-ch$FBornT      -mean(ch$FBornT      ,na.rm=T)
ch$FBornWc      <-ch$FBornW      -mean(ch$FBornW      ,na.rm=T)
ch$FBornBc      <-ch$FBornB      -mean(ch$FBornB      ,na.rm=T)
ch$FBornHc      <-ch$FBornH      -mean(ch$FBornH      ,na.rm=T)
ch$NotCtzTc     <-ch$NotCtzT     -mean(ch$NotCtzT     ,na.rm=T)
ch$NotCtzWc     <-ch$NotCtzW     -mean(ch$NotCtzW     ,na.rm=T)
ch$NotCtzBc     <-ch$NotCtzB     -mean(ch$NotCtzB     ,na.rm=T)
ch$NotCtzHc     <-ch$NotCtzH     -mean(ch$NotCtzH     ,na.rm=T)
ch$MoveTc       <-ch$MoveT       -mean(ch$MoveT       ,na.rm=T)
ch$MoveWc       <-ch$MoveW       -mean(ch$MoveW       ,na.rm=T)
ch$MoveBc       <-ch$MoveB       -mean(ch$MoveB       ,na.rm=T)
ch$MoveHc       <-ch$MoveH       -mean(ch$MoveH       ,na.rm=T)
ch$VacantTc     <-ch$VacantT     -mean(ch$VacantT     ,na.rm=T)
ch$OwnerTc      <-ch$OwnerT      -mean(ch$OwnerT      ,na.rm=T)
ch$OwnerWc      <-ch$OwnerW      -mean(ch$OwnerW      ,na.rm=T)
ch$OwnerBc      <-ch$OwnerB      -mean(ch$OwnerB      ,na.rm=T)
ch$OwnerHc      <-ch$OwnerH      -mean(ch$OwnerH      ,na.rm=T)
ch$CrowdTc      <-ch$CrowdT      -mean(ch$CrowdT      ,na.rm=T)
ch$CrowdWc      <-ch$CrowdW      -mean(ch$CrowdW      ,na.rm=T)
ch$CrowdBc      <-ch$CrowdB      -mean(ch$CrowdB      ,na.rm=T)
ch$CrowdHc      <-ch$CrowdH      -mean(ch$CrowdH      ,na.rm=T)
ch$MobileTc     <-ch$MobileT     -mean(ch$MobileT     ,na.rm=T)
ch$MobileWc     <-ch$MobileW     -mean(ch$MobileW     ,na.rm=T)
ch$MobileBc     <-ch$MobileB     -mean(ch$MobileB     ,na.rm=T)
ch$MobileHc     <-ch$MobileH     -mean(ch$MobileH     ,na.rm=T)
ch$DisablTc     <-ch$DisablT     -mean(ch$DisablT     ,na.rm=T)
ch$DisablWc     <-ch$DisablW     -mean(ch$DisablW     ,na.rm=T)
ch$DisablBc     <-ch$DisablB     -mean(ch$DisablB     ,na.rm=T)
ch$DisablHc     <-ch$DisablH     -mean(ch$DisablH     ,na.rm=T)
ch$DisablTCc    <-ch$DisablTC    -mean(ch$DisablTC    ,na.rm=T)
ch$DisablWCc    <-ch$DisablWC    -mean(ch$DisablWC    ,na.rm=T)
ch$DisablBCc    <-ch$DisablBC    -mean(ch$DisablBC    ,na.rm=T)
ch$DisablHCc    <-ch$DisablHC    -mean(ch$DisablHC    ,na.rm=T)
ch$DisablTMc    <-ch$DisablTM    -mean(ch$DisablTM    ,na.rm=T)
ch$DisablTFc    <-ch$DisablTF    -mean(ch$DisablTF    ,na.rm=T)
ch$Urban1c      <-ch$Urban1      -mean(ch$Urban1      ,na.rm=T)
ch$Urban2c      <-ch$Urban2      -mean(ch$Urban2      ,na.rm=T)
ch$LBWT1rc      <-ch$LBWT1r      -mean(ch$LBWT1r      ,na.rm=T)
ch$LBWM1rc      <-ch$LBWM1r      -mean(ch$LBWM1r      ,na.rm=T)
ch$LBWF1rc      <-ch$LBWF1r      -mean(ch$LBWF1r      ,na.rm=T)
ch$LBWW1rc      <-ch$LBWW1r      -mean(ch$LBWW1r      ,na.rm=T)
ch$LBWB1rc      <-ch$LBWB1r      -mean(ch$LBWB1r      ,na.rm=T)
ch$LBWH1rc      <-ch$LBWH1r      -mean(ch$LBWH1r      ,na.rm=T)
ch$PTBT1rc      <-ch$PTBT1r      -mean(ch$PTBT1r      ,na.rm=T)
ch$PTBM1rc      <-ch$PTBM1r      -mean(ch$PTBM1r      ,na.rm=T)
ch$PTBF1rc      <-ch$PTBF1r      -mean(ch$PTBF1r      ,na.rm=T)
ch$PTBW1rc      <-ch$PTBW1r      -mean(ch$PTBW1r      ,na.rm=T)
ch$PTBB1rc      <-ch$PTBB1r      -mean(ch$PTBB1r      ,na.rm=T)
ch$PTBH1rc      <-ch$PTBH1r      -mean(ch$PTBH1r      ,na.rm=T)
ch$PNCT1rc      <-ch$PNCT1r      -mean(ch$PNCT1r      ,na.rm=T)
ch$PNCM1rc      <-ch$PNCM1r      -mean(ch$PNCM1r      ,na.rm=T)
ch$PNCF1rc      <-ch$PNCF1r      -mean(ch$PNCF1r      ,na.rm=T)
ch$PNCW1rc      <-ch$PNCW1r      -mean(ch$PNCW1r      ,na.rm=T)
ch$PNCB1rc      <-ch$PNCB1r      -mean(ch$PNCB1r      ,na.rm=T)
ch$PNCH1rc      <-ch$PNCH1r      -mean(ch$PNCH1r      ,na.rm=T)
ch$TBBT1rc      <-ch$TBBT1r      -mean(ch$TBBT1r      ,na.rm=T)
ch$TBBM1rc      <-ch$TBBM1r      -mean(ch$TBBM1r      ,na.rm=T)
ch$TBBF1rc      <-ch$TBBF1r      -mean(ch$TBBF1r      ,na.rm=T)
ch$TBBW1rc      <-ch$TBBW1r      -mean(ch$TBBW1r      ,na.rm=T)
ch$TBBB1rc      <-ch$TBBB1r      -mean(ch$TBBB1r      ,na.rm=T)
ch$TBBH1rc      <-ch$TBBH1r      -mean(ch$TBBH1r      ,na.rm=T)
ch$TBTT1rc      <-ch$TBTT1r      -mean(ch$TBTT1r      ,na.rm=T)
ch$TBTM1rc      <-ch$TBTM1r      -mean(ch$TBTM1r      ,na.rm=T)
ch$TBTF1rc      <-ch$TBTF1r      -mean(ch$TBTF1r      ,na.rm=T)
ch$TBTW1rc      <-ch$TBTW1r      -mean(ch$TBTW1r      ,na.rm=T)
ch$TBTB1rc      <-ch$TBTB1r      -mean(ch$TBTB1r      ,na.rm=T)
ch$TBTH1rc      <-ch$TBTH1r      -mean(ch$TBTH1r      ,na.rm=T)
ch$LBWT5rc      <-ch$LBWT5r      -mean(ch$LBWT5r      ,na.rm=T)
ch$LBWM5rc      <-ch$LBWM5r      -mean(ch$LBWM5r      ,na.rm=T)
ch$LBWF5rc      <-ch$LBWF5r      -mean(ch$LBWF5r      ,na.rm=T)
ch$LBWW5rc      <-ch$LBWW5r      -mean(ch$LBWW5r      ,na.rm=T)
ch$LBWB5rc      <-ch$LBWB5r      -mean(ch$LBWB5r      ,na.rm=T)
ch$LBWH5rc      <-ch$LBWH5r      -mean(ch$LBWH5r      ,na.rm=T)
ch$PTBT5rc      <-ch$PTBT5r      -mean(ch$PTBT5r      ,na.rm=T)
ch$PTBM5rc      <-ch$PTBM5r      -mean(ch$PTBM5r      ,na.rm=T)
ch$PTBF5rc      <-ch$PTBF5r      -mean(ch$PTBF5r      ,na.rm=T)
ch$PTBW5rc      <-ch$PTBW5r      -mean(ch$PTBW5r      ,na.rm=T)
ch$PTBB5rc      <-ch$PTBB5r      -mean(ch$PTBB5r      ,na.rm=T)
ch$PTBH5rc      <-ch$PTBH5r      -mean(ch$PTBH5r      ,na.rm=T)
ch$PNCT5rc      <-ch$PNCT5r      -mean(ch$PNCT5r      ,na.rm=T)
ch$PNCM5rc      <-ch$PNCM5r      -mean(ch$PNCM5r      ,na.rm=T)
ch$PNCF5rc      <-ch$PNCF5r      -mean(ch$PNCF5r      ,na.rm=T)
ch$PNCW5rc      <-ch$PNCW5r      -mean(ch$PNCW5r      ,na.rm=T)
ch$PNCB5rc      <-ch$PNCB5r      -mean(ch$PNCB5r      ,na.rm=T)
ch$PNCH5rc      <-ch$PNCH5r      -mean(ch$PNCH5r      ,na.rm=T)
ch$TBBT5rc      <-ch$TBBT5r      -mean(ch$TBBT5r      ,na.rm=T)
ch$TBBM5rc      <-ch$TBBM5r      -mean(ch$TBBM5r      ,na.rm=T)
ch$TBBF5rc      <-ch$TBBF5r      -mean(ch$TBBF5r      ,na.rm=T)
ch$TBBW5rc      <-ch$TBBW5r      -mean(ch$TBBW5r      ,na.rm=T)
ch$TBBB5rc      <-ch$TBBB5r      -mean(ch$TBBB5r      ,na.rm=T)
ch$TBBH5rc      <-ch$TBBH5r      -mean(ch$TBBH5r      ,na.rm=T)
ch$TBTT5rc      <-ch$TBTT5r      -mean(ch$TBTT5r      ,na.rm=T)
ch$TBTM5rc      <-ch$TBTM5r      -mean(ch$TBTM5r      ,na.rm=T)
ch$TBTF5rc      <-ch$TBTF5r      -mean(ch$TBTF5r      ,na.rm=T)
ch$TBTW5rc      <-ch$TBTW5r      -mean(ch$TBTW5r      ,na.rm=T)
ch$TBTB5rc      <-ch$TBTB5r      -mean(ch$TBTB5r      ,na.rm=T)
ch$TBTH5rc      <-ch$TBTH5r      -mean(ch$TBTH5r      ,na.rm=T)
ch$Opioidc      <-ch$Opioid      -mean(ch$Opioid      ,na.rm=T)
ch$LifeExpc     <-ch$LifeExp     -mean(ch$LifeExp     ,na.rm=T)
ch$LifeExpBc    <-ch$LifeExpB    -mean(ch$LifeExpB    ,na.rm=T)
ch$LifeExpHc    <-ch$LifeExpH    -mean(ch$LifeExpH    ,na.rm=T)
ch$LifeExpWc    <-ch$LifeExpW    -mean(ch$LifeExpW    ,na.rm=T)
ch$ChdDeathc    <-ch$ChdDeath    -mean(ch$ChdDeath    ,na.rm=T)
ch$ChdDeathBc   <-ch$ChdDeathB   -mean(ch$ChdDeathB   ,na.rm=T)
ch$ChdDeathHc   <-ch$ChdDeathH   -mean(ch$ChdDeathH   ,na.rm=T)
ch$ChdDeathWc   <-ch$ChdDeathW   -mean(ch$ChdDeathW   ,na.rm=T)
ch$InfDeathc    <-ch$InfDeath    -mean(ch$InfDeath    ,na.rm=T)
ch$InfDeathBc   <-ch$InfDeathB   -mean(ch$InfDeathB   ,na.rm=T)
ch$InfDeathHc   <-ch$InfDeathH   -mean(ch$InfDeathH   ,na.rm=T)
ch$InfDeathWc   <-ch$InfDeathW   -mean(ch$InfDeathW   ,na.rm=T)
ch$Injuryc      <-ch$Injury      -mean(ch$Injury      ,na.rm=T)
ch$InjuryBc     <-ch$InjuryB     -mean(ch$InjuryB     ,na.rm=T)
ch$InjuryHc     <-ch$InjuryH     -mean(ch$InjuryH     ,na.rm=T)
ch$InjuryWc     <-ch$InjuryW     -mean(ch$InjuryW     ,na.rm=T)
ch$GunDeathc    <-ch$GunDeath    -mean(ch$GunDeath    ,na.rm=T)
ch$GunDeathBc   <-ch$GunDeathB   -mean(ch$GunDeathB   ,na.rm=T)
ch$GunDeathWc   <-ch$GunDeathW   -mean(ch$GunDeathW   ,na.rm=T)
ch$PrmDeath_c   <-ch$PrmDeath    -mean(ch$PrmDeath    ,na.rm=T)
ch$PrmDeathcc   <-ch$PrmDeathc   -mean(ch$PrmDeathc   ,na.rm=T)
ch$PrmDeathBc   <-ch$PrmDeathB   -mean(ch$PrmDeathB   ,na.rm=T)
ch$PrmDeathHc   <-ch$PrmDeathH   -mean(ch$PrmDeathH   ,na.rm=T)
ch$PrmDeathWc   <-ch$PrmDeathW   -mean(ch$PrmDeathW   ,na.rm=T)
ch$PrmDeath2_c  <-ch$PrmDeath2   -mean(ch$PrmDeath2   ,na.rm=T)
ch$PrmDeath2cc  <-ch$PrmDeath2c  -mean(ch$PrmDeath2c  ,na.rm=T)
ch$PrmDeath2Bc  <-ch$PrmDeath2B  -mean(ch$PrmDeath2B  ,na.rm=T)
ch$PrmDeath2Hc  <-ch$PrmDeath2H  -mean(ch$PrmDeath2H  ,na.rm=T)
ch$PrmDeath2Wc  <-ch$PrmDeath2W  -mean(ch$PrmDeath2W  ,na.rm=T)
ch$Suicidec     <-ch$Suicide     -mean(ch$Suicide     ,na.rm=T)
ch$Diabetc      <-ch$Diabet      -mean(ch$Diabet      ,na.rm=T)
ch$Obesityc     <-ch$Obesity     -mean(ch$Obesity     ,na.rm=T)
ch$Physicalc    <-ch$Physical    -mean(ch$Physical    ,na.rm=T)
ch$PoorHlthc    <-ch$PoorHlth    -mean(ch$PoorHlth    ,na.rm=T)
ch$PoorMHc      <-ch$PoorMH      -mean(ch$PoorMH      ,na.rm=T)
ch$PoorPhyc     <-ch$PoorPhy     -mean(ch$PoorPhy     ,na.rm=T)
ch$Sleepc       <-ch$Sleep       -mean(ch$Sleep       ,na.rm=T)
ch$DrugOdc      <-ch$DrugOd      -mean(ch$DrugOd      ,na.rm=T)
ch$DrugOdBc     <-ch$DrugOdB     -mean(ch$DrugOdB     ,na.rm=T)
ch$DrugOdHc     <-ch$DrugOdH     -mean(ch$DrugOdH     ,na.rm=T)
ch$DrugOdWc     <-ch$DrugOdW     -mean(ch$DrugOdW     ,na.rm=T)
ch$DWIDeathc    <-ch$DWIDeath    -mean(ch$DWIDeath    ,na.rm=T)
ch$EDrinkc      <-ch$EDrink      -mean(ch$EDrink      ,na.rm=T)
ch$Smokec       <-ch$Smoke       -mean(ch$Smoke       ,na.rm=T)
ch$FastFoodc    <-ch$FastFood    -mean(ch$FastFood    ,na.rm=T)
ch$FoodEnvc     <-ch$FoodEnv     -mean(ch$FoodEnv     ,na.rm=T)
ch$FoodInsc     <-ch$FoodIns     -mean(ch$FoodIns     ,na.rm=T)
ch$FrLunchc     <-ch$FrLunch     -mean(ch$FrLunch     ,na.rm=T)
ch$LAccFoodc    <-ch$LAccFood    -mean(ch$LAccFood    ,na.rm=T)
ch$Gymc         <-ch$Gym         -mean(ch$Gym         ,na.rm=T)
ch$Gym2c        <-ch$Gym2        -mean(ch$Gym2        ,na.rm=T)
ch$Inactivec    <-ch$Inactive    -mean(ch$Inactive    ,na.rm=T)
ch$HousCostc    <-ch$HousCost    -mean(ch$HousCost    ,na.rm=T)
ch$HousCostsc   <-ch$HousCosts   -mean(ch$HousCosts   ,na.rm=T)
ch$HousCrowdc   <-ch$HousCrowd   -mean(ch$HousCrowd   ,na.rm=T)
ch$Housingc     <-ch$Housing     -mean(ch$Housing     ,na.rm=T)
ch$HousPlumbc   <-ch$HousPlumb   -mean(ch$HousPlumb   ,na.rm=T)
ch$Insuredc     <-ch$Insured     -mean(ch$Insured     ,na.rm=T)
ch$InsuredAc    <-ch$InsuredA    -mean(ch$InsuredA    ,na.rm=T)
ch$InsuredCc    <-ch$InsuredC    -mean(ch$InsuredC    ,na.rm=T)
ch$JuvArrc      <-ch$JuvArr      -mean(ch$JuvArr      ,na.rm=T)
ch$Murderc      <-ch$Murder      -mean(ch$Murder      ,na.rm=T)
ch$Violentc     <-ch$Violent     -mean(ch$Violent     ,na.rm=T)
ch$LongCommc    <-ch$LongComm    -mean(ch$LongComm    ,na.rm=T)
ch$LowBWc       <-ch$LowBW       -mean(ch$LowBW       ,na.rm=T)
ch$LowBWBc      <-ch$LowBWB      -mean(ch$LowBWB      ,na.rm=T)
ch$LowBWHc      <-ch$LowBWH      -mean(ch$LowBWH      ,na.rm=T)
ch$LowBWWc      <-ch$LowBWW      -mean(ch$LowBWW      ,na.rm=T)
ch$TeenBthc     <-ch$TeenBth     -mean(ch$TeenBth     ,na.rm=T)
ch$TeenBthBc    <-ch$TeenBthB    -mean(ch$TeenBthB    ,na.rm=T)
ch$TeenBthHc    <-ch$TeenBthH    -mean(ch$TeenBthH    ,na.rm=T)
ch$TeenBthWc    <-ch$TeenBthW    -mean(ch$TeenBthW    ,na.rm=T)
ch$Mentalc      <-ch$Mental      -mean(ch$Mental      ,na.rm=T)
ch$MHPrvdc      <-ch$MHPrvd      -mean(ch$MHPrvd      ,na.rm=T)
ch$PCPc         <-ch$PCP         -mean(ch$PCP         ,na.rm=T)
ch$PCP2c        <-ch$PCP2        -mean(ch$PCP2        ,na.rm=T)
ch$Dentistc     <-ch$Dentist     -mean(ch$Dentist     ,na.rm=T)
ch$PrvtHospc    <-ch$PrvtHosp    -mean(ch$PrvtHosp    ,na.rm=T)
ch$PrvtHospBc   <-ch$PrvtHospB   -mean(ch$PrvtHospB   ,na.rm=T)
ch$PrvtHospHc   <-ch$PrvtHospH   -mean(ch$PrvtHospH   ,na.rm=T)
ch$PrvtHospWc   <-ch$PrvtHospW   -mean(ch$PrvtHospW   ,na.rm=T)
ch$SegBWc       <-ch$SegBW       -mean(ch$SegBW       ,na.rm=T)
ch$SegNWc       <-ch$SegNW       -mean(ch$SegNW       ,na.rm=T)
ch$SocAssoc     <-ch$SocAsso     -mean(ch$SocAsso     ,na.rm=T)
ch$SocSuppc     <-ch$SocSupp     -mean(ch$SocSupp     ,na.rm=T)
ch$MIECHVc      <-ch$MIECHV      -mean(ch$MIECHV      ,na.rm=T)
ch$NHVRCc       <-ch$NHVRC       -mean(ch$NHVRC       ,na.rm=T)
ch$FoodInsecurec<-ch$FoodInsecure-mean(ch$FoodInsecure,na.rm=T)
ch$PCPAllc      <-ch$PCPAll      -mean(ch$PCPAll      ,na.rm=T)
ch$MH_PCPc      <-ch$MH_PCP      -mean(ch$MH_PCP      ,na.rm=T)

ch<-cbind(ch,demean(ch,select=c(
  "CPopBP","CPopHP","CPopBPc","CPopHPc",
  "ChildPT","ChildPW","ChildPB","ChildPH","ChildPTc","ChildPWc","ChildPBc","ChildPHc",
  "CARatioT100","CARatioW100","CARatioB100","CARatioH100","CARatioT100c","CARatioW100c","CARatioB100c","CARatioH100c",
  "MalePT","MalePW","MalePB","MalePH","MalePTc","MalePWc","MalePBc","MalePHc",
  "MFRatioT100","MFRatioW100","MFRatioB100","MFRatioH100","MFRatioT100c","MFRatioW100c","MFRatioB100c","MFRatioH100c",
  "ElderT","ElderW","ElderB","ElderH","ElderTc","ElderWc","ElderBc","ElderHc",
  "SingleT","SingleW","SingleB","SingleH","SingleTc","SingleWc","SingleBc","SingleHc",
  "FHeadT","FHeadW","FHeadB","FHeadH","FHeadTc","FHeadWc","FHeadBc","FHeadHc",
  "NoHighT","NoHighW","NoHighB","NoHighH","NoHighTc","NoHighWc","NoHighBc","NoHighHc",
  "UnempT","UnempW","UnempB","UnempH","UnempTc","UnempWc","UnempBc","UnempHc",
  "CPovT","CPovW","CPovB","CPovH","CPov1","CPov2","CPov3","CPovTc","CPovWc","CPovBc","CPovHc","CPov1c","CPov2c","CPov3c",
  "PubAsT","WelfarT","SnapT","SnapW","SnapB","SnapH","PubAsTc","WelfarTc","SnapTc","SnapWc","SnapBc","SnapHc",
  "IncomeT1k","IncomeW1k","IncomeB1k","IncomeH1k","IncomeT1kc","IncomeW1kc","IncomeB1kc","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","OCostDT100","MRentDT100","MCostT100c","OCostDT100c","MRentDT100c",
  "OCostPT","MRentPT","MortgT","OCostPTc","MRentPTc","MortgTc",
  "LangAPT","LangAPW","LangAPB","LangAPH","LangBPT","LangBPW","LangBPB","LangBPH","LangCPT",
  "LangAPTc","LangAPWc","LangAPBc","LangAPHc","LangBPTc","LangBPWc","LangBPBc","LangBPHc","LangCPTc",
  "OutUsT","OutUsW","OutUsB","OutUsH","OutUsTc","OutUsWc","OutUsBc","OutUsHc",
  "FBornT","FBornW","FBornB","FBornH","FBornTc","FBornWc","FBornBc","FBornHc",
  "NotCtzT","NotCtzW","NotCtzB","NotCtzH","NotCtzTc","NotCtzWc","NotCtzBc","NotCtzHc",
  "MoveT","MoveW","MoveB","MoveH","MoveTc","MoveWc","MoveBc","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerW","OwnerB","OwnerH","OwnerTc","OwnerWc","OwnerBc","OwnerHc",
  "CrowdT","CrowdW","CrowdB","CrowdH","CrowdTc","CrowdWc","CrowdBc","CrowdHc",
  "MobileT","MobileW","MobileB","MobileH","MobileTc","MobileWc","MobileBc","MobileHc",
  "DisablT","DisablW","DisablB","DisablH","DisablTc","DisablWc","DisablBc","DisablHc",
  "DisablTC","DisablWC","DisablBC","DisablHC","DisablTM","DisablTF","DisablTCc","DisablWCc","DisablBCc","DisablHCc","DisablTMc","DisablTFc",
  "Urban1","Urban2","Urban1c","Urban2c",
  "LBWT1r","LBWM1r","LBWF1r","LBWW1r","LBWB1r","LBWH1r","LBWT1rc","LBWM1rc","LBWF1rc","LBWW1rc","LBWB1rc","LBWH1rc",
  "PTBT1r","PTBM1r","PTBF1r","PTBW1r","PTBB1r","PTBH1r","PTBT1rc","PTBM1rc","PTBF1rc","PTBW1rc","PTBB1rc","PTBH1rc",
  "PNCT1r","PNCM1r","PNCF1r","PNCW1r","PNCB1r","PNCH1r","PNCT1rc","PNCM1rc","PNCF1rc","PNCW1rc","PNCB1rc","PNCH1rc",
  "TBBT1r","TBBM1r","TBBF1r","TBBW1r","TBBB1r","TBBH1r","TBBT1rc","TBBM1rc","TBBF1rc","TBBW1rc","TBBB1rc","TBBH1rc",
  "TBTT1r","TBTM1r","TBTF1r","TBTW1r","TBTB1r","TBTH1r","TBTT1rc","TBTM1rc","TBTF1rc","TBTW1rc","TBTB1rc","TBTH1rc",
  "LBWT5r","LBWM5r","LBWF5r","LBWW5r","LBWB5r","LBWH5r","LBWT5rc","LBWM5rc","LBWF5rc","LBWW5rc","LBWB5rc","LBWH5rc",
  "PTBT5r","PTBM5r","PTBF5r","PTBW5r","PTBB5r","PTBH5r","PTBT5rc","PTBM5rc","PTBF5rc","PTBW5rc","PTBB5rc","PTBH5rc",
  "PNCT5r","PNCM5r","PNCF5r","PNCW5r","PNCB5r","PNCH5r","PNCT5rc","PNCM5rc","PNCF5rc","PNCW5rc","PNCB5rc","PNCH5rc",
  "TBBT5r","TBBM5r","TBBF5r","TBBW5r","TBBB5r","TBBH5r","TBBT5rc","TBBM5rc","TBBF5rc","TBBW5rc","TBBB5rc","TBBH5rc",
  "TBTT5r","TBTM5r","TBTF5r","TBTW5r","TBTB5r","TBTH5r","TBTT5rc","TBTM5rc","TBTF5rc","TBTW5rc","TBTB5rc","TBTH5rc",
  "Opioid","Opioidc",
  "LifeExp","LifeExpB","LifeExpH","LifeExpW","LifeExpc","LifeExpBc","LifeExpHc","LifeExpWc",
  "ChdDeath","ChdDeathB","ChdDeathH","ChdDeathW","ChdDeathc","ChdDeathBc","ChdDeathHc","ChdDeathWc",
  "InfDeath","InfDeathB","InfDeathH","InfDeathW","InfDeathc","InfDeathBc","InfDeathHc","InfDeathWc",
  "Injury","InjuryB","InjuryH","InjuryW","Injuryc","InjuryBc","InjuryHc","InjuryWc",
  "GunDeath","GunDeathB","GunDeathW","GunDeathc","GunDeathBc","GunDeathWc",
  "PrmDeath","PrmDeathc","PrmDeathB","PrmDeathH","PrmDeathW","PrmDeath_c","PrmDeathcc","PrmDeathBc","PrmDeathHc","PrmDeathWc",
  "PrmDeath2","PrmDeath2c","PrmDeath2B","PrmDeath2H","PrmDeath2W","PrmDeath2_c","PrmDeath2cc","PrmDeath2Bc","PrmDeath2Hc","PrmDeath2Wc",
  "Suicide","Suicidec",
  "Diabet","Obesity","Diabetc","Obesityc",
  "Mental","Physical","PoorHlth","PoorMH","PoorPhy","Mentalc","Physicalc","PoorHlthc","PoorMHc","PoorPhyc",
  "Sleep","Sleepc",
  "DrugOd","DrugOdB","DrugOdH","DrugOdW","DrugOdc","DrugOdBc","DrugOdHc","DrugOdWc",
  "DWIDeath","EDrink","DWIDeathc","EDrinkc",
  "Smoke","Smokec",
  "FastFood","FoodEnv","FoodIns","FrLunch","LAccFood","FastFoodc","FoodEnvc","FoodInsc","FrLunchc","LAccFoodc",
  "Gym","Gym2","Inactive","Gymc","Gym2c","Inactivec",
  "HousCost","HousCosts","HousCrowd","Housing","HousPlumb","HousCostc","HousCostsc","HousCrowdc","Housingc","HousPlumbc",
  "Insured","InsuredA","InsuredC","Insuredc","InsuredAc","InsuredCc",
  "JuvArr","Murder","Violent","JuvArrc","Murderc","Violentc",
  "LongComm","LongCommc",
  "LowBW","LowBWB","LowBWH","LowBWW","LowBWc","LowBWBc","LowBWHc","LowBWWc",
  "TeenBth","TeenBthB","TeenBthH","TeenBthW","TeenBthc","TeenBthBc","TeenBthHc","TeenBthWc",
  "MHPrvd","PCP","PCP2","Dentist","PCPAll","MH_PCP","MHPrvdc","PCPc","PCP2c","Dentistc","PCPAllc","MH_PCPc",
  "PrvtHosp","PrvtHospB","PrvtHospH","PrvtHospW","PrvtHospc","PrvtHospBc","PrvtHospHc","PrvtHospWc",
  "SegBW","SegNW","SegBWc","SegNWc",
  "SocAsso","SocSupp","SocAssoc","SocSuppc",
  "MIECHV","NHVRC","MIECHVc","NHVRCc",
  "FoodInsecure","FoodInsecurec"
),group="CountyFIPS"))





# Modeling Building
chm01<-lmer(RptHr~Yearf+USDA_RUC+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
# Mental Health
chm02<-lmer(RptHr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm03<-lmer(RptHr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm04<-lmer(RptHr~Yearf+USDA_RUC+Mentalc_within+Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
# Mental Health Interaction
chm05<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm06<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+USDA_RUC*MHPrvdc_within+USDA_RUC*MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
# Mental Health Random Slope
chm07<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (Mentalc_within|CountyFIPS)+(1|StateFIPS),data=ch)
chm08<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Mentalc_within+USDA_RUC*Mentalc_between+MHPrvdc_within+MHPrvdc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (Mentalc_within|CountyFIPS)+(Mentalc_within|StateFIPS),data=ch)
# Physical Health
chm12<-lmer(RptHr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm13<-lmer(RptHr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm14<-lmer(RptHr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
# Physical Health Interaction
chm15<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+PCPc_within+PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
chm16<-lmer(RptHr~Yearf+USDA_RUC+USDA_RUC*Physicalc_within+USDA_RUC*Physicalc_between+USDA_RUC*PCPc_within+USDA_RUC*PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (1|CountyFIPS)+(1|StateFIPS),data=ch)
# Physical Health Random Slope
chm17<-lmer(RptHr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (Physicalc_within|CountyFIPS)+(1|StateFIPS),data=ch)
chm18<-lmer(RptHr~Yearf+USDA_RUC+Physicalc_within+Physicalc_between+PCPc_within+PCPc_between+
              IncomeH1kc_within+IncomeH1kc_between+SingleHc_within+SingleHc_between+
              CPopBPc+CPopHPc+FBornHc_within+FBornHc_between+
              ChildPHc_within+ChildPHc_between+DisablHc_within+DisablHc_between+MoveHc_within+MoveHc_between+
              (Physicalc_within|CountyFIPS)+(Physicalc_within|StateFIPS),data=ch)

# bootstrap confidence interval
chm01CI<-confint(chm01,method='boot',nsim=500,boot.type='perc')
chm02CI<-confint(chm02,method='boot',nsim=500,boot.type='perc')
chm03CI<-confint(chm03,method='boot',nsim=500,boot.type='perc')
chm04CI<-confint(chm04,method='boot',nsim=500,boot.type='perc')
chm05CI<-confint(chm05,method='boot',nsim=500,boot.type='perc')
chm06CI<-confint(chm06,method='boot',nsim=500,boot.type='perc')
chm07CI<-confint(chm07,method='boot',nsim=500,boot.type='perc')
chm08CI<-confint(chm08,method='boot',nsim=500,boot.type='perc')
chm12CI<-confint(chm12,method='boot',nsim=500,boot.type='perc')
chm13CI<-confint(chm13,method='boot',nsim=500,boot.type='perc')
chm14CI<-confint(chm14,method='boot',nsim=500,boot.type='perc')
chm15CI<-confint(chm15,method='boot',nsim=500,boot.type='perc')
chm16CI<-confint(chm16,method='boot',nsim=500,boot.type='perc')
chm17CI<-confint(chm17,method='boot',nsim=500,boot.type='perc')
chm18CI<-confint(chm18,method='boot',nsim=500,boot.type='perc')

AIC(chm01,chm02,chm03,chm04,chm05,chm06,chm07,chm08)
anova(chm04,chm05,chm06)
anova(chm04,chm05,chm07,chm08)
AIC(chm01,chm12,chm13,chm14,chm15,chm16,chm17,chm18)
anova(chm14,chm15,chm16)
anova(chm14,chm17,chm18)

tab_model(chm01,chm02,chm03,chm04,chm05,chm06,chm07,chm08,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
tab_model(chm01,chm12,chm13,chm14,chm15,chm16,chm17,chm18,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)

# Model Check
check_collinearity(chm01)
check_collinearity(chm02)
check_collinearity(chm03)
check_collinearity(chm04)
check_collinearity(chm05)
check_collinearity(chm06)
check_collinearity(chm07)
check_collinearity(chm14)
isSingular(chm01)
isSingular(chm02)
isSingular(chm03)
isSingular(chm04)
isSingular(chm05)
isSingular(chm06)
isSingular(chm07)
isSingular(chm08)
isSingular(chm14)
isSingular(chm15)
isSingular(chm16)
isSingular(chm17)
isSingular(chm18)




###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
# Results - Tables
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

MTotal1<-data.table(Name=c(names(fixef(ctm01)),as.data.table(VarCorr(ctm01))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm01),as.data.table(VarCorr(ctm01))$vcov,AIC(ctm01),r2(ctm01)[[2]],r2(ctm01)[[1]],nobs(ctm01),ngrps(ctm01)),4),LL=round(c(ctm01CI[-(1:3),1],ctm01CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm01CI[-(1:3),2],ctm01CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal2<-data.table(Name=c(names(fixef(ctm02)),as.data.table(VarCorr(ctm02))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm02),as.data.table(VarCorr(ctm02))$vcov,AIC(ctm02),r2(ctm02)[[2]],r2(ctm02)[[1]],nobs(ctm02),ngrps(ctm02)),4),LL=round(c(ctm02CI[-(1:3),1],ctm02CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm02CI[-(1:3),2],ctm02CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal3<-data.table(Name=c(names(fixef(ctm03)),as.data.table(VarCorr(ctm03))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm03),as.data.table(VarCorr(ctm03))$vcov,AIC(ctm03),r2(ctm03)[[2]],r2(ctm03)[[1]],nobs(ctm03),ngrps(ctm03)),4),LL=round(c(ctm03CI[-(1:3),1],ctm03CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm03CI[-(1:3),2],ctm03CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal4<-data.table(Name=c(names(fixef(ctm04)),as.data.table(VarCorr(ctm04))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm04),as.data.table(VarCorr(ctm04))$vcov,AIC(ctm04),r2(ctm04)[[2]],r2(ctm04)[[1]],nobs(ctm04),ngrps(ctm04)),4),LL=round(c(ctm04CI[-(1:3),1],ctm04CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm04CI[-(1:3),2],ctm04CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal5<-data.table(Name=c(names(fixef(ctm05)),as.data.table(VarCorr(ctm05))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm05),as.data.table(VarCorr(ctm05))$vcov,AIC(ctm05),r2(ctm05)[[2]],r2(ctm05)[[1]],nobs(ctm05),ngrps(ctm05)),4),LL=round(c(ctm05CI[-(1:3),1],ctm05CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm05CI[-(1:3),2],ctm05CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal6<-data.table(Name=c(names(fixef(ctm06)),as.data.table(VarCorr(ctm06))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm06),as.data.table(VarCorr(ctm06))$vcov,AIC(ctm06),r2(ctm06)[[2]],r2(ctm06)[[1]],nobs(ctm06),ngrps(ctm06)),4),LL=round(c(ctm06CI[-(1:3),1],ctm06CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm06CI[-(1:3),2],ctm06CI[1:3,2]^2,0,0,0,0,0,0),4))
MTotal7<-data.table(Name=c(names(fixef(ctm07)),as.data.table(VarCorr(ctm07))$grp,"AIC","R2M","R2C","N1","N2","N3"),Estimate=round(c(fixef(ctm07),as.data.table(VarCorr(ctm07))$vcov,AIC(ctm07),r2(ctm07)[[2]],r2(ctm07)[[1]],nobs(ctm07),ngrps(ctm07)),4),LL=round(c(ctm07CI[-(1:3),1],ctm07CI[1:3,1]^2,0,0,0,0,0,0),4),UL=round(c(ctm07CI[-(1:3),2],ctm07CI[1:3,2]^2,0,0,0,0,0,0),4))

MUrban1<-data.table(Name=c(names(fixef(ctm04)[7:10]),names(fixef(ctm042)[27:34]),"AIC","R2M","R2C","N1","N2","N3"),
                    M1Est=round(c(fixef(ctm04 )[7:10],0,0,0,0,0,0,0,0,AIC(ctm04),r2(ctm04)[[2]],r2(ctm04)[[1]],nobs(ctm04),ngrps(ctm04)),4),M1LL=round(c(ctm04CI[10:13,1],0,0,0,0,0,0,0,0,0,0,0,0,0,0),4),M1UL=round(c(ctm04CI[10:13,2],0,0,0,0,0,0,0,0,0,0,0,0,0,0),4),
                    M2Est=round(c(fixef(ctm041)[7:10],fixef(ctm041)[27:30],0,0,0,0,AIC(ctm041),r2(ctm041)[[2]],r2(ctm041)[[1]],nobs(ctm041),ngrps(ctm041)),4),M2LL=round(c(ctm041CI[10:13,1],ctm041CI[30:33,1],0,0,0,0,0,0,0,0,0,0),4),M2UL=round(c(ctm041CI[10:13,2],ctm041CI[30:33,2],0,0,0,0,0,0,0,0,0,0),4),
                    M3Est=round(c(fixef(ctm042)[7:10],fixef(ctm042)[27:34],AIC(ctm042),r2(ctm042)[[2]],r2(ctm042)[[1]],nobs(ctm042),ngrps(ctm042)),4),M3LL=round(c(ctm042CI[10:13,1],ctm042CI[30:37,1],0,0,0,0,0,0),4),M3UL=round(c(ctm042CI[10:13,2],ctm042CI[30:37,2],0,0,0,0,0,0),4))

MUrban2<-data.table(Name=c(names(fixef(ctm07)[7:10]),names(fixef(ctm072)[27:34]),"AIC","R2M","R2C","N1","N2","N3"),
                    M1Est=round(c(fixef(ctm07 )[7:10],0,0,0,0,0,0,0,0,AIC(ctm07),r2(ctm07)[[2]],r2(ctm07)[[1]],nobs(ctm07),ngrps(ctm07)),4),M1LL=round(c(ctm07CI[10:13,1],0,0,0,0,0,0,0,0,0,0,0,0,0,0),4),M1UL=round(c(ctm07CI[10:13,2],0,0,0,0,0,0,0,0,0,0,0,0,0,0),4),
                    M2Est=round(c(fixef(ctm071)[7:10],fixef(ctm071)[27:30],0,0,0,0,AIC(ctm071),r2(ctm071)[[2]],r2(ctm071)[[1]],nobs(ctm071),ngrps(ctm071)),4),M2LL=round(c(ctm071CI[10:13,1],ctm071CI[30:33,1],0,0,0,0,0,0,0,0,0,0),4),M2UL=round(c(ctm071CI[10:13,2],ctm071CI[30:33,2],0,0,0,0,0,0,0,0,0,0),4),
                    M3Est=round(c(fixef(ctm072)[7:10],fixef(ctm072)[27:34],AIC(ctm072),r2(ctm072)[[2]],r2(ctm072)[[1]],nobs(ctm072),ngrps(ctm072)),4),M3LL=round(c(ctm072CI[10:13,1],ctm072CI[30:37,1],0,0,0,0,0,0),4),M3UL=round(c(ctm072CI[10:13,2],ctm072CI[30:37,2],0,0,0,0,0,0),4))

MAge1<-data.table(Name=c(names(fixef(c1m04)[7:10]),"MeanY",names(fixef(c1m04)[7:10]),"R2M","R2C","N1","N2","N3"),
                  C1Est=round(c(fixef(c1m04)[7:10],mean(c1$Rpt1r),fixef(c1m04)[7:10]/mean(c1$Rpt1r)*100,r2(c1m04)[[2]],r2(c1m04)[[1]],nobs(c1m04),ngrps(c1m04)),4),C1LL=round(c(c1m04CI[10:13,1],mean(c1$Rpt1r),c1m04CI[10:13,1]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),C1UL=round(c(c1m04CI[10:13,2],mean(c1$Rpt1r),c1m04CI[10:13,2]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),
                  C2Est=round(c(fixef(c2m04)[7:10],mean(c2$Rpt2r),fixef(c2m04)[7:10]/mean(c2$Rpt2r)*100,r2(c2m04)[[2]],r2(c2m04)[[1]],nobs(c2m04),ngrps(c2m04)),4),C2LL=round(c(c2m04CI[10:13,1],mean(c2$Rpt2r),c2m04CI[10:13,1]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),C2UL=round(c(c2m04CI[10:13,2],mean(c2$Rpt2r),c2m04CI[10:13,2]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),
                  C3Est=round(c(fixef(c3m04)[7:10],mean(c3$Rpt3r),fixef(c3m04)[7:10]/mean(c3$Rpt3r)*100,r2(c3m04)[[2]],r2(c3m04)[[1]],nobs(c3m04),ngrps(c3m04)),4),C3LL=round(c(c3m04CI[10:13,1],mean(c3$Rpt3r),c3m04CI[10:13,1]/mean(c3$Rpt3r)*100,0,0,0,0,0),4),C3UL=round(c(c3m04CI[10:13,2],mean(c3$Rpt3r),c3m04CI[10:13,2]/mean(c3$Rpt3r)*100,0,0,0,0,0),4))

MAge2<-data.table(Name=c(names(fixef(c1m07)[7:10]),"MeanY",names(fixef(c1m07)[7:10]),"R2M","R2C","N1","N2","N3"),
                  C1Est=round(c(fixef(c1m07)[7:10],mean(c1$Rpt1r),fixef(c1m07)[7:10]/mean(c1$Rpt1r)*100,r2(c1m07)[[2]],r2(c1m07)[[1]],nobs(c1m07),ngrps(c1m07)),4),C1LL=round(c(c1m07CI[10:13,1],mean(c1$Rpt1r),c1m07CI[10:13,1]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),C1UL=round(c(c1m07CI[10:13,2],mean(c1$Rpt1r),c1m07CI[10:13,2]/mean(c1$Rpt1r)*100,0,0,0,0,0),4),
                  C2Est=round(c(fixef(c2m07)[7:10],mean(c2$Rpt2r),fixef(c2m07)[7:10]/mean(c2$Rpt2r)*100,r2(c2m07)[[2]],r2(c2m07)[[1]],nobs(c2m07),ngrps(c2m07)),4),C2LL=round(c(c2m07CI[10:13,1],mean(c2$Rpt2r),c2m07CI[10:13,1]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),C2UL=round(c(c2m07CI[10:13,2],mean(c2$Rpt2r),c2m07CI[10:13,2]/mean(c2$Rpt2r)*100,0,0,0,0,0),4),
                  C3Est=round(c(fixef(c3m07)[7:10],mean(c3$Rpt3r),fixef(c3m07)[7:10]/mean(c3$Rpt3r)*100,r2(c3m07)[[2]],r2(c3m07)[[1]],nobs(c3m07),ngrps(c3m07)),4),C3LL=round(c(c3m07CI[10:13,1],mean(c3$Rpt3r),c3m07CI[10:13,1]/mean(c3$Rpt3r)*100,0,0,0,0,0),4),C3UL=round(c(c3m07CI[10:13,2],mean(c3$Rpt3r),c3m07CI[10:13,2]/mean(c3$Rpt3r)*100,0,0,0,0,0),4))

MSex1<-data.table(Name=c(names(fixef(cmm04)[7:10]),"MeanY",names(fixef(cmm04)[7:10]),"R2M","R2C","N1","N2","N3"),
                  CmEst=round(c(fixef(cmm04)[7:10],mean(cm$RptMr),fixef(cmm04)[7:10]/mean(cm$RptMr)*100,r2(cmm04)[[2]],r2(cmm04)[[1]],nobs(cmm04),ngrps(cmm04)),4),CmLL=round(c(cmm04CI[10:13,1],mean(cm$RptMr),cmm04CI[10:13,1]/mean(cm$RptMr)*100,0,0,0,0,0),4),CmUL=round(c(cmm04CI[10:13,2],mean(cm$RptMr),cmm04CI[10:13,2]/mean(cm$RptMr)*100,0,0,0,0,0),4),
                  CfEst=round(c(fixef(cfm04)[7:10],mean(cf$RptFr),fixef(cfm04)[7:10]/mean(cf$RptFr)*100,r2(cfm04)[[2]],r2(cfm04)[[1]],nobs(cfm04),ngrps(cfm04)),4),CfLL=round(c(cfm04CI[10:13,1],mean(cf$RptFr),cfm04CI[10:13,1]/mean(cf$RptFr)*100,0,0,0,0,0),4),CfUL=round(c(cfm04CI[10:13,2],mean(cf$RptFr),cfm04CI[10:13,2]/mean(cf$RptFr)*100,0,0,0,0,0),4))

MSex2<-data.table(Name=c(names(fixef(cmm07)[7:10]),"MeanY",names(fixef(cmm07)[7:10]),"R2M","R2C","N1","N2","N3"),
                  CmEst=round(c(fixef(cmm07)[7:10],mean(cm$RptMr),fixef(cmm07)[7:10]/mean(cm$RptMr)*100,r2(cmm07)[[2]],r2(cmm07)[[1]],nobs(cmm07),ngrps(cmm07)),4),CmLL=round(c(cmm07CI[10:13,1],mean(cm$RptMr),cmm07CI[10:13,1]/mean(cm$RptMr)*100,0,0,0,0,0),4),CmUL=round(c(cmm07CI[10:13,2],mean(cm$RptMr),cmm07CI[10:13,2]/mean(cm$RptMr)*100,0,0,0,0,0),4),
                  CfEst=round(c(fixef(cfm07)[7:10],mean(cf$RptFr),fixef(cfm07)[7:10]/mean(cf$RptFr)*100,r2(cfm07)[[2]],r2(cfm07)[[1]],nobs(cfm07),ngrps(cfm07)),4),CfLL=round(c(cfm07CI[10:13,1],mean(cf$RptFr),cfm07CI[10:13,1]/mean(cf$RptFr)*100,0,0,0,0,0),4),CfUL=round(c(cfm07CI[10:13,2],mean(cf$RptFr),cfm07CI[10:13,2]/mean(cf$RptFr)*100,0,0,0,0,0),4))

MType1<-data.table(Name=c(names(fixef(cnm04)[7:10]),"MeanY",names(fixef(cnm04)[7:10]),"R2M","R2C","N1","N2","N3"),
                   CnEst=round(c(fixef(cnm04)[7:10],mean(cn$NegTr),fixef(cnm04)[7:10]/mean(cn$NegTr)*100,r2(cnm04)[[2]],r2(cnm04)[[1]],nobs(cnm04),ngrps(cnm04)),4),CnLL=round(c(cnm04CI[10:13,1],mean(cn$NegTr),cnm04CI[10:13,1]/mean(cn$NegTr)*100,0,0,0,0,0),4),CnUL=round(c(cnm04CI[10:13,2],mean(cn$NegTr),cnm04CI[10:13,2]/mean(cn$NegTr)*100,0,0,0,0,0),4),
                   CpEst=round(c(fixef(cpm04)[7:10],mean(cp$PhyTr),fixef(cpm04)[7:10]/mean(cp$PhyTr)*100,r2(cpm04)[[2]],r2(cpm04)[[1]],nobs(cpm04),ngrps(cpm04)),4),CpLL=round(c(cpm04CI[10:13,1],mean(cp$PhyTr),cpm04CI[10:13,1]/mean(cp$PhyTr)*100,0,0,0,0,0),4),CpUL=round(c(cpm04CI[10:13,2],mean(cp$PhyTr),cpm04CI[10:13,2]/mean(cp$PhyTr)*100,0,0,0,0,0),4),
                   CsEst=round(c(fixef(csm04)[7:10],mean(cs$SexTr),fixef(csm04)[7:10]/mean(cs$SexTr)*100,r2(csm04)[[2]],r2(csm04)[[1]],nobs(csm04),ngrps(csm04)),4),CsLL=round(c(csm04CI[10:13,1],mean(cs$SexTr),csm04CI[10:13,1]/mean(cs$SexTr)*100,0,0,0,0,0),4),CsUL=round(c(csm04CI[10:13,2],mean(cs$SexTr),csm04CI[10:13,2]/mean(cs$SexTr)*100,0,0,0,0,0),4))

MType2<-data.table(Name=c(names(fixef(cnm07)[7:10]),"MeanY",names(fixef(cnm07)[7:10]),"R2M","R2C","N1","N2","N3"),
                   CnEst=round(c(fixef(cnm07)[7:10],mean(cn$NegTr),fixef(cnm07)[7:10]/mean(cn$NegTr)*100,r2(cnm07)[[2]],r2(cnm07)[[1]],nobs(cnm07),ngrps(cnm07)),4),CnLL=round(c(cnm07CI[10:13,1],mean(cn$NegTr),cnm07CI[10:13,1]/mean(cn$NegTr)*100,0,0,0,0,0),4),CnUL=round(c(cnm07CI[10:13,2],mean(cn$NegTr),cnm07CI[10:13,2]/mean(cn$NegTr)*100,0,0,0,0,0),4),
                   CpEst=round(c(fixef(cpm07)[7:10],mean(cp$PhyTr),fixef(cpm07)[7:10]/mean(cp$PhyTr)*100,r2(cpm07)[[2]],r2(cpm07)[[1]],nobs(cpm07),ngrps(cpm07)),4),CpLL=round(c(cpm07CI[10:13,1],mean(cp$PhyTr),cpm07CI[10:13,1]/mean(cp$PhyTr)*100,0,0,0,0,0),4),CpUL=round(c(cpm07CI[10:13,2],mean(cp$PhyTr),cpm07CI[10:13,2]/mean(cp$PhyTr)*100,0,0,0,0,0),4),
                   CsEst=round(c(fixef(csm07)[7:10],mean(cs$SexTr),fixef(csm07)[7:10]/mean(cs$SexTr)*100,r2(csm07)[[2]],r2(csm07)[[1]],nobs(csm07),ngrps(csm07)),4),CsLL=round(c(csm07CI[10:13,1],mean(cs$SexTr),csm07CI[10:13,1]/mean(cs$SexTr)*100,0,0,0,0,0),4),CsUL=round(c(csm07CI[10:13,2],mean(cs$SexTr),csm07CI[10:13,2]/mean(cs$SexTr)*100,0,0,0,0,0),4))

MRace1<-data.table(Name=c(names(fixef(cwm04)[7:10]),"MeanY",names(fixef(cwm04)[7:10]),"R2M","R2C","N1","N2","N3"),
                   CwEst=round(c(fixef(cwm04)[7:10],mean(cw$RptWr),fixef(cwm04)[7:10]/mean(cw$RptWr)*100,r2(cwm04)[[2]],r2(cwm04)[[1]],nobs(cwm04),ngrps(cwm04)),4),CwLL=round(c(cwm04CI[10:13,1],mean(cw$RptWr),cwm04CI[10:13,1]/mean(cw$RptWr)*100,0,0,0,0,0),4),CwUL=round(c(cwm04CI[10:13,2],mean(cw$RptWr),cwm04CI[10:13,2]/mean(cw$RptWr)*100,0,0,0,0,0),4),
                   CbEst=round(c(fixef(cbm04)[7:10],mean(cb$RptBr),fixef(cbm04)[7:10]/mean(cb$RptBr)*100,r2(cbm04)[[2]],r2(cbm04)[[1]],nobs(cbm04),ngrps(cbm04)),4),CbLL=round(c(cbm04CI[10:13,1],mean(cb$RptBr),cbm04CI[10:13,1]/mean(cb$RptBr)*100,0,0,0,0,0),4),CbUL=round(c(cbm04CI[10:13,2],mean(cb$RptBr),cbm04CI[10:13,2]/mean(cb$RptBr)*100,0,0,0,0,0),4),
                   ChEst=round(c(fixef(chm04)[7:10],mean(ch$RptHr),fixef(chm04)[7:10]/mean(ch$RptHr)*100,r2(chm04)[[2]],r2(chm04)[[1]],nobs(chm04),ngrps(chm04)),4),ChLL=round(c(chm04CI[10:13,1],mean(ch$RptHr),chm04CI[10:13,1]/mean(ch$RptHr)*100,0,0,0,0,0),4),ChUL=round(c(chm04CI[10:13,2],mean(ch$RptHr),chm04CI[10:13,2]/mean(ch$RptHr)*100,0,0,0,0,0),4))

MRace2<-data.table(Name=c(names(fixef(cwm07)[7:10]),"MeanY",names(fixef(cwm07)[7:10]),"R2M","R2C","N1","N2","N3"),
                   CwEst=round(c(fixef(cwm07)[7:10],mean(cw$RptWr),fixef(cwm07)[7:10]/mean(cw$RptWr)*100,r2(cwm07)[[2]],r2(cwm07)[[1]],nobs(cwm07),ngrps(cwm07)),4),CwLL=round(c(cwm07CI[10:13,1],mean(cw$RptWr),cwm07CI[10:13,1]/mean(cw$RptWr)*100,0,0,0,0,0),4),CwUL=round(c(cwm07CI[10:13,2],mean(cw$RptWr),cwm07CI[10:13,2]/mean(cw$RptWr)*100,0,0,0,0,0),4),
                   CbEst=round(c(fixef(cbm07)[7:10],mean(cb$RptBr),fixef(cbm07)[7:10]/mean(cb$RptBr)*100,r2(cbm07)[[2]],r2(cbm07)[[1]],nobs(cbm07),ngrps(cbm07)),4),CbLL=round(c(cbm07CI[10:13,1],mean(cb$RptBr),cbm07CI[10:13,1]/mean(cb$RptBr)*100,0,0,0,0,0),4),CbUL=round(c(cbm07CI[10:13,2],mean(cb$RptBr),cbm07CI[10:13,2]/mean(cb$RptBr)*100,0,0,0,0,0),4),
                   ChEst=round(c(fixef(chm07)[7:10],mean(ch$RptHr),fixef(chm07)[7:10]/mean(ch$RptHr)*100,r2(chm07)[[2]],r2(chm07)[[1]],nobs(chm07),ngrps(chm07)),4),ChLL=round(c(chm07CI[10:13,1],mean(ch$RptHr),chm07CI[10:13,1]/mean(ch$RptHr)*100,0,0,0,0,0),4),ChUL=round(c(chm07CI[10:13,2],mean(ch$RptHr),chm07CI[10:13,2]/mean(ch$RptHr)*100,0,0,0,0,0),4))

write.csv(MTotal1,"Z:/CDCK01/Analysis/Service/Mental/MTotal1.csv")
write.csv(MTotal2,"Z:/CDCK01/Analysis/Service/Mental/MTotal2.csv")
write.csv(MTotal3,"Z:/CDCK01/Analysis/Service/Mental/MTotal3.csv")
write.csv(MTotal4,"Z:/CDCK01/Analysis/Service/Mental/MTotal4.csv")
write.csv(MUrban1,"Z:/CDCK01/Analysis/Service/Mental/MUrban1.csv")
write.csv(MAge1,"Z:/CDCK01/Analysis/Service/Mental/MAge1.csv")
write.csv(MSex1,"Z:/CDCK01/Analysis/Service/Mental/MSex1.csv")
write.csv(MType1,"Z:/CDCK01/Analysis/Service/Mental/MType1.csv")
write.csv(MRace1,"Z:/CDCK01/Analysis/Service/Mental/MRace1.csv")

write.csv(MTotal1,"Z:/CDCK01/Analysis/Service/Physical/MTotal1.csv")
write.csv(MTotal5,"Z:/CDCK01/Analysis/Service/Physical/MTotal5.csv")
write.csv(MTotal6,"Z:/CDCK01/Analysis/Service/Physical/MTotal6.csv")
write.csv(MTotal7,"Z:/CDCK01/Analysis/Service/Physical/MTotal7.csv")
write.csv(MUrban2,"Z:/CDCK01/Analysis/Service/Physical/MUrban2.csv")
write.csv(MAge2,"Z:/CDCK01/Analysis/Service/Physical/MAge2.csv")
write.csv(MSex2,"Z:/CDCK01/Analysis/Service/Physical/MSex2.csv")
write.csv(MType2,"Z:/CDCK01/Analysis/Service/Physical/MType2.csv")
write.csv(MRace2,"Z:/CDCK01/Analysis/Service/Physical/MRace2.csv")

# Checking
library(kableExtra)

tab_model(ctm01,ctm02,ctm03,ctm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm01CI %>% kbl(caption="ctm01CI") %>% kable_paper("striped","hover",full_width=F)
ctm02CI %>% kbl(caption="ctm02CI") %>% kable_paper("striped","hover",full_width=F)
ctm03CI %>% kbl(caption="ctm03CI") %>% kable_paper("striped","hover",full_width=F)
ctm04CI %>% kbl(caption="ctm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(ctm04,ctm041,ctm042,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm04CI  %>% kbl(caption="ctm04CI" ) %>% kable_paper("striped","hover",full_width=F)
ctm041CI %>% kbl(caption="ctm041CI") %>% kable_paper("striped","hover",full_width=F)
ctm042CI %>% kbl(caption="ctm042CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m04,c2m04,c3m04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m04CI %>% kbl(caption="c1m04CI") %>% kable_paper("striped","hover",full_width=F)
c2m04CI %>% kbl(caption="c2m04CI") %>% kable_paper("striped","hover",full_width=F)
c3m04CI %>% kbl(caption="c3m04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm04,cfm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm04CI %>% kbl(caption="cmm04CI") %>% kable_paper("striped","hover",full_width=F)
cfm04CI %>% kbl(caption="cfm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm04,cpm04,csm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm04CI %>% kbl(caption="cnm04CI") %>% kable_paper("striped","hover",full_width=F)
cpm04CI %>% kbl(caption="cpm04CI") %>% kable_paper("striped","hover",full_width=F)
csm04CI %>% kbl(caption="csm04CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm04,cbm04,chm04,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm04CI %>% kbl(caption="cwm04CI") %>% kable_paper("striped","hover",full_width=F)
cbm04CI %>% kbl(caption="cbm04CI") %>% kable_paper("striped","hover",full_width=F)
chm04CI %>% kbl(caption="chm04CI") %>% kable_paper("striped","hover",full_width=F)

###

tab_model(ctm01,ctm05,ctm06,ctm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm01CI %>% kbl(caption="ctm01CI") %>% kable_paper("striped","hover",full_width=F)
ctm05CI %>% kbl(caption="ctm05CI") %>% kable_paper("striped","hover",full_width=F)
ctm06CI %>% kbl(caption="ctm06CI") %>% kable_paper("striped","hover",full_width=F)
ctm07CI %>% kbl(caption="ctm07CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(ctm07,ctm071,ctm072,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
ctm07CI  %>% kbl(caption="ctm07CI" ) %>% kable_paper("striped","hover",full_width=F)
ctm071CI %>% kbl(caption="ctm071CI") %>% kable_paper("striped","hover",full_width=F)
ctm072CI %>% kbl(caption="ctm072CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(c1m07,c2m07,c3m07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
c1m07CI %>% kbl(caption="c1m07CI") %>% kable_paper("striped","hover",full_width=F)
c2m07CI %>% kbl(caption="c2m07CI") %>% kable_paper("striped","hover",full_width=F)
c3m07CI %>% kbl(caption="c3m07CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cmm07,cfm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cmm07CI %>% kbl(caption="cmm07CI") %>% kable_paper("striped","hover",full_width=F)
cfm07CI %>% kbl(caption="cfm07CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cnm07,cpm07,csm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cnm07CI %>% kbl(caption="cnm07CI") %>% kable_paper("striped","hover",full_width=F)
cpm07CI %>% kbl(caption="cpm07CI") %>% kable_paper("striped","hover",full_width=F)
csm07CI %>% kbl(caption="csm07CI") %>% kable_paper("striped","hover",full_width=F)

tab_model(cwm07,cbm07,chm07,show.ci=F,show.se=T,auto.label=F,string.se="SE",show.icc=F,show.aic=T)
cwm07CI %>% kbl(caption="cwm07CI") %>% kable_paper("striped","hover",full_width=F)
cbm07CI %>% kbl(caption="cbm07CI") %>% kable_paper("striped","hover",full_width=F)
chm07CI %>% kbl(caption="chm07CI") %>% kable_paper("striped","hover",full_width=F)




