


# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(spaMM)      # for spatial modeling
library(scales)     # for rescale
library(DHARMa)     # for simulateResiduals

# Loading Data
z<-read_sas("Z:/CDCK01/Data_Zip/cdck01zip.sas7bdat")       # N=11064,  829 variables
z<-data.table(z)

memory.limit(300000000000) # Increase memory limit

# as.integer -- for negative binomial DV and offset
z$CPopT <-as.integer(z$CPopT )
z$CPopW <-as.integer(z$CPopW )
z$CPopB <-as.integer(z$CPopB )
z$CPopH <-as.integer(z$CPopH )
z$CPopTM<-as.integer(z$CPopTM)
z$CPopTF<-as.integer(z$CPopTF)
z$CPop1 <-as.integer(z$CPop1 )
z$CPop2 <-as.integer(z$CPop2 )
z$CPop3 <-as.integer(z$CPop3 )
z$RptT  <-as.integer(z$RptT  )
z$RptW  <-as.integer(z$RptW  )
z$RptB  <-as.integer(z$RptB  )
z$RptH  <-as.integer(z$RptH  )
z$RptM  <-as.integer(z$RptM  )
z$RptF  <-as.integer(z$RptF  )
z$Rpt1  <-as.integer(z$Rpt1  )
z$Rpt2  <-as.integer(z$Rpt2  )
z$Rpt3  <-as.integer(z$Rpt3  )
z$NegT  <-as.integer(z$NegT  )
z$PhyT  <-as.integer(z$PhyT  )
z$SexT  <-as.integer(z$SexT  )
z$EmoT  <-as.integer(z$EmoT  )

# making categorical variables as.factor & scaling (roughly 0-100) continuous variables
z$Yearf      <-as.factor(z$Year)
z$NCHS_RUC   <-as.factor(z$NCHS_RUC)
z$USDA_RUC   <-as.factor(z$USDA_RUC)
z$USDA_RUC2  <-factor(z$USDA_RUC,levels=c(2,1,3))
z$USDA_RUC3  <-factor(z$USDA_RUC,levels=c(3,1,2))
z$USDA_RUC0  <-as.factor(z$USDA_RUC0)
z$IncomeT1k  <-z$IncomeT /1000
z$IncomeW1k  <-z$IncomeW /1000
z$IncomeB1k  <-z$IncomeB /1000
z$IncomeH1k  <-z$IncomeH /1000
z$HValueT10k <-z$HValueT /10000
z$MCostT100  <-z$MCostT  /100
z$OCostDT100 <-z$OCostDT /100
z$MRentDT100 <-z$MRentDT /100
z$CARatioT100<-z$CARatioT*100
z$CARatioW100<-z$CARatioW*100
z$CARatioB100<-z$CARatioB*100
z$CARatioH100<-z$CARatioH*100
z$MFRatioT100<-z$MFRatioT*100
z$MFRatioW100<-z$MFRatioW*100
z$MFRatioB100<-z$MFRatioB*100
z$MFRatioH100<-z$MFRatioH*100
z$OwnerT     <-z$OwnNT/z$OHUnitT*100
z$OwnerW     <-z$OwnNW/z$OHUnitW*100
z$OwnerB     <-z$OwnNB/z$OHUnitB*100
z$OwnerH     <-z$OwnNH/z$OHUnitH*100
z$GiniT100   <-z$GiniT*100
z$FoodIS     <-z$FoodInsP*100

# Spatial data
z$pos<-numFactor(z$Longitude,z$Latitude)





# MHV data -- Replacing missing with 0
z$MHV_C4[is.na(z$MHV_C4)]<-0
z$MHV_C5[is.na(z$MHV_C5)]<-0

z0<-z[CPop1 >=300 & CPop2 >=300 & CPop3 >=300,] # N=11064 --> 3827

# Creating Outcome-Specific Data
zt<-z0 # total
zw<-z0 # White
zb<-z0 # Black
zh<-z0 # Hispanic
zm<-z0 # Male
zf<-z0 # Female
z1<-z0 # Age 0-5
z2<-z0 # Age 6-11
z3<-z0 # Age 12-17
zn<-z0 # Neglect
zp<-z0 # Physical abuse
zs<-z0 # Sexual abuse

# Excluding Counties with Low Child Population, Missing Outcome, or Outlier
zt<-zt[CPopT >=300,] # N=3827 -> 3827
zw<-zw[CPopW >=300,] # N=3827 -> 3566
zb<-zb[CPopB >=300,] # N=3827 -> 1666
zh<-zh[CPopH >=300,] # N=3827 -> 2328
zm<-zm[CPopTM>=300,] # N=3827 -> 3827
zf<-zf[CPopTF>=300,] # N=3827 -> 3827
z1<-z1[CPop1 >=300,] # N=3827 -> 3827
z2<-z2[CPop2 >=300,] # N=3827 -> 3827
z3<-z3[CPop3 >=300,] # N=3827 -> 3827
zn<-zn[CPopT >=300,] # N=3827 -> 3827
zp<-zp[CPopT >=300,] # N=3827 -> 3827
zs<-zs[CPopT >=300,] # N=3827 -> 3827
zt<-zt[zt$RptTr<min(boxplot.stats(zt$RptTr,coef=4.5)$out),] # N=3827 -> 3827
zw<-zw[zw$RptWr<min(boxplot.stats(zw$RptWr,coef=4.5)$out),] # N=3566 -> 3554
zb<-zb[zb$RptBr<min(boxplot.stats(zb$RptBr,coef=4.5)$out),] # N=1666 -> 1665
zh<-zh[zh$RptHr<min(boxplot.stats(zh$RptHr,coef=4.5)$out),] # N=2328 -> 2327
zm<-zm[zm$RptMr<min(boxplot.stats(zm$RptMr,coef=4.5)$out),] # N=3827 -> 3827
zf<-zf[zf$RptFr<min(boxplot.stats(zf$RptFr,coef=4.5)$out),] # N=3827 -> 3827
z1<-z1[z1$Rpt1r<min(boxplot.stats(z1$Rpt1r,coef=4.5)$out),] # N=3827 -> 3827
z2<-z2[z2$Rpt2r<min(boxplot.stats(z2$Rpt2r,coef=4.5)$out),] # N=3827 -> 3827
z3<-z3[z3$Rpt3r<min(boxplot.stats(z3$Rpt3r,coef=4.5)$out),] # N=3827 -> 3827
zn<-zn[zn$NegTr<min(boxplot.stats(zn$NegTr,coef=4.5)$out),] # N=3827 -> 3827
zp<-zp[zp$PhyTr<min(boxplot.stats(zp$PhyTr,coef=4.5)$out),] # N=3827 -> 3827
zs<-zs[zs$SexTr<min(boxplot.stats(zs$SexTr,coef=4.5)$out),] # N=3827 -> 3827

sum(zt$CPopT)/sum(z$CPopT)*100 # 90.93
sum(zw$CPopW)/sum(z$CPopW)*100 # 84.64
sum(zb$CPopB)/sum(z$CPopB)*100 # 93.83
sum(zh$CPopH)/sum(z$CPopH)*100 # 95.23
sum(zm$CPopTM)/sum(z$CPopTM)*100 # 90.86
sum(zf$CPopTF)/sum(z$CPopTF)*100 # 91.00
sum(z1$CPop1)/sum(z$CPop1)*100 # 91.39
sum(z2$CPop2)/sum(z$CPop2)*100 # 90.94
sum(z3$CPop3)/sum(z$CPop3)*100 # 90.48

# zt<-zt[!is.na(zt$HValueT),]
# zw<-zw[!is.na(zw$HValueT),]
# zb<-zb[!is.na(zb$HValueT),]
# zh<-zh[!is.na(zh$HValueT),]
# zm<-zm[!is.na(zm$HValueT),]
# zf<-zf[!is.na(zf$HValueT),]
# z1<-z1[!is.na(z1$HValueT),]
# z2<-z2[!is.na(z2$HValueT),]
# z3<-z3[!is.na(z3$HValueT),]
# zn<-zn[!is.na(zn$HValueT),]
# zp<-zp[!is.na(zp$HValueT),]
# zs<-zs[!is.na(zs$HValueT),]

# Outcome distribution
# plot(density(zt$RptTr))
# plot(density(zw$RptWr))
# plot(density(zb$RptBr))
# plot(density(zh$RptHr))
# plot(density(zm$RptMr))
# plot(density(zf$RptFr))
# plot(density(z1$Rpt1r))
# plot(density(z2$Rpt2r))
# plot(density(z3$Rpt3r))
# plot(density(zn$NegTr))
# plot(density(zp$PhyTr))
# plot(density(zs$SexTr))

# Data for sensitivity analysis - Child Population >= 500
# Excluding Counties with Low Child Population, Missing Outcome, or Outlier
zt1<-zt[CPopT >=500,] # N=3827 -> 3827
zw1<-zw[CPopW >=500,] # N=3554 -> 3504
zb1<-zb[CPopB >=500,] # N=1665 -> 1324
zh1<-zh[CPopH >=500,] # N=2327 -> 1863
zm1<-zm[CPopTM>=500,] # N=3827 -> 3801
zf1<-zf[CPopTF>=500,] # N=3827 -> 3761
z11<-z1[CPop1 >=500,] # N=3827 -> 3296
z21<-z2[CPop2 >=500,] # N=3827 -> 3388
z31<-z3[CPop3 >=500,] # N=3827 -> 3439
zn1<-zn[CPopT >=500,] # N=3827 -> 3827
zp1<-zp[CPopT >=500,] # N=3827 -> 3827
zs1<-zs[CPopT >=500,] # N=3827 -> 3827

# zt1<-zt1[!is.na(zt1$HValueT),]
# zw1<-zw1[!is.na(zw1$HValueT),]
# zb1<-zb1[!is.na(zb1$HValueT),]
# zh1<-zh1[!is.na(zh1$HValueT),]
# zm1<-zm1[!is.na(zm1$HValueT),]
# zf1<-zf1[!is.na(zf1$HValueT),]
# z11<-z11[!is.na(z11$HValueT),]
# z21<-z21[!is.na(z21$HValueT),]
# z31<-z31[!is.na(z31$HValueT),]
# zn1<-zn1[!is.na(zn1$HValueT),]
# zp1<-zp1[!is.na(zp1$HValueT),]
# zs1<-zs1[!is.na(zs1$HValueT),]

# Outcome distribution
# plot(density(zt1$RptTr))
# plot(density(zw1$RptWr))
# plot(density(zb1$RptBr))
# plot(density(zh1$RptHr))
# plot(density(zm1$RptMr))
# plot(density(zf1$RptFr))
# plot(density(z11$Rpt1r))
# plot(density(z21$Rpt2r))
# plot(density(z31$Rpt3r))
# plot(density(zn1$NegTr))
# plot(density(zp1$PhyTr))
# plot(density(zs1$SexTr))

# Data for sensitivity analysis - Child Population >= 1000
# Excluding Counties with Low Child Population, Missing Outcome, or Outlier
zt2<-zt[CPopT >=1000,] # N=3827 -> 3814
zw2<-zw[CPopW >=1000,] # N=3554 -> 3234
zb2<-zb[CPopB >=1000,] # N=1665 ->  886
zh2<-zh[CPopH >=1000,] # N=2327 -> 1159
zm2<-zm[CPopTM>=1000,] # N=3827 -> 3098
zf2<-zf[CPopTF>=1000,] # N=3827 -> 3040
z12<-z1[CPop1 >=1000,] # N=3827 -> 2449
z22<-z2[CPop2 >=1000,] # N=3827 -> 2522
z32<-z3[CPop3 >=1000,] # N=3827 -> 2560
zn2<-zn[CPopT >=1000,] # N=3827 -> 3814
zp2<-zp[CPopT >=1000,] # N=3827 -> 3814
zs2<-zs[CPopT >=1000,] # N=3827 -> 3814

# zt2<-zt2[!is.na(zt2$HValueT),]
# zw2<-zw2[!is.na(zw2$HValueT),]
# zb2<-zb2[!is.na(zb2$HValueT),]
# zh2<-zh2[!is.na(zh2$HValueT),]
# zm2<-zm2[!is.na(zm2$HValueT),]
# zf2<-zf2[!is.na(zf2$HValueT),]
# z12<-z12[!is.na(z12$HValueT),]
# z22<-z22[!is.na(z22$HValueT),]
# z32<-z32[!is.na(z32$HValueT),]
# zn2<-zn2[!is.na(zn2$HValueT),]
# zp2<-zp2[!is.na(zp2$HValueT),]
# zs2<-zs2[!is.na(zs2$HValueT),]

# Outcome distribution
# plot(density(zt2$RptTr))
# plot(density(zw2$RptWr))
# plot(density(zb2$RptBr))
# plot(density(zh2$RptHr))
# plot(density(zm2$RptMr))
# plot(density(zf2$RptFr))
# plot(density(z12$Rpt1r))
# plot(density(z22$Rpt2r))
# plot(density(z32$Rpt3r))
# plot(density(zn2$NegTr))
# plot(density(zp2$PhyTr))
# plot(density(zs2$SexTr))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Total
# Income - Total
# Income - Total
# Income - Total
# Income - Total
# Income - Total
# Income - Total
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Checking Sample Size
# length(ct1$CountyFIPS)
# length(ct4$CountyFIPS)
# length(unique(ct1$CountyFIPS))
# length(unique(ct4$CountyFIPS))
# sum(ct1$CPopT)
# sum(ct4$CPopT)

# Check DV Distribution
# boxplot(ct4$RptTr)
# skewness(ct4$RptTr)
# plot(density(ct4$RptTr))

# Check IV Distribution
# boxplot(ct4$CPovT)
# boxplot(ct4$IncomeT)
# boxplot(ct4$FoodInsecure)
# plot(density(ct4$CPovT))
# plot(density(ct4$IncomeT))
# plot(density(ct4$FoodInsecure))

# Longitudinal Trend
# ct4[,list(mean=mean(RptTr)),by=Year]
# ct4[,list(mean=mean(CPovT)),by=Year]
# ct4[,list(mean=mean(IncomeT1k)),by=Year]
# ct4[,list(mean=mean(FoodInsecure)),by=Year]
# ggline(ct4, x="Year", y="FoodInsecure", add=c("mean_se"))
# ggline(ct4, x="Year", y="RptTr", add=c("mean_se"))
# ggline(ct4, x="Year", y="IncomeT1k", add=c("mean_se"))
# ggline(ct4, x="Year", y="CPovT", add=c("mean_se"))
# ggplot(ct4,aes(x=Year,y=FoodInsecure,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=RptTr       ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=IncomeT1k    ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=CPovT       ,group=CountyFIPS,color=StateFIPS))+geom_line()





# Centering Variables
zt$Yearc        <-zt$Year        -mean(zt$Year        ,na.rm=T)
zt$CPopBPc      <-zt$CPopBP      -mean(zt$CPopBP      ,na.rm=T)
zt$CPopHPc      <-zt$CPopHP      -mean(zt$CPopHP      ,na.rm=T)
zt$ChildPTc     <-zt$ChildPT     -mean(zt$ChildPT     ,na.rm=T)
zt$ChildPWc     <-zt$ChildPW     -mean(zt$ChildPW     ,na.rm=T)
zt$ChildPBc     <-zt$ChildPB     -mean(zt$ChildPB     ,na.rm=T)
zt$ChildPHc     <-zt$ChildPH     -mean(zt$ChildPH     ,na.rm=T)
zt$CARatioT100c <-zt$CARatioT100 -mean(zt$CARatioT100 ,na.rm=T)
zt$CARatioW100c <-zt$CARatioW100 -mean(zt$CARatioW100 ,na.rm=T)
zt$CARatioB100c <-zt$CARatioB100 -mean(zt$CARatioB100 ,na.rm=T)
zt$CARatioH100c <-zt$CARatioH100 -mean(zt$CARatioH100 ,na.rm=T)
zt$MalePTc      <-zt$MalePT      -mean(zt$MalePT      ,na.rm=T)
zt$MalePWc      <-zt$MalePW      -mean(zt$MalePW      ,na.rm=T)
zt$MalePBc      <-zt$MalePB      -mean(zt$MalePB      ,na.rm=T)
zt$MalePHc      <-zt$MalePH      -mean(zt$MalePH      ,na.rm=T)
zt$MFRatioT100c <-zt$MFRatioT100 -mean(zt$MFRatioT100 ,na.rm=T)
zt$MFRatioW100c <-zt$MFRatioW100 -mean(zt$MFRatioW100 ,na.rm=T)
zt$MFRatioB100c <-zt$MFRatioB100 -mean(zt$MFRatioB100 ,na.rm=T)
zt$MFRatioH100c <-zt$MFRatioH100 -mean(zt$MFRatioH100 ,na.rm=T)
zt$ElderTc      <-zt$ElderT      -mean(zt$ElderT      ,na.rm=T)
zt$ElderWc      <-zt$ElderW      -mean(zt$ElderW      ,na.rm=T)
zt$ElderBc      <-zt$ElderB      -mean(zt$ElderB      ,na.rm=T)
zt$ElderHc      <-zt$ElderH      -mean(zt$ElderH      ,na.rm=T)
zt$SingleTc     <-zt$SingleT     -mean(zt$SingleT     ,na.rm=T)
zt$SingleWc     <-zt$SingleW     -mean(zt$SingleW     ,na.rm=T)
zt$SingleBc     <-zt$SingleB     -mean(zt$SingleB     ,na.rm=T)
zt$SingleHc     <-zt$SingleH     -mean(zt$SingleH     ,na.rm=T)
zt$FHeadTc      <-zt$FHeadT      -mean(zt$FHeadT      ,na.rm=T)
zt$FHeadWc      <-zt$FHeadW      -mean(zt$FHeadW      ,na.rm=T)
zt$FHeadBc      <-zt$FHeadB      -mean(zt$FHeadB      ,na.rm=T)
zt$FHeadHc      <-zt$FHeadH      -mean(zt$FHeadH      ,na.rm=T)
zt$NoHighTc     <-zt$NoHighT     -mean(zt$NoHighT     ,na.rm=T)
zt$NoHighWc     <-zt$NoHighW     -mean(zt$NoHighW     ,na.rm=T)
zt$NoHighBc     <-zt$NoHighB     -mean(zt$NoHighB     ,na.rm=T)
zt$NoHighHc     <-zt$NoHighH     -mean(zt$NoHighH     ,na.rm=T)
zt$UnempTc      <-zt$UnempT      -mean(zt$UnempT      ,na.rm=T)
zt$UnempWc      <-zt$UnempW      -mean(zt$UnempW      ,na.rm=T)
zt$UnempBc      <-zt$UnempB      -mean(zt$UnempB      ,na.rm=T)
zt$UnempHc      <-zt$UnempH      -mean(zt$UnempH      ,na.rm=T)
zt$CPovTc       <-zt$CPovT       -mean(zt$CPovT       ,na.rm=T)
zt$CPovWc       <-zt$CPovW       -mean(zt$CPovW       ,na.rm=T)
zt$CPovBc       <-zt$CPovB       -mean(zt$CPovB       ,na.rm=T)
zt$CPovHc       <-zt$CPovH       -mean(zt$CPovH       ,na.rm=T)
zt$CPov1c       <-zt$CPov1       -mean(zt$CPov1       ,na.rm=T)
zt$CPov2c       <-zt$CPov2       -mean(zt$CPov2       ,na.rm=T)
zt$CPov3c       <-zt$CPov3       -mean(zt$CPov3       ,na.rm=T)
zt$PubAsTc      <-zt$PubAsT      -mean(zt$PubAsT      ,na.rm=T)
zt$WelfarTc     <-zt$WelfarT     -mean(zt$WelfarT     ,na.rm=T)
zt$SnapTc       <-zt$SnapT       -mean(zt$SnapT       ,na.rm=T)
zt$SnapWc       <-zt$SnapW       -mean(zt$SnapW       ,na.rm=T)
zt$SnapBc       <-zt$SnapB       -mean(zt$SnapB       ,na.rm=T)
zt$SnapHc       <-zt$SnapH       -mean(zt$SnapH       ,na.rm=T)
zt$IncomeT1kc   <-zt$IncomeT1k   -mean(zt$IncomeT1k   ,na.rm=T)
zt$IncomeW1kc   <-zt$IncomeW1k   -mean(zt$IncomeW1k   ,na.rm=T)
zt$IncomeB1kc   <-zt$IncomeB1k   -mean(zt$IncomeB1k   ,na.rm=T)
zt$IncomeH1kc   <-zt$IncomeH1k   -mean(zt$IncomeH1k   ,na.rm=T)
zt$GiniT100c    <-zt$GiniT100    -mean(zt$GiniT100    ,na.rm=T)
zt$HValueT10kc  <-zt$HValueT10k  -mean(zt$HValueT10k  ,na.rm=T)
zt$MCostT100c   <-zt$MCostT100   -mean(zt$MCostT100   ,na.rm=T)
zt$OCostDT100c  <-zt$OCostDT100  -mean(zt$OCostDT100  ,na.rm=T)
zt$MRentDT100c  <-zt$MRentDT100  -mean(zt$MRentDT100  ,na.rm=T)
zt$OCostPTc     <-zt$OCostPT     -mean(zt$OCostPT     ,na.rm=T)
zt$MRentPTc     <-zt$MRentPT     -mean(zt$MRentPT     ,na.rm=T)
zt$MortgTc      <-zt$MortgT      -mean(zt$MortgT      ,na.rm=T)
zt$LangAPTc     <-zt$LangAPT     -mean(zt$LangAPT     ,na.rm=T)
zt$LangAPWc     <-zt$LangAPW     -mean(zt$LangAPW     ,na.rm=T)
zt$LangAPBc     <-zt$LangAPB     -mean(zt$LangAPB     ,na.rm=T)
zt$LangAPHc     <-zt$LangAPH     -mean(zt$LangAPH     ,na.rm=T)
zt$LangBPTc     <-zt$LangBPT     -mean(zt$LangBPT     ,na.rm=T)
zt$LangBPWc     <-zt$LangBPW     -mean(zt$LangBPW     ,na.rm=T)
zt$LangBPBc     <-zt$LangBPB     -mean(zt$LangBPB     ,na.rm=T)
zt$LangBPHc     <-zt$LangBPH     -mean(zt$LangBPH     ,na.rm=T)
zt$LangCPTc     <-zt$LangCPT     -mean(zt$LangCPT     ,na.rm=T)
zt$OutUsTc      <-zt$OutUsT      -mean(zt$OutUsT      ,na.rm=T)
zt$OutUsWc      <-zt$OutUsW      -mean(zt$OutUsW      ,na.rm=T)
zt$OutUsBc      <-zt$OutUsB      -mean(zt$OutUsB      ,na.rm=T)
zt$OutUsHc      <-zt$OutUsH      -mean(zt$OutUsH      ,na.rm=T)
zt$FBornTc      <-zt$FBornT      -mean(zt$FBornT      ,na.rm=T)
zt$FBornWc      <-zt$FBornW      -mean(zt$FBornW      ,na.rm=T)
zt$FBornBc      <-zt$FBornB      -mean(zt$FBornB      ,na.rm=T)
zt$FBornHc      <-zt$FBornH      -mean(zt$FBornH      ,na.rm=T)
zt$NotCtzTc     <-zt$NotCtzT     -mean(zt$NotCtzT     ,na.rm=T)
zt$NotCtzWc     <-zt$NotCtzW     -mean(zt$NotCtzW     ,na.rm=T)
zt$NotCtzBc     <-zt$NotCtzB     -mean(zt$NotCtzB     ,na.rm=T)
zt$NotCtzHc     <-zt$NotCtzH     -mean(zt$NotCtzH     ,na.rm=T)
zt$MoveTc       <-zt$MoveT       -mean(zt$MoveT       ,na.rm=T)
zt$MoveWc       <-zt$MoveW       -mean(zt$MoveW       ,na.rm=T)
zt$MoveBc       <-zt$MoveB       -mean(zt$MoveB       ,na.rm=T)
zt$MoveHc       <-zt$MoveH       -mean(zt$MoveH       ,na.rm=T)
zt$VacantTc     <-zt$VacantT     -mean(zt$VacantT     ,na.rm=T)
zt$OwnerTc      <-zt$OwnerT      -mean(zt$OwnerT      ,na.rm=T)
zt$OwnerWc      <-zt$OwnerW      -mean(zt$OwnerW      ,na.rm=T)
zt$OwnerBc      <-zt$OwnerB      -mean(zt$OwnerB      ,na.rm=T)
zt$OwnerHc      <-zt$OwnerH      -mean(zt$OwnerH      ,na.rm=T)
zt$CrowdTc      <-zt$CrowdT      -mean(zt$CrowdT      ,na.rm=T)
zt$CrowdWc      <-zt$CrowdW      -mean(zt$CrowdW      ,na.rm=T)
zt$CrowdBc      <-zt$CrowdB      -mean(zt$CrowdB      ,na.rm=T)
zt$CrowdHc      <-zt$CrowdH      -mean(zt$CrowdH      ,na.rm=T)
zt$MobileTc     <-zt$MobileT     -mean(zt$MobileT     ,na.rm=T)
zt$MobileWc     <-zt$MobileW     -mean(zt$MobileW     ,na.rm=T)
zt$MobileBc     <-zt$MobileB     -mean(zt$MobileB     ,na.rm=T)
zt$MobileHc     <-zt$MobileH     -mean(zt$MobileH     ,na.rm=T)
zt$DisablTc     <-zt$DisablT     -mean(zt$DisablT     ,na.rm=T)
zt$DisablWc     <-zt$DisablW     -mean(zt$DisablW     ,na.rm=T)
zt$DisablBc     <-zt$DisablB     -mean(zt$DisablB     ,na.rm=T)
zt$DisablHc     <-zt$DisablH     -mean(zt$DisablH     ,na.rm=T)
zt$DisablTCc    <-zt$DisablTC    -mean(zt$DisablTC    ,na.rm=T)
zt$DisablWCc    <-zt$DisablWC    -mean(zt$DisablWC    ,na.rm=T)
zt$DisablBCc    <-zt$DisablBC    -mean(zt$DisablBC    ,na.rm=T)
zt$DisablHCc    <-zt$DisablHC    -mean(zt$DisablHC    ,na.rm=T)
zt$DisablTMc    <-zt$DisablTM    -mean(zt$DisablTM    ,na.rm=T)
zt$DisablTFc    <-zt$DisablTF    -mean(zt$DisablTF    ,na.rm=T)
zt$Urban1c      <-zt$Urban1      -mean(zt$Urban1      ,na.rm=T)
zt$Urban2c      <-zt$Urban2      -mean(zt$Urban2      ,na.rm=T)
zt$ISBE_PFAc    <-zt$ISBE_PFA    -mean(zt$ISBE_PFA    ,na.rm=T)
zt$ISBE_PFAEc   <-zt$ISBE_PFAE   -mean(zt$ISBE_PFAE   ,na.rm=T)
zt$ISBE_PIc     <-zt$ISBE_PI     -mean(zt$ISBE_PI     ,na.rm=T)
zt$HeadStartc   <-zt$HeadStart   -mean(zt$HeadStart   ,na.rm=T)
zt$ElyHeadSc    <-zt$ElyHeadS    -mean(zt$ElyHeadS    ,na.rm=T)
zt$HeadSAllc    <-zt$HeadSAll    -mean(zt$HeadSAll    ,na.rm=T)
zt$PFA_HS1c     <-zt$PFA_HS1     -mean(zt$PFA_HS1     ,na.rm=T)
zt$PFA_HS2c     <-zt$PFA_HS2     -mean(zt$PFA_HS2     ,na.rm=T)
zt$LCCCc        <-zt$LCCC        -mean(zt$LCCC        ,na.rm=T)
zt$LECCCc       <-zt$LECCC       -mean(zt$LECCC       ,na.rm=T)
zt$LFCCc        <-zt$LFCC        -mean(zt$LFCC        ,na.rm=T)
zt$LLECCCc      <-zt$LLECCC      -mean(zt$LLECCC      ,na.rm=T)
zt$LCLFCCc      <-zt$LCLFCC      -mean(zt$LCLFCC      ,na.rm=T)
zt$LCCCB1c      <-zt$LCCCB1      -mean(zt$LCCCB1      ,na.rm=T)
zt$LCCCB2c      <-zt$LCCCB2      -mean(zt$LCCCB2      ,na.rm=T)
zt$LCCB1c       <-zt$LCCB1       -mean(zt$LCCB1       ,na.rm=T)
zt$LCCB2c       <-zt$LCCB2       -mean(zt$LCCB2       ,na.rm=T)
zt$LCCCS1c      <-zt$LCCCS1      -mean(zt$LCCCS1      ,na.rm=T)
zt$LCCCS2c      <-zt$LCCCS2      -mean(zt$LCCCS2      ,na.rm=T)
zt$LCCS1c       <-zt$LCCS1       -mean(zt$LCCS1       ,na.rm=T)
zt$LCCS2c       <-zt$LCCS2       -mean(zt$LCCS2       ,na.rm=T)
zt$LCCCG1c      <-zt$LCCCG1      -mean(zt$LCCCG1      ,na.rm=T)
zt$LCCCG2c      <-zt$LCCCG2      -mean(zt$LCCCG2      ,na.rm=T)
zt$LCCG1c       <-zt$LCCG1       -mean(zt$LCCG1       ,na.rm=T)
zt$LCCG2c       <-zt$LCCG2       -mean(zt$LCCG2       ,na.rm=T)
zt$ChildCare1c  <-zt$ChildCare1  -mean(zt$ChildCare1  ,na.rm=T)
zt$ChildCare2c  <-zt$ChildCare2  -mean(zt$ChildCare2  ,na.rm=T)
zt$ChildCare3c  <-zt$ChildCare3  -mean(zt$ChildCare3  ,na.rm=T)
zt$CCAPc        <-zt$CCAP        -mean(zt$CCAP        ,na.rm=T)
zt$Homelessc    <-zt$Homeless    -mean(zt$Homeless    ,na.rm=T)
zt$Homeless2c   <-zt$Homeless2   -mean(zt$Homeless2   ,na.rm=T)
zt$DHS_HFIrc    <-zt$DHS_HFIr    -mean(zt$DHS_HFIr    ,na.rm=T)
zt$DHS_PTSrc    <-zt$DHS_PTSr    -mean(zt$DHS_PTSr    ,na.rm=T)
zt$DHS_HVPrc    <-zt$DHS_HVPr    -mean(zt$DHS_HVPr    ,na.rm=T)
zt$IDHS_EIrc    <-zt$IDHS_EIr    -mean(zt$IDHS_EIr    ,na.rm=T)
zt$MHV_C4c      <-zt$MHV_C4      -mean(zt$MHV_C4      ,na.rm=T)
zt$MHV_P4c      <-zt$MHV_P4      -mean(zt$MHV_P4      ,na.rm=T)
zt$MHV_C5c      <-zt$MHV_C5      -mean(zt$MHV_C5      ,na.rm=T)
zt$MHV_P5c      <-zt$MHV_P5      -mean(zt$MHV_P5      ,na.rm=T)
zt$FoodInsPc    <-zt$FoodInsP    -mean(zt$FoodInsP    ,na.rm=T)
zt$FoodISc      <-zt$FoodIS      -mean(zt$FoodIS      ,na.rm=T)
zt$RPovTc       <-zt$RPovT       -mean(zt$RPovT       ,na.rm=T)
zt$PovTc        <-zt$PovT        -mean(zt$PovT        ,na.rm=T)
zt$MHV_C4k <-zt$MHV_C4 *10
zt$MHV_C5k <-zt$MHV_C5 *10
zt$MHV_C4kc<-zt$MHV_C4c*10
zt$MHV_C5kc<-zt$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zt1$Yearc        <-zt1$Year        -mean(zt1$Year        ,na.rm=T)
zt1$CPopBPc      <-zt1$CPopBP      -mean(zt1$CPopBP      ,na.rm=T)
zt1$CPopHPc      <-zt1$CPopHP      -mean(zt1$CPopHP      ,na.rm=T)
zt1$ChildPTc     <-zt1$ChildPT     -mean(zt1$ChildPT     ,na.rm=T)
zt1$ChildPWc     <-zt1$ChildPW     -mean(zt1$ChildPW     ,na.rm=T)
zt1$ChildPBc     <-zt1$ChildPB     -mean(zt1$ChildPB     ,na.rm=T)
zt1$ChildPHc     <-zt1$ChildPH     -mean(zt1$ChildPH     ,na.rm=T)
zt1$CARatioT100c <-zt1$CARatioT100 -mean(zt1$CARatioT100 ,na.rm=T)
zt1$CARatioW100c <-zt1$CARatioW100 -mean(zt1$CARatioW100 ,na.rm=T)
zt1$CARatioB100c <-zt1$CARatioB100 -mean(zt1$CARatioB100 ,na.rm=T)
zt1$CARatioH100c <-zt1$CARatioH100 -mean(zt1$CARatioH100 ,na.rm=T)
zt1$MalePTc      <-zt1$MalePT      -mean(zt1$MalePT      ,na.rm=T)
zt1$MalePWc      <-zt1$MalePW      -mean(zt1$MalePW      ,na.rm=T)
zt1$MalePBc      <-zt1$MalePB      -mean(zt1$MalePB      ,na.rm=T)
zt1$MalePHc      <-zt1$MalePH      -mean(zt1$MalePH      ,na.rm=T)
zt1$MFRatioT100c <-zt1$MFRatioT100 -mean(zt1$MFRatioT100 ,na.rm=T)
zt1$MFRatioW100c <-zt1$MFRatioW100 -mean(zt1$MFRatioW100 ,na.rm=T)
zt1$MFRatioB100c <-zt1$MFRatioB100 -mean(zt1$MFRatioB100 ,na.rm=T)
zt1$MFRatioH100c <-zt1$MFRatioH100 -mean(zt1$MFRatioH100 ,na.rm=T)
zt1$ElderTc      <-zt1$ElderT      -mean(zt1$ElderT      ,na.rm=T)
zt1$ElderWc      <-zt1$ElderW      -mean(zt1$ElderW      ,na.rm=T)
zt1$ElderBc      <-zt1$ElderB      -mean(zt1$ElderB      ,na.rm=T)
zt1$ElderHc      <-zt1$ElderH      -mean(zt1$ElderH      ,na.rm=T)
zt1$SingleTc     <-zt1$SingleT     -mean(zt1$SingleT     ,na.rm=T)
zt1$SingleWc     <-zt1$SingleW     -mean(zt1$SingleW     ,na.rm=T)
zt1$SingleBc     <-zt1$SingleB     -mean(zt1$SingleB     ,na.rm=T)
zt1$SingleHc     <-zt1$SingleH     -mean(zt1$SingleH     ,na.rm=T)
zt1$FHeadTc      <-zt1$FHeadT      -mean(zt1$FHeadT      ,na.rm=T)
zt1$FHeadWc      <-zt1$FHeadW      -mean(zt1$FHeadW      ,na.rm=T)
zt1$FHeadBc      <-zt1$FHeadB      -mean(zt1$FHeadB      ,na.rm=T)
zt1$FHeadHc      <-zt1$FHeadH      -mean(zt1$FHeadH      ,na.rm=T)
zt1$NoHighTc     <-zt1$NoHighT     -mean(zt1$NoHighT     ,na.rm=T)
zt1$NoHighWc     <-zt1$NoHighW     -mean(zt1$NoHighW     ,na.rm=T)
zt1$NoHighBc     <-zt1$NoHighB     -mean(zt1$NoHighB     ,na.rm=T)
zt1$NoHighHc     <-zt1$NoHighH     -mean(zt1$NoHighH     ,na.rm=T)
zt1$UnempTc      <-zt1$UnempT      -mean(zt1$UnempT      ,na.rm=T)
zt1$UnempWc      <-zt1$UnempW      -mean(zt1$UnempW      ,na.rm=T)
zt1$UnempBc      <-zt1$UnempB      -mean(zt1$UnempB      ,na.rm=T)
zt1$UnempHc      <-zt1$UnempH      -mean(zt1$UnempH      ,na.rm=T)
zt1$CPovTc       <-zt1$CPovT       -mean(zt1$CPovT       ,na.rm=T)
zt1$CPovWc       <-zt1$CPovW       -mean(zt1$CPovW       ,na.rm=T)
zt1$CPovBc       <-zt1$CPovB       -mean(zt1$CPovB       ,na.rm=T)
zt1$CPovHc       <-zt1$CPovH       -mean(zt1$CPovH       ,na.rm=T)
zt1$CPov1c       <-zt1$CPov1       -mean(zt1$CPov1       ,na.rm=T)
zt1$CPov2c       <-zt1$CPov2       -mean(zt1$CPov2       ,na.rm=T)
zt1$CPov3c       <-zt1$CPov3       -mean(zt1$CPov3       ,na.rm=T)
zt1$PubAsTc      <-zt1$PubAsT      -mean(zt1$PubAsT      ,na.rm=T)
zt1$WelfarTc     <-zt1$WelfarT     -mean(zt1$WelfarT     ,na.rm=T)
zt1$SnapTc       <-zt1$SnapT       -mean(zt1$SnapT       ,na.rm=T)
zt1$SnapWc       <-zt1$SnapW       -mean(zt1$SnapW       ,na.rm=T)
zt1$SnapBc       <-zt1$SnapB       -mean(zt1$SnapB       ,na.rm=T)
zt1$SnapHc       <-zt1$SnapH       -mean(zt1$SnapH       ,na.rm=T)
zt1$IncomeT1kc   <-zt1$IncomeT1k   -mean(zt1$IncomeT1k   ,na.rm=T)
zt1$IncomeW1kc   <-zt1$IncomeW1k   -mean(zt1$IncomeW1k   ,na.rm=T)
zt1$IncomeB1kc   <-zt1$IncomeB1k   -mean(zt1$IncomeB1k   ,na.rm=T)
zt1$IncomeH1kc   <-zt1$IncomeH1k   -mean(zt1$IncomeH1k   ,na.rm=T)
zt1$GiniT100c    <-zt1$GiniT100    -mean(zt1$GiniT100    ,na.rm=T)
zt1$HValueT10kc  <-zt1$HValueT10k  -mean(zt1$HValueT10k  ,na.rm=T)
zt1$MCostT100c   <-zt1$MCostT100   -mean(zt1$MCostT100   ,na.rm=T)
zt1$OCostDT100c  <-zt1$OCostDT100  -mean(zt1$OCostDT100  ,na.rm=T)
zt1$MRentDT100c  <-zt1$MRentDT100  -mean(zt1$MRentDT100  ,na.rm=T)
zt1$OCostPTc     <-zt1$OCostPT     -mean(zt1$OCostPT     ,na.rm=T)
zt1$MRentPTc     <-zt1$MRentPT     -mean(zt1$MRentPT     ,na.rm=T)
zt1$MortgTc      <-zt1$MortgT      -mean(zt1$MortgT      ,na.rm=T)
zt1$LangAPTc     <-zt1$LangAPT     -mean(zt1$LangAPT     ,na.rm=T)
zt1$LangAPWc     <-zt1$LangAPW     -mean(zt1$LangAPW     ,na.rm=T)
zt1$LangAPBc     <-zt1$LangAPB     -mean(zt1$LangAPB     ,na.rm=T)
zt1$LangAPHc     <-zt1$LangAPH     -mean(zt1$LangAPH     ,na.rm=T)
zt1$LangBPTc     <-zt1$LangBPT     -mean(zt1$LangBPT     ,na.rm=T)
zt1$LangBPWc     <-zt1$LangBPW     -mean(zt1$LangBPW     ,na.rm=T)
zt1$LangBPBc     <-zt1$LangBPB     -mean(zt1$LangBPB     ,na.rm=T)
zt1$LangBPHc     <-zt1$LangBPH     -mean(zt1$LangBPH     ,na.rm=T)
zt1$LangCPTc     <-zt1$LangCPT     -mean(zt1$LangCPT     ,na.rm=T)
zt1$OutUsTc      <-zt1$OutUsT      -mean(zt1$OutUsT      ,na.rm=T)
zt1$OutUsWc      <-zt1$OutUsW      -mean(zt1$OutUsW      ,na.rm=T)
zt1$OutUsBc      <-zt1$OutUsB      -mean(zt1$OutUsB      ,na.rm=T)
zt1$OutUsHc      <-zt1$OutUsH      -mean(zt1$OutUsH      ,na.rm=T)
zt1$FBornTc      <-zt1$FBornT      -mean(zt1$FBornT      ,na.rm=T)
zt1$FBornWc      <-zt1$FBornW      -mean(zt1$FBornW      ,na.rm=T)
zt1$FBornBc      <-zt1$FBornB      -mean(zt1$FBornB      ,na.rm=T)
zt1$FBornHc      <-zt1$FBornH      -mean(zt1$FBornH      ,na.rm=T)
zt1$NotCtzTc     <-zt1$NotCtzT     -mean(zt1$NotCtzT     ,na.rm=T)
zt1$NotCtzWc     <-zt1$NotCtzW     -mean(zt1$NotCtzW     ,na.rm=T)
zt1$NotCtzBc     <-zt1$NotCtzB     -mean(zt1$NotCtzB     ,na.rm=T)
zt1$NotCtzHc     <-zt1$NotCtzH     -mean(zt1$NotCtzH     ,na.rm=T)
zt1$MoveTc       <-zt1$MoveT       -mean(zt1$MoveT       ,na.rm=T)
zt1$MoveWc       <-zt1$MoveW       -mean(zt1$MoveW       ,na.rm=T)
zt1$MoveBc       <-zt1$MoveB       -mean(zt1$MoveB       ,na.rm=T)
zt1$MoveHc       <-zt1$MoveH       -mean(zt1$MoveH       ,na.rm=T)
zt1$VacantTc     <-zt1$VacantT     -mean(zt1$VacantT     ,na.rm=T)
zt1$OwnerTc      <-zt1$OwnerT      -mean(zt1$OwnerT      ,na.rm=T)
zt1$OwnerWc      <-zt1$OwnerW      -mean(zt1$OwnerW      ,na.rm=T)
zt1$OwnerBc      <-zt1$OwnerB      -mean(zt1$OwnerB      ,na.rm=T)
zt1$OwnerHc      <-zt1$OwnerH      -mean(zt1$OwnerH      ,na.rm=T)
zt1$CrowdTc      <-zt1$CrowdT      -mean(zt1$CrowdT      ,na.rm=T)
zt1$CrowdWc      <-zt1$CrowdW      -mean(zt1$CrowdW      ,na.rm=T)
zt1$CrowdBc      <-zt1$CrowdB      -mean(zt1$CrowdB      ,na.rm=T)
zt1$CrowdHc      <-zt1$CrowdH      -mean(zt1$CrowdH      ,na.rm=T)
zt1$MobileTc     <-zt1$MobileT     -mean(zt1$MobileT     ,na.rm=T)
zt1$MobileWc     <-zt1$MobileW     -mean(zt1$MobileW     ,na.rm=T)
zt1$MobileBc     <-zt1$MobileB     -mean(zt1$MobileB     ,na.rm=T)
zt1$MobileHc     <-zt1$MobileH     -mean(zt1$MobileH     ,na.rm=T)
zt1$DisablTc     <-zt1$DisablT     -mean(zt1$DisablT     ,na.rm=T)
zt1$DisablWc     <-zt1$DisablW     -mean(zt1$DisablW     ,na.rm=T)
zt1$DisablBc     <-zt1$DisablB     -mean(zt1$DisablB     ,na.rm=T)
zt1$DisablHc     <-zt1$DisablH     -mean(zt1$DisablH     ,na.rm=T)
zt1$DisablTCc    <-zt1$DisablTC    -mean(zt1$DisablTC    ,na.rm=T)
zt1$DisablWCc    <-zt1$DisablWC    -mean(zt1$DisablWC    ,na.rm=T)
zt1$DisablBCc    <-zt1$DisablBC    -mean(zt1$DisablBC    ,na.rm=T)
zt1$DisablHCc    <-zt1$DisablHC    -mean(zt1$DisablHC    ,na.rm=T)
zt1$DisablTMc    <-zt1$DisablTM    -mean(zt1$DisablTM    ,na.rm=T)
zt1$DisablTFc    <-zt1$DisablTF    -mean(zt1$DisablTF    ,na.rm=T)
zt1$Urban1c      <-zt1$Urban1      -mean(zt1$Urban1      ,na.rm=T)
zt1$Urban2c      <-zt1$Urban2      -mean(zt1$Urban2      ,na.rm=T)
zt1$ISBE_PFAc    <-zt1$ISBE_PFA    -mean(zt1$ISBE_PFA    ,na.rm=T)
zt1$ISBE_PFAEc   <-zt1$ISBE_PFAE   -mean(zt1$ISBE_PFAE   ,na.rm=T)
zt1$ISBE_PIc     <-zt1$ISBE_PI     -mean(zt1$ISBE_PI     ,na.rm=T)
zt1$HeadStartc   <-zt1$HeadStart   -mean(zt1$HeadStart   ,na.rm=T)
zt1$ElyHeadSc    <-zt1$ElyHeadS    -mean(zt1$ElyHeadS    ,na.rm=T)
zt1$HeadSAllc    <-zt1$HeadSAll    -mean(zt1$HeadSAll    ,na.rm=T)
zt1$PFA_HS1c     <-zt1$PFA_HS1     -mean(zt1$PFA_HS1     ,na.rm=T)
zt1$PFA_HS2c     <-zt1$PFA_HS2     -mean(zt1$PFA_HS2     ,na.rm=T)
zt1$LCCCc        <-zt1$LCCC        -mean(zt1$LCCC        ,na.rm=T)
zt1$LECCCc       <-zt1$LECCC       -mean(zt1$LECCC       ,na.rm=T)
zt1$LFCCc        <-zt1$LFCC        -mean(zt1$LFCC        ,na.rm=T)
zt1$LLECCCc      <-zt1$LLECCC      -mean(zt1$LLECCC      ,na.rm=T)
zt1$LCLFCCc      <-zt1$LCLFCC      -mean(zt1$LCLFCC      ,na.rm=T)
zt1$LCCCB1c      <-zt1$LCCCB1      -mean(zt1$LCCCB1      ,na.rm=T)
zt1$LCCCB2c      <-zt1$LCCCB2      -mean(zt1$LCCCB2      ,na.rm=T)
zt1$LCCB1c       <-zt1$LCCB1       -mean(zt1$LCCB1       ,na.rm=T)
zt1$LCCB2c       <-zt1$LCCB2       -mean(zt1$LCCB2       ,na.rm=T)
zt1$LCCCS1c      <-zt1$LCCCS1      -mean(zt1$LCCCS1      ,na.rm=T)
zt1$LCCCS2c      <-zt1$LCCCS2      -mean(zt1$LCCCS2      ,na.rm=T)
zt1$LCCS1c       <-zt1$LCCS1       -mean(zt1$LCCS1       ,na.rm=T)
zt1$LCCS2c       <-zt1$LCCS2       -mean(zt1$LCCS2       ,na.rm=T)
zt1$LCCCG1c      <-zt1$LCCCG1      -mean(zt1$LCCCG1      ,na.rm=T)
zt1$LCCCG2c      <-zt1$LCCCG2      -mean(zt1$LCCCG2      ,na.rm=T)
zt1$LCCG1c       <-zt1$LCCG1       -mean(zt1$LCCG1       ,na.rm=T)
zt1$LCCG2c       <-zt1$LCCG2       -mean(zt1$LCCG2       ,na.rm=T)
zt1$ChildCare1c  <-zt1$ChildCare1  -mean(zt1$ChildCare1  ,na.rm=T)
zt1$ChildCare2c  <-zt1$ChildCare2  -mean(zt1$ChildCare2  ,na.rm=T)
zt1$ChildCare3c  <-zt1$ChildCare3  -mean(zt1$ChildCare3  ,na.rm=T)
zt1$CCAPc        <-zt1$CCAP        -mean(zt1$CCAP        ,na.rm=T)
zt1$Homelessc    <-zt1$Homeless    -mean(zt1$Homeless    ,na.rm=T)
zt1$Homeless2c   <-zt1$Homeless2   -mean(zt1$Homeless2   ,na.rm=T)
zt1$DHS_HFIrc    <-zt1$DHS_HFIr    -mean(zt1$DHS_HFIr    ,na.rm=T)
zt1$DHS_PTSrc    <-zt1$DHS_PTSr    -mean(zt1$DHS_PTSr    ,na.rm=T)
zt1$DHS_HVPrc    <-zt1$DHS_HVPr    -mean(zt1$DHS_HVPr    ,na.rm=T)
zt1$IDHS_EIrc    <-zt1$IDHS_EIr    -mean(zt1$IDHS_EIr    ,na.rm=T)
zt1$MHV_C4c      <-zt1$MHV_C4      -mean(zt1$MHV_C4      ,na.rm=T)
zt1$MHV_P4c      <-zt1$MHV_P4      -mean(zt1$MHV_P4      ,na.rm=T)
zt1$MHV_C5c      <-zt1$MHV_C5      -mean(zt1$MHV_C5      ,na.rm=T)
zt1$MHV_P5c      <-zt1$MHV_P5      -mean(zt1$MHV_P5      ,na.rm=T)
zt1$FoodInsPc    <-zt1$FoodInsP    -mean(zt1$FoodInsP    ,na.rm=T)
zt1$FoodISc      <-zt1$FoodIS      -mean(zt1$FoodIS      ,na.rm=T)
zt1$RPovTc       <-zt1$RPovT       -mean(zt1$RPovT       ,na.rm=T)
zt1$PovTc        <-zt1$PovT        -mean(zt1$PovT        ,na.rm=T)
zt1$MHV_C4k <-zt1$MHV_C4 *10
zt1$MHV_C5k <-zt1$MHV_C5 *10
zt1$MHV_C4kc<-zt1$MHV_C4c*10
zt1$MHV_C5kc<-zt1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zt2$Yearc        <-zt2$Year        -mean(zt2$Year        ,na.rm=T)
zt2$CPopBPc      <-zt2$CPopBP      -mean(zt2$CPopBP      ,na.rm=T)
zt2$CPopHPc      <-zt2$CPopHP      -mean(zt2$CPopHP      ,na.rm=T)
zt2$ChildPTc     <-zt2$ChildPT     -mean(zt2$ChildPT     ,na.rm=T)
zt2$ChildPWc     <-zt2$ChildPW     -mean(zt2$ChildPW     ,na.rm=T)
zt2$ChildPBc     <-zt2$ChildPB     -mean(zt2$ChildPB     ,na.rm=T)
zt2$ChildPHc     <-zt2$ChildPH     -mean(zt2$ChildPH     ,na.rm=T)
zt2$CARatioT100c <-zt2$CARatioT100 -mean(zt2$CARatioT100 ,na.rm=T)
zt2$CARatioW100c <-zt2$CARatioW100 -mean(zt2$CARatioW100 ,na.rm=T)
zt2$CARatioB100c <-zt2$CARatioB100 -mean(zt2$CARatioB100 ,na.rm=T)
zt2$CARatioH100c <-zt2$CARatioH100 -mean(zt2$CARatioH100 ,na.rm=T)
zt2$MalePTc      <-zt2$MalePT      -mean(zt2$MalePT      ,na.rm=T)
zt2$MalePWc      <-zt2$MalePW      -mean(zt2$MalePW      ,na.rm=T)
zt2$MalePBc      <-zt2$MalePB      -mean(zt2$MalePB      ,na.rm=T)
zt2$MalePHc      <-zt2$MalePH      -mean(zt2$MalePH      ,na.rm=T)
zt2$MFRatioT100c <-zt2$MFRatioT100 -mean(zt2$MFRatioT100 ,na.rm=T)
zt2$MFRatioW100c <-zt2$MFRatioW100 -mean(zt2$MFRatioW100 ,na.rm=T)
zt2$MFRatioB100c <-zt2$MFRatioB100 -mean(zt2$MFRatioB100 ,na.rm=T)
zt2$MFRatioH100c <-zt2$MFRatioH100 -mean(zt2$MFRatioH100 ,na.rm=T)
zt2$ElderTc      <-zt2$ElderT      -mean(zt2$ElderT      ,na.rm=T)
zt2$ElderWc      <-zt2$ElderW      -mean(zt2$ElderW      ,na.rm=T)
zt2$ElderBc      <-zt2$ElderB      -mean(zt2$ElderB      ,na.rm=T)
zt2$ElderHc      <-zt2$ElderH      -mean(zt2$ElderH      ,na.rm=T)
zt2$SingleTc     <-zt2$SingleT     -mean(zt2$SingleT     ,na.rm=T)
zt2$SingleWc     <-zt2$SingleW     -mean(zt2$SingleW     ,na.rm=T)
zt2$SingleBc     <-zt2$SingleB     -mean(zt2$SingleB     ,na.rm=T)
zt2$SingleHc     <-zt2$SingleH     -mean(zt2$SingleH     ,na.rm=T)
zt2$FHeadTc      <-zt2$FHeadT      -mean(zt2$FHeadT      ,na.rm=T)
zt2$FHeadWc      <-zt2$FHeadW      -mean(zt2$FHeadW      ,na.rm=T)
zt2$FHeadBc      <-zt2$FHeadB      -mean(zt2$FHeadB      ,na.rm=T)
zt2$FHeadHc      <-zt2$FHeadH      -mean(zt2$FHeadH      ,na.rm=T)
zt2$NoHighTc     <-zt2$NoHighT     -mean(zt2$NoHighT     ,na.rm=T)
zt2$NoHighWc     <-zt2$NoHighW     -mean(zt2$NoHighW     ,na.rm=T)
zt2$NoHighBc     <-zt2$NoHighB     -mean(zt2$NoHighB     ,na.rm=T)
zt2$NoHighHc     <-zt2$NoHighH     -mean(zt2$NoHighH     ,na.rm=T)
zt2$UnempTc      <-zt2$UnempT      -mean(zt2$UnempT      ,na.rm=T)
zt2$UnempWc      <-zt2$UnempW      -mean(zt2$UnempW      ,na.rm=T)
zt2$UnempBc      <-zt2$UnempB      -mean(zt2$UnempB      ,na.rm=T)
zt2$UnempHc      <-zt2$UnempH      -mean(zt2$UnempH      ,na.rm=T)
zt2$CPovTc       <-zt2$CPovT       -mean(zt2$CPovT       ,na.rm=T)
zt2$CPovWc       <-zt2$CPovW       -mean(zt2$CPovW       ,na.rm=T)
zt2$CPovBc       <-zt2$CPovB       -mean(zt2$CPovB       ,na.rm=T)
zt2$CPovHc       <-zt2$CPovH       -mean(zt2$CPovH       ,na.rm=T)
zt2$CPov1c       <-zt2$CPov1       -mean(zt2$CPov1       ,na.rm=T)
zt2$CPov2c       <-zt2$CPov2       -mean(zt2$CPov2       ,na.rm=T)
zt2$CPov3c       <-zt2$CPov3       -mean(zt2$CPov3       ,na.rm=T)
zt2$PubAsTc      <-zt2$PubAsT      -mean(zt2$PubAsT      ,na.rm=T)
zt2$WelfarTc     <-zt2$WelfarT     -mean(zt2$WelfarT     ,na.rm=T)
zt2$SnapTc       <-zt2$SnapT       -mean(zt2$SnapT       ,na.rm=T)
zt2$SnapWc       <-zt2$SnapW       -mean(zt2$SnapW       ,na.rm=T)
zt2$SnapBc       <-zt2$SnapB       -mean(zt2$SnapB       ,na.rm=T)
zt2$SnapHc       <-zt2$SnapH       -mean(zt2$SnapH       ,na.rm=T)
zt2$IncomeT1kc   <-zt2$IncomeT1k   -mean(zt2$IncomeT1k   ,na.rm=T)
zt2$IncomeW1kc   <-zt2$IncomeW1k   -mean(zt2$IncomeW1k   ,na.rm=T)
zt2$IncomeB1kc   <-zt2$IncomeB1k   -mean(zt2$IncomeB1k   ,na.rm=T)
zt2$IncomeH1kc   <-zt2$IncomeH1k   -mean(zt2$IncomeH1k   ,na.rm=T)
zt2$GiniT100c    <-zt2$GiniT100    -mean(zt2$GiniT100    ,na.rm=T)
zt2$HValueT10kc  <-zt2$HValueT10k  -mean(zt2$HValueT10k  ,na.rm=T)
zt2$MCostT100c   <-zt2$MCostT100   -mean(zt2$MCostT100   ,na.rm=T)
zt2$OCostDT100c  <-zt2$OCostDT100  -mean(zt2$OCostDT100  ,na.rm=T)
zt2$MRentDT100c  <-zt2$MRentDT100  -mean(zt2$MRentDT100  ,na.rm=T)
zt2$OCostPTc     <-zt2$OCostPT     -mean(zt2$OCostPT     ,na.rm=T)
zt2$MRentPTc     <-zt2$MRentPT     -mean(zt2$MRentPT     ,na.rm=T)
zt2$MortgTc      <-zt2$MortgT      -mean(zt2$MortgT      ,na.rm=T)
zt2$LangAPTc     <-zt2$LangAPT     -mean(zt2$LangAPT     ,na.rm=T)
zt2$LangAPWc     <-zt2$LangAPW     -mean(zt2$LangAPW     ,na.rm=T)
zt2$LangAPBc     <-zt2$LangAPB     -mean(zt2$LangAPB     ,na.rm=T)
zt2$LangAPHc     <-zt2$LangAPH     -mean(zt2$LangAPH     ,na.rm=T)
zt2$LangBPTc     <-zt2$LangBPT     -mean(zt2$LangBPT     ,na.rm=T)
zt2$LangBPWc     <-zt2$LangBPW     -mean(zt2$LangBPW     ,na.rm=T)
zt2$LangBPBc     <-zt2$LangBPB     -mean(zt2$LangBPB     ,na.rm=T)
zt2$LangBPHc     <-zt2$LangBPH     -mean(zt2$LangBPH     ,na.rm=T)
zt2$LangCPTc     <-zt2$LangCPT     -mean(zt2$LangCPT     ,na.rm=T)
zt2$OutUsTc      <-zt2$OutUsT      -mean(zt2$OutUsT      ,na.rm=T)
zt2$OutUsWc      <-zt2$OutUsW      -mean(zt2$OutUsW      ,na.rm=T)
zt2$OutUsBc      <-zt2$OutUsB      -mean(zt2$OutUsB      ,na.rm=T)
zt2$OutUsHc      <-zt2$OutUsH      -mean(zt2$OutUsH      ,na.rm=T)
zt2$FBornTc      <-zt2$FBornT      -mean(zt2$FBornT      ,na.rm=T)
zt2$FBornWc      <-zt2$FBornW      -mean(zt2$FBornW      ,na.rm=T)
zt2$FBornBc      <-zt2$FBornB      -mean(zt2$FBornB      ,na.rm=T)
zt2$FBornHc      <-zt2$FBornH      -mean(zt2$FBornH      ,na.rm=T)
zt2$NotCtzTc     <-zt2$NotCtzT     -mean(zt2$NotCtzT     ,na.rm=T)
zt2$NotCtzWc     <-zt2$NotCtzW     -mean(zt2$NotCtzW     ,na.rm=T)
zt2$NotCtzBc     <-zt2$NotCtzB     -mean(zt2$NotCtzB     ,na.rm=T)
zt2$NotCtzHc     <-zt2$NotCtzH     -mean(zt2$NotCtzH     ,na.rm=T)
zt2$MoveTc       <-zt2$MoveT       -mean(zt2$MoveT       ,na.rm=T)
zt2$MoveWc       <-zt2$MoveW       -mean(zt2$MoveW       ,na.rm=T)
zt2$MoveBc       <-zt2$MoveB       -mean(zt2$MoveB       ,na.rm=T)
zt2$MoveHc       <-zt2$MoveH       -mean(zt2$MoveH       ,na.rm=T)
zt2$VacantTc     <-zt2$VacantT     -mean(zt2$VacantT     ,na.rm=T)
zt2$OwnerTc      <-zt2$OwnerT      -mean(zt2$OwnerT      ,na.rm=T)
zt2$OwnerWc      <-zt2$OwnerW      -mean(zt2$OwnerW      ,na.rm=T)
zt2$OwnerBc      <-zt2$OwnerB      -mean(zt2$OwnerB      ,na.rm=T)
zt2$OwnerHc      <-zt2$OwnerH      -mean(zt2$OwnerH      ,na.rm=T)
zt2$CrowdTc      <-zt2$CrowdT      -mean(zt2$CrowdT      ,na.rm=T)
zt2$CrowdWc      <-zt2$CrowdW      -mean(zt2$CrowdW      ,na.rm=T)
zt2$CrowdBc      <-zt2$CrowdB      -mean(zt2$CrowdB      ,na.rm=T)
zt2$CrowdHc      <-zt2$CrowdH      -mean(zt2$CrowdH      ,na.rm=T)
zt2$MobileTc     <-zt2$MobileT     -mean(zt2$MobileT     ,na.rm=T)
zt2$MobileWc     <-zt2$MobileW     -mean(zt2$MobileW     ,na.rm=T)
zt2$MobileBc     <-zt2$MobileB     -mean(zt2$MobileB     ,na.rm=T)
zt2$MobileHc     <-zt2$MobileH     -mean(zt2$MobileH     ,na.rm=T)
zt2$DisablTc     <-zt2$DisablT     -mean(zt2$DisablT     ,na.rm=T)
zt2$DisablWc     <-zt2$DisablW     -mean(zt2$DisablW     ,na.rm=T)
zt2$DisablBc     <-zt2$DisablB     -mean(zt2$DisablB     ,na.rm=T)
zt2$DisablHc     <-zt2$DisablH     -mean(zt2$DisablH     ,na.rm=T)
zt2$DisablTCc    <-zt2$DisablTC    -mean(zt2$DisablTC    ,na.rm=T)
zt2$DisablWCc    <-zt2$DisablWC    -mean(zt2$DisablWC    ,na.rm=T)
zt2$DisablBCc    <-zt2$DisablBC    -mean(zt2$DisablBC    ,na.rm=T)
zt2$DisablHCc    <-zt2$DisablHC    -mean(zt2$DisablHC    ,na.rm=T)
zt2$DisablTMc    <-zt2$DisablTM    -mean(zt2$DisablTM    ,na.rm=T)
zt2$DisablTFc    <-zt2$DisablTF    -mean(zt2$DisablTF    ,na.rm=T)
zt2$Urban1c      <-zt2$Urban1      -mean(zt2$Urban1      ,na.rm=T)
zt2$Urban2c      <-zt2$Urban2      -mean(zt2$Urban2      ,na.rm=T)
zt2$ISBE_PFAc    <-zt2$ISBE_PFA    -mean(zt2$ISBE_PFA    ,na.rm=T)
zt2$ISBE_PFAEc   <-zt2$ISBE_PFAE   -mean(zt2$ISBE_PFAE   ,na.rm=T)
zt2$ISBE_PIc     <-zt2$ISBE_PI     -mean(zt2$ISBE_PI     ,na.rm=T)
zt2$HeadStartc   <-zt2$HeadStart   -mean(zt2$HeadStart   ,na.rm=T)
zt2$ElyHeadSc    <-zt2$ElyHeadS    -mean(zt2$ElyHeadS    ,na.rm=T)
zt2$HeadSAllc    <-zt2$HeadSAll    -mean(zt2$HeadSAll    ,na.rm=T)
zt2$PFA_HS1c     <-zt2$PFA_HS1     -mean(zt2$PFA_HS1     ,na.rm=T)
zt2$PFA_HS2c     <-zt2$PFA_HS2     -mean(zt2$PFA_HS2     ,na.rm=T)
zt2$LCCCc        <-zt2$LCCC        -mean(zt2$LCCC        ,na.rm=T)
zt2$LECCCc       <-zt2$LECCC       -mean(zt2$LECCC       ,na.rm=T)
zt2$LFCCc        <-zt2$LFCC        -mean(zt2$LFCC        ,na.rm=T)
zt2$LLECCCc      <-zt2$LLECCC      -mean(zt2$LLECCC      ,na.rm=T)
zt2$LCLFCCc      <-zt2$LCLFCC      -mean(zt2$LCLFCC      ,na.rm=T)
zt2$LCCCB1c      <-zt2$LCCCB1      -mean(zt2$LCCCB1      ,na.rm=T)
zt2$LCCCB2c      <-zt2$LCCCB2      -mean(zt2$LCCCB2      ,na.rm=T)
zt2$LCCB1c       <-zt2$LCCB1       -mean(zt2$LCCB1       ,na.rm=T)
zt2$LCCB2c       <-zt2$LCCB2       -mean(zt2$LCCB2       ,na.rm=T)
zt2$LCCCS1c      <-zt2$LCCCS1      -mean(zt2$LCCCS1      ,na.rm=T)
zt2$LCCCS2c      <-zt2$LCCCS2      -mean(zt2$LCCCS2      ,na.rm=T)
zt2$LCCS1c       <-zt2$LCCS1       -mean(zt2$LCCS1       ,na.rm=T)
zt2$LCCS2c       <-zt2$LCCS2       -mean(zt2$LCCS2       ,na.rm=T)
zt2$LCCCG1c      <-zt2$LCCCG1      -mean(zt2$LCCCG1      ,na.rm=T)
zt2$LCCCG2c      <-zt2$LCCCG2      -mean(zt2$LCCCG2      ,na.rm=T)
zt2$LCCG1c       <-zt2$LCCG1       -mean(zt2$LCCG1       ,na.rm=T)
zt2$LCCG2c       <-zt2$LCCG2       -mean(zt2$LCCG2       ,na.rm=T)
zt2$ChildCare1c  <-zt2$ChildCare1  -mean(zt2$ChildCare1  ,na.rm=T)
zt2$ChildCare2c  <-zt2$ChildCare2  -mean(zt2$ChildCare2  ,na.rm=T)
zt2$ChildCare3c  <-zt2$ChildCare3  -mean(zt2$ChildCare3  ,na.rm=T)
zt2$CCAPc        <-zt2$CCAP        -mean(zt2$CCAP        ,na.rm=T)
zt2$Homelessc    <-zt2$Homeless    -mean(zt2$Homeless    ,na.rm=T)
zt2$Homeless2c   <-zt2$Homeless2   -mean(zt2$Homeless2   ,na.rm=T)
zt2$DHS_HFIrc    <-zt2$DHS_HFIr    -mean(zt2$DHS_HFIr    ,na.rm=T)
zt2$DHS_PTSrc    <-zt2$DHS_PTSr    -mean(zt2$DHS_PTSr    ,na.rm=T)
zt2$DHS_HVPrc    <-zt2$DHS_HVPr    -mean(zt2$DHS_HVPr    ,na.rm=T)
zt2$IDHS_EIrc    <-zt2$IDHS_EIr    -mean(zt2$IDHS_EIr    ,na.rm=T)
zt2$MHV_C4c      <-zt2$MHV_C4      -mean(zt2$MHV_C4      ,na.rm=T)
zt2$MHV_P4c      <-zt2$MHV_P4      -mean(zt2$MHV_P4      ,na.rm=T)
zt2$MHV_C5c      <-zt2$MHV_C5      -mean(zt2$MHV_C5      ,na.rm=T)
zt2$MHV_P5c      <-zt2$MHV_P5      -mean(zt2$MHV_P5      ,na.rm=T)
zt2$FoodInsPc    <-zt2$FoodInsP    -mean(zt2$FoodInsP    ,na.rm=T)
zt2$FoodISc      <-zt2$FoodIS      -mean(zt2$FoodIS      ,na.rm=T)
zt2$RPovTc       <-zt2$RPovT       -mean(zt2$RPovT       ,na.rm=T)
zt2$PovTc        <-zt2$PovT        -mean(zt2$PovT        ,na.rm=T)
zt2$MHV_C4k <-zt2$MHV_C4 *10
zt2$MHV_C5k <-zt2$MHV_C5 *10
zt2$MHV_C4kc<-zt2$MHV_C4c*10
zt2$MHV_C5kc<-zt2$MHV_C5c*10





# demean - within and between variables
zt<-cbind(zt,demean(zt,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zt1<-cbind(zt1,demean(zt1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zt2<-cbind(zt2,demean(zt2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Age 0-5
# Income - Age 0-5
# Income - Age 0-5
# Income - Age 0-5
# Income - Age 0-5
# Income - Age 0-5
# Income - Age 0-5
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z1$Yearc        <-z1$Year        -mean(z1$Year        ,na.rm=T)
z1$CPopBPc      <-z1$CPopBP      -mean(z1$CPopBP      ,na.rm=T)
z1$CPopHPc      <-z1$CPopHP      -mean(z1$CPopHP      ,na.rm=T)
z1$ChildPTc     <-z1$ChildPT     -mean(z1$ChildPT     ,na.rm=T)
z1$ChildPWc     <-z1$ChildPW     -mean(z1$ChildPW     ,na.rm=T)
z1$ChildPBc     <-z1$ChildPB     -mean(z1$ChildPB     ,na.rm=T)
z1$ChildPHc     <-z1$ChildPH     -mean(z1$ChildPH     ,na.rm=T)
z1$CARatioT100c <-z1$CARatioT100 -mean(z1$CARatioT100 ,na.rm=T)
z1$CARatioW100c <-z1$CARatioW100 -mean(z1$CARatioW100 ,na.rm=T)
z1$CARatioB100c <-z1$CARatioB100 -mean(z1$CARatioB100 ,na.rm=T)
z1$CARatioH100c <-z1$CARatioH100 -mean(z1$CARatioH100 ,na.rm=T)
z1$MalePTc      <-z1$MalePT      -mean(z1$MalePT      ,na.rm=T)
z1$MalePWc      <-z1$MalePW      -mean(z1$MalePW      ,na.rm=T)
z1$MalePBc      <-z1$MalePB      -mean(z1$MalePB      ,na.rm=T)
z1$MalePHc      <-z1$MalePH      -mean(z1$MalePH      ,na.rm=T)
z1$MFRatioT100c <-z1$MFRatioT100 -mean(z1$MFRatioT100 ,na.rm=T)
z1$MFRatioW100c <-z1$MFRatioW100 -mean(z1$MFRatioW100 ,na.rm=T)
z1$MFRatioB100c <-z1$MFRatioB100 -mean(z1$MFRatioB100 ,na.rm=T)
z1$MFRatioH100c <-z1$MFRatioH100 -mean(z1$MFRatioH100 ,na.rm=T)
z1$ElderTc      <-z1$ElderT      -mean(z1$ElderT      ,na.rm=T)
z1$ElderWc      <-z1$ElderW      -mean(z1$ElderW      ,na.rm=T)
z1$ElderBc      <-z1$ElderB      -mean(z1$ElderB      ,na.rm=T)
z1$ElderHc      <-z1$ElderH      -mean(z1$ElderH      ,na.rm=T)
z1$SingleTc     <-z1$SingleT     -mean(z1$SingleT     ,na.rm=T)
z1$SingleWc     <-z1$SingleW     -mean(z1$SingleW     ,na.rm=T)
z1$SingleBc     <-z1$SingleB     -mean(z1$SingleB     ,na.rm=T)
z1$SingleHc     <-z1$SingleH     -mean(z1$SingleH     ,na.rm=T)
z1$FHeadTc      <-z1$FHeadT      -mean(z1$FHeadT      ,na.rm=T)
z1$FHeadWc      <-z1$FHeadW      -mean(z1$FHeadW      ,na.rm=T)
z1$FHeadBc      <-z1$FHeadB      -mean(z1$FHeadB      ,na.rm=T)
z1$FHeadHc      <-z1$FHeadH      -mean(z1$FHeadH      ,na.rm=T)
z1$NoHighTc     <-z1$NoHighT     -mean(z1$NoHighT     ,na.rm=T)
z1$NoHighWc     <-z1$NoHighW     -mean(z1$NoHighW     ,na.rm=T)
z1$NoHighBc     <-z1$NoHighB     -mean(z1$NoHighB     ,na.rm=T)
z1$NoHighHc     <-z1$NoHighH     -mean(z1$NoHighH     ,na.rm=T)
z1$UnempTc      <-z1$UnempT      -mean(z1$UnempT      ,na.rm=T)
z1$UnempWc      <-z1$UnempW      -mean(z1$UnempW      ,na.rm=T)
z1$UnempBc      <-z1$UnempB      -mean(z1$UnempB      ,na.rm=T)
z1$UnempHc      <-z1$UnempH      -mean(z1$UnempH      ,na.rm=T)
z1$CPovTc       <-z1$CPovT       -mean(z1$CPovT       ,na.rm=T)
z1$CPovWc       <-z1$CPovW       -mean(z1$CPovW       ,na.rm=T)
z1$CPovBc       <-z1$CPovB       -mean(z1$CPovB       ,na.rm=T)
z1$CPovHc       <-z1$CPovH       -mean(z1$CPovH       ,na.rm=T)
z1$CPov1c       <-z1$CPov1       -mean(z1$CPov1       ,na.rm=T)
z1$CPov2c       <-z1$CPov2       -mean(z1$CPov2       ,na.rm=T)
z1$CPov3c       <-z1$CPov3       -mean(z1$CPov3       ,na.rm=T)
z1$PubAsTc      <-z1$PubAsT      -mean(z1$PubAsT      ,na.rm=T)
z1$WelfarTc     <-z1$WelfarT     -mean(z1$WelfarT     ,na.rm=T)
z1$SnapTc       <-z1$SnapT       -mean(z1$SnapT       ,na.rm=T)
z1$SnapWc       <-z1$SnapW       -mean(z1$SnapW       ,na.rm=T)
z1$SnapBc       <-z1$SnapB       -mean(z1$SnapB       ,na.rm=T)
z1$SnapHc       <-z1$SnapH       -mean(z1$SnapH       ,na.rm=T)
z1$IncomeT1kc   <-z1$IncomeT1k   -mean(z1$IncomeT1k   ,na.rm=T)
z1$IncomeW1kc   <-z1$IncomeW1k   -mean(z1$IncomeW1k   ,na.rm=T)
z1$IncomeB1kc   <-z1$IncomeB1k   -mean(z1$IncomeB1k   ,na.rm=T)
z1$IncomeH1kc   <-z1$IncomeH1k   -mean(z1$IncomeH1k   ,na.rm=T)
z1$GiniT100c    <-z1$GiniT100    -mean(z1$GiniT100    ,na.rm=T)
z1$HValueT10kc  <-z1$HValueT10k  -mean(z1$HValueT10k  ,na.rm=T)
z1$MCostT100c   <-z1$MCostT100   -mean(z1$MCostT100   ,na.rm=T)
z1$OCostDT100c  <-z1$OCostDT100  -mean(z1$OCostDT100  ,na.rm=T)
z1$MRentDT100c  <-z1$MRentDT100  -mean(z1$MRentDT100  ,na.rm=T)
z1$OCostPTc     <-z1$OCostPT     -mean(z1$OCostPT     ,na.rm=T)
z1$MRentPTc     <-z1$MRentPT     -mean(z1$MRentPT     ,na.rm=T)
z1$MortgTc      <-z1$MortgT      -mean(z1$MortgT      ,na.rm=T)
z1$LangAPTc     <-z1$LangAPT     -mean(z1$LangAPT     ,na.rm=T)
z1$LangAPWc     <-z1$LangAPW     -mean(z1$LangAPW     ,na.rm=T)
z1$LangAPBc     <-z1$LangAPB     -mean(z1$LangAPB     ,na.rm=T)
z1$LangAPHc     <-z1$LangAPH     -mean(z1$LangAPH     ,na.rm=T)
z1$LangBPTc     <-z1$LangBPT     -mean(z1$LangBPT     ,na.rm=T)
z1$LangBPWc     <-z1$LangBPW     -mean(z1$LangBPW     ,na.rm=T)
z1$LangBPBc     <-z1$LangBPB     -mean(z1$LangBPB     ,na.rm=T)
z1$LangBPHc     <-z1$LangBPH     -mean(z1$LangBPH     ,na.rm=T)
z1$LangCPTc     <-z1$LangCPT     -mean(z1$LangCPT     ,na.rm=T)
z1$OutUsTc      <-z1$OutUsT      -mean(z1$OutUsT      ,na.rm=T)
z1$OutUsWc      <-z1$OutUsW      -mean(z1$OutUsW      ,na.rm=T)
z1$OutUsBc      <-z1$OutUsB      -mean(z1$OutUsB      ,na.rm=T)
z1$OutUsHc      <-z1$OutUsH      -mean(z1$OutUsH      ,na.rm=T)
z1$FBornTc      <-z1$FBornT      -mean(z1$FBornT      ,na.rm=T)
z1$FBornWc      <-z1$FBornW      -mean(z1$FBornW      ,na.rm=T)
z1$FBornBc      <-z1$FBornB      -mean(z1$FBornB      ,na.rm=T)
z1$FBornHc      <-z1$FBornH      -mean(z1$FBornH      ,na.rm=T)
z1$NotCtzTc     <-z1$NotCtzT     -mean(z1$NotCtzT     ,na.rm=T)
z1$NotCtzWc     <-z1$NotCtzW     -mean(z1$NotCtzW     ,na.rm=T)
z1$NotCtzBc     <-z1$NotCtzB     -mean(z1$NotCtzB     ,na.rm=T)
z1$NotCtzHc     <-z1$NotCtzH     -mean(z1$NotCtzH     ,na.rm=T)
z1$MoveTc       <-z1$MoveT       -mean(z1$MoveT       ,na.rm=T)
z1$MoveWc       <-z1$MoveW       -mean(z1$MoveW       ,na.rm=T)
z1$MoveBc       <-z1$MoveB       -mean(z1$MoveB       ,na.rm=T)
z1$MoveHc       <-z1$MoveH       -mean(z1$MoveH       ,na.rm=T)
z1$VacantTc     <-z1$VacantT     -mean(z1$VacantT     ,na.rm=T)
z1$OwnerTc      <-z1$OwnerT      -mean(z1$OwnerT      ,na.rm=T)
z1$OwnerWc      <-z1$OwnerW      -mean(z1$OwnerW      ,na.rm=T)
z1$OwnerBc      <-z1$OwnerB      -mean(z1$OwnerB      ,na.rm=T)
z1$OwnerHc      <-z1$OwnerH      -mean(z1$OwnerH      ,na.rm=T)
z1$CrowdTc      <-z1$CrowdT      -mean(z1$CrowdT      ,na.rm=T)
z1$CrowdWc      <-z1$CrowdW      -mean(z1$CrowdW      ,na.rm=T)
z1$CrowdBc      <-z1$CrowdB      -mean(z1$CrowdB      ,na.rm=T)
z1$CrowdHc      <-z1$CrowdH      -mean(z1$CrowdH      ,na.rm=T)
z1$MobileTc     <-z1$MobileT     -mean(z1$MobileT     ,na.rm=T)
z1$MobileWc     <-z1$MobileW     -mean(z1$MobileW     ,na.rm=T)
z1$MobileBc     <-z1$MobileB     -mean(z1$MobileB     ,na.rm=T)
z1$MobileHc     <-z1$MobileH     -mean(z1$MobileH     ,na.rm=T)
z1$DisablTc     <-z1$DisablT     -mean(z1$DisablT     ,na.rm=T)
z1$DisablWc     <-z1$DisablW     -mean(z1$DisablW     ,na.rm=T)
z1$DisablBc     <-z1$DisablB     -mean(z1$DisablB     ,na.rm=T)
z1$DisablHc     <-z1$DisablH     -mean(z1$DisablH     ,na.rm=T)
z1$DisablTCc    <-z1$DisablTC    -mean(z1$DisablTC    ,na.rm=T)
z1$DisablWCc    <-z1$DisablWC    -mean(z1$DisablWC    ,na.rm=T)
z1$DisablBCc    <-z1$DisablBC    -mean(z1$DisablBC    ,na.rm=T)
z1$DisablHCc    <-z1$DisablHC    -mean(z1$DisablHC    ,na.rm=T)
z1$DisablTMc    <-z1$DisablTM    -mean(z1$DisablTM    ,na.rm=T)
z1$DisablTFc    <-z1$DisablTF    -mean(z1$DisablTF    ,na.rm=T)
z1$Urban1c      <-z1$Urban1      -mean(z1$Urban1      ,na.rm=T)
z1$Urban2c      <-z1$Urban2      -mean(z1$Urban2      ,na.rm=T)
z1$ISBE_PFAc    <-z1$ISBE_PFA    -mean(z1$ISBE_PFA    ,na.rm=T)
z1$ISBE_PFAEc   <-z1$ISBE_PFAE   -mean(z1$ISBE_PFAE   ,na.rm=T)
z1$ISBE_PIc     <-z1$ISBE_PI     -mean(z1$ISBE_PI     ,na.rm=T)
z1$HeadStartc   <-z1$HeadStart   -mean(z1$HeadStart   ,na.rm=T)
z1$ElyHeadSc    <-z1$ElyHeadS    -mean(z1$ElyHeadS    ,na.rm=T)
z1$HeadSAllc    <-z1$HeadSAll    -mean(z1$HeadSAll    ,na.rm=T)
z1$PFA_HS1c     <-z1$PFA_HS1     -mean(z1$PFA_HS1     ,na.rm=T)
z1$PFA_HS2c     <-z1$PFA_HS2     -mean(z1$PFA_HS2     ,na.rm=T)
z1$LCCCc        <-z1$LCCC        -mean(z1$LCCC        ,na.rm=T)
z1$LECCCc       <-z1$LECCC       -mean(z1$LECCC       ,na.rm=T)
z1$LFCCc        <-z1$LFCC        -mean(z1$LFCC        ,na.rm=T)
z1$LLECCCc      <-z1$LLECCC      -mean(z1$LLECCC      ,na.rm=T)
z1$LCLFCCc      <-z1$LCLFCC      -mean(z1$LCLFCC      ,na.rm=T)
z1$LCCCB1c      <-z1$LCCCB1      -mean(z1$LCCCB1      ,na.rm=T)
z1$LCCCB2c      <-z1$LCCCB2      -mean(z1$LCCCB2      ,na.rm=T)
z1$LCCB1c       <-z1$LCCB1       -mean(z1$LCCB1       ,na.rm=T)
z1$LCCB2c       <-z1$LCCB2       -mean(z1$LCCB2       ,na.rm=T)
z1$LCCCS1c      <-z1$LCCCS1      -mean(z1$LCCCS1      ,na.rm=T)
z1$LCCCS2c      <-z1$LCCCS2      -mean(z1$LCCCS2      ,na.rm=T)
z1$LCCS1c       <-z1$LCCS1       -mean(z1$LCCS1       ,na.rm=T)
z1$LCCS2c       <-z1$LCCS2       -mean(z1$LCCS2       ,na.rm=T)
z1$LCCCG1c      <-z1$LCCCG1      -mean(z1$LCCCG1      ,na.rm=T)
z1$LCCCG2c      <-z1$LCCCG2      -mean(z1$LCCCG2      ,na.rm=T)
z1$LCCG1c       <-z1$LCCG1       -mean(z1$LCCG1       ,na.rm=T)
z1$LCCG2c       <-z1$LCCG2       -mean(z1$LCCG2       ,na.rm=T)
z1$ChildCare1c  <-z1$ChildCare1  -mean(z1$ChildCare1  ,na.rm=T)
z1$ChildCare2c  <-z1$ChildCare2  -mean(z1$ChildCare2  ,na.rm=T)
z1$ChildCare3c  <-z1$ChildCare3  -mean(z1$ChildCare3  ,na.rm=T)
z1$CCAPc        <-z1$CCAP        -mean(z1$CCAP        ,na.rm=T)
z1$Homelessc    <-z1$Homeless    -mean(z1$Homeless    ,na.rm=T)
z1$Homeless2c   <-z1$Homeless2   -mean(z1$Homeless2   ,na.rm=T)
z1$DHS_HFIrc    <-z1$DHS_HFIr    -mean(z1$DHS_HFIr    ,na.rm=T)
z1$DHS_PTSrc    <-z1$DHS_PTSr    -mean(z1$DHS_PTSr    ,na.rm=T)
z1$DHS_HVPrc    <-z1$DHS_HVPr    -mean(z1$DHS_HVPr    ,na.rm=T)
z1$IDHS_EIrc    <-z1$IDHS_EIr    -mean(z1$IDHS_EIr    ,na.rm=T)
z1$MHV_C4c      <-z1$MHV_C4      -mean(z1$MHV_C4      ,na.rm=T)
z1$MHV_P4c      <-z1$MHV_P4      -mean(z1$MHV_P4      ,na.rm=T)
z1$MHV_C5c      <-z1$MHV_C5      -mean(z1$MHV_C5      ,na.rm=T)
z1$MHV_P5c      <-z1$MHV_P5      -mean(z1$MHV_P5      ,na.rm=T)
z1$FoodInsPc    <-z1$FoodInsP    -mean(z1$FoodInsP    ,na.rm=T)
z1$FoodISc      <-z1$FoodIS      -mean(z1$FoodIS      ,na.rm=T)
z1$RPovTc       <-z1$RPovT       -mean(z1$RPovT       ,na.rm=T)
z1$PovTc        <-z1$PovT        -mean(z1$PovT        ,na.rm=T)
z1$MHV_C4k <-z1$MHV_C4 *10
z1$MHV_C5k <-z1$MHV_C5 *10
z1$MHV_C4kc<-z1$MHV_C4c*10
z1$MHV_C5kc<-z1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
z11$Yearc        <-z11$Year        -mean(z11$Year        ,na.rm=T)
z11$CPopBPc      <-z11$CPopBP      -mean(z11$CPopBP      ,na.rm=T)
z11$CPopHPc      <-z11$CPopHP      -mean(z11$CPopHP      ,na.rm=T)
z11$ChildPTc     <-z11$ChildPT     -mean(z11$ChildPT     ,na.rm=T)
z11$ChildPWc     <-z11$ChildPW     -mean(z11$ChildPW     ,na.rm=T)
z11$ChildPBc     <-z11$ChildPB     -mean(z11$ChildPB     ,na.rm=T)
z11$ChildPHc     <-z11$ChildPH     -mean(z11$ChildPH     ,na.rm=T)
z11$CARatioT100c <-z11$CARatioT100 -mean(z11$CARatioT100 ,na.rm=T)
z11$CARatioW100c <-z11$CARatioW100 -mean(z11$CARatioW100 ,na.rm=T)
z11$CARatioB100c <-z11$CARatioB100 -mean(z11$CARatioB100 ,na.rm=T)
z11$CARatioH100c <-z11$CARatioH100 -mean(z11$CARatioH100 ,na.rm=T)
z11$MalePTc      <-z11$MalePT      -mean(z11$MalePT      ,na.rm=T)
z11$MalePWc      <-z11$MalePW      -mean(z11$MalePW      ,na.rm=T)
z11$MalePBc      <-z11$MalePB      -mean(z11$MalePB      ,na.rm=T)
z11$MalePHc      <-z11$MalePH      -mean(z11$MalePH      ,na.rm=T)
z11$MFRatioT100c <-z11$MFRatioT100 -mean(z11$MFRatioT100 ,na.rm=T)
z11$MFRatioW100c <-z11$MFRatioW100 -mean(z11$MFRatioW100 ,na.rm=T)
z11$MFRatioB100c <-z11$MFRatioB100 -mean(z11$MFRatioB100 ,na.rm=T)
z11$MFRatioH100c <-z11$MFRatioH100 -mean(z11$MFRatioH100 ,na.rm=T)
z11$ElderTc      <-z11$ElderT      -mean(z11$ElderT      ,na.rm=T)
z11$ElderWc      <-z11$ElderW      -mean(z11$ElderW      ,na.rm=T)
z11$ElderBc      <-z11$ElderB      -mean(z11$ElderB      ,na.rm=T)
z11$ElderHc      <-z11$ElderH      -mean(z11$ElderH      ,na.rm=T)
z11$SingleTc     <-z11$SingleT     -mean(z11$SingleT     ,na.rm=T)
z11$SingleWc     <-z11$SingleW     -mean(z11$SingleW     ,na.rm=T)
z11$SingleBc     <-z11$SingleB     -mean(z11$SingleB     ,na.rm=T)
z11$SingleHc     <-z11$SingleH     -mean(z11$SingleH     ,na.rm=T)
z11$FHeadTc      <-z11$FHeadT      -mean(z11$FHeadT      ,na.rm=T)
z11$FHeadWc      <-z11$FHeadW      -mean(z11$FHeadW      ,na.rm=T)
z11$FHeadBc      <-z11$FHeadB      -mean(z11$FHeadB      ,na.rm=T)
z11$FHeadHc      <-z11$FHeadH      -mean(z11$FHeadH      ,na.rm=T)
z11$NoHighTc     <-z11$NoHighT     -mean(z11$NoHighT     ,na.rm=T)
z11$NoHighWc     <-z11$NoHighW     -mean(z11$NoHighW     ,na.rm=T)
z11$NoHighBc     <-z11$NoHighB     -mean(z11$NoHighB     ,na.rm=T)
z11$NoHighHc     <-z11$NoHighH     -mean(z11$NoHighH     ,na.rm=T)
z11$UnempTc      <-z11$UnempT      -mean(z11$UnempT      ,na.rm=T)
z11$UnempWc      <-z11$UnempW      -mean(z11$UnempW      ,na.rm=T)
z11$UnempBc      <-z11$UnempB      -mean(z11$UnempB      ,na.rm=T)
z11$UnempHc      <-z11$UnempH      -mean(z11$UnempH      ,na.rm=T)
z11$CPovTc       <-z11$CPovT       -mean(z11$CPovT       ,na.rm=T)
z11$CPovWc       <-z11$CPovW       -mean(z11$CPovW       ,na.rm=T)
z11$CPovBc       <-z11$CPovB       -mean(z11$CPovB       ,na.rm=T)
z11$CPovHc       <-z11$CPovH       -mean(z11$CPovH       ,na.rm=T)
z11$CPov1c       <-z11$CPov1       -mean(z11$CPov1       ,na.rm=T)
z11$CPov2c       <-z11$CPov2       -mean(z11$CPov2       ,na.rm=T)
z11$CPov3c       <-z11$CPov3       -mean(z11$CPov3       ,na.rm=T)
z11$PubAsTc      <-z11$PubAsT      -mean(z11$PubAsT      ,na.rm=T)
z11$WelfarTc     <-z11$WelfarT     -mean(z11$WelfarT     ,na.rm=T)
z11$SnapTc       <-z11$SnapT       -mean(z11$SnapT       ,na.rm=T)
z11$SnapWc       <-z11$SnapW       -mean(z11$SnapW       ,na.rm=T)
z11$SnapBc       <-z11$SnapB       -mean(z11$SnapB       ,na.rm=T)
z11$SnapHc       <-z11$SnapH       -mean(z11$SnapH       ,na.rm=T)
z11$IncomeT1kc   <-z11$IncomeT1k   -mean(z11$IncomeT1k   ,na.rm=T)
z11$IncomeW1kc   <-z11$IncomeW1k   -mean(z11$IncomeW1k   ,na.rm=T)
z11$IncomeB1kc   <-z11$IncomeB1k   -mean(z11$IncomeB1k   ,na.rm=T)
z11$IncomeH1kc   <-z11$IncomeH1k   -mean(z11$IncomeH1k   ,na.rm=T)
z11$GiniT100c    <-z11$GiniT100    -mean(z11$GiniT100    ,na.rm=T)
z11$HValueT10kc  <-z11$HValueT10k  -mean(z11$HValueT10k  ,na.rm=T)
z11$MCostT100c   <-z11$MCostT100   -mean(z11$MCostT100   ,na.rm=T)
z11$OCostDT100c  <-z11$OCostDT100  -mean(z11$OCostDT100  ,na.rm=T)
z11$MRentDT100c  <-z11$MRentDT100  -mean(z11$MRentDT100  ,na.rm=T)
z11$OCostPTc     <-z11$OCostPT     -mean(z11$OCostPT     ,na.rm=T)
z11$MRentPTc     <-z11$MRentPT     -mean(z11$MRentPT     ,na.rm=T)
z11$MortgTc      <-z11$MortgT      -mean(z11$MortgT      ,na.rm=T)
z11$LangAPTc     <-z11$LangAPT     -mean(z11$LangAPT     ,na.rm=T)
z11$LangAPWc     <-z11$LangAPW     -mean(z11$LangAPW     ,na.rm=T)
z11$LangAPBc     <-z11$LangAPB     -mean(z11$LangAPB     ,na.rm=T)
z11$LangAPHc     <-z11$LangAPH     -mean(z11$LangAPH     ,na.rm=T)
z11$LangBPTc     <-z11$LangBPT     -mean(z11$LangBPT     ,na.rm=T)
z11$LangBPWc     <-z11$LangBPW     -mean(z11$LangBPW     ,na.rm=T)
z11$LangBPBc     <-z11$LangBPB     -mean(z11$LangBPB     ,na.rm=T)
z11$LangBPHc     <-z11$LangBPH     -mean(z11$LangBPH     ,na.rm=T)
z11$LangCPTc     <-z11$LangCPT     -mean(z11$LangCPT     ,na.rm=T)
z11$OutUsTc      <-z11$OutUsT      -mean(z11$OutUsT      ,na.rm=T)
z11$OutUsWc      <-z11$OutUsW      -mean(z11$OutUsW      ,na.rm=T)
z11$OutUsBc      <-z11$OutUsB      -mean(z11$OutUsB      ,na.rm=T)
z11$OutUsHc      <-z11$OutUsH      -mean(z11$OutUsH      ,na.rm=T)
z11$FBornTc      <-z11$FBornT      -mean(z11$FBornT      ,na.rm=T)
z11$FBornWc      <-z11$FBornW      -mean(z11$FBornW      ,na.rm=T)
z11$FBornBc      <-z11$FBornB      -mean(z11$FBornB      ,na.rm=T)
z11$FBornHc      <-z11$FBornH      -mean(z11$FBornH      ,na.rm=T)
z11$NotCtzTc     <-z11$NotCtzT     -mean(z11$NotCtzT     ,na.rm=T)
z11$NotCtzWc     <-z11$NotCtzW     -mean(z11$NotCtzW     ,na.rm=T)
z11$NotCtzBc     <-z11$NotCtzB     -mean(z11$NotCtzB     ,na.rm=T)
z11$NotCtzHc     <-z11$NotCtzH     -mean(z11$NotCtzH     ,na.rm=T)
z11$MoveTc       <-z11$MoveT       -mean(z11$MoveT       ,na.rm=T)
z11$MoveWc       <-z11$MoveW       -mean(z11$MoveW       ,na.rm=T)
z11$MoveBc       <-z11$MoveB       -mean(z11$MoveB       ,na.rm=T)
z11$MoveHc       <-z11$MoveH       -mean(z11$MoveH       ,na.rm=T)
z11$VacantTc     <-z11$VacantT     -mean(z11$VacantT     ,na.rm=T)
z11$OwnerTc      <-z11$OwnerT      -mean(z11$OwnerT      ,na.rm=T)
z11$OwnerWc      <-z11$OwnerW      -mean(z11$OwnerW      ,na.rm=T)
z11$OwnerBc      <-z11$OwnerB      -mean(z11$OwnerB      ,na.rm=T)
z11$OwnerHc      <-z11$OwnerH      -mean(z11$OwnerH      ,na.rm=T)
z11$CrowdTc      <-z11$CrowdT      -mean(z11$CrowdT      ,na.rm=T)
z11$CrowdWc      <-z11$CrowdW      -mean(z11$CrowdW      ,na.rm=T)
z11$CrowdBc      <-z11$CrowdB      -mean(z11$CrowdB      ,na.rm=T)
z11$CrowdHc      <-z11$CrowdH      -mean(z11$CrowdH      ,na.rm=T)
z11$MobileTc     <-z11$MobileT     -mean(z11$MobileT     ,na.rm=T)
z11$MobileWc     <-z11$MobileW     -mean(z11$MobileW     ,na.rm=T)
z11$MobileBc     <-z11$MobileB     -mean(z11$MobileB     ,na.rm=T)
z11$MobileHc     <-z11$MobileH     -mean(z11$MobileH     ,na.rm=T)
z11$DisablTc     <-z11$DisablT     -mean(z11$DisablT     ,na.rm=T)
z11$DisablWc     <-z11$DisablW     -mean(z11$DisablW     ,na.rm=T)
z11$DisablBc     <-z11$DisablB     -mean(z11$DisablB     ,na.rm=T)
z11$DisablHc     <-z11$DisablH     -mean(z11$DisablH     ,na.rm=T)
z11$DisablTCc    <-z11$DisablTC    -mean(z11$DisablTC    ,na.rm=T)
z11$DisablWCc    <-z11$DisablWC    -mean(z11$DisablWC    ,na.rm=T)
z11$DisablBCc    <-z11$DisablBC    -mean(z11$DisablBC    ,na.rm=T)
z11$DisablHCc    <-z11$DisablHC    -mean(z11$DisablHC    ,na.rm=T)
z11$DisablTMc    <-z11$DisablTM    -mean(z11$DisablTM    ,na.rm=T)
z11$DisablTFc    <-z11$DisablTF    -mean(z11$DisablTF    ,na.rm=T)
z11$Urban1c      <-z11$Urban1      -mean(z11$Urban1      ,na.rm=T)
z11$Urban2c      <-z11$Urban2      -mean(z11$Urban2      ,na.rm=T)
z11$ISBE_PFAc    <-z11$ISBE_PFA    -mean(z11$ISBE_PFA    ,na.rm=T)
z11$ISBE_PFAEc   <-z11$ISBE_PFAE   -mean(z11$ISBE_PFAE   ,na.rm=T)
z11$ISBE_PIc     <-z11$ISBE_PI     -mean(z11$ISBE_PI     ,na.rm=T)
z11$HeadStartc   <-z11$HeadStart   -mean(z11$HeadStart   ,na.rm=T)
z11$ElyHeadSc    <-z11$ElyHeadS    -mean(z11$ElyHeadS    ,na.rm=T)
z11$HeadSAllc    <-z11$HeadSAll    -mean(z11$HeadSAll    ,na.rm=T)
z11$PFA_HS1c     <-z11$PFA_HS1     -mean(z11$PFA_HS1     ,na.rm=T)
z11$PFA_HS2c     <-z11$PFA_HS2     -mean(z11$PFA_HS2     ,na.rm=T)
z11$LCCCc        <-z11$LCCC        -mean(z11$LCCC        ,na.rm=T)
z11$LECCCc       <-z11$LECCC       -mean(z11$LECCC       ,na.rm=T)
z11$LFCCc        <-z11$LFCC        -mean(z11$LFCC        ,na.rm=T)
z11$LLECCCc      <-z11$LLECCC      -mean(z11$LLECCC      ,na.rm=T)
z11$LCLFCCc      <-z11$LCLFCC      -mean(z11$LCLFCC      ,na.rm=T)
z11$LCCCB1c      <-z11$LCCCB1      -mean(z11$LCCCB1      ,na.rm=T)
z11$LCCCB2c      <-z11$LCCCB2      -mean(z11$LCCCB2      ,na.rm=T)
z11$LCCB1c       <-z11$LCCB1       -mean(z11$LCCB1       ,na.rm=T)
z11$LCCB2c       <-z11$LCCB2       -mean(z11$LCCB2       ,na.rm=T)
z11$LCCCS1c      <-z11$LCCCS1      -mean(z11$LCCCS1      ,na.rm=T)
z11$LCCCS2c      <-z11$LCCCS2      -mean(z11$LCCCS2      ,na.rm=T)
z11$LCCS1c       <-z11$LCCS1       -mean(z11$LCCS1       ,na.rm=T)
z11$LCCS2c       <-z11$LCCS2       -mean(z11$LCCS2       ,na.rm=T)
z11$LCCCG1c      <-z11$LCCCG1      -mean(z11$LCCCG1      ,na.rm=T)
z11$LCCCG2c      <-z11$LCCCG2      -mean(z11$LCCCG2      ,na.rm=T)
z11$LCCG1c       <-z11$LCCG1       -mean(z11$LCCG1       ,na.rm=T)
z11$LCCG2c       <-z11$LCCG2       -mean(z11$LCCG2       ,na.rm=T)
z11$ChildCare1c  <-z11$ChildCare1  -mean(z11$ChildCare1  ,na.rm=T)
z11$ChildCare2c  <-z11$ChildCare2  -mean(z11$ChildCare2  ,na.rm=T)
z11$ChildCare3c  <-z11$ChildCare3  -mean(z11$ChildCare3  ,na.rm=T)
z11$CCAPc        <-z11$CCAP        -mean(z11$CCAP        ,na.rm=T)
z11$Homelessc    <-z11$Homeless    -mean(z11$Homeless    ,na.rm=T)
z11$Homeless2c   <-z11$Homeless2   -mean(z11$Homeless2   ,na.rm=T)
z11$DHS_HFIrc    <-z11$DHS_HFIr    -mean(z11$DHS_HFIr    ,na.rm=T)
z11$DHS_PTSrc    <-z11$DHS_PTSr    -mean(z11$DHS_PTSr    ,na.rm=T)
z11$DHS_HVPrc    <-z11$DHS_HVPr    -mean(z11$DHS_HVPr    ,na.rm=T)
z11$IDHS_EIrc    <-z11$IDHS_EIr    -mean(z11$IDHS_EIr    ,na.rm=T)
z11$MHV_C4c      <-z11$MHV_C4      -mean(z11$MHV_C4      ,na.rm=T)
z11$MHV_P4c      <-z11$MHV_P4      -mean(z11$MHV_P4      ,na.rm=T)
z11$MHV_C5c      <-z11$MHV_C5      -mean(z11$MHV_C5      ,na.rm=T)
z11$MHV_P5c      <-z11$MHV_P5      -mean(z11$MHV_P5      ,na.rm=T)
z11$FoodInsPc    <-z11$FoodInsP    -mean(z11$FoodInsP    ,na.rm=T)
z11$FoodISc      <-z11$FoodIS      -mean(z11$FoodIS      ,na.rm=T)
z11$RPovTc       <-z11$RPovT       -mean(z11$RPovT       ,na.rm=T)
z11$PovTc        <-z11$PovT        -mean(z11$PovT        ,na.rm=T)
z11$MHV_C4k <-z11$MHV_C4 *10
z11$MHV_C5k <-z11$MHV_C5 *10
z11$MHV_C4kc<-z11$MHV_C4c*10
z11$MHV_C5kc<-z11$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
z12$Yearc        <-z12$Year        -mean(z12$Year        ,na.rm=T)
z12$CPopBPc      <-z12$CPopBP      -mean(z12$CPopBP      ,na.rm=T)
z12$CPopHPc      <-z12$CPopHP      -mean(z12$CPopHP      ,na.rm=T)
z12$ChildPTc     <-z12$ChildPT     -mean(z12$ChildPT     ,na.rm=T)
z12$ChildPWc     <-z12$ChildPW     -mean(z12$ChildPW     ,na.rm=T)
z12$ChildPBc     <-z12$ChildPB     -mean(z12$ChildPB     ,na.rm=T)
z12$ChildPHc     <-z12$ChildPH     -mean(z12$ChildPH     ,na.rm=T)
z12$CARatioT100c <-z12$CARatioT100 -mean(z12$CARatioT100 ,na.rm=T)
z12$CARatioW100c <-z12$CARatioW100 -mean(z12$CARatioW100 ,na.rm=T)
z12$CARatioB100c <-z12$CARatioB100 -mean(z12$CARatioB100 ,na.rm=T)
z12$CARatioH100c <-z12$CARatioH100 -mean(z12$CARatioH100 ,na.rm=T)
z12$MalePTc      <-z12$MalePT      -mean(z12$MalePT      ,na.rm=T)
z12$MalePWc      <-z12$MalePW      -mean(z12$MalePW      ,na.rm=T)
z12$MalePBc      <-z12$MalePB      -mean(z12$MalePB      ,na.rm=T)
z12$MalePHc      <-z12$MalePH      -mean(z12$MalePH      ,na.rm=T)
z12$MFRatioT100c <-z12$MFRatioT100 -mean(z12$MFRatioT100 ,na.rm=T)
z12$MFRatioW100c <-z12$MFRatioW100 -mean(z12$MFRatioW100 ,na.rm=T)
z12$MFRatioB100c <-z12$MFRatioB100 -mean(z12$MFRatioB100 ,na.rm=T)
z12$MFRatioH100c <-z12$MFRatioH100 -mean(z12$MFRatioH100 ,na.rm=T)
z12$ElderTc      <-z12$ElderT      -mean(z12$ElderT      ,na.rm=T)
z12$ElderWc      <-z12$ElderW      -mean(z12$ElderW      ,na.rm=T)
z12$ElderBc      <-z12$ElderB      -mean(z12$ElderB      ,na.rm=T)
z12$ElderHc      <-z12$ElderH      -mean(z12$ElderH      ,na.rm=T)
z12$SingleTc     <-z12$SingleT     -mean(z12$SingleT     ,na.rm=T)
z12$SingleWc     <-z12$SingleW     -mean(z12$SingleW     ,na.rm=T)
z12$SingleBc     <-z12$SingleB     -mean(z12$SingleB     ,na.rm=T)
z12$SingleHc     <-z12$SingleH     -mean(z12$SingleH     ,na.rm=T)
z12$FHeadTc      <-z12$FHeadT      -mean(z12$FHeadT      ,na.rm=T)
z12$FHeadWc      <-z12$FHeadW      -mean(z12$FHeadW      ,na.rm=T)
z12$FHeadBc      <-z12$FHeadB      -mean(z12$FHeadB      ,na.rm=T)
z12$FHeadHc      <-z12$FHeadH      -mean(z12$FHeadH      ,na.rm=T)
z12$NoHighTc     <-z12$NoHighT     -mean(z12$NoHighT     ,na.rm=T)
z12$NoHighWc     <-z12$NoHighW     -mean(z12$NoHighW     ,na.rm=T)
z12$NoHighBc     <-z12$NoHighB     -mean(z12$NoHighB     ,na.rm=T)
z12$NoHighHc     <-z12$NoHighH     -mean(z12$NoHighH     ,na.rm=T)
z12$UnempTc      <-z12$UnempT      -mean(z12$UnempT      ,na.rm=T)
z12$UnempWc      <-z12$UnempW      -mean(z12$UnempW      ,na.rm=T)
z12$UnempBc      <-z12$UnempB      -mean(z12$UnempB      ,na.rm=T)
z12$UnempHc      <-z12$UnempH      -mean(z12$UnempH      ,na.rm=T)
z12$CPovTc       <-z12$CPovT       -mean(z12$CPovT       ,na.rm=T)
z12$CPovWc       <-z12$CPovW       -mean(z12$CPovW       ,na.rm=T)
z12$CPovBc       <-z12$CPovB       -mean(z12$CPovB       ,na.rm=T)
z12$CPovHc       <-z12$CPovH       -mean(z12$CPovH       ,na.rm=T)
z12$CPov1c       <-z12$CPov1       -mean(z12$CPov1       ,na.rm=T)
z12$CPov2c       <-z12$CPov2       -mean(z12$CPov2       ,na.rm=T)
z12$CPov3c       <-z12$CPov3       -mean(z12$CPov3       ,na.rm=T)
z12$PubAsTc      <-z12$PubAsT      -mean(z12$PubAsT      ,na.rm=T)
z12$WelfarTc     <-z12$WelfarT     -mean(z12$WelfarT     ,na.rm=T)
z12$SnapTc       <-z12$SnapT       -mean(z12$SnapT       ,na.rm=T)
z12$SnapWc       <-z12$SnapW       -mean(z12$SnapW       ,na.rm=T)
z12$SnapBc       <-z12$SnapB       -mean(z12$SnapB       ,na.rm=T)
z12$SnapHc       <-z12$SnapH       -mean(z12$SnapH       ,na.rm=T)
z12$IncomeT1kc   <-z12$IncomeT1k   -mean(z12$IncomeT1k   ,na.rm=T)
z12$IncomeW1kc   <-z12$IncomeW1k   -mean(z12$IncomeW1k   ,na.rm=T)
z12$IncomeB1kc   <-z12$IncomeB1k   -mean(z12$IncomeB1k   ,na.rm=T)
z12$IncomeH1kc   <-z12$IncomeH1k   -mean(z12$IncomeH1k   ,na.rm=T)
z12$GiniT100c    <-z12$GiniT100    -mean(z12$GiniT100    ,na.rm=T)
z12$HValueT10kc  <-z12$HValueT10k  -mean(z12$HValueT10k  ,na.rm=T)
z12$MCostT100c   <-z12$MCostT100   -mean(z12$MCostT100   ,na.rm=T)
z12$OCostDT100c  <-z12$OCostDT100  -mean(z12$OCostDT100  ,na.rm=T)
z12$MRentDT100c  <-z12$MRentDT100  -mean(z12$MRentDT100  ,na.rm=T)
z12$OCostPTc     <-z12$OCostPT     -mean(z12$OCostPT     ,na.rm=T)
z12$MRentPTc     <-z12$MRentPT     -mean(z12$MRentPT     ,na.rm=T)
z12$MortgTc      <-z12$MortgT      -mean(z12$MortgT      ,na.rm=T)
z12$LangAPTc     <-z12$LangAPT     -mean(z12$LangAPT     ,na.rm=T)
z12$LangAPWc     <-z12$LangAPW     -mean(z12$LangAPW     ,na.rm=T)
z12$LangAPBc     <-z12$LangAPB     -mean(z12$LangAPB     ,na.rm=T)
z12$LangAPHc     <-z12$LangAPH     -mean(z12$LangAPH     ,na.rm=T)
z12$LangBPTc     <-z12$LangBPT     -mean(z12$LangBPT     ,na.rm=T)
z12$LangBPWc     <-z12$LangBPW     -mean(z12$LangBPW     ,na.rm=T)
z12$LangBPBc     <-z12$LangBPB     -mean(z12$LangBPB     ,na.rm=T)
z12$LangBPHc     <-z12$LangBPH     -mean(z12$LangBPH     ,na.rm=T)
z12$LangCPTc     <-z12$LangCPT     -mean(z12$LangCPT     ,na.rm=T)
z12$OutUsTc      <-z12$OutUsT      -mean(z12$OutUsT      ,na.rm=T)
z12$OutUsWc      <-z12$OutUsW      -mean(z12$OutUsW      ,na.rm=T)
z12$OutUsBc      <-z12$OutUsB      -mean(z12$OutUsB      ,na.rm=T)
z12$OutUsHc      <-z12$OutUsH      -mean(z12$OutUsH      ,na.rm=T)
z12$FBornTc      <-z12$FBornT      -mean(z12$FBornT      ,na.rm=T)
z12$FBornWc      <-z12$FBornW      -mean(z12$FBornW      ,na.rm=T)
z12$FBornBc      <-z12$FBornB      -mean(z12$FBornB      ,na.rm=T)
z12$FBornHc      <-z12$FBornH      -mean(z12$FBornH      ,na.rm=T)
z12$NotCtzTc     <-z12$NotCtzT     -mean(z12$NotCtzT     ,na.rm=T)
z12$NotCtzWc     <-z12$NotCtzW     -mean(z12$NotCtzW     ,na.rm=T)
z12$NotCtzBc     <-z12$NotCtzB     -mean(z12$NotCtzB     ,na.rm=T)
z12$NotCtzHc     <-z12$NotCtzH     -mean(z12$NotCtzH     ,na.rm=T)
z12$MoveTc       <-z12$MoveT       -mean(z12$MoveT       ,na.rm=T)
z12$MoveWc       <-z12$MoveW       -mean(z12$MoveW       ,na.rm=T)
z12$MoveBc       <-z12$MoveB       -mean(z12$MoveB       ,na.rm=T)
z12$MoveHc       <-z12$MoveH       -mean(z12$MoveH       ,na.rm=T)
z12$VacantTc     <-z12$VacantT     -mean(z12$VacantT     ,na.rm=T)
z12$OwnerTc      <-z12$OwnerT      -mean(z12$OwnerT      ,na.rm=T)
z12$OwnerWc      <-z12$OwnerW      -mean(z12$OwnerW      ,na.rm=T)
z12$OwnerBc      <-z12$OwnerB      -mean(z12$OwnerB      ,na.rm=T)
z12$OwnerHc      <-z12$OwnerH      -mean(z12$OwnerH      ,na.rm=T)
z12$CrowdTc      <-z12$CrowdT      -mean(z12$CrowdT      ,na.rm=T)
z12$CrowdWc      <-z12$CrowdW      -mean(z12$CrowdW      ,na.rm=T)
z12$CrowdBc      <-z12$CrowdB      -mean(z12$CrowdB      ,na.rm=T)
z12$CrowdHc      <-z12$CrowdH      -mean(z12$CrowdH      ,na.rm=T)
z12$MobileTc     <-z12$MobileT     -mean(z12$MobileT     ,na.rm=T)
z12$MobileWc     <-z12$MobileW     -mean(z12$MobileW     ,na.rm=T)
z12$MobileBc     <-z12$MobileB     -mean(z12$MobileB     ,na.rm=T)
z12$MobileHc     <-z12$MobileH     -mean(z12$MobileH     ,na.rm=T)
z12$DisablTc     <-z12$DisablT     -mean(z12$DisablT     ,na.rm=T)
z12$DisablWc     <-z12$DisablW     -mean(z12$DisablW     ,na.rm=T)
z12$DisablBc     <-z12$DisablB     -mean(z12$DisablB     ,na.rm=T)
z12$DisablHc     <-z12$DisablH     -mean(z12$DisablH     ,na.rm=T)
z12$DisablTCc    <-z12$DisablTC    -mean(z12$DisablTC    ,na.rm=T)
z12$DisablWCc    <-z12$DisablWC    -mean(z12$DisablWC    ,na.rm=T)
z12$DisablBCc    <-z12$DisablBC    -mean(z12$DisablBC    ,na.rm=T)
z12$DisablHCc    <-z12$DisablHC    -mean(z12$DisablHC    ,na.rm=T)
z12$DisablTMc    <-z12$DisablTM    -mean(z12$DisablTM    ,na.rm=T)
z12$DisablTFc    <-z12$DisablTF    -mean(z12$DisablTF    ,na.rm=T)
z12$Urban1c      <-z12$Urban1      -mean(z12$Urban1      ,na.rm=T)
z12$Urban2c      <-z12$Urban2      -mean(z12$Urban2      ,na.rm=T)
z12$ISBE_PFAc    <-z12$ISBE_PFA    -mean(z12$ISBE_PFA    ,na.rm=T)
z12$ISBE_PFAEc   <-z12$ISBE_PFAE   -mean(z12$ISBE_PFAE   ,na.rm=T)
z12$ISBE_PIc     <-z12$ISBE_PI     -mean(z12$ISBE_PI     ,na.rm=T)
z12$HeadStartc   <-z12$HeadStart   -mean(z12$HeadStart   ,na.rm=T)
z12$ElyHeadSc    <-z12$ElyHeadS    -mean(z12$ElyHeadS    ,na.rm=T)
z12$HeadSAllc    <-z12$HeadSAll    -mean(z12$HeadSAll    ,na.rm=T)
z12$PFA_HS1c     <-z12$PFA_HS1     -mean(z12$PFA_HS1     ,na.rm=T)
z12$PFA_HS2c     <-z12$PFA_HS2     -mean(z12$PFA_HS2     ,na.rm=T)
z12$LCCCc        <-z12$LCCC        -mean(z12$LCCC        ,na.rm=T)
z12$LECCCc       <-z12$LECCC       -mean(z12$LECCC       ,na.rm=T)
z12$LFCCc        <-z12$LFCC        -mean(z12$LFCC        ,na.rm=T)
z12$LLECCCc      <-z12$LLECCC      -mean(z12$LLECCC      ,na.rm=T)
z12$LCLFCCc      <-z12$LCLFCC      -mean(z12$LCLFCC      ,na.rm=T)
z12$LCCCB1c      <-z12$LCCCB1      -mean(z12$LCCCB1      ,na.rm=T)
z12$LCCCB2c      <-z12$LCCCB2      -mean(z12$LCCCB2      ,na.rm=T)
z12$LCCB1c       <-z12$LCCB1       -mean(z12$LCCB1       ,na.rm=T)
z12$LCCB2c       <-z12$LCCB2       -mean(z12$LCCB2       ,na.rm=T)
z12$LCCCS1c      <-z12$LCCCS1      -mean(z12$LCCCS1      ,na.rm=T)
z12$LCCCS2c      <-z12$LCCCS2      -mean(z12$LCCCS2      ,na.rm=T)
z12$LCCS1c       <-z12$LCCS1       -mean(z12$LCCS1       ,na.rm=T)
z12$LCCS2c       <-z12$LCCS2       -mean(z12$LCCS2       ,na.rm=T)
z12$LCCCG1c      <-z12$LCCCG1      -mean(z12$LCCCG1      ,na.rm=T)
z12$LCCCG2c      <-z12$LCCCG2      -mean(z12$LCCCG2      ,na.rm=T)
z12$LCCG1c       <-z12$LCCG1       -mean(z12$LCCG1       ,na.rm=T)
z12$LCCG2c       <-z12$LCCG2       -mean(z12$LCCG2       ,na.rm=T)
z12$ChildCare1c  <-z12$ChildCare1  -mean(z12$ChildCare1  ,na.rm=T)
z12$ChildCare2c  <-z12$ChildCare2  -mean(z12$ChildCare2  ,na.rm=T)
z12$ChildCare3c  <-z12$ChildCare3  -mean(z12$ChildCare3  ,na.rm=T)
z12$CCAPc        <-z12$CCAP        -mean(z12$CCAP        ,na.rm=T)
z12$Homelessc    <-z12$Homeless    -mean(z12$Homeless    ,na.rm=T)
z12$Homeless2c   <-z12$Homeless2   -mean(z12$Homeless2   ,na.rm=T)
z12$DHS_HFIrc    <-z12$DHS_HFIr    -mean(z12$DHS_HFIr    ,na.rm=T)
z12$DHS_PTSrc    <-z12$DHS_PTSr    -mean(z12$DHS_PTSr    ,na.rm=T)
z12$DHS_HVPrc    <-z12$DHS_HVPr    -mean(z12$DHS_HVPr    ,na.rm=T)
z12$IDHS_EIrc    <-z12$IDHS_EIr    -mean(z12$IDHS_EIr    ,na.rm=T)
z12$MHV_C4c      <-z12$MHV_C4      -mean(z12$MHV_C4      ,na.rm=T)
z12$MHV_P4c      <-z12$MHV_P4      -mean(z12$MHV_P4      ,na.rm=T)
z12$MHV_C5c      <-z12$MHV_C5      -mean(z12$MHV_C5      ,na.rm=T)
z12$MHV_P5c      <-z12$MHV_P5      -mean(z12$MHV_P5      ,na.rm=T)
z12$FoodInsPc    <-z12$FoodInsP    -mean(z12$FoodInsP    ,na.rm=T)
z12$FoodISc      <-z12$FoodIS      -mean(z12$FoodIS      ,na.rm=T)
z12$RPovTc       <-z12$RPovT       -mean(z12$RPovT       ,na.rm=T)
z12$PovTc        <-z12$PovT        -mean(z12$PovT        ,na.rm=T)
z12$MHV_C4k <-z12$MHV_C4 *10
z12$MHV_C5k <-z12$MHV_C5 *10
z12$MHV_C4kc<-z12$MHV_C4c*10
z12$MHV_C5kc<-z12$MHV_C5c*10





# demean - within and between variables
z1<-cbind(z1,demean(z1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z11<-cbind(z11,demean(z1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z12<-cbind(z12,demean(z12,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Age 6-11
# Income - Age 6-11
# Income - Age 6-11
# Income - Age 6-11
# Income - Age 6-11
# Income - Age 6-11
# Income - Age 6-11
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z2$Yearc        <-z2$Year        -mean(z2$Year        ,na.rm=T)
z2$CPopBPc      <-z2$CPopBP      -mean(z2$CPopBP      ,na.rm=T)
z2$CPopHPc      <-z2$CPopHP      -mean(z2$CPopHP      ,na.rm=T)
z2$ChildPTc     <-z2$ChildPT     -mean(z2$ChildPT     ,na.rm=T)
z2$ChildPWc     <-z2$ChildPW     -mean(z2$ChildPW     ,na.rm=T)
z2$ChildPBc     <-z2$ChildPB     -mean(z2$ChildPB     ,na.rm=T)
z2$ChildPHc     <-z2$ChildPH     -mean(z2$ChildPH     ,na.rm=T)
z2$CARatioT100c <-z2$CARatioT100 -mean(z2$CARatioT100 ,na.rm=T)
z2$CARatioW100c <-z2$CARatioW100 -mean(z2$CARatioW100 ,na.rm=T)
z2$CARatioB100c <-z2$CARatioB100 -mean(z2$CARatioB100 ,na.rm=T)
z2$CARatioH100c <-z2$CARatioH100 -mean(z2$CARatioH100 ,na.rm=T)
z2$MalePTc      <-z2$MalePT      -mean(z2$MalePT      ,na.rm=T)
z2$MalePWc      <-z2$MalePW      -mean(z2$MalePW      ,na.rm=T)
z2$MalePBc      <-z2$MalePB      -mean(z2$MalePB      ,na.rm=T)
z2$MalePHc      <-z2$MalePH      -mean(z2$MalePH      ,na.rm=T)
z2$MFRatioT100c <-z2$MFRatioT100 -mean(z2$MFRatioT100 ,na.rm=T)
z2$MFRatioW100c <-z2$MFRatioW100 -mean(z2$MFRatioW100 ,na.rm=T)
z2$MFRatioB100c <-z2$MFRatioB100 -mean(z2$MFRatioB100 ,na.rm=T)
z2$MFRatioH100c <-z2$MFRatioH100 -mean(z2$MFRatioH100 ,na.rm=T)
z2$ElderTc      <-z2$ElderT      -mean(z2$ElderT      ,na.rm=T)
z2$ElderWc      <-z2$ElderW      -mean(z2$ElderW      ,na.rm=T)
z2$ElderBc      <-z2$ElderB      -mean(z2$ElderB      ,na.rm=T)
z2$ElderHc      <-z2$ElderH      -mean(z2$ElderH      ,na.rm=T)
z2$SingleTc     <-z2$SingleT     -mean(z2$SingleT     ,na.rm=T)
z2$SingleWc     <-z2$SingleW     -mean(z2$SingleW     ,na.rm=T)
z2$SingleBc     <-z2$SingleB     -mean(z2$SingleB     ,na.rm=T)
z2$SingleHc     <-z2$SingleH     -mean(z2$SingleH     ,na.rm=T)
z2$FHeadTc      <-z2$FHeadT      -mean(z2$FHeadT      ,na.rm=T)
z2$FHeadWc      <-z2$FHeadW      -mean(z2$FHeadW      ,na.rm=T)
z2$FHeadBc      <-z2$FHeadB      -mean(z2$FHeadB      ,na.rm=T)
z2$FHeadHc      <-z2$FHeadH      -mean(z2$FHeadH      ,na.rm=T)
z2$NoHighTc     <-z2$NoHighT     -mean(z2$NoHighT     ,na.rm=T)
z2$NoHighWc     <-z2$NoHighW     -mean(z2$NoHighW     ,na.rm=T)
z2$NoHighBc     <-z2$NoHighB     -mean(z2$NoHighB     ,na.rm=T)
z2$NoHighHc     <-z2$NoHighH     -mean(z2$NoHighH     ,na.rm=T)
z2$UnempTc      <-z2$UnempT      -mean(z2$UnempT      ,na.rm=T)
z2$UnempWc      <-z2$UnempW      -mean(z2$UnempW      ,na.rm=T)
z2$UnempBc      <-z2$UnempB      -mean(z2$UnempB      ,na.rm=T)
z2$UnempHc      <-z2$UnempH      -mean(z2$UnempH      ,na.rm=T)
z2$CPovTc       <-z2$CPovT       -mean(z2$CPovT       ,na.rm=T)
z2$CPovWc       <-z2$CPovW       -mean(z2$CPovW       ,na.rm=T)
z2$CPovBc       <-z2$CPovB       -mean(z2$CPovB       ,na.rm=T)
z2$CPovHc       <-z2$CPovH       -mean(z2$CPovH       ,na.rm=T)
z2$CPov1c       <-z2$CPov1       -mean(z2$CPov1       ,na.rm=T)
z2$CPov2c       <-z2$CPov2       -mean(z2$CPov2       ,na.rm=T)
z2$CPov3c       <-z2$CPov3       -mean(z2$CPov3       ,na.rm=T)
z2$PubAsTc      <-z2$PubAsT      -mean(z2$PubAsT      ,na.rm=T)
z2$WelfarTc     <-z2$WelfarT     -mean(z2$WelfarT     ,na.rm=T)
z2$SnapTc       <-z2$SnapT       -mean(z2$SnapT       ,na.rm=T)
z2$SnapWc       <-z2$SnapW       -mean(z2$SnapW       ,na.rm=T)
z2$SnapBc       <-z2$SnapB       -mean(z2$SnapB       ,na.rm=T)
z2$SnapHc       <-z2$SnapH       -mean(z2$SnapH       ,na.rm=T)
z2$IncomeT1kc   <-z2$IncomeT1k   -mean(z2$IncomeT1k   ,na.rm=T)
z2$IncomeW1kc   <-z2$IncomeW1k   -mean(z2$IncomeW1k   ,na.rm=T)
z2$IncomeB1kc   <-z2$IncomeB1k   -mean(z2$IncomeB1k   ,na.rm=T)
z2$IncomeH1kc   <-z2$IncomeH1k   -mean(z2$IncomeH1k   ,na.rm=T)
z2$GiniT100c    <-z2$GiniT100    -mean(z2$GiniT100    ,na.rm=T)
z2$HValueT10kc  <-z2$HValueT10k  -mean(z2$HValueT10k  ,na.rm=T)
z2$MCostT100c   <-z2$MCostT100   -mean(z2$MCostT100   ,na.rm=T)
z2$OCostDT100c  <-z2$OCostDT100  -mean(z2$OCostDT100  ,na.rm=T)
z2$MRentDT100c  <-z2$MRentDT100  -mean(z2$MRentDT100  ,na.rm=T)
z2$OCostPTc     <-z2$OCostPT     -mean(z2$OCostPT     ,na.rm=T)
z2$MRentPTc     <-z2$MRentPT     -mean(z2$MRentPT     ,na.rm=T)
z2$MortgTc      <-z2$MortgT      -mean(z2$MortgT      ,na.rm=T)
z2$LangAPTc     <-z2$LangAPT     -mean(z2$LangAPT     ,na.rm=T)
z2$LangAPWc     <-z2$LangAPW     -mean(z2$LangAPW     ,na.rm=T)
z2$LangAPBc     <-z2$LangAPB     -mean(z2$LangAPB     ,na.rm=T)
z2$LangAPHc     <-z2$LangAPH     -mean(z2$LangAPH     ,na.rm=T)
z2$LangBPTc     <-z2$LangBPT     -mean(z2$LangBPT     ,na.rm=T)
z2$LangBPWc     <-z2$LangBPW     -mean(z2$LangBPW     ,na.rm=T)
z2$LangBPBc     <-z2$LangBPB     -mean(z2$LangBPB     ,na.rm=T)
z2$LangBPHc     <-z2$LangBPH     -mean(z2$LangBPH     ,na.rm=T)
z2$LangCPTc     <-z2$LangCPT     -mean(z2$LangCPT     ,na.rm=T)
z2$OutUsTc      <-z2$OutUsT      -mean(z2$OutUsT      ,na.rm=T)
z2$OutUsWc      <-z2$OutUsW      -mean(z2$OutUsW      ,na.rm=T)
z2$OutUsBc      <-z2$OutUsB      -mean(z2$OutUsB      ,na.rm=T)
z2$OutUsHc      <-z2$OutUsH      -mean(z2$OutUsH      ,na.rm=T)
z2$FBornTc      <-z2$FBornT      -mean(z2$FBornT      ,na.rm=T)
z2$FBornWc      <-z2$FBornW      -mean(z2$FBornW      ,na.rm=T)
z2$FBornBc      <-z2$FBornB      -mean(z2$FBornB      ,na.rm=T)
z2$FBornHc      <-z2$FBornH      -mean(z2$FBornH      ,na.rm=T)
z2$NotCtzTc     <-z2$NotCtzT     -mean(z2$NotCtzT     ,na.rm=T)
z2$NotCtzWc     <-z2$NotCtzW     -mean(z2$NotCtzW     ,na.rm=T)
z2$NotCtzBc     <-z2$NotCtzB     -mean(z2$NotCtzB     ,na.rm=T)
z2$NotCtzHc     <-z2$NotCtzH     -mean(z2$NotCtzH     ,na.rm=T)
z2$MoveTc       <-z2$MoveT       -mean(z2$MoveT       ,na.rm=T)
z2$MoveWc       <-z2$MoveW       -mean(z2$MoveW       ,na.rm=T)
z2$MoveBc       <-z2$MoveB       -mean(z2$MoveB       ,na.rm=T)
z2$MoveHc       <-z2$MoveH       -mean(z2$MoveH       ,na.rm=T)
z2$VacantTc     <-z2$VacantT     -mean(z2$VacantT     ,na.rm=T)
z2$OwnerTc      <-z2$OwnerT      -mean(z2$OwnerT      ,na.rm=T)
z2$OwnerWc      <-z2$OwnerW      -mean(z2$OwnerW      ,na.rm=T)
z2$OwnerBc      <-z2$OwnerB      -mean(z2$OwnerB      ,na.rm=T)
z2$OwnerHc      <-z2$OwnerH      -mean(z2$OwnerH      ,na.rm=T)
z2$CrowdTc      <-z2$CrowdT      -mean(z2$CrowdT      ,na.rm=T)
z2$CrowdWc      <-z2$CrowdW      -mean(z2$CrowdW      ,na.rm=T)
z2$CrowdBc      <-z2$CrowdB      -mean(z2$CrowdB      ,na.rm=T)
z2$CrowdHc      <-z2$CrowdH      -mean(z2$CrowdH      ,na.rm=T)
z2$MobileTc     <-z2$MobileT     -mean(z2$MobileT     ,na.rm=T)
z2$MobileWc     <-z2$MobileW     -mean(z2$MobileW     ,na.rm=T)
z2$MobileBc     <-z2$MobileB     -mean(z2$MobileB     ,na.rm=T)
z2$MobileHc     <-z2$MobileH     -mean(z2$MobileH     ,na.rm=T)
z2$DisablTc     <-z2$DisablT     -mean(z2$DisablT     ,na.rm=T)
z2$DisablWc     <-z2$DisablW     -mean(z2$DisablW     ,na.rm=T)
z2$DisablBc     <-z2$DisablB     -mean(z2$DisablB     ,na.rm=T)
z2$DisablHc     <-z2$DisablH     -mean(z2$DisablH     ,na.rm=T)
z2$DisablTCc    <-z2$DisablTC    -mean(z2$DisablTC    ,na.rm=T)
z2$DisablWCc    <-z2$DisablWC    -mean(z2$DisablWC    ,na.rm=T)
z2$DisablBCc    <-z2$DisablBC    -mean(z2$DisablBC    ,na.rm=T)
z2$DisablHCc    <-z2$DisablHC    -mean(z2$DisablHC    ,na.rm=T)
z2$DisablTMc    <-z2$DisablTM    -mean(z2$DisablTM    ,na.rm=T)
z2$DisablTFc    <-z2$DisablTF    -mean(z2$DisablTF    ,na.rm=T)
z2$Urban1c      <-z2$Urban1      -mean(z2$Urban1      ,na.rm=T)
z2$Urban2c      <-z2$Urban2      -mean(z2$Urban2      ,na.rm=T)
z2$ISBE_PFAc    <-z2$ISBE_PFA    -mean(z2$ISBE_PFA    ,na.rm=T)
z2$ISBE_PFAEc   <-z2$ISBE_PFAE   -mean(z2$ISBE_PFAE   ,na.rm=T)
z2$ISBE_PIc     <-z2$ISBE_PI     -mean(z2$ISBE_PI     ,na.rm=T)
z2$HeadStartc   <-z2$HeadStart   -mean(z2$HeadStart   ,na.rm=T)
z2$ElyHeadSc    <-z2$ElyHeadS    -mean(z2$ElyHeadS    ,na.rm=T)
z2$HeadSAllc    <-z2$HeadSAll    -mean(z2$HeadSAll    ,na.rm=T)
z2$PFA_HS1c     <-z2$PFA_HS1     -mean(z2$PFA_HS1     ,na.rm=T)
z2$PFA_HS2c     <-z2$PFA_HS2     -mean(z2$PFA_HS2     ,na.rm=T)
z2$LCCCc        <-z2$LCCC        -mean(z2$LCCC        ,na.rm=T)
z2$LECCCc       <-z2$LECCC       -mean(z2$LECCC       ,na.rm=T)
z2$LFCCc        <-z2$LFCC        -mean(z2$LFCC        ,na.rm=T)
z2$LLECCCc      <-z2$LLECCC      -mean(z2$LLECCC      ,na.rm=T)
z2$LCLFCCc      <-z2$LCLFCC      -mean(z2$LCLFCC      ,na.rm=T)
z2$LCCCB1c      <-z2$LCCCB1      -mean(z2$LCCCB1      ,na.rm=T)
z2$LCCCB2c      <-z2$LCCCB2      -mean(z2$LCCCB2      ,na.rm=T)
z2$LCCB1c       <-z2$LCCB1       -mean(z2$LCCB1       ,na.rm=T)
z2$LCCB2c       <-z2$LCCB2       -mean(z2$LCCB2       ,na.rm=T)
z2$LCCCS1c      <-z2$LCCCS1      -mean(z2$LCCCS1      ,na.rm=T)
z2$LCCCS2c      <-z2$LCCCS2      -mean(z2$LCCCS2      ,na.rm=T)
z2$LCCS1c       <-z2$LCCS1       -mean(z2$LCCS1       ,na.rm=T)
z2$LCCS2c       <-z2$LCCS2       -mean(z2$LCCS2       ,na.rm=T)
z2$LCCCG1c      <-z2$LCCCG1      -mean(z2$LCCCG1      ,na.rm=T)
z2$LCCCG2c      <-z2$LCCCG2      -mean(z2$LCCCG2      ,na.rm=T)
z2$LCCG1c       <-z2$LCCG1       -mean(z2$LCCG1       ,na.rm=T)
z2$LCCG2c       <-z2$LCCG2       -mean(z2$LCCG2       ,na.rm=T)
z2$ChildCare1c  <-z2$ChildCare1  -mean(z2$ChildCare1  ,na.rm=T)
z2$ChildCare2c  <-z2$ChildCare2  -mean(z2$ChildCare2  ,na.rm=T)
z2$ChildCare3c  <-z2$ChildCare3  -mean(z2$ChildCare3  ,na.rm=T)
z2$CCAPc        <-z2$CCAP        -mean(z2$CCAP        ,na.rm=T)
z2$Homelessc    <-z2$Homeless    -mean(z2$Homeless    ,na.rm=T)
z2$Homeless2c   <-z2$Homeless2   -mean(z2$Homeless2   ,na.rm=T)
z2$DHS_HFIrc    <-z2$DHS_HFIr    -mean(z2$DHS_HFIr    ,na.rm=T)
z2$DHS_PTSrc    <-z2$DHS_PTSr    -mean(z2$DHS_PTSr    ,na.rm=T)
z2$DHS_HVPrc    <-z2$DHS_HVPr    -mean(z2$DHS_HVPr    ,na.rm=T)
z2$IDHS_EIrc    <-z2$IDHS_EIr    -mean(z2$IDHS_EIr    ,na.rm=T)
z2$MHV_C4c      <-z2$MHV_C4      -mean(z2$MHV_C4      ,na.rm=T)
z2$MHV_P4c      <-z2$MHV_P4      -mean(z2$MHV_P4      ,na.rm=T)
z2$MHV_C5c      <-z2$MHV_C5      -mean(z2$MHV_C5      ,na.rm=T)
z2$MHV_P5c      <-z2$MHV_P5      -mean(z2$MHV_P5      ,na.rm=T)
z2$FoodInsPc    <-z2$FoodInsP    -mean(z2$FoodInsP    ,na.rm=T)
z2$FoodISc      <-z2$FoodIS      -mean(z2$FoodIS      ,na.rm=T)
z2$RPovTc       <-z2$RPovT       -mean(z2$RPovT       ,na.rm=T)
z2$PovTc        <-z2$PovT        -mean(z2$PovT        ,na.rm=T)
z2$MHV_C4k <-z2$MHV_C4 *10
z2$MHV_C5k <-z2$MHV_C5 *10
z2$MHV_C4kc<-z2$MHV_C4c*10
z2$MHV_C5kc<-z2$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
z21$Yearc        <-z21$Year        -mean(z21$Year        ,na.rm=T)
z21$CPopBPc      <-z21$CPopBP      -mean(z21$CPopBP      ,na.rm=T)
z21$CPopHPc      <-z21$CPopHP      -mean(z21$CPopHP      ,na.rm=T)
z21$ChildPTc     <-z21$ChildPT     -mean(z21$ChildPT     ,na.rm=T)
z21$ChildPWc     <-z21$ChildPW     -mean(z21$ChildPW     ,na.rm=T)
z21$ChildPBc     <-z21$ChildPB     -mean(z21$ChildPB     ,na.rm=T)
z21$ChildPHc     <-z21$ChildPH     -mean(z21$ChildPH     ,na.rm=T)
z21$CARatioT100c <-z21$CARatioT100 -mean(z21$CARatioT100 ,na.rm=T)
z21$CARatioW100c <-z21$CARatioW100 -mean(z21$CARatioW100 ,na.rm=T)
z21$CARatioB100c <-z21$CARatioB100 -mean(z21$CARatioB100 ,na.rm=T)
z21$CARatioH100c <-z21$CARatioH100 -mean(z21$CARatioH100 ,na.rm=T)
z21$MalePTc      <-z21$MalePT      -mean(z21$MalePT      ,na.rm=T)
z21$MalePWc      <-z21$MalePW      -mean(z21$MalePW      ,na.rm=T)
z21$MalePBc      <-z21$MalePB      -mean(z21$MalePB      ,na.rm=T)
z21$MalePHc      <-z21$MalePH      -mean(z21$MalePH      ,na.rm=T)
z21$MFRatioT100c <-z21$MFRatioT100 -mean(z21$MFRatioT100 ,na.rm=T)
z21$MFRatioW100c <-z21$MFRatioW100 -mean(z21$MFRatioW100 ,na.rm=T)
z21$MFRatioB100c <-z21$MFRatioB100 -mean(z21$MFRatioB100 ,na.rm=T)
z21$MFRatioH100c <-z21$MFRatioH100 -mean(z21$MFRatioH100 ,na.rm=T)
z21$ElderTc      <-z21$ElderT      -mean(z21$ElderT      ,na.rm=T)
z21$ElderWc      <-z21$ElderW      -mean(z21$ElderW      ,na.rm=T)
z21$ElderBc      <-z21$ElderB      -mean(z21$ElderB      ,na.rm=T)
z21$ElderHc      <-z21$ElderH      -mean(z21$ElderH      ,na.rm=T)
z21$SingleTc     <-z21$SingleT     -mean(z21$SingleT     ,na.rm=T)
z21$SingleWc     <-z21$SingleW     -mean(z21$SingleW     ,na.rm=T)
z21$SingleBc     <-z21$SingleB     -mean(z21$SingleB     ,na.rm=T)
z21$SingleHc     <-z21$SingleH     -mean(z21$SingleH     ,na.rm=T)
z21$FHeadTc      <-z21$FHeadT      -mean(z21$FHeadT      ,na.rm=T)
z21$FHeadWc      <-z21$FHeadW      -mean(z21$FHeadW      ,na.rm=T)
z21$FHeadBc      <-z21$FHeadB      -mean(z21$FHeadB      ,na.rm=T)
z21$FHeadHc      <-z21$FHeadH      -mean(z21$FHeadH      ,na.rm=T)
z21$NoHighTc     <-z21$NoHighT     -mean(z21$NoHighT     ,na.rm=T)
z21$NoHighWc     <-z21$NoHighW     -mean(z21$NoHighW     ,na.rm=T)
z21$NoHighBc     <-z21$NoHighB     -mean(z21$NoHighB     ,na.rm=T)
z21$NoHighHc     <-z21$NoHighH     -mean(z21$NoHighH     ,na.rm=T)
z21$UnempTc      <-z21$UnempT      -mean(z21$UnempT      ,na.rm=T)
z21$UnempWc      <-z21$UnempW      -mean(z21$UnempW      ,na.rm=T)
z21$UnempBc      <-z21$UnempB      -mean(z21$UnempB      ,na.rm=T)
z21$UnempHc      <-z21$UnempH      -mean(z21$UnempH      ,na.rm=T)
z21$CPovTc       <-z21$CPovT       -mean(z21$CPovT       ,na.rm=T)
z21$CPovWc       <-z21$CPovW       -mean(z21$CPovW       ,na.rm=T)
z21$CPovBc       <-z21$CPovB       -mean(z21$CPovB       ,na.rm=T)
z21$CPovHc       <-z21$CPovH       -mean(z21$CPovH       ,na.rm=T)
z21$CPov1c       <-z21$CPov1       -mean(z21$CPov1       ,na.rm=T)
z21$CPov2c       <-z21$CPov2       -mean(z21$CPov2       ,na.rm=T)
z21$CPov3c       <-z21$CPov3       -mean(z21$CPov3       ,na.rm=T)
z21$PubAsTc      <-z21$PubAsT      -mean(z21$PubAsT      ,na.rm=T)
z21$WelfarTc     <-z21$WelfarT     -mean(z21$WelfarT     ,na.rm=T)
z21$SnapTc       <-z21$SnapT       -mean(z21$SnapT       ,na.rm=T)
z21$SnapWc       <-z21$SnapW       -mean(z21$SnapW       ,na.rm=T)
z21$SnapBc       <-z21$SnapB       -mean(z21$SnapB       ,na.rm=T)
z21$SnapHc       <-z21$SnapH       -mean(z21$SnapH       ,na.rm=T)
z21$IncomeT1kc   <-z21$IncomeT1k   -mean(z21$IncomeT1k   ,na.rm=T)
z21$IncomeW1kc   <-z21$IncomeW1k   -mean(z21$IncomeW1k   ,na.rm=T)
z21$IncomeB1kc   <-z21$IncomeB1k   -mean(z21$IncomeB1k   ,na.rm=T)
z21$IncomeH1kc   <-z21$IncomeH1k   -mean(z21$IncomeH1k   ,na.rm=T)
z21$GiniT100c    <-z21$GiniT100    -mean(z21$GiniT100    ,na.rm=T)
z21$HValueT10kc  <-z21$HValueT10k  -mean(z21$HValueT10k  ,na.rm=T)
z21$MCostT100c   <-z21$MCostT100   -mean(z21$MCostT100   ,na.rm=T)
z21$OCostDT100c  <-z21$OCostDT100  -mean(z21$OCostDT100  ,na.rm=T)
z21$MRentDT100c  <-z21$MRentDT100  -mean(z21$MRentDT100  ,na.rm=T)
z21$OCostPTc     <-z21$OCostPT     -mean(z21$OCostPT     ,na.rm=T)
z21$MRentPTc     <-z21$MRentPT     -mean(z21$MRentPT     ,na.rm=T)
z21$MortgTc      <-z21$MortgT      -mean(z21$MortgT      ,na.rm=T)
z21$LangAPTc     <-z21$LangAPT     -mean(z21$LangAPT     ,na.rm=T)
z21$LangAPWc     <-z21$LangAPW     -mean(z21$LangAPW     ,na.rm=T)
z21$LangAPBc     <-z21$LangAPB     -mean(z21$LangAPB     ,na.rm=T)
z21$LangAPHc     <-z21$LangAPH     -mean(z21$LangAPH     ,na.rm=T)
z21$LangBPTc     <-z21$LangBPT     -mean(z21$LangBPT     ,na.rm=T)
z21$LangBPWc     <-z21$LangBPW     -mean(z21$LangBPW     ,na.rm=T)
z21$LangBPBc     <-z21$LangBPB     -mean(z21$LangBPB     ,na.rm=T)
z21$LangBPHc     <-z21$LangBPH     -mean(z21$LangBPH     ,na.rm=T)
z21$LangCPTc     <-z21$LangCPT     -mean(z21$LangCPT     ,na.rm=T)
z21$OutUsTc      <-z21$OutUsT      -mean(z21$OutUsT      ,na.rm=T)
z21$OutUsWc      <-z21$OutUsW      -mean(z21$OutUsW      ,na.rm=T)
z21$OutUsBc      <-z21$OutUsB      -mean(z21$OutUsB      ,na.rm=T)
z21$OutUsHc      <-z21$OutUsH      -mean(z21$OutUsH      ,na.rm=T)
z21$FBornTc      <-z21$FBornT      -mean(z21$FBornT      ,na.rm=T)
z21$FBornWc      <-z21$FBornW      -mean(z21$FBornW      ,na.rm=T)
z21$FBornBc      <-z21$FBornB      -mean(z21$FBornB      ,na.rm=T)
z21$FBornHc      <-z21$FBornH      -mean(z21$FBornH      ,na.rm=T)
z21$NotCtzTc     <-z21$NotCtzT     -mean(z21$NotCtzT     ,na.rm=T)
z21$NotCtzWc     <-z21$NotCtzW     -mean(z21$NotCtzW     ,na.rm=T)
z21$NotCtzBc     <-z21$NotCtzB     -mean(z21$NotCtzB     ,na.rm=T)
z21$NotCtzHc     <-z21$NotCtzH     -mean(z21$NotCtzH     ,na.rm=T)
z21$MoveTc       <-z21$MoveT       -mean(z21$MoveT       ,na.rm=T)
z21$MoveWc       <-z21$MoveW       -mean(z21$MoveW       ,na.rm=T)
z21$MoveBc       <-z21$MoveB       -mean(z21$MoveB       ,na.rm=T)
z21$MoveHc       <-z21$MoveH       -mean(z21$MoveH       ,na.rm=T)
z21$VacantTc     <-z21$VacantT     -mean(z21$VacantT     ,na.rm=T)
z21$OwnerTc      <-z21$OwnerT      -mean(z21$OwnerT      ,na.rm=T)
z21$OwnerWc      <-z21$OwnerW      -mean(z21$OwnerW      ,na.rm=T)
z21$OwnerBc      <-z21$OwnerB      -mean(z21$OwnerB      ,na.rm=T)
z21$OwnerHc      <-z21$OwnerH      -mean(z21$OwnerH      ,na.rm=T)
z21$CrowdTc      <-z21$CrowdT      -mean(z21$CrowdT      ,na.rm=T)
z21$CrowdWc      <-z21$CrowdW      -mean(z21$CrowdW      ,na.rm=T)
z21$CrowdBc      <-z21$CrowdB      -mean(z21$CrowdB      ,na.rm=T)
z21$CrowdHc      <-z21$CrowdH      -mean(z21$CrowdH      ,na.rm=T)
z21$MobileTc     <-z21$MobileT     -mean(z21$MobileT     ,na.rm=T)
z21$MobileWc     <-z21$MobileW     -mean(z21$MobileW     ,na.rm=T)
z21$MobileBc     <-z21$MobileB     -mean(z21$MobileB     ,na.rm=T)
z21$MobileHc     <-z21$MobileH     -mean(z21$MobileH     ,na.rm=T)
z21$DisablTc     <-z21$DisablT     -mean(z21$DisablT     ,na.rm=T)
z21$DisablWc     <-z21$DisablW     -mean(z21$DisablW     ,na.rm=T)
z21$DisablBc     <-z21$DisablB     -mean(z21$DisablB     ,na.rm=T)
z21$DisablHc     <-z21$DisablH     -mean(z21$DisablH     ,na.rm=T)
z21$DisablTCc    <-z21$DisablTC    -mean(z21$DisablTC    ,na.rm=T)
z21$DisablWCc    <-z21$DisablWC    -mean(z21$DisablWC    ,na.rm=T)
z21$DisablBCc    <-z21$DisablBC    -mean(z21$DisablBC    ,na.rm=T)
z21$DisablHCc    <-z21$DisablHC    -mean(z21$DisablHC    ,na.rm=T)
z21$DisablTMc    <-z21$DisablTM    -mean(z21$DisablTM    ,na.rm=T)
z21$DisablTFc    <-z21$DisablTF    -mean(z21$DisablTF    ,na.rm=T)
z21$Urban1c      <-z21$Urban1      -mean(z21$Urban1      ,na.rm=T)
z21$Urban2c      <-z21$Urban2      -mean(z21$Urban2      ,na.rm=T)
z21$ISBE_PFAc    <-z21$ISBE_PFA    -mean(z21$ISBE_PFA    ,na.rm=T)
z21$ISBE_PFAEc   <-z21$ISBE_PFAE   -mean(z21$ISBE_PFAE   ,na.rm=T)
z21$ISBE_PIc     <-z21$ISBE_PI     -mean(z21$ISBE_PI     ,na.rm=T)
z21$HeadStartc   <-z21$HeadStart   -mean(z21$HeadStart   ,na.rm=T)
z21$ElyHeadSc    <-z21$ElyHeadS    -mean(z21$ElyHeadS    ,na.rm=T)
z21$HeadSAllc    <-z21$HeadSAll    -mean(z21$HeadSAll    ,na.rm=T)
z21$PFA_HS1c     <-z21$PFA_HS1     -mean(z21$PFA_HS1     ,na.rm=T)
z21$PFA_HS2c     <-z21$PFA_HS2     -mean(z21$PFA_HS2     ,na.rm=T)
z21$LCCCc        <-z21$LCCC        -mean(z21$LCCC        ,na.rm=T)
z21$LECCCc       <-z21$LECCC       -mean(z21$LECCC       ,na.rm=T)
z21$LFCCc        <-z21$LFCC        -mean(z21$LFCC        ,na.rm=T)
z21$LLECCCc      <-z21$LLECCC      -mean(z21$LLECCC      ,na.rm=T)
z21$LCLFCCc      <-z21$LCLFCC      -mean(z21$LCLFCC      ,na.rm=T)
z21$LCCCB1c      <-z21$LCCCB1      -mean(z21$LCCCB1      ,na.rm=T)
z21$LCCCB2c      <-z21$LCCCB2      -mean(z21$LCCCB2      ,na.rm=T)
z21$LCCB1c       <-z21$LCCB1       -mean(z21$LCCB1       ,na.rm=T)
z21$LCCB2c       <-z21$LCCB2       -mean(z21$LCCB2       ,na.rm=T)
z21$LCCCS1c      <-z21$LCCCS1      -mean(z21$LCCCS1      ,na.rm=T)
z21$LCCCS2c      <-z21$LCCCS2      -mean(z21$LCCCS2      ,na.rm=T)
z21$LCCS1c       <-z21$LCCS1       -mean(z21$LCCS1       ,na.rm=T)
z21$LCCS2c       <-z21$LCCS2       -mean(z21$LCCS2       ,na.rm=T)
z21$LCCCG1c      <-z21$LCCCG1      -mean(z21$LCCCG1      ,na.rm=T)
z21$LCCCG2c      <-z21$LCCCG2      -mean(z21$LCCCG2      ,na.rm=T)
z21$LCCG1c       <-z21$LCCG1       -mean(z21$LCCG1       ,na.rm=T)
z21$LCCG2c       <-z21$LCCG2       -mean(z21$LCCG2       ,na.rm=T)
z21$ChildCare1c  <-z21$ChildCare1  -mean(z21$ChildCare1  ,na.rm=T)
z21$ChildCare2c  <-z21$ChildCare2  -mean(z21$ChildCare2  ,na.rm=T)
z21$ChildCare3c  <-z21$ChildCare3  -mean(z21$ChildCare3  ,na.rm=T)
z21$CCAPc        <-z21$CCAP        -mean(z21$CCAP        ,na.rm=T)
z21$Homelessc    <-z21$Homeless    -mean(z21$Homeless    ,na.rm=T)
z21$Homeless2c   <-z21$Homeless2   -mean(z21$Homeless2   ,na.rm=T)
z21$DHS_HFIrc    <-z21$DHS_HFIr    -mean(z21$DHS_HFIr    ,na.rm=T)
z21$DHS_PTSrc    <-z21$DHS_PTSr    -mean(z21$DHS_PTSr    ,na.rm=T)
z21$DHS_HVPrc    <-z21$DHS_HVPr    -mean(z21$DHS_HVPr    ,na.rm=T)
z21$IDHS_EIrc    <-z21$IDHS_EIr    -mean(z21$IDHS_EIr    ,na.rm=T)
z21$MHV_C4c      <-z21$MHV_C4      -mean(z21$MHV_C4      ,na.rm=T)
z21$MHV_P4c      <-z21$MHV_P4      -mean(z21$MHV_P4      ,na.rm=T)
z21$MHV_C5c      <-z21$MHV_C5      -mean(z21$MHV_C5      ,na.rm=T)
z21$MHV_P5c      <-z21$MHV_P5      -mean(z21$MHV_P5      ,na.rm=T)
z21$FoodInsPc    <-z21$FoodInsP    -mean(z21$FoodInsP    ,na.rm=T)
z21$FoodISc      <-z21$FoodIS      -mean(z21$FoodIS      ,na.rm=T)
z21$RPovTc       <-z21$RPovT       -mean(z21$RPovT       ,na.rm=T)
z21$PovTc        <-z21$PovT        -mean(z21$PovT        ,na.rm=T)
z21$MHV_C4k <-z21$MHV_C4 *10
z21$MHV_C5k <-z21$MHV_C5 *10
z21$MHV_C4kc<-z21$MHV_C4c*10
z21$MHV_C5kc<-z21$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
z22$Yearc        <-z22$Year        -mean(z22$Year        ,na.rm=T)
z22$CPopBPc      <-z22$CPopBP      -mean(z22$CPopBP      ,na.rm=T)
z22$CPopHPc      <-z22$CPopHP      -mean(z22$CPopHP      ,na.rm=T)
z22$ChildPTc     <-z22$ChildPT     -mean(z22$ChildPT     ,na.rm=T)
z22$ChildPWc     <-z22$ChildPW     -mean(z22$ChildPW     ,na.rm=T)
z22$ChildPBc     <-z22$ChildPB     -mean(z22$ChildPB     ,na.rm=T)
z22$ChildPHc     <-z22$ChildPH     -mean(z22$ChildPH     ,na.rm=T)
z22$CARatioT100c <-z22$CARatioT100 -mean(z22$CARatioT100 ,na.rm=T)
z22$CARatioW100c <-z22$CARatioW100 -mean(z22$CARatioW100 ,na.rm=T)
z22$CARatioB100c <-z22$CARatioB100 -mean(z22$CARatioB100 ,na.rm=T)
z22$CARatioH100c <-z22$CARatioH100 -mean(z22$CARatioH100 ,na.rm=T)
z22$MalePTc      <-z22$MalePT      -mean(z22$MalePT      ,na.rm=T)
z22$MalePWc      <-z22$MalePW      -mean(z22$MalePW      ,na.rm=T)
z22$MalePBc      <-z22$MalePB      -mean(z22$MalePB      ,na.rm=T)
z22$MalePHc      <-z22$MalePH      -mean(z22$MalePH      ,na.rm=T)
z22$MFRatioT100c <-z22$MFRatioT100 -mean(z22$MFRatioT100 ,na.rm=T)
z22$MFRatioW100c <-z22$MFRatioW100 -mean(z22$MFRatioW100 ,na.rm=T)
z22$MFRatioB100c <-z22$MFRatioB100 -mean(z22$MFRatioB100 ,na.rm=T)
z22$MFRatioH100c <-z22$MFRatioH100 -mean(z22$MFRatioH100 ,na.rm=T)
z22$ElderTc      <-z22$ElderT      -mean(z22$ElderT      ,na.rm=T)
z22$ElderWc      <-z22$ElderW      -mean(z22$ElderW      ,na.rm=T)
z22$ElderBc      <-z22$ElderB      -mean(z22$ElderB      ,na.rm=T)
z22$ElderHc      <-z22$ElderH      -mean(z22$ElderH      ,na.rm=T)
z22$SingleTc     <-z22$SingleT     -mean(z22$SingleT     ,na.rm=T)
z22$SingleWc     <-z22$SingleW     -mean(z22$SingleW     ,na.rm=T)
z22$SingleBc     <-z22$SingleB     -mean(z22$SingleB     ,na.rm=T)
z22$SingleHc     <-z22$SingleH     -mean(z22$SingleH     ,na.rm=T)
z22$FHeadTc      <-z22$FHeadT      -mean(z22$FHeadT      ,na.rm=T)
z22$FHeadWc      <-z22$FHeadW      -mean(z22$FHeadW      ,na.rm=T)
z22$FHeadBc      <-z22$FHeadB      -mean(z22$FHeadB      ,na.rm=T)
z22$FHeadHc      <-z22$FHeadH      -mean(z22$FHeadH      ,na.rm=T)
z22$NoHighTc     <-z22$NoHighT     -mean(z22$NoHighT     ,na.rm=T)
z22$NoHighWc     <-z22$NoHighW     -mean(z22$NoHighW     ,na.rm=T)
z22$NoHighBc     <-z22$NoHighB     -mean(z22$NoHighB     ,na.rm=T)
z22$NoHighHc     <-z22$NoHighH     -mean(z22$NoHighH     ,na.rm=T)
z22$UnempTc      <-z22$UnempT      -mean(z22$UnempT      ,na.rm=T)
z22$UnempWc      <-z22$UnempW      -mean(z22$UnempW      ,na.rm=T)
z22$UnempBc      <-z22$UnempB      -mean(z22$UnempB      ,na.rm=T)
z22$UnempHc      <-z22$UnempH      -mean(z22$UnempH      ,na.rm=T)
z22$CPovTc       <-z22$CPovT       -mean(z22$CPovT       ,na.rm=T)
z22$CPovWc       <-z22$CPovW       -mean(z22$CPovW       ,na.rm=T)
z22$CPovBc       <-z22$CPovB       -mean(z22$CPovB       ,na.rm=T)
z22$CPovHc       <-z22$CPovH       -mean(z22$CPovH       ,na.rm=T)
z22$CPov1c       <-z22$CPov1       -mean(z22$CPov1       ,na.rm=T)
z22$CPov2c       <-z22$CPov2       -mean(z22$CPov2       ,na.rm=T)
z22$CPov3c       <-z22$CPov3       -mean(z22$CPov3       ,na.rm=T)
z22$PubAsTc      <-z22$PubAsT      -mean(z22$PubAsT      ,na.rm=T)
z22$WelfarTc     <-z22$WelfarT     -mean(z22$WelfarT     ,na.rm=T)
z22$SnapTc       <-z22$SnapT       -mean(z22$SnapT       ,na.rm=T)
z22$SnapWc       <-z22$SnapW       -mean(z22$SnapW       ,na.rm=T)
z22$SnapBc       <-z22$SnapB       -mean(z22$SnapB       ,na.rm=T)
z22$SnapHc       <-z22$SnapH       -mean(z22$SnapH       ,na.rm=T)
z22$IncomeT1kc   <-z22$IncomeT1k   -mean(z22$IncomeT1k   ,na.rm=T)
z22$IncomeW1kc   <-z22$IncomeW1k   -mean(z22$IncomeW1k   ,na.rm=T)
z22$IncomeB1kc   <-z22$IncomeB1k   -mean(z22$IncomeB1k   ,na.rm=T)
z22$IncomeH1kc   <-z22$IncomeH1k   -mean(z22$IncomeH1k   ,na.rm=T)
z22$GiniT100c    <-z22$GiniT100    -mean(z22$GiniT100    ,na.rm=T)
z22$HValueT10kc  <-z22$HValueT10k  -mean(z22$HValueT10k  ,na.rm=T)
z22$MCostT100c   <-z22$MCostT100   -mean(z22$MCostT100   ,na.rm=T)
z22$OCostDT100c  <-z22$OCostDT100  -mean(z22$OCostDT100  ,na.rm=T)
z22$MRentDT100c  <-z22$MRentDT100  -mean(z22$MRentDT100  ,na.rm=T)
z22$OCostPTc     <-z22$OCostPT     -mean(z22$OCostPT     ,na.rm=T)
z22$MRentPTc     <-z22$MRentPT     -mean(z22$MRentPT     ,na.rm=T)
z22$MortgTc      <-z22$MortgT      -mean(z22$MortgT      ,na.rm=T)
z22$LangAPTc     <-z22$LangAPT     -mean(z22$LangAPT     ,na.rm=T)
z22$LangAPWc     <-z22$LangAPW     -mean(z22$LangAPW     ,na.rm=T)
z22$LangAPBc     <-z22$LangAPB     -mean(z22$LangAPB     ,na.rm=T)
z22$LangAPHc     <-z22$LangAPH     -mean(z22$LangAPH     ,na.rm=T)
z22$LangBPTc     <-z22$LangBPT     -mean(z22$LangBPT     ,na.rm=T)
z22$LangBPWc     <-z22$LangBPW     -mean(z22$LangBPW     ,na.rm=T)
z22$LangBPBc     <-z22$LangBPB     -mean(z22$LangBPB     ,na.rm=T)
z22$LangBPHc     <-z22$LangBPH     -mean(z22$LangBPH     ,na.rm=T)
z22$LangCPTc     <-z22$LangCPT     -mean(z22$LangCPT     ,na.rm=T)
z22$OutUsTc      <-z22$OutUsT      -mean(z22$OutUsT      ,na.rm=T)
z22$OutUsWc      <-z22$OutUsW      -mean(z22$OutUsW      ,na.rm=T)
z22$OutUsBc      <-z22$OutUsB      -mean(z22$OutUsB      ,na.rm=T)
z22$OutUsHc      <-z22$OutUsH      -mean(z22$OutUsH      ,na.rm=T)
z22$FBornTc      <-z22$FBornT      -mean(z22$FBornT      ,na.rm=T)
z22$FBornWc      <-z22$FBornW      -mean(z22$FBornW      ,na.rm=T)
z22$FBornBc      <-z22$FBornB      -mean(z22$FBornB      ,na.rm=T)
z22$FBornHc      <-z22$FBornH      -mean(z22$FBornH      ,na.rm=T)
z22$NotCtzTc     <-z22$NotCtzT     -mean(z22$NotCtzT     ,na.rm=T)
z22$NotCtzWc     <-z22$NotCtzW     -mean(z22$NotCtzW     ,na.rm=T)
z22$NotCtzBc     <-z22$NotCtzB     -mean(z22$NotCtzB     ,na.rm=T)
z22$NotCtzHc     <-z22$NotCtzH     -mean(z22$NotCtzH     ,na.rm=T)
z22$MoveTc       <-z22$MoveT       -mean(z22$MoveT       ,na.rm=T)
z22$MoveWc       <-z22$MoveW       -mean(z22$MoveW       ,na.rm=T)
z22$MoveBc       <-z22$MoveB       -mean(z22$MoveB       ,na.rm=T)
z22$MoveHc       <-z22$MoveH       -mean(z22$MoveH       ,na.rm=T)
z22$VacantTc     <-z22$VacantT     -mean(z22$VacantT     ,na.rm=T)
z22$OwnerTc      <-z22$OwnerT      -mean(z22$OwnerT      ,na.rm=T)
z22$OwnerWc      <-z22$OwnerW      -mean(z22$OwnerW      ,na.rm=T)
z22$OwnerBc      <-z22$OwnerB      -mean(z22$OwnerB      ,na.rm=T)
z22$OwnerHc      <-z22$OwnerH      -mean(z22$OwnerH      ,na.rm=T)
z22$CrowdTc      <-z22$CrowdT      -mean(z22$CrowdT      ,na.rm=T)
z22$CrowdWc      <-z22$CrowdW      -mean(z22$CrowdW      ,na.rm=T)
z22$CrowdBc      <-z22$CrowdB      -mean(z22$CrowdB      ,na.rm=T)
z22$CrowdHc      <-z22$CrowdH      -mean(z22$CrowdH      ,na.rm=T)
z22$MobileTc     <-z22$MobileT     -mean(z22$MobileT     ,na.rm=T)
z22$MobileWc     <-z22$MobileW     -mean(z22$MobileW     ,na.rm=T)
z22$MobileBc     <-z22$MobileB     -mean(z22$MobileB     ,na.rm=T)
z22$MobileHc     <-z22$MobileH     -mean(z22$MobileH     ,na.rm=T)
z22$DisablTc     <-z22$DisablT     -mean(z22$DisablT     ,na.rm=T)
z22$DisablWc     <-z22$DisablW     -mean(z22$DisablW     ,na.rm=T)
z22$DisablBc     <-z22$DisablB     -mean(z22$DisablB     ,na.rm=T)
z22$DisablHc     <-z22$DisablH     -mean(z22$DisablH     ,na.rm=T)
z22$DisablTCc    <-z22$DisablTC    -mean(z22$DisablTC    ,na.rm=T)
z22$DisablWCc    <-z22$DisablWC    -mean(z22$DisablWC    ,na.rm=T)
z22$DisablBCc    <-z22$DisablBC    -mean(z22$DisablBC    ,na.rm=T)
z22$DisablHCc    <-z22$DisablHC    -mean(z22$DisablHC    ,na.rm=T)
z22$DisablTMc    <-z22$DisablTM    -mean(z22$DisablTM    ,na.rm=T)
z22$DisablTFc    <-z22$DisablTF    -mean(z22$DisablTF    ,na.rm=T)
z22$Urban1c      <-z22$Urban1      -mean(z22$Urban1      ,na.rm=T)
z22$Urban2c      <-z22$Urban2      -mean(z22$Urban2      ,na.rm=T)
z22$ISBE_PFAc    <-z22$ISBE_PFA    -mean(z22$ISBE_PFA    ,na.rm=T)
z22$ISBE_PFAEc   <-z22$ISBE_PFAE   -mean(z22$ISBE_PFAE   ,na.rm=T)
z22$ISBE_PIc     <-z22$ISBE_PI     -mean(z22$ISBE_PI     ,na.rm=T)
z22$HeadStartc   <-z22$HeadStart   -mean(z22$HeadStart   ,na.rm=T)
z22$ElyHeadSc    <-z22$ElyHeadS    -mean(z22$ElyHeadS    ,na.rm=T)
z22$HeadSAllc    <-z22$HeadSAll    -mean(z22$HeadSAll    ,na.rm=T)
z22$PFA_HS1c     <-z22$PFA_HS1     -mean(z22$PFA_HS1     ,na.rm=T)
z22$PFA_HS2c     <-z22$PFA_HS2     -mean(z22$PFA_HS2     ,na.rm=T)
z22$LCCCc        <-z22$LCCC        -mean(z22$LCCC        ,na.rm=T)
z22$LECCCc       <-z22$LECCC       -mean(z22$LECCC       ,na.rm=T)
z22$LFCCc        <-z22$LFCC        -mean(z22$LFCC        ,na.rm=T)
z22$LLECCCc      <-z22$LLECCC      -mean(z22$LLECCC      ,na.rm=T)
z22$LCLFCCc      <-z22$LCLFCC      -mean(z22$LCLFCC      ,na.rm=T)
z22$LCCCB1c      <-z22$LCCCB1      -mean(z22$LCCCB1      ,na.rm=T)
z22$LCCCB2c      <-z22$LCCCB2      -mean(z22$LCCCB2      ,na.rm=T)
z22$LCCB1c       <-z22$LCCB1       -mean(z22$LCCB1       ,na.rm=T)
z22$LCCB2c       <-z22$LCCB2       -mean(z22$LCCB2       ,na.rm=T)
z22$LCCCS1c      <-z22$LCCCS1      -mean(z22$LCCCS1      ,na.rm=T)
z22$LCCCS2c      <-z22$LCCCS2      -mean(z22$LCCCS2      ,na.rm=T)
z22$LCCS1c       <-z22$LCCS1       -mean(z22$LCCS1       ,na.rm=T)
z22$LCCS2c       <-z22$LCCS2       -mean(z22$LCCS2       ,na.rm=T)
z22$LCCCG1c      <-z22$LCCCG1      -mean(z22$LCCCG1      ,na.rm=T)
z22$LCCCG2c      <-z22$LCCCG2      -mean(z22$LCCCG2      ,na.rm=T)
z22$LCCG1c       <-z22$LCCG1       -mean(z22$LCCG1       ,na.rm=T)
z22$LCCG2c       <-z22$LCCG2       -mean(z22$LCCG2       ,na.rm=T)
z22$ChildCare1c  <-z22$ChildCare1  -mean(z22$ChildCare1  ,na.rm=T)
z22$ChildCare2c  <-z22$ChildCare2  -mean(z22$ChildCare2  ,na.rm=T)
z22$ChildCare3c  <-z22$ChildCare3  -mean(z22$ChildCare3  ,na.rm=T)
z22$CCAPc        <-z22$CCAP        -mean(z22$CCAP        ,na.rm=T)
z22$Homelessc    <-z22$Homeless    -mean(z22$Homeless    ,na.rm=T)
z22$Homeless2c   <-z22$Homeless2   -mean(z22$Homeless2   ,na.rm=T)
z22$DHS_HFIrc    <-z22$DHS_HFIr    -mean(z22$DHS_HFIr    ,na.rm=T)
z22$DHS_PTSrc    <-z22$DHS_PTSr    -mean(z22$DHS_PTSr    ,na.rm=T)
z22$DHS_HVPrc    <-z22$DHS_HVPr    -mean(z22$DHS_HVPr    ,na.rm=T)
z22$IDHS_EIrc    <-z22$IDHS_EIr    -mean(z22$IDHS_EIr    ,na.rm=T)
z22$MHV_C4c      <-z22$MHV_C4      -mean(z22$MHV_C4      ,na.rm=T)
z22$MHV_P4c      <-z22$MHV_P4      -mean(z22$MHV_P4      ,na.rm=T)
z22$MHV_C5c      <-z22$MHV_C5      -mean(z22$MHV_C5      ,na.rm=T)
z22$MHV_P5c      <-z22$MHV_P5      -mean(z22$MHV_P5      ,na.rm=T)
z22$FoodInsPc    <-z22$FoodInsP    -mean(z22$FoodInsP    ,na.rm=T)
z22$FoodISc      <-z22$FoodIS      -mean(z22$FoodIS      ,na.rm=T)
z22$RPovTc       <-z22$RPovT       -mean(z22$RPovT       ,na.rm=T)
z22$PovTc        <-z22$PovT        -mean(z22$PovT        ,na.rm=T)
z22$MHV_C4k <-z22$MHV_C4 *10
z22$MHV_C5k <-z22$MHV_C5 *10
z22$MHV_C4kc<-z22$MHV_C4c*10
z22$MHV_C5kc<-z22$MHV_C5c*10





# demean - within and between variables
z2<-cbind(z2,demean(z2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z21<-cbind(z21,demean(z21,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z22<-cbind(z22,demean(z22,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Age 12-17
# Income - Age 12-17
# Income - Age 12-17
# Income - Age 12-17
# Income - Age 12-17
# Income - Age 12-17
# Income - Age 12-17
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z3$Yearc        <-z3$Year        -mean(z3$Year        ,na.rm=T)
z3$CPopBPc      <-z3$CPopBP      -mean(z3$CPopBP      ,na.rm=T)
z3$CPopHPc      <-z3$CPopHP      -mean(z3$CPopHP      ,na.rm=T)
z3$ChildPTc     <-z3$ChildPT     -mean(z3$ChildPT     ,na.rm=T)
z3$ChildPWc     <-z3$ChildPW     -mean(z3$ChildPW     ,na.rm=T)
z3$ChildPBc     <-z3$ChildPB     -mean(z3$ChildPB     ,na.rm=T)
z3$ChildPHc     <-z3$ChildPH     -mean(z3$ChildPH     ,na.rm=T)
z3$CARatioT100c <-z3$CARatioT100 -mean(z3$CARatioT100 ,na.rm=T)
z3$CARatioW100c <-z3$CARatioW100 -mean(z3$CARatioW100 ,na.rm=T)
z3$CARatioB100c <-z3$CARatioB100 -mean(z3$CARatioB100 ,na.rm=T)
z3$CARatioH100c <-z3$CARatioH100 -mean(z3$CARatioH100 ,na.rm=T)
z3$MalePTc      <-z3$MalePT      -mean(z3$MalePT      ,na.rm=T)
z3$MalePWc      <-z3$MalePW      -mean(z3$MalePW      ,na.rm=T)
z3$MalePBc      <-z3$MalePB      -mean(z3$MalePB      ,na.rm=T)
z3$MalePHc      <-z3$MalePH      -mean(z3$MalePH      ,na.rm=T)
z3$MFRatioT100c <-z3$MFRatioT100 -mean(z3$MFRatioT100 ,na.rm=T)
z3$MFRatioW100c <-z3$MFRatioW100 -mean(z3$MFRatioW100 ,na.rm=T)
z3$MFRatioB100c <-z3$MFRatioB100 -mean(z3$MFRatioB100 ,na.rm=T)
z3$MFRatioH100c <-z3$MFRatioH100 -mean(z3$MFRatioH100 ,na.rm=T)
z3$ElderTc      <-z3$ElderT      -mean(z3$ElderT      ,na.rm=T)
z3$ElderWc      <-z3$ElderW      -mean(z3$ElderW      ,na.rm=T)
z3$ElderBc      <-z3$ElderB      -mean(z3$ElderB      ,na.rm=T)
z3$ElderHc      <-z3$ElderH      -mean(z3$ElderH      ,na.rm=T)
z3$SingleTc     <-z3$SingleT     -mean(z3$SingleT     ,na.rm=T)
z3$SingleWc     <-z3$SingleW     -mean(z3$SingleW     ,na.rm=T)
z3$SingleBc     <-z3$SingleB     -mean(z3$SingleB     ,na.rm=T)
z3$SingleHc     <-z3$SingleH     -mean(z3$SingleH     ,na.rm=T)
z3$FHeadTc      <-z3$FHeadT      -mean(z3$FHeadT      ,na.rm=T)
z3$FHeadWc      <-z3$FHeadW      -mean(z3$FHeadW      ,na.rm=T)
z3$FHeadBc      <-z3$FHeadB      -mean(z3$FHeadB      ,na.rm=T)
z3$FHeadHc      <-z3$FHeadH      -mean(z3$FHeadH      ,na.rm=T)
z3$NoHighTc     <-z3$NoHighT     -mean(z3$NoHighT     ,na.rm=T)
z3$NoHighWc     <-z3$NoHighW     -mean(z3$NoHighW     ,na.rm=T)
z3$NoHighBc     <-z3$NoHighB     -mean(z3$NoHighB     ,na.rm=T)
z3$NoHighHc     <-z3$NoHighH     -mean(z3$NoHighH     ,na.rm=T)
z3$UnempTc      <-z3$UnempT      -mean(z3$UnempT      ,na.rm=T)
z3$UnempWc      <-z3$UnempW      -mean(z3$UnempW      ,na.rm=T)
z3$UnempBc      <-z3$UnempB      -mean(z3$UnempB      ,na.rm=T)
z3$UnempHc      <-z3$UnempH      -mean(z3$UnempH      ,na.rm=T)
z3$CPovTc       <-z3$CPovT       -mean(z3$CPovT       ,na.rm=T)
z3$CPovWc       <-z3$CPovW       -mean(z3$CPovW       ,na.rm=T)
z3$CPovBc       <-z3$CPovB       -mean(z3$CPovB       ,na.rm=T)
z3$CPovHc       <-z3$CPovH       -mean(z3$CPovH       ,na.rm=T)
z3$CPov1c       <-z3$CPov1       -mean(z3$CPov1       ,na.rm=T)
z3$CPov2c       <-z3$CPov2       -mean(z3$CPov2       ,na.rm=T)
z3$CPov3c       <-z3$CPov3       -mean(z3$CPov3       ,na.rm=T)
z3$PubAsTc      <-z3$PubAsT      -mean(z3$PubAsT      ,na.rm=T)
z3$WelfarTc     <-z3$WelfarT     -mean(z3$WelfarT     ,na.rm=T)
z3$SnapTc       <-z3$SnapT       -mean(z3$SnapT       ,na.rm=T)
z3$SnapWc       <-z3$SnapW       -mean(z3$SnapW       ,na.rm=T)
z3$SnapBc       <-z3$SnapB       -mean(z3$SnapB       ,na.rm=T)
z3$SnapHc       <-z3$SnapH       -mean(z3$SnapH       ,na.rm=T)
z3$IncomeT1kc   <-z3$IncomeT1k   -mean(z3$IncomeT1k   ,na.rm=T)
z3$IncomeW1kc   <-z3$IncomeW1k   -mean(z3$IncomeW1k   ,na.rm=T)
z3$IncomeB1kc   <-z3$IncomeB1k   -mean(z3$IncomeB1k   ,na.rm=T)
z3$IncomeH1kc   <-z3$IncomeH1k   -mean(z3$IncomeH1k   ,na.rm=T)
z3$GiniT100c    <-z3$GiniT100    -mean(z3$GiniT100    ,na.rm=T)
z3$HValueT10kc  <-z3$HValueT10k  -mean(z3$HValueT10k  ,na.rm=T)
z3$MCostT100c   <-z3$MCostT100   -mean(z3$MCostT100   ,na.rm=T)
z3$OCostDT100c  <-z3$OCostDT100  -mean(z3$OCostDT100  ,na.rm=T)
z3$MRentDT100c  <-z3$MRentDT100  -mean(z3$MRentDT100  ,na.rm=T)
z3$OCostPTc     <-z3$OCostPT     -mean(z3$OCostPT     ,na.rm=T)
z3$MRentPTc     <-z3$MRentPT     -mean(z3$MRentPT     ,na.rm=T)
z3$MortgTc      <-z3$MortgT      -mean(z3$MortgT      ,na.rm=T)
z3$LangAPTc     <-z3$LangAPT     -mean(z3$LangAPT     ,na.rm=T)
z3$LangAPWc     <-z3$LangAPW     -mean(z3$LangAPW     ,na.rm=T)
z3$LangAPBc     <-z3$LangAPB     -mean(z3$LangAPB     ,na.rm=T)
z3$LangAPHc     <-z3$LangAPH     -mean(z3$LangAPH     ,na.rm=T)
z3$LangBPTc     <-z3$LangBPT     -mean(z3$LangBPT     ,na.rm=T)
z3$LangBPWc     <-z3$LangBPW     -mean(z3$LangBPW     ,na.rm=T)
z3$LangBPBc     <-z3$LangBPB     -mean(z3$LangBPB     ,na.rm=T)
z3$LangBPHc     <-z3$LangBPH     -mean(z3$LangBPH     ,na.rm=T)
z3$LangCPTc     <-z3$LangCPT     -mean(z3$LangCPT     ,na.rm=T)
z3$OutUsTc      <-z3$OutUsT      -mean(z3$OutUsT      ,na.rm=T)
z3$OutUsWc      <-z3$OutUsW      -mean(z3$OutUsW      ,na.rm=T)
z3$OutUsBc      <-z3$OutUsB      -mean(z3$OutUsB      ,na.rm=T)
z3$OutUsHc      <-z3$OutUsH      -mean(z3$OutUsH      ,na.rm=T)
z3$FBornTc      <-z3$FBornT      -mean(z3$FBornT      ,na.rm=T)
z3$FBornWc      <-z3$FBornW      -mean(z3$FBornW      ,na.rm=T)
z3$FBornBc      <-z3$FBornB      -mean(z3$FBornB      ,na.rm=T)
z3$FBornHc      <-z3$FBornH      -mean(z3$FBornH      ,na.rm=T)
z3$NotCtzTc     <-z3$NotCtzT     -mean(z3$NotCtzT     ,na.rm=T)
z3$NotCtzWc     <-z3$NotCtzW     -mean(z3$NotCtzW     ,na.rm=T)
z3$NotCtzBc     <-z3$NotCtzB     -mean(z3$NotCtzB     ,na.rm=T)
z3$NotCtzHc     <-z3$NotCtzH     -mean(z3$NotCtzH     ,na.rm=T)
z3$MoveTc       <-z3$MoveT       -mean(z3$MoveT       ,na.rm=T)
z3$MoveWc       <-z3$MoveW       -mean(z3$MoveW       ,na.rm=T)
z3$MoveBc       <-z3$MoveB       -mean(z3$MoveB       ,na.rm=T)
z3$MoveHc       <-z3$MoveH       -mean(z3$MoveH       ,na.rm=T)
z3$VacantTc     <-z3$VacantT     -mean(z3$VacantT     ,na.rm=T)
z3$OwnerTc      <-z3$OwnerT      -mean(z3$OwnerT      ,na.rm=T)
z3$OwnerWc      <-z3$OwnerW      -mean(z3$OwnerW      ,na.rm=T)
z3$OwnerBc      <-z3$OwnerB      -mean(z3$OwnerB      ,na.rm=T)
z3$OwnerHc      <-z3$OwnerH      -mean(z3$OwnerH      ,na.rm=T)
z3$CrowdTc      <-z3$CrowdT      -mean(z3$CrowdT      ,na.rm=T)
z3$CrowdWc      <-z3$CrowdW      -mean(z3$CrowdW      ,na.rm=T)
z3$CrowdBc      <-z3$CrowdB      -mean(z3$CrowdB      ,na.rm=T)
z3$CrowdHc      <-z3$CrowdH      -mean(z3$CrowdH      ,na.rm=T)
z3$MobileTc     <-z3$MobileT     -mean(z3$MobileT     ,na.rm=T)
z3$MobileWc     <-z3$MobileW     -mean(z3$MobileW     ,na.rm=T)
z3$MobileBc     <-z3$MobileB     -mean(z3$MobileB     ,na.rm=T)
z3$MobileHc     <-z3$MobileH     -mean(z3$MobileH     ,na.rm=T)
z3$DisablTc     <-z3$DisablT     -mean(z3$DisablT     ,na.rm=T)
z3$DisablWc     <-z3$DisablW     -mean(z3$DisablW     ,na.rm=T)
z3$DisablBc     <-z3$DisablB     -mean(z3$DisablB     ,na.rm=T)
z3$DisablHc     <-z3$DisablH     -mean(z3$DisablH     ,na.rm=T)
z3$DisablTCc    <-z3$DisablTC    -mean(z3$DisablTC    ,na.rm=T)
z3$DisablWCc    <-z3$DisablWC    -mean(z3$DisablWC    ,na.rm=T)
z3$DisablBCc    <-z3$DisablBC    -mean(z3$DisablBC    ,na.rm=T)
z3$DisablHCc    <-z3$DisablHC    -mean(z3$DisablHC    ,na.rm=T)
z3$DisablTMc    <-z3$DisablTM    -mean(z3$DisablTM    ,na.rm=T)
z3$DisablTFc    <-z3$DisablTF    -mean(z3$DisablTF    ,na.rm=T)
z3$Urban1c      <-z3$Urban1      -mean(z3$Urban1      ,na.rm=T)
z3$Urban2c      <-z3$Urban2      -mean(z3$Urban2      ,na.rm=T)
z3$ISBE_PFAc    <-z3$ISBE_PFA    -mean(z3$ISBE_PFA    ,na.rm=T)
z3$ISBE_PFAEc   <-z3$ISBE_PFAE   -mean(z3$ISBE_PFAE   ,na.rm=T)
z3$ISBE_PIc     <-z3$ISBE_PI     -mean(z3$ISBE_PI     ,na.rm=T)
z3$HeadStartc   <-z3$HeadStart   -mean(z3$HeadStart   ,na.rm=T)
z3$ElyHeadSc    <-z3$ElyHeadS    -mean(z3$ElyHeadS    ,na.rm=T)
z3$HeadSAllc    <-z3$HeadSAll    -mean(z3$HeadSAll    ,na.rm=T)
z3$PFA_HS1c     <-z3$PFA_HS1     -mean(z3$PFA_HS1     ,na.rm=T)
z3$PFA_HS2c     <-z3$PFA_HS2     -mean(z3$PFA_HS2     ,na.rm=T)
z3$LCCCc        <-z3$LCCC        -mean(z3$LCCC        ,na.rm=T)
z3$LECCCc       <-z3$LECCC       -mean(z3$LECCC       ,na.rm=T)
z3$LFCCc        <-z3$LFCC        -mean(z3$LFCC        ,na.rm=T)
z3$LLECCCc      <-z3$LLECCC      -mean(z3$LLECCC      ,na.rm=T)
z3$LCLFCCc      <-z3$LCLFCC      -mean(z3$LCLFCC      ,na.rm=T)
z3$LCCCB1c      <-z3$LCCCB1      -mean(z3$LCCCB1      ,na.rm=T)
z3$LCCCB2c      <-z3$LCCCB2      -mean(z3$LCCCB2      ,na.rm=T)
z3$LCCB1c       <-z3$LCCB1       -mean(z3$LCCB1       ,na.rm=T)
z3$LCCB2c       <-z3$LCCB2       -mean(z3$LCCB2       ,na.rm=T)
z3$LCCCS1c      <-z3$LCCCS1      -mean(z3$LCCCS1      ,na.rm=T)
z3$LCCCS2c      <-z3$LCCCS2      -mean(z3$LCCCS2      ,na.rm=T)
z3$LCCS1c       <-z3$LCCS1       -mean(z3$LCCS1       ,na.rm=T)
z3$LCCS2c       <-z3$LCCS2       -mean(z3$LCCS2       ,na.rm=T)
z3$LCCCG1c      <-z3$LCCCG1      -mean(z3$LCCCG1      ,na.rm=T)
z3$LCCCG2c      <-z3$LCCCG2      -mean(z3$LCCCG2      ,na.rm=T)
z3$LCCG1c       <-z3$LCCG1       -mean(z3$LCCG1       ,na.rm=T)
z3$LCCG2c       <-z3$LCCG2       -mean(z3$LCCG2       ,na.rm=T)
z3$ChildCare1c  <-z3$ChildCare1  -mean(z3$ChildCare1  ,na.rm=T)
z3$ChildCare2c  <-z3$ChildCare2  -mean(z3$ChildCare2  ,na.rm=T)
z3$ChildCare3c  <-z3$ChildCare3  -mean(z3$ChildCare3  ,na.rm=T)
z3$CCAPc        <-z3$CCAP        -mean(z3$CCAP        ,na.rm=T)
z3$Homelessc    <-z3$Homeless    -mean(z3$Homeless    ,na.rm=T)
z3$Homeless2c   <-z3$Homeless2   -mean(z3$Homeless2   ,na.rm=T)
z3$DHS_HFIrc    <-z3$DHS_HFIr    -mean(z3$DHS_HFIr    ,na.rm=T)
z3$DHS_PTSrc    <-z3$DHS_PTSr    -mean(z3$DHS_PTSr    ,na.rm=T)
z3$DHS_HVPrc    <-z3$DHS_HVPr    -mean(z3$DHS_HVPr    ,na.rm=T)
z3$IDHS_EIrc    <-z3$IDHS_EIr    -mean(z3$IDHS_EIr    ,na.rm=T)
z3$MHV_C4c      <-z3$MHV_C4      -mean(z3$MHV_C4      ,na.rm=T)
z3$MHV_P4c      <-z3$MHV_P4      -mean(z3$MHV_P4      ,na.rm=T)
z3$MHV_C5c      <-z3$MHV_C5      -mean(z3$MHV_C5      ,na.rm=T)
z3$MHV_P5c      <-z3$MHV_P5      -mean(z3$MHV_P5      ,na.rm=T)
z3$FoodInsPc    <-z3$FoodInsP    -mean(z3$FoodInsP    ,na.rm=T)
z3$FoodISc      <-z3$FoodIS      -mean(z3$FoodIS      ,na.rm=T)
z3$RPovTc       <-z3$RPovT       -mean(z3$RPovT       ,na.rm=T)
z3$PovTc        <-z3$PovT        -mean(z3$PovT        ,na.rm=T)
z3$MHV_C4k <-z3$MHV_C4 *10
z3$MHV_C5k <-z3$MHV_C5 *10
z3$MHV_C4kc<-z3$MHV_C4c*10
z3$MHV_C5kc<-z3$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
z31$Yearc        <-z31$Year        -mean(z31$Year        ,na.rm=T)
z31$CPopBPc      <-z31$CPopBP      -mean(z31$CPopBP      ,na.rm=T)
z31$CPopHPc      <-z31$CPopHP      -mean(z31$CPopHP      ,na.rm=T)
z31$ChildPTc     <-z31$ChildPT     -mean(z31$ChildPT     ,na.rm=T)
z31$ChildPWc     <-z31$ChildPW     -mean(z31$ChildPW     ,na.rm=T)
z31$ChildPBc     <-z31$ChildPB     -mean(z31$ChildPB     ,na.rm=T)
z31$ChildPHc     <-z31$ChildPH     -mean(z31$ChildPH     ,na.rm=T)
z31$CARatioT100c <-z31$CARatioT100 -mean(z31$CARatioT100 ,na.rm=T)
z31$CARatioW100c <-z31$CARatioW100 -mean(z31$CARatioW100 ,na.rm=T)
z31$CARatioB100c <-z31$CARatioB100 -mean(z31$CARatioB100 ,na.rm=T)
z31$CARatioH100c <-z31$CARatioH100 -mean(z31$CARatioH100 ,na.rm=T)
z31$MalePTc      <-z31$MalePT      -mean(z31$MalePT      ,na.rm=T)
z31$MalePWc      <-z31$MalePW      -mean(z31$MalePW      ,na.rm=T)
z31$MalePBc      <-z31$MalePB      -mean(z31$MalePB      ,na.rm=T)
z31$MalePHc      <-z31$MalePH      -mean(z31$MalePH      ,na.rm=T)
z31$MFRatioT100c <-z31$MFRatioT100 -mean(z31$MFRatioT100 ,na.rm=T)
z31$MFRatioW100c <-z31$MFRatioW100 -mean(z31$MFRatioW100 ,na.rm=T)
z31$MFRatioB100c <-z31$MFRatioB100 -mean(z31$MFRatioB100 ,na.rm=T)
z31$MFRatioH100c <-z31$MFRatioH100 -mean(z31$MFRatioH100 ,na.rm=T)
z31$ElderTc      <-z31$ElderT      -mean(z31$ElderT      ,na.rm=T)
z31$ElderWc      <-z31$ElderW      -mean(z31$ElderW      ,na.rm=T)
z31$ElderBc      <-z31$ElderB      -mean(z31$ElderB      ,na.rm=T)
z31$ElderHc      <-z31$ElderH      -mean(z31$ElderH      ,na.rm=T)
z31$SingleTc     <-z31$SingleT     -mean(z31$SingleT     ,na.rm=T)
z31$SingleWc     <-z31$SingleW     -mean(z31$SingleW     ,na.rm=T)
z31$SingleBc     <-z31$SingleB     -mean(z31$SingleB     ,na.rm=T)
z31$SingleHc     <-z31$SingleH     -mean(z31$SingleH     ,na.rm=T)
z31$FHeadTc      <-z31$FHeadT      -mean(z31$FHeadT      ,na.rm=T)
z31$FHeadWc      <-z31$FHeadW      -mean(z31$FHeadW      ,na.rm=T)
z31$FHeadBc      <-z31$FHeadB      -mean(z31$FHeadB      ,na.rm=T)
z31$FHeadHc      <-z31$FHeadH      -mean(z31$FHeadH      ,na.rm=T)
z31$NoHighTc     <-z31$NoHighT     -mean(z31$NoHighT     ,na.rm=T)
z31$NoHighWc     <-z31$NoHighW     -mean(z31$NoHighW     ,na.rm=T)
z31$NoHighBc     <-z31$NoHighB     -mean(z31$NoHighB     ,na.rm=T)
z31$NoHighHc     <-z31$NoHighH     -mean(z31$NoHighH     ,na.rm=T)
z31$UnempTc      <-z31$UnempT      -mean(z31$UnempT      ,na.rm=T)
z31$UnempWc      <-z31$UnempW      -mean(z31$UnempW      ,na.rm=T)
z31$UnempBc      <-z31$UnempB      -mean(z31$UnempB      ,na.rm=T)
z31$UnempHc      <-z31$UnempH      -mean(z31$UnempH      ,na.rm=T)
z31$CPovTc       <-z31$CPovT       -mean(z31$CPovT       ,na.rm=T)
z31$CPovWc       <-z31$CPovW       -mean(z31$CPovW       ,na.rm=T)
z31$CPovBc       <-z31$CPovB       -mean(z31$CPovB       ,na.rm=T)
z31$CPovHc       <-z31$CPovH       -mean(z31$CPovH       ,na.rm=T)
z31$CPov1c       <-z31$CPov1       -mean(z31$CPov1       ,na.rm=T)
z31$CPov2c       <-z31$CPov2       -mean(z31$CPov2       ,na.rm=T)
z31$CPov3c       <-z31$CPov3       -mean(z31$CPov3       ,na.rm=T)
z31$PubAsTc      <-z31$PubAsT      -mean(z31$PubAsT      ,na.rm=T)
z31$WelfarTc     <-z31$WelfarT     -mean(z31$WelfarT     ,na.rm=T)
z31$SnapTc       <-z31$SnapT       -mean(z31$SnapT       ,na.rm=T)
z31$SnapWc       <-z31$SnapW       -mean(z31$SnapW       ,na.rm=T)
z31$SnapBc       <-z31$SnapB       -mean(z31$SnapB       ,na.rm=T)
z31$SnapHc       <-z31$SnapH       -mean(z31$SnapH       ,na.rm=T)
z31$IncomeT1kc   <-z31$IncomeT1k   -mean(z31$IncomeT1k   ,na.rm=T)
z31$IncomeW1kc   <-z31$IncomeW1k   -mean(z31$IncomeW1k   ,na.rm=T)
z31$IncomeB1kc   <-z31$IncomeB1k   -mean(z31$IncomeB1k   ,na.rm=T)
z31$IncomeH1kc   <-z31$IncomeH1k   -mean(z31$IncomeH1k   ,na.rm=T)
z31$GiniT100c    <-z31$GiniT100    -mean(z31$GiniT100    ,na.rm=T)
z31$HValueT10kc  <-z31$HValueT10k  -mean(z31$HValueT10k  ,na.rm=T)
z31$MCostT100c   <-z31$MCostT100   -mean(z31$MCostT100   ,na.rm=T)
z31$OCostDT100c  <-z31$OCostDT100  -mean(z31$OCostDT100  ,na.rm=T)
z31$MRentDT100c  <-z31$MRentDT100  -mean(z31$MRentDT100  ,na.rm=T)
z31$OCostPTc     <-z31$OCostPT     -mean(z31$OCostPT     ,na.rm=T)
z31$MRentPTc     <-z31$MRentPT     -mean(z31$MRentPT     ,na.rm=T)
z31$MortgTc      <-z31$MortgT      -mean(z31$MortgT      ,na.rm=T)
z31$LangAPTc     <-z31$LangAPT     -mean(z31$LangAPT     ,na.rm=T)
z31$LangAPWc     <-z31$LangAPW     -mean(z31$LangAPW     ,na.rm=T)
z31$LangAPBc     <-z31$LangAPB     -mean(z31$LangAPB     ,na.rm=T)
z31$LangAPHc     <-z31$LangAPH     -mean(z31$LangAPH     ,na.rm=T)
z31$LangBPTc     <-z31$LangBPT     -mean(z31$LangBPT     ,na.rm=T)
z31$LangBPWc     <-z31$LangBPW     -mean(z31$LangBPW     ,na.rm=T)
z31$LangBPBc     <-z31$LangBPB     -mean(z31$LangBPB     ,na.rm=T)
z31$LangBPHc     <-z31$LangBPH     -mean(z31$LangBPH     ,na.rm=T)
z31$LangCPTc     <-z31$LangCPT     -mean(z31$LangCPT     ,na.rm=T)
z31$OutUsTc      <-z31$OutUsT      -mean(z31$OutUsT      ,na.rm=T)
z31$OutUsWc      <-z31$OutUsW      -mean(z31$OutUsW      ,na.rm=T)
z31$OutUsBc      <-z31$OutUsB      -mean(z31$OutUsB      ,na.rm=T)
z31$OutUsHc      <-z31$OutUsH      -mean(z31$OutUsH      ,na.rm=T)
z31$FBornTc      <-z31$FBornT      -mean(z31$FBornT      ,na.rm=T)
z31$FBornWc      <-z31$FBornW      -mean(z31$FBornW      ,na.rm=T)
z31$FBornBc      <-z31$FBornB      -mean(z31$FBornB      ,na.rm=T)
z31$FBornHc      <-z31$FBornH      -mean(z31$FBornH      ,na.rm=T)
z31$NotCtzTc     <-z31$NotCtzT     -mean(z31$NotCtzT     ,na.rm=T)
z31$NotCtzWc     <-z31$NotCtzW     -mean(z31$NotCtzW     ,na.rm=T)
z31$NotCtzBc     <-z31$NotCtzB     -mean(z31$NotCtzB     ,na.rm=T)
z31$NotCtzHc     <-z31$NotCtzH     -mean(z31$NotCtzH     ,na.rm=T)
z31$MoveTc       <-z31$MoveT       -mean(z31$MoveT       ,na.rm=T)
z31$MoveWc       <-z31$MoveW       -mean(z31$MoveW       ,na.rm=T)
z31$MoveBc       <-z31$MoveB       -mean(z31$MoveB       ,na.rm=T)
z31$MoveHc       <-z31$MoveH       -mean(z31$MoveH       ,na.rm=T)
z31$VacantTc     <-z31$VacantT     -mean(z31$VacantT     ,na.rm=T)
z31$OwnerTc      <-z31$OwnerT      -mean(z31$OwnerT      ,na.rm=T)
z31$OwnerWc      <-z31$OwnerW      -mean(z31$OwnerW      ,na.rm=T)
z31$OwnerBc      <-z31$OwnerB      -mean(z31$OwnerB      ,na.rm=T)
z31$OwnerHc      <-z31$OwnerH      -mean(z31$OwnerH      ,na.rm=T)
z31$CrowdTc      <-z31$CrowdT      -mean(z31$CrowdT      ,na.rm=T)
z31$CrowdWc      <-z31$CrowdW      -mean(z31$CrowdW      ,na.rm=T)
z31$CrowdBc      <-z31$CrowdB      -mean(z31$CrowdB      ,na.rm=T)
z31$CrowdHc      <-z31$CrowdH      -mean(z31$CrowdH      ,na.rm=T)
z31$MobileTc     <-z31$MobileT     -mean(z31$MobileT     ,na.rm=T)
z31$MobileWc     <-z31$MobileW     -mean(z31$MobileW     ,na.rm=T)
z31$MobileBc     <-z31$MobileB     -mean(z31$MobileB     ,na.rm=T)
z31$MobileHc     <-z31$MobileH     -mean(z31$MobileH     ,na.rm=T)
z31$DisablTc     <-z31$DisablT     -mean(z31$DisablT     ,na.rm=T)
z31$DisablWc     <-z31$DisablW     -mean(z31$DisablW     ,na.rm=T)
z31$DisablBc     <-z31$DisablB     -mean(z31$DisablB     ,na.rm=T)
z31$DisablHc     <-z31$DisablH     -mean(z31$DisablH     ,na.rm=T)
z31$DisablTCc    <-z31$DisablTC    -mean(z31$DisablTC    ,na.rm=T)
z31$DisablWCc    <-z31$DisablWC    -mean(z31$DisablWC    ,na.rm=T)
z31$DisablBCc    <-z31$DisablBC    -mean(z31$DisablBC    ,na.rm=T)
z31$DisablHCc    <-z31$DisablHC    -mean(z31$DisablHC    ,na.rm=T)
z31$DisablTMc    <-z31$DisablTM    -mean(z31$DisablTM    ,na.rm=T)
z31$DisablTFc    <-z31$DisablTF    -mean(z31$DisablTF    ,na.rm=T)
z31$Urban1c      <-z31$Urban1      -mean(z31$Urban1      ,na.rm=T)
z31$Urban2c      <-z31$Urban2      -mean(z31$Urban2      ,na.rm=T)
z31$ISBE_PFAc    <-z31$ISBE_PFA    -mean(z31$ISBE_PFA    ,na.rm=T)
z31$ISBE_PFAEc   <-z31$ISBE_PFAE   -mean(z31$ISBE_PFAE   ,na.rm=T)
z31$ISBE_PIc     <-z31$ISBE_PI     -mean(z31$ISBE_PI     ,na.rm=T)
z31$HeadStartc   <-z31$HeadStart   -mean(z31$HeadStart   ,na.rm=T)
z31$ElyHeadSc    <-z31$ElyHeadS    -mean(z31$ElyHeadS    ,na.rm=T)
z31$HeadSAllc    <-z31$HeadSAll    -mean(z31$HeadSAll    ,na.rm=T)
z31$PFA_HS1c     <-z31$PFA_HS1     -mean(z31$PFA_HS1     ,na.rm=T)
z31$PFA_HS2c     <-z31$PFA_HS2     -mean(z31$PFA_HS2     ,na.rm=T)
z31$LCCCc        <-z31$LCCC        -mean(z31$LCCC        ,na.rm=T)
z31$LECCCc       <-z31$LECCC       -mean(z31$LECCC       ,na.rm=T)
z31$LFCCc        <-z31$LFCC        -mean(z31$LFCC        ,na.rm=T)
z31$LLECCCc      <-z31$LLECCC      -mean(z31$LLECCC      ,na.rm=T)
z31$LCLFCCc      <-z31$LCLFCC      -mean(z31$LCLFCC      ,na.rm=T)
z31$LCCCB1c      <-z31$LCCCB1      -mean(z31$LCCCB1      ,na.rm=T)
z31$LCCCB2c      <-z31$LCCCB2      -mean(z31$LCCCB2      ,na.rm=T)
z31$LCCB1c       <-z31$LCCB1       -mean(z31$LCCB1       ,na.rm=T)
z31$LCCB2c       <-z31$LCCB2       -mean(z31$LCCB2       ,na.rm=T)
z31$LCCCS1c      <-z31$LCCCS1      -mean(z31$LCCCS1      ,na.rm=T)
z31$LCCCS2c      <-z31$LCCCS2      -mean(z31$LCCCS2      ,na.rm=T)
z31$LCCS1c       <-z31$LCCS1       -mean(z31$LCCS1       ,na.rm=T)
z31$LCCS2c       <-z31$LCCS2       -mean(z31$LCCS2       ,na.rm=T)
z31$LCCCG1c      <-z31$LCCCG1      -mean(z31$LCCCG1      ,na.rm=T)
z31$LCCCG2c      <-z31$LCCCG2      -mean(z31$LCCCG2      ,na.rm=T)
z31$LCCG1c       <-z31$LCCG1       -mean(z31$LCCG1       ,na.rm=T)
z31$LCCG2c       <-z31$LCCG2       -mean(z31$LCCG2       ,na.rm=T)
z31$ChildCare1c  <-z31$ChildCare1  -mean(z31$ChildCare1  ,na.rm=T)
z31$ChildCare2c  <-z31$ChildCare2  -mean(z31$ChildCare2  ,na.rm=T)
z31$ChildCare3c  <-z31$ChildCare3  -mean(z31$ChildCare3  ,na.rm=T)
z31$CCAPc        <-z31$CCAP        -mean(z31$CCAP        ,na.rm=T)
z31$Homelessc    <-z31$Homeless    -mean(z31$Homeless    ,na.rm=T)
z31$Homeless2c   <-z31$Homeless2   -mean(z31$Homeless2   ,na.rm=T)
z31$DHS_HFIrc    <-z31$DHS_HFIr    -mean(z31$DHS_HFIr    ,na.rm=T)
z31$DHS_PTSrc    <-z31$DHS_PTSr    -mean(z31$DHS_PTSr    ,na.rm=T)
z31$DHS_HVPrc    <-z31$DHS_HVPr    -mean(z31$DHS_HVPr    ,na.rm=T)
z31$IDHS_EIrc    <-z31$IDHS_EIr    -mean(z31$IDHS_EIr    ,na.rm=T)
z31$MHV_C4c      <-z31$MHV_C4      -mean(z31$MHV_C4      ,na.rm=T)
z31$MHV_P4c      <-z31$MHV_P4      -mean(z31$MHV_P4      ,na.rm=T)
z31$MHV_C5c      <-z31$MHV_C5      -mean(z31$MHV_C5      ,na.rm=T)
z31$MHV_P5c      <-z31$MHV_P5      -mean(z31$MHV_P5      ,na.rm=T)
z31$FoodInsPc    <-z31$FoodInsP    -mean(z31$FoodInsP    ,na.rm=T)
z31$FoodISc      <-z31$FoodIS      -mean(z31$FoodIS      ,na.rm=T)
z31$RPovTc       <-z31$RPovT       -mean(z31$RPovT       ,na.rm=T)
z31$PovTc        <-z31$PovT        -mean(z31$PovT        ,na.rm=T)
z31$MHV_C4k <-z31$MHV_C4 *10
z31$MHV_C5k <-z31$MHV_C5 *10
z31$MHV_C4kc<-z31$MHV_C4c*10
z31$MHV_C5kc<-z31$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
z32$Yearc        <-z32$Year        -mean(z32$Year        ,na.rm=T)
z32$CPopBPc      <-z32$CPopBP      -mean(z32$CPopBP      ,na.rm=T)
z32$CPopHPc      <-z32$CPopHP      -mean(z32$CPopHP      ,na.rm=T)
z32$ChildPTc     <-z32$ChildPT     -mean(z32$ChildPT     ,na.rm=T)
z32$ChildPWc     <-z32$ChildPW     -mean(z32$ChildPW     ,na.rm=T)
z32$ChildPBc     <-z32$ChildPB     -mean(z32$ChildPB     ,na.rm=T)
z32$ChildPHc     <-z32$ChildPH     -mean(z32$ChildPH     ,na.rm=T)
z32$CARatioT100c <-z32$CARatioT100 -mean(z32$CARatioT100 ,na.rm=T)
z32$CARatioW100c <-z32$CARatioW100 -mean(z32$CARatioW100 ,na.rm=T)
z32$CARatioB100c <-z32$CARatioB100 -mean(z32$CARatioB100 ,na.rm=T)
z32$CARatioH100c <-z32$CARatioH100 -mean(z32$CARatioH100 ,na.rm=T)
z32$MalePTc      <-z32$MalePT      -mean(z32$MalePT      ,na.rm=T)
z32$MalePWc      <-z32$MalePW      -mean(z32$MalePW      ,na.rm=T)
z32$MalePBc      <-z32$MalePB      -mean(z32$MalePB      ,na.rm=T)
z32$MalePHc      <-z32$MalePH      -mean(z32$MalePH      ,na.rm=T)
z32$MFRatioT100c <-z32$MFRatioT100 -mean(z32$MFRatioT100 ,na.rm=T)
z32$MFRatioW100c <-z32$MFRatioW100 -mean(z32$MFRatioW100 ,na.rm=T)
z32$MFRatioB100c <-z32$MFRatioB100 -mean(z32$MFRatioB100 ,na.rm=T)
z32$MFRatioH100c <-z32$MFRatioH100 -mean(z32$MFRatioH100 ,na.rm=T)
z32$ElderTc      <-z32$ElderT      -mean(z32$ElderT      ,na.rm=T)
z32$ElderWc      <-z32$ElderW      -mean(z32$ElderW      ,na.rm=T)
z32$ElderBc      <-z32$ElderB      -mean(z32$ElderB      ,na.rm=T)
z32$ElderHc      <-z32$ElderH      -mean(z32$ElderH      ,na.rm=T)
z32$SingleTc     <-z32$SingleT     -mean(z32$SingleT     ,na.rm=T)
z32$SingleWc     <-z32$SingleW     -mean(z32$SingleW     ,na.rm=T)
z32$SingleBc     <-z32$SingleB     -mean(z32$SingleB     ,na.rm=T)
z32$SingleHc     <-z32$SingleH     -mean(z32$SingleH     ,na.rm=T)
z32$FHeadTc      <-z32$FHeadT      -mean(z32$FHeadT      ,na.rm=T)
z32$FHeadWc      <-z32$FHeadW      -mean(z32$FHeadW      ,na.rm=T)
z32$FHeadBc      <-z32$FHeadB      -mean(z32$FHeadB      ,na.rm=T)
z32$FHeadHc      <-z32$FHeadH      -mean(z32$FHeadH      ,na.rm=T)
z32$NoHighTc     <-z32$NoHighT     -mean(z32$NoHighT     ,na.rm=T)
z32$NoHighWc     <-z32$NoHighW     -mean(z32$NoHighW     ,na.rm=T)
z32$NoHighBc     <-z32$NoHighB     -mean(z32$NoHighB     ,na.rm=T)
z32$NoHighHc     <-z32$NoHighH     -mean(z32$NoHighH     ,na.rm=T)
z32$UnempTc      <-z32$UnempT      -mean(z32$UnempT      ,na.rm=T)
z32$UnempWc      <-z32$UnempW      -mean(z32$UnempW      ,na.rm=T)
z32$UnempBc      <-z32$UnempB      -mean(z32$UnempB      ,na.rm=T)
z32$UnempHc      <-z32$UnempH      -mean(z32$UnempH      ,na.rm=T)
z32$CPovTc       <-z32$CPovT       -mean(z32$CPovT       ,na.rm=T)
z32$CPovWc       <-z32$CPovW       -mean(z32$CPovW       ,na.rm=T)
z32$CPovBc       <-z32$CPovB       -mean(z32$CPovB       ,na.rm=T)
z32$CPovHc       <-z32$CPovH       -mean(z32$CPovH       ,na.rm=T)
z32$CPov1c       <-z32$CPov1       -mean(z32$CPov1       ,na.rm=T)
z32$CPov2c       <-z32$CPov2       -mean(z32$CPov2       ,na.rm=T)
z32$CPov3c       <-z32$CPov3       -mean(z32$CPov3       ,na.rm=T)
z32$PubAsTc      <-z32$PubAsT      -mean(z32$PubAsT      ,na.rm=T)
z32$WelfarTc     <-z32$WelfarT     -mean(z32$WelfarT     ,na.rm=T)
z32$SnapTc       <-z32$SnapT       -mean(z32$SnapT       ,na.rm=T)
z32$SnapWc       <-z32$SnapW       -mean(z32$SnapW       ,na.rm=T)
z32$SnapBc       <-z32$SnapB       -mean(z32$SnapB       ,na.rm=T)
z32$SnapHc       <-z32$SnapH       -mean(z32$SnapH       ,na.rm=T)
z32$IncomeT1kc   <-z32$IncomeT1k   -mean(z32$IncomeT1k   ,na.rm=T)
z32$IncomeW1kc   <-z32$IncomeW1k   -mean(z32$IncomeW1k   ,na.rm=T)
z32$IncomeB1kc   <-z32$IncomeB1k   -mean(z32$IncomeB1k   ,na.rm=T)
z32$IncomeH1kc   <-z32$IncomeH1k   -mean(z32$IncomeH1k   ,na.rm=T)
z32$GiniT100c    <-z32$GiniT100    -mean(z32$GiniT100    ,na.rm=T)
z32$HValueT10kc  <-z32$HValueT10k  -mean(z32$HValueT10k  ,na.rm=T)
z32$MCostT100c   <-z32$MCostT100   -mean(z32$MCostT100   ,na.rm=T)
z32$OCostDT100c  <-z32$OCostDT100  -mean(z32$OCostDT100  ,na.rm=T)
z32$MRentDT100c  <-z32$MRentDT100  -mean(z32$MRentDT100  ,na.rm=T)
z32$OCostPTc     <-z32$OCostPT     -mean(z32$OCostPT     ,na.rm=T)
z32$MRentPTc     <-z32$MRentPT     -mean(z32$MRentPT     ,na.rm=T)
z32$MortgTc      <-z32$MortgT      -mean(z32$MortgT      ,na.rm=T)
z32$LangAPTc     <-z32$LangAPT     -mean(z32$LangAPT     ,na.rm=T)
z32$LangAPWc     <-z32$LangAPW     -mean(z32$LangAPW     ,na.rm=T)
z32$LangAPBc     <-z32$LangAPB     -mean(z32$LangAPB     ,na.rm=T)
z32$LangAPHc     <-z32$LangAPH     -mean(z32$LangAPH     ,na.rm=T)
z32$LangBPTc     <-z32$LangBPT     -mean(z32$LangBPT     ,na.rm=T)
z32$LangBPWc     <-z32$LangBPW     -mean(z32$LangBPW     ,na.rm=T)
z32$LangBPBc     <-z32$LangBPB     -mean(z32$LangBPB     ,na.rm=T)
z32$LangBPHc     <-z32$LangBPH     -mean(z32$LangBPH     ,na.rm=T)
z32$LangCPTc     <-z32$LangCPT     -mean(z32$LangCPT     ,na.rm=T)
z32$OutUsTc      <-z32$OutUsT      -mean(z32$OutUsT      ,na.rm=T)
z32$OutUsWc      <-z32$OutUsW      -mean(z32$OutUsW      ,na.rm=T)
z32$OutUsBc      <-z32$OutUsB      -mean(z32$OutUsB      ,na.rm=T)
z32$OutUsHc      <-z32$OutUsH      -mean(z32$OutUsH      ,na.rm=T)
z32$FBornTc      <-z32$FBornT      -mean(z32$FBornT      ,na.rm=T)
z32$FBornWc      <-z32$FBornW      -mean(z32$FBornW      ,na.rm=T)
z32$FBornBc      <-z32$FBornB      -mean(z32$FBornB      ,na.rm=T)
z32$FBornHc      <-z32$FBornH      -mean(z32$FBornH      ,na.rm=T)
z32$NotCtzTc     <-z32$NotCtzT     -mean(z32$NotCtzT     ,na.rm=T)
z32$NotCtzWc     <-z32$NotCtzW     -mean(z32$NotCtzW     ,na.rm=T)
z32$NotCtzBc     <-z32$NotCtzB     -mean(z32$NotCtzB     ,na.rm=T)
z32$NotCtzHc     <-z32$NotCtzH     -mean(z32$NotCtzH     ,na.rm=T)
z32$MoveTc       <-z32$MoveT       -mean(z32$MoveT       ,na.rm=T)
z32$MoveWc       <-z32$MoveW       -mean(z32$MoveW       ,na.rm=T)
z32$MoveBc       <-z32$MoveB       -mean(z32$MoveB       ,na.rm=T)
z32$MoveHc       <-z32$MoveH       -mean(z32$MoveH       ,na.rm=T)
z32$VacantTc     <-z32$VacantT     -mean(z32$VacantT     ,na.rm=T)
z32$OwnerTc      <-z32$OwnerT      -mean(z32$OwnerT      ,na.rm=T)
z32$OwnerWc      <-z32$OwnerW      -mean(z32$OwnerW      ,na.rm=T)
z32$OwnerBc      <-z32$OwnerB      -mean(z32$OwnerB      ,na.rm=T)
z32$OwnerHc      <-z32$OwnerH      -mean(z32$OwnerH      ,na.rm=T)
z32$CrowdTc      <-z32$CrowdT      -mean(z32$CrowdT      ,na.rm=T)
z32$CrowdWc      <-z32$CrowdW      -mean(z32$CrowdW      ,na.rm=T)
z32$CrowdBc      <-z32$CrowdB      -mean(z32$CrowdB      ,na.rm=T)
z32$CrowdHc      <-z32$CrowdH      -mean(z32$CrowdH      ,na.rm=T)
z32$MobileTc     <-z32$MobileT     -mean(z32$MobileT     ,na.rm=T)
z32$MobileWc     <-z32$MobileW     -mean(z32$MobileW     ,na.rm=T)
z32$MobileBc     <-z32$MobileB     -mean(z32$MobileB     ,na.rm=T)
z32$MobileHc     <-z32$MobileH     -mean(z32$MobileH     ,na.rm=T)
z32$DisablTc     <-z32$DisablT     -mean(z32$DisablT     ,na.rm=T)
z32$DisablWc     <-z32$DisablW     -mean(z32$DisablW     ,na.rm=T)
z32$DisablBc     <-z32$DisablB     -mean(z32$DisablB     ,na.rm=T)
z32$DisablHc     <-z32$DisablH     -mean(z32$DisablH     ,na.rm=T)
z32$DisablTCc    <-z32$DisablTC    -mean(z32$DisablTC    ,na.rm=T)
z32$DisablWCc    <-z32$DisablWC    -mean(z32$DisablWC    ,na.rm=T)
z32$DisablBCc    <-z32$DisablBC    -mean(z32$DisablBC    ,na.rm=T)
z32$DisablHCc    <-z32$DisablHC    -mean(z32$DisablHC    ,na.rm=T)
z32$DisablTMc    <-z32$DisablTM    -mean(z32$DisablTM    ,na.rm=T)
z32$DisablTFc    <-z32$DisablTF    -mean(z32$DisablTF    ,na.rm=T)
z32$Urban1c      <-z32$Urban1      -mean(z32$Urban1      ,na.rm=T)
z32$Urban2c      <-z32$Urban2      -mean(z32$Urban2      ,na.rm=T)
z32$ISBE_PFAc    <-z32$ISBE_PFA    -mean(z32$ISBE_PFA    ,na.rm=T)
z32$ISBE_PFAEc   <-z32$ISBE_PFAE   -mean(z32$ISBE_PFAE   ,na.rm=T)
z32$ISBE_PIc     <-z32$ISBE_PI     -mean(z32$ISBE_PI     ,na.rm=T)
z32$HeadStartc   <-z32$HeadStart   -mean(z32$HeadStart   ,na.rm=T)
z32$ElyHeadSc    <-z32$ElyHeadS    -mean(z32$ElyHeadS    ,na.rm=T)
z32$HeadSAllc    <-z32$HeadSAll    -mean(z32$HeadSAll    ,na.rm=T)
z32$PFA_HS1c     <-z32$PFA_HS1     -mean(z32$PFA_HS1     ,na.rm=T)
z32$PFA_HS2c     <-z32$PFA_HS2     -mean(z32$PFA_HS2     ,na.rm=T)
z32$LCCCc        <-z32$LCCC        -mean(z32$LCCC        ,na.rm=T)
z32$LECCCc       <-z32$LECCC       -mean(z32$LECCC       ,na.rm=T)
z32$LFCCc        <-z32$LFCC        -mean(z32$LFCC        ,na.rm=T)
z32$LLECCCc      <-z32$LLECCC      -mean(z32$LLECCC      ,na.rm=T)
z32$LCLFCCc      <-z32$LCLFCC      -mean(z32$LCLFCC      ,na.rm=T)
z32$LCCCB1c      <-z32$LCCCB1      -mean(z32$LCCCB1      ,na.rm=T)
z32$LCCCB2c      <-z32$LCCCB2      -mean(z32$LCCCB2      ,na.rm=T)
z32$LCCB1c       <-z32$LCCB1       -mean(z32$LCCB1       ,na.rm=T)
z32$LCCB2c       <-z32$LCCB2       -mean(z32$LCCB2       ,na.rm=T)
z32$LCCCS1c      <-z32$LCCCS1      -mean(z32$LCCCS1      ,na.rm=T)
z32$LCCCS2c      <-z32$LCCCS2      -mean(z32$LCCCS2      ,na.rm=T)
z32$LCCS1c       <-z32$LCCS1       -mean(z32$LCCS1       ,na.rm=T)
z32$LCCS2c       <-z32$LCCS2       -mean(z32$LCCS2       ,na.rm=T)
z32$LCCCG1c      <-z32$LCCCG1      -mean(z32$LCCCG1      ,na.rm=T)
z32$LCCCG2c      <-z32$LCCCG2      -mean(z32$LCCCG2      ,na.rm=T)
z32$LCCG1c       <-z32$LCCG1       -mean(z32$LCCG1       ,na.rm=T)
z32$LCCG2c       <-z32$LCCG2       -mean(z32$LCCG2       ,na.rm=T)
z32$ChildCare1c  <-z32$ChildCare1  -mean(z32$ChildCare1  ,na.rm=T)
z32$ChildCare2c  <-z32$ChildCare2  -mean(z32$ChildCare2  ,na.rm=T)
z32$ChildCare3c  <-z32$ChildCare3  -mean(z32$ChildCare3  ,na.rm=T)
z32$CCAPc        <-z32$CCAP        -mean(z32$CCAP        ,na.rm=T)
z32$Homelessc    <-z32$Homeless    -mean(z32$Homeless    ,na.rm=T)
z32$Homeless2c   <-z32$Homeless2   -mean(z32$Homeless2   ,na.rm=T)
z32$DHS_HFIrc    <-z32$DHS_HFIr    -mean(z32$DHS_HFIr    ,na.rm=T)
z32$DHS_PTSrc    <-z32$DHS_PTSr    -mean(z32$DHS_PTSr    ,na.rm=T)
z32$DHS_HVPrc    <-z32$DHS_HVPr    -mean(z32$DHS_HVPr    ,na.rm=T)
z32$IDHS_EIrc    <-z32$IDHS_EIr    -mean(z32$IDHS_EIr    ,na.rm=T)
z32$MHV_C4c      <-z32$MHV_C4      -mean(z32$MHV_C4      ,na.rm=T)
z32$MHV_P4c      <-z32$MHV_P4      -mean(z32$MHV_P4      ,na.rm=T)
z32$MHV_C5c      <-z32$MHV_C5      -mean(z32$MHV_C5      ,na.rm=T)
z32$MHV_P5c      <-z32$MHV_P5      -mean(z32$MHV_P5      ,na.rm=T)
z32$FoodInsPc    <-z32$FoodInsP    -mean(z32$FoodInsP    ,na.rm=T)
z32$FoodISc      <-z32$FoodIS      -mean(z32$FoodIS      ,na.rm=T)
z32$RPovTc       <-z32$RPovT       -mean(z32$RPovT       ,na.rm=T)
z32$PovTc        <-z32$PovT        -mean(z32$PovT        ,na.rm=T)
z32$MHV_C4k <-z32$MHV_C4 *10
z32$MHV_C5k <-z32$MHV_C5 *10
z32$MHV_C4kc<-z32$MHV_C4c*10
z32$MHV_C5kc<-z32$MHV_C5c*10





# demean - within and between variables
z3<-cbind(z3,demean(z3,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z31<-cbind(z31,demean(z31,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
z32<-cbind(z32,demean(z32,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Male Children
# Income - Male Children
# Income - Male Children
# Income - Male Children
# Income - Male Children
# Income - Male Children
# Income - Male Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zm$Yearc        <-zm$Year        -mean(zm$Year        ,na.rm=T)
zm$CPopBPc      <-zm$CPopBP      -mean(zm$CPopBP      ,na.rm=T)
zm$CPopHPc      <-zm$CPopHP      -mean(zm$CPopHP      ,na.rm=T)
zm$ChildPTc     <-zm$ChildPT     -mean(zm$ChildPT     ,na.rm=T)
zm$ChildPWc     <-zm$ChildPW     -mean(zm$ChildPW     ,na.rm=T)
zm$ChildPBc     <-zm$ChildPB     -mean(zm$ChildPB     ,na.rm=T)
zm$ChildPHc     <-zm$ChildPH     -mean(zm$ChildPH     ,na.rm=T)
zm$CARatioT100c <-zm$CARatioT100 -mean(zm$CARatioT100 ,na.rm=T)
zm$CARatioW100c <-zm$CARatioW100 -mean(zm$CARatioW100 ,na.rm=T)
zm$CARatioB100c <-zm$CARatioB100 -mean(zm$CARatioB100 ,na.rm=T)
zm$CARatioH100c <-zm$CARatioH100 -mean(zm$CARatioH100 ,na.rm=T)
zm$MalePTc      <-zm$MalePT      -mean(zm$MalePT      ,na.rm=T)
zm$MalePWc      <-zm$MalePW      -mean(zm$MalePW      ,na.rm=T)
zm$MalePBc      <-zm$MalePB      -mean(zm$MalePB      ,na.rm=T)
zm$MalePHc      <-zm$MalePH      -mean(zm$MalePH      ,na.rm=T)
zm$MFRatioT100c <-zm$MFRatioT100 -mean(zm$MFRatioT100 ,na.rm=T)
zm$MFRatioW100c <-zm$MFRatioW100 -mean(zm$MFRatioW100 ,na.rm=T)
zm$MFRatioB100c <-zm$MFRatioB100 -mean(zm$MFRatioB100 ,na.rm=T)
zm$MFRatioH100c <-zm$MFRatioH100 -mean(zm$MFRatioH100 ,na.rm=T)
zm$ElderTc      <-zm$ElderT      -mean(zm$ElderT      ,na.rm=T)
zm$ElderWc      <-zm$ElderW      -mean(zm$ElderW      ,na.rm=T)
zm$ElderBc      <-zm$ElderB      -mean(zm$ElderB      ,na.rm=T)
zm$ElderHc      <-zm$ElderH      -mean(zm$ElderH      ,na.rm=T)
zm$SingleTc     <-zm$SingleT     -mean(zm$SingleT     ,na.rm=T)
zm$SingleWc     <-zm$SingleW     -mean(zm$SingleW     ,na.rm=T)
zm$SingleBc     <-zm$SingleB     -mean(zm$SingleB     ,na.rm=T)
zm$SingleHc     <-zm$SingleH     -mean(zm$SingleH     ,na.rm=T)
zm$FHeadTc      <-zm$FHeadT      -mean(zm$FHeadT      ,na.rm=T)
zm$FHeadWc      <-zm$FHeadW      -mean(zm$FHeadW      ,na.rm=T)
zm$FHeadBc      <-zm$FHeadB      -mean(zm$FHeadB      ,na.rm=T)
zm$FHeadHc      <-zm$FHeadH      -mean(zm$FHeadH      ,na.rm=T)
zm$NoHighTc     <-zm$NoHighT     -mean(zm$NoHighT     ,na.rm=T)
zm$NoHighWc     <-zm$NoHighW     -mean(zm$NoHighW     ,na.rm=T)
zm$NoHighBc     <-zm$NoHighB     -mean(zm$NoHighB     ,na.rm=T)
zm$NoHighHc     <-zm$NoHighH     -mean(zm$NoHighH     ,na.rm=T)
zm$UnempTc      <-zm$UnempT      -mean(zm$UnempT      ,na.rm=T)
zm$UnempWc      <-zm$UnempW      -mean(zm$UnempW      ,na.rm=T)
zm$UnempBc      <-zm$UnempB      -mean(zm$UnempB      ,na.rm=T)
zm$UnempHc      <-zm$UnempH      -mean(zm$UnempH      ,na.rm=T)
zm$CPovTc       <-zm$CPovT       -mean(zm$CPovT       ,na.rm=T)
zm$CPovWc       <-zm$CPovW       -mean(zm$CPovW       ,na.rm=T)
zm$CPovBc       <-zm$CPovB       -mean(zm$CPovB       ,na.rm=T)
zm$CPovHc       <-zm$CPovH       -mean(zm$CPovH       ,na.rm=T)
zm$CPov1c       <-zm$CPov1       -mean(zm$CPov1       ,na.rm=T)
zm$CPov2c       <-zm$CPov2       -mean(zm$CPov2       ,na.rm=T)
zm$CPov3c       <-zm$CPov3       -mean(zm$CPov3       ,na.rm=T)
zm$PubAsTc      <-zm$PubAsT      -mean(zm$PubAsT      ,na.rm=T)
zm$WelfarTc     <-zm$WelfarT     -mean(zm$WelfarT     ,na.rm=T)
zm$SnapTc       <-zm$SnapT       -mean(zm$SnapT       ,na.rm=T)
zm$SnapWc       <-zm$SnapW       -mean(zm$SnapW       ,na.rm=T)
zm$SnapBc       <-zm$SnapB       -mean(zm$SnapB       ,na.rm=T)
zm$SnapHc       <-zm$SnapH       -mean(zm$SnapH       ,na.rm=T)
zm$IncomeT1kc   <-zm$IncomeT1k   -mean(zm$IncomeT1k   ,na.rm=T)
zm$IncomeW1kc   <-zm$IncomeW1k   -mean(zm$IncomeW1k   ,na.rm=T)
zm$IncomeB1kc   <-zm$IncomeB1k   -mean(zm$IncomeB1k   ,na.rm=T)
zm$IncomeH1kc   <-zm$IncomeH1k   -mean(zm$IncomeH1k   ,na.rm=T)
zm$GiniT100c    <-zm$GiniT100    -mean(zm$GiniT100    ,na.rm=T)
zm$HValueT10kc  <-zm$HValueT10k  -mean(zm$HValueT10k  ,na.rm=T)
zm$MCostT100c   <-zm$MCostT100   -mean(zm$MCostT100   ,na.rm=T)
zm$OCostDT100c  <-zm$OCostDT100  -mean(zm$OCostDT100  ,na.rm=T)
zm$MRentDT100c  <-zm$MRentDT100  -mean(zm$MRentDT100  ,na.rm=T)
zm$OCostPTc     <-zm$OCostPT     -mean(zm$OCostPT     ,na.rm=T)
zm$MRentPTc     <-zm$MRentPT     -mean(zm$MRentPT     ,na.rm=T)
zm$MortgTc      <-zm$MortgT      -mean(zm$MortgT      ,na.rm=T)
zm$LangAPTc     <-zm$LangAPT     -mean(zm$LangAPT     ,na.rm=T)
zm$LangAPWc     <-zm$LangAPW     -mean(zm$LangAPW     ,na.rm=T)
zm$LangAPBc     <-zm$LangAPB     -mean(zm$LangAPB     ,na.rm=T)
zm$LangAPHc     <-zm$LangAPH     -mean(zm$LangAPH     ,na.rm=T)
zm$LangBPTc     <-zm$LangBPT     -mean(zm$LangBPT     ,na.rm=T)
zm$LangBPWc     <-zm$LangBPW     -mean(zm$LangBPW     ,na.rm=T)
zm$LangBPBc     <-zm$LangBPB     -mean(zm$LangBPB     ,na.rm=T)
zm$LangBPHc     <-zm$LangBPH     -mean(zm$LangBPH     ,na.rm=T)
zm$LangCPTc     <-zm$LangCPT     -mean(zm$LangCPT     ,na.rm=T)
zm$OutUsTc      <-zm$OutUsT      -mean(zm$OutUsT      ,na.rm=T)
zm$OutUsWc      <-zm$OutUsW      -mean(zm$OutUsW      ,na.rm=T)
zm$OutUsBc      <-zm$OutUsB      -mean(zm$OutUsB      ,na.rm=T)
zm$OutUsHc      <-zm$OutUsH      -mean(zm$OutUsH      ,na.rm=T)
zm$FBornTc      <-zm$FBornT      -mean(zm$FBornT      ,na.rm=T)
zm$FBornWc      <-zm$FBornW      -mean(zm$FBornW      ,na.rm=T)
zm$FBornBc      <-zm$FBornB      -mean(zm$FBornB      ,na.rm=T)
zm$FBornHc      <-zm$FBornH      -mean(zm$FBornH      ,na.rm=T)
zm$NotCtzTc     <-zm$NotCtzT     -mean(zm$NotCtzT     ,na.rm=T)
zm$NotCtzWc     <-zm$NotCtzW     -mean(zm$NotCtzW     ,na.rm=T)
zm$NotCtzBc     <-zm$NotCtzB     -mean(zm$NotCtzB     ,na.rm=T)
zm$NotCtzHc     <-zm$NotCtzH     -mean(zm$NotCtzH     ,na.rm=T)
zm$MoveTc       <-zm$MoveT       -mean(zm$MoveT       ,na.rm=T)
zm$MoveWc       <-zm$MoveW       -mean(zm$MoveW       ,na.rm=T)
zm$MoveBc       <-zm$MoveB       -mean(zm$MoveB       ,na.rm=T)
zm$MoveHc       <-zm$MoveH       -mean(zm$MoveH       ,na.rm=T)
zm$VacantTc     <-zm$VacantT     -mean(zm$VacantT     ,na.rm=T)
zm$OwnerTc      <-zm$OwnerT      -mean(zm$OwnerT      ,na.rm=T)
zm$OwnerWc      <-zm$OwnerW      -mean(zm$OwnerW      ,na.rm=T)
zm$OwnerBc      <-zm$OwnerB      -mean(zm$OwnerB      ,na.rm=T)
zm$OwnerHc      <-zm$OwnerH      -mean(zm$OwnerH      ,na.rm=T)
zm$CrowdTc      <-zm$CrowdT      -mean(zm$CrowdT      ,na.rm=T)
zm$CrowdWc      <-zm$CrowdW      -mean(zm$CrowdW      ,na.rm=T)
zm$CrowdBc      <-zm$CrowdB      -mean(zm$CrowdB      ,na.rm=T)
zm$CrowdHc      <-zm$CrowdH      -mean(zm$CrowdH      ,na.rm=T)
zm$MobileTc     <-zm$MobileT     -mean(zm$MobileT     ,na.rm=T)
zm$MobileWc     <-zm$MobileW     -mean(zm$MobileW     ,na.rm=T)
zm$MobileBc     <-zm$MobileB     -mean(zm$MobileB     ,na.rm=T)
zm$MobileHc     <-zm$MobileH     -mean(zm$MobileH     ,na.rm=T)
zm$DisablTc     <-zm$DisablT     -mean(zm$DisablT     ,na.rm=T)
zm$DisablWc     <-zm$DisablW     -mean(zm$DisablW     ,na.rm=T)
zm$DisablBc     <-zm$DisablB     -mean(zm$DisablB     ,na.rm=T)
zm$DisablHc     <-zm$DisablH     -mean(zm$DisablH     ,na.rm=T)
zm$DisablTCc    <-zm$DisablTC    -mean(zm$DisablTC    ,na.rm=T)
zm$DisablWCc    <-zm$DisablWC    -mean(zm$DisablWC    ,na.rm=T)
zm$DisablBCc    <-zm$DisablBC    -mean(zm$DisablBC    ,na.rm=T)
zm$DisablHCc    <-zm$DisablHC    -mean(zm$DisablHC    ,na.rm=T)
zm$DisablTMc    <-zm$DisablTM    -mean(zm$DisablTM    ,na.rm=T)
zm$DisablTFc    <-zm$DisablTF    -mean(zm$DisablTF    ,na.rm=T)
zm$Urban1c      <-zm$Urban1      -mean(zm$Urban1      ,na.rm=T)
zm$Urban2c      <-zm$Urban2      -mean(zm$Urban2      ,na.rm=T)
zm$ISBE_PFAc    <-zm$ISBE_PFA    -mean(zm$ISBE_PFA    ,na.rm=T)
zm$ISBE_PFAEc   <-zm$ISBE_PFAE   -mean(zm$ISBE_PFAE   ,na.rm=T)
zm$ISBE_PIc     <-zm$ISBE_PI     -mean(zm$ISBE_PI     ,na.rm=T)
zm$HeadStartc   <-zm$HeadStart   -mean(zm$HeadStart   ,na.rm=T)
zm$ElyHeadSc    <-zm$ElyHeadS    -mean(zm$ElyHeadS    ,na.rm=T)
zm$HeadSAllc    <-zm$HeadSAll    -mean(zm$HeadSAll    ,na.rm=T)
zm$PFA_HS1c     <-zm$PFA_HS1     -mean(zm$PFA_HS1     ,na.rm=T)
zm$PFA_HS2c     <-zm$PFA_HS2     -mean(zm$PFA_HS2     ,na.rm=T)
zm$LCCCc        <-zm$LCCC        -mean(zm$LCCC        ,na.rm=T)
zm$LECCCc       <-zm$LECCC       -mean(zm$LECCC       ,na.rm=T)
zm$LFCCc        <-zm$LFCC        -mean(zm$LFCC        ,na.rm=T)
zm$LLECCCc      <-zm$LLECCC      -mean(zm$LLECCC      ,na.rm=T)
zm$LCLFCCc      <-zm$LCLFCC      -mean(zm$LCLFCC      ,na.rm=T)
zm$LCCCB1c      <-zm$LCCCB1      -mean(zm$LCCCB1      ,na.rm=T)
zm$LCCCB2c      <-zm$LCCCB2      -mean(zm$LCCCB2      ,na.rm=T)
zm$LCCB1c       <-zm$LCCB1       -mean(zm$LCCB1       ,na.rm=T)
zm$LCCB2c       <-zm$LCCB2       -mean(zm$LCCB2       ,na.rm=T)
zm$LCCCS1c      <-zm$LCCCS1      -mean(zm$LCCCS1      ,na.rm=T)
zm$LCCCS2c      <-zm$LCCCS2      -mean(zm$LCCCS2      ,na.rm=T)
zm$LCCS1c       <-zm$LCCS1       -mean(zm$LCCS1       ,na.rm=T)
zm$LCCS2c       <-zm$LCCS2       -mean(zm$LCCS2       ,na.rm=T)
zm$LCCCG1c      <-zm$LCCCG1      -mean(zm$LCCCG1      ,na.rm=T)
zm$LCCCG2c      <-zm$LCCCG2      -mean(zm$LCCCG2      ,na.rm=T)
zm$LCCG1c       <-zm$LCCG1       -mean(zm$LCCG1       ,na.rm=T)
zm$LCCG2c       <-zm$LCCG2       -mean(zm$LCCG2       ,na.rm=T)
zm$ChildCare1c  <-zm$ChildCare1  -mean(zm$ChildCare1  ,na.rm=T)
zm$ChildCare2c  <-zm$ChildCare2  -mean(zm$ChildCare2  ,na.rm=T)
zm$ChildCare3c  <-zm$ChildCare3  -mean(zm$ChildCare3  ,na.rm=T)
zm$CCAPc        <-zm$CCAP        -mean(zm$CCAP        ,na.rm=T)
zm$Homelessc    <-zm$Homeless    -mean(zm$Homeless    ,na.rm=T)
zm$Homeless2c   <-zm$Homeless2   -mean(zm$Homeless2   ,na.rm=T)
zm$DHS_HFIrc    <-zm$DHS_HFIr    -mean(zm$DHS_HFIr    ,na.rm=T)
zm$DHS_PTSrc    <-zm$DHS_PTSr    -mean(zm$DHS_PTSr    ,na.rm=T)
zm$DHS_HVPrc    <-zm$DHS_HVPr    -mean(zm$DHS_HVPr    ,na.rm=T)
zm$IDHS_EIrc    <-zm$IDHS_EIr    -mean(zm$IDHS_EIr    ,na.rm=T)
zm$MHV_C4c      <-zm$MHV_C4      -mean(zm$MHV_C4      ,na.rm=T)
zm$MHV_P4c      <-zm$MHV_P4      -mean(zm$MHV_P4      ,na.rm=T)
zm$MHV_C5c      <-zm$MHV_C5      -mean(zm$MHV_C5      ,na.rm=T)
zm$MHV_P5c      <-zm$MHV_P5      -mean(zm$MHV_P5      ,na.rm=T)
zm$FoodInsPc    <-zm$FoodInsP    -mean(zm$FoodInsP    ,na.rm=T)
zm$FoodISc      <-zm$FoodIS      -mean(zm$FoodIS      ,na.rm=T)
zm$RPovTc       <-zm$RPovT       -mean(zm$RPovT       ,na.rm=T)
zm$PovTc        <-zm$PovT        -mean(zm$PovT        ,na.rm=T)
zm$MHV_C4k <-zm$MHV_C4 *10
zm$MHV_C5k <-zm$MHV_C5 *10
zm$MHV_C4kc<-zm$MHV_C4c*10
zm$MHV_C5kc<-zm$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zm1$Yearc        <-zm1$Year        -mean(zm1$Year        ,na.rm=T)
zm1$CPopBPc      <-zm1$CPopBP      -mean(zm1$CPopBP      ,na.rm=T)
zm1$CPopHPc      <-zm1$CPopHP      -mean(zm1$CPopHP      ,na.rm=T)
zm1$ChildPTc     <-zm1$ChildPT     -mean(zm1$ChildPT     ,na.rm=T)
zm1$ChildPWc     <-zm1$ChildPW     -mean(zm1$ChildPW     ,na.rm=T)
zm1$ChildPBc     <-zm1$ChildPB     -mean(zm1$ChildPB     ,na.rm=T)
zm1$ChildPHc     <-zm1$ChildPH     -mean(zm1$ChildPH     ,na.rm=T)
zm1$CARatioT100c <-zm1$CARatioT100 -mean(zm1$CARatioT100 ,na.rm=T)
zm1$CARatioW100c <-zm1$CARatioW100 -mean(zm1$CARatioW100 ,na.rm=T)
zm1$CARatioB100c <-zm1$CARatioB100 -mean(zm1$CARatioB100 ,na.rm=T)
zm1$CARatioH100c <-zm1$CARatioH100 -mean(zm1$CARatioH100 ,na.rm=T)
zm1$MalePTc      <-zm1$MalePT      -mean(zm1$MalePT      ,na.rm=T)
zm1$MalePWc      <-zm1$MalePW      -mean(zm1$MalePW      ,na.rm=T)
zm1$MalePBc      <-zm1$MalePB      -mean(zm1$MalePB      ,na.rm=T)
zm1$MalePHc      <-zm1$MalePH      -mean(zm1$MalePH      ,na.rm=T)
zm1$MFRatioT100c <-zm1$MFRatioT100 -mean(zm1$MFRatioT100 ,na.rm=T)
zm1$MFRatioW100c <-zm1$MFRatioW100 -mean(zm1$MFRatioW100 ,na.rm=T)
zm1$MFRatioB100c <-zm1$MFRatioB100 -mean(zm1$MFRatioB100 ,na.rm=T)
zm1$MFRatioH100c <-zm1$MFRatioH100 -mean(zm1$MFRatioH100 ,na.rm=T)
zm1$ElderTc      <-zm1$ElderT      -mean(zm1$ElderT      ,na.rm=T)
zm1$ElderWc      <-zm1$ElderW      -mean(zm1$ElderW      ,na.rm=T)
zm1$ElderBc      <-zm1$ElderB      -mean(zm1$ElderB      ,na.rm=T)
zm1$ElderHc      <-zm1$ElderH      -mean(zm1$ElderH      ,na.rm=T)
zm1$SingleTc     <-zm1$SingleT     -mean(zm1$SingleT     ,na.rm=T)
zm1$SingleWc     <-zm1$SingleW     -mean(zm1$SingleW     ,na.rm=T)
zm1$SingleBc     <-zm1$SingleB     -mean(zm1$SingleB     ,na.rm=T)
zm1$SingleHc     <-zm1$SingleH     -mean(zm1$SingleH     ,na.rm=T)
zm1$FHeadTc      <-zm1$FHeadT      -mean(zm1$FHeadT      ,na.rm=T)
zm1$FHeadWc      <-zm1$FHeadW      -mean(zm1$FHeadW      ,na.rm=T)
zm1$FHeadBc      <-zm1$FHeadB      -mean(zm1$FHeadB      ,na.rm=T)
zm1$FHeadHc      <-zm1$FHeadH      -mean(zm1$FHeadH      ,na.rm=T)
zm1$NoHighTc     <-zm1$NoHighT     -mean(zm1$NoHighT     ,na.rm=T)
zm1$NoHighWc     <-zm1$NoHighW     -mean(zm1$NoHighW     ,na.rm=T)
zm1$NoHighBc     <-zm1$NoHighB     -mean(zm1$NoHighB     ,na.rm=T)
zm1$NoHighHc     <-zm1$NoHighH     -mean(zm1$NoHighH     ,na.rm=T)
zm1$UnempTc      <-zm1$UnempT      -mean(zm1$UnempT      ,na.rm=T)
zm1$UnempWc      <-zm1$UnempW      -mean(zm1$UnempW      ,na.rm=T)
zm1$UnempBc      <-zm1$UnempB      -mean(zm1$UnempB      ,na.rm=T)
zm1$UnempHc      <-zm1$UnempH      -mean(zm1$UnempH      ,na.rm=T)
zm1$CPovTc       <-zm1$CPovT       -mean(zm1$CPovT       ,na.rm=T)
zm1$CPovWc       <-zm1$CPovW       -mean(zm1$CPovW       ,na.rm=T)
zm1$CPovBc       <-zm1$CPovB       -mean(zm1$CPovB       ,na.rm=T)
zm1$CPovHc       <-zm1$CPovH       -mean(zm1$CPovH       ,na.rm=T)
zm1$CPov1c       <-zm1$CPov1       -mean(zm1$CPov1       ,na.rm=T)
zm1$CPov2c       <-zm1$CPov2       -mean(zm1$CPov2       ,na.rm=T)
zm1$CPov3c       <-zm1$CPov3       -mean(zm1$CPov3       ,na.rm=T)
zm1$PubAsTc      <-zm1$PubAsT      -mean(zm1$PubAsT      ,na.rm=T)
zm1$WelfarTc     <-zm1$WelfarT     -mean(zm1$WelfarT     ,na.rm=T)
zm1$SnapTc       <-zm1$SnapT       -mean(zm1$SnapT       ,na.rm=T)
zm1$SnapWc       <-zm1$SnapW       -mean(zm1$SnapW       ,na.rm=T)
zm1$SnapBc       <-zm1$SnapB       -mean(zm1$SnapB       ,na.rm=T)
zm1$SnapHc       <-zm1$SnapH       -mean(zm1$SnapH       ,na.rm=T)
zm1$IncomeT1kc   <-zm1$IncomeT1k   -mean(zm1$IncomeT1k   ,na.rm=T)
zm1$IncomeW1kc   <-zm1$IncomeW1k   -mean(zm1$IncomeW1k   ,na.rm=T)
zm1$IncomeB1kc   <-zm1$IncomeB1k   -mean(zm1$IncomeB1k   ,na.rm=T)
zm1$IncomeH1kc   <-zm1$IncomeH1k   -mean(zm1$IncomeH1k   ,na.rm=T)
zm1$GiniT100c    <-zm1$GiniT100    -mean(zm1$GiniT100    ,na.rm=T)
zm1$HValueT10kc  <-zm1$HValueT10k  -mean(zm1$HValueT10k  ,na.rm=T)
zm1$MCostT100c   <-zm1$MCostT100   -mean(zm1$MCostT100   ,na.rm=T)
zm1$OCostDT100c  <-zm1$OCostDT100  -mean(zm1$OCostDT100  ,na.rm=T)
zm1$MRentDT100c  <-zm1$MRentDT100  -mean(zm1$MRentDT100  ,na.rm=T)
zm1$OCostPTc     <-zm1$OCostPT     -mean(zm1$OCostPT     ,na.rm=T)
zm1$MRentPTc     <-zm1$MRentPT     -mean(zm1$MRentPT     ,na.rm=T)
zm1$MortgTc      <-zm1$MortgT      -mean(zm1$MortgT      ,na.rm=T)
zm1$LangAPTc     <-zm1$LangAPT     -mean(zm1$LangAPT     ,na.rm=T)
zm1$LangAPWc     <-zm1$LangAPW     -mean(zm1$LangAPW     ,na.rm=T)
zm1$LangAPBc     <-zm1$LangAPB     -mean(zm1$LangAPB     ,na.rm=T)
zm1$LangAPHc     <-zm1$LangAPH     -mean(zm1$LangAPH     ,na.rm=T)
zm1$LangBPTc     <-zm1$LangBPT     -mean(zm1$LangBPT     ,na.rm=T)
zm1$LangBPWc     <-zm1$LangBPW     -mean(zm1$LangBPW     ,na.rm=T)
zm1$LangBPBc     <-zm1$LangBPB     -mean(zm1$LangBPB     ,na.rm=T)
zm1$LangBPHc     <-zm1$LangBPH     -mean(zm1$LangBPH     ,na.rm=T)
zm1$LangCPTc     <-zm1$LangCPT     -mean(zm1$LangCPT     ,na.rm=T)
zm1$OutUsTc      <-zm1$OutUsT      -mean(zm1$OutUsT      ,na.rm=T)
zm1$OutUsWc      <-zm1$OutUsW      -mean(zm1$OutUsW      ,na.rm=T)
zm1$OutUsBc      <-zm1$OutUsB      -mean(zm1$OutUsB      ,na.rm=T)
zm1$OutUsHc      <-zm1$OutUsH      -mean(zm1$OutUsH      ,na.rm=T)
zm1$FBornTc      <-zm1$FBornT      -mean(zm1$FBornT      ,na.rm=T)
zm1$FBornWc      <-zm1$FBornW      -mean(zm1$FBornW      ,na.rm=T)
zm1$FBornBc      <-zm1$FBornB      -mean(zm1$FBornB      ,na.rm=T)
zm1$FBornHc      <-zm1$FBornH      -mean(zm1$FBornH      ,na.rm=T)
zm1$NotCtzTc     <-zm1$NotCtzT     -mean(zm1$NotCtzT     ,na.rm=T)
zm1$NotCtzWc     <-zm1$NotCtzW     -mean(zm1$NotCtzW     ,na.rm=T)
zm1$NotCtzBc     <-zm1$NotCtzB     -mean(zm1$NotCtzB     ,na.rm=T)
zm1$NotCtzHc     <-zm1$NotCtzH     -mean(zm1$NotCtzH     ,na.rm=T)
zm1$MoveTc       <-zm1$MoveT       -mean(zm1$MoveT       ,na.rm=T)
zm1$MoveWc       <-zm1$MoveW       -mean(zm1$MoveW       ,na.rm=T)
zm1$MoveBc       <-zm1$MoveB       -mean(zm1$MoveB       ,na.rm=T)
zm1$MoveHc       <-zm1$MoveH       -mean(zm1$MoveH       ,na.rm=T)
zm1$VacantTc     <-zm1$VacantT     -mean(zm1$VacantT     ,na.rm=T)
zm1$OwnerTc      <-zm1$OwnerT      -mean(zm1$OwnerT      ,na.rm=T)
zm1$OwnerWc      <-zm1$OwnerW      -mean(zm1$OwnerW      ,na.rm=T)
zm1$OwnerBc      <-zm1$OwnerB      -mean(zm1$OwnerB      ,na.rm=T)
zm1$OwnerHc      <-zm1$OwnerH      -mean(zm1$OwnerH      ,na.rm=T)
zm1$CrowdTc      <-zm1$CrowdT      -mean(zm1$CrowdT      ,na.rm=T)
zm1$CrowdWc      <-zm1$CrowdW      -mean(zm1$CrowdW      ,na.rm=T)
zm1$CrowdBc      <-zm1$CrowdB      -mean(zm1$CrowdB      ,na.rm=T)
zm1$CrowdHc      <-zm1$CrowdH      -mean(zm1$CrowdH      ,na.rm=T)
zm1$MobileTc     <-zm1$MobileT     -mean(zm1$MobileT     ,na.rm=T)
zm1$MobileWc     <-zm1$MobileW     -mean(zm1$MobileW     ,na.rm=T)
zm1$MobileBc     <-zm1$MobileB     -mean(zm1$MobileB     ,na.rm=T)
zm1$MobileHc     <-zm1$MobileH     -mean(zm1$MobileH     ,na.rm=T)
zm1$DisablTc     <-zm1$DisablT     -mean(zm1$DisablT     ,na.rm=T)
zm1$DisablWc     <-zm1$DisablW     -mean(zm1$DisablW     ,na.rm=T)
zm1$DisablBc     <-zm1$DisablB     -mean(zm1$DisablB     ,na.rm=T)
zm1$DisablHc     <-zm1$DisablH     -mean(zm1$DisablH     ,na.rm=T)
zm1$DisablTCc    <-zm1$DisablTC    -mean(zm1$DisablTC    ,na.rm=T)
zm1$DisablWCc    <-zm1$DisablWC    -mean(zm1$DisablWC    ,na.rm=T)
zm1$DisablBCc    <-zm1$DisablBC    -mean(zm1$DisablBC    ,na.rm=T)
zm1$DisablHCc    <-zm1$DisablHC    -mean(zm1$DisablHC    ,na.rm=T)
zm1$DisablTMc    <-zm1$DisablTM    -mean(zm1$DisablTM    ,na.rm=T)
zm1$DisablTFc    <-zm1$DisablTF    -mean(zm1$DisablTF    ,na.rm=T)
zm1$Urban1c      <-zm1$Urban1      -mean(zm1$Urban1      ,na.rm=T)
zm1$Urban2c      <-zm1$Urban2      -mean(zm1$Urban2      ,na.rm=T)
zm1$ISBE_PFAc    <-zm1$ISBE_PFA    -mean(zm1$ISBE_PFA    ,na.rm=T)
zm1$ISBE_PFAEc   <-zm1$ISBE_PFAE   -mean(zm1$ISBE_PFAE   ,na.rm=T)
zm1$ISBE_PIc     <-zm1$ISBE_PI     -mean(zm1$ISBE_PI     ,na.rm=T)
zm1$HeadStartc   <-zm1$HeadStart   -mean(zm1$HeadStart   ,na.rm=T)
zm1$ElyHeadSc    <-zm1$ElyHeadS    -mean(zm1$ElyHeadS    ,na.rm=T)
zm1$HeadSAllc    <-zm1$HeadSAll    -mean(zm1$HeadSAll    ,na.rm=T)
zm1$PFA_HS1c     <-zm1$PFA_HS1     -mean(zm1$PFA_HS1     ,na.rm=T)
zm1$PFA_HS2c     <-zm1$PFA_HS2     -mean(zm1$PFA_HS2     ,na.rm=T)
zm1$LCCCc        <-zm1$LCCC        -mean(zm1$LCCC        ,na.rm=T)
zm1$LECCCc       <-zm1$LECCC       -mean(zm1$LECCC       ,na.rm=T)
zm1$LFCCc        <-zm1$LFCC        -mean(zm1$LFCC        ,na.rm=T)
zm1$LLECCCc      <-zm1$LLECCC      -mean(zm1$LLECCC      ,na.rm=T)
zm1$LCLFCCc      <-zm1$LCLFCC      -mean(zm1$LCLFCC      ,na.rm=T)
zm1$LCCCB1c      <-zm1$LCCCB1      -mean(zm1$LCCCB1      ,na.rm=T)
zm1$LCCCB2c      <-zm1$LCCCB2      -mean(zm1$LCCCB2      ,na.rm=T)
zm1$LCCB1c       <-zm1$LCCB1       -mean(zm1$LCCB1       ,na.rm=T)
zm1$LCCB2c       <-zm1$LCCB2       -mean(zm1$LCCB2       ,na.rm=T)
zm1$LCCCS1c      <-zm1$LCCCS1      -mean(zm1$LCCCS1      ,na.rm=T)
zm1$LCCCS2c      <-zm1$LCCCS2      -mean(zm1$LCCCS2      ,na.rm=T)
zm1$LCCS1c       <-zm1$LCCS1       -mean(zm1$LCCS1       ,na.rm=T)
zm1$LCCS2c       <-zm1$LCCS2       -mean(zm1$LCCS2       ,na.rm=T)
zm1$LCCCG1c      <-zm1$LCCCG1      -mean(zm1$LCCCG1      ,na.rm=T)
zm1$LCCCG2c      <-zm1$LCCCG2      -mean(zm1$LCCCG2      ,na.rm=T)
zm1$LCCG1c       <-zm1$LCCG1       -mean(zm1$LCCG1       ,na.rm=T)
zm1$LCCG2c       <-zm1$LCCG2       -mean(zm1$LCCG2       ,na.rm=T)
zm1$ChildCare1c  <-zm1$ChildCare1  -mean(zm1$ChildCare1  ,na.rm=T)
zm1$ChildCare2c  <-zm1$ChildCare2  -mean(zm1$ChildCare2  ,na.rm=T)
zm1$ChildCare3c  <-zm1$ChildCare3  -mean(zm1$ChildCare3  ,na.rm=T)
zm1$CCAPc        <-zm1$CCAP        -mean(zm1$CCAP        ,na.rm=T)
zm1$Homelessc    <-zm1$Homeless    -mean(zm1$Homeless    ,na.rm=T)
zm1$Homeless2c   <-zm1$Homeless2   -mean(zm1$Homeless2   ,na.rm=T)
zm1$DHS_HFIrc    <-zm1$DHS_HFIr    -mean(zm1$DHS_HFIr    ,na.rm=T)
zm1$DHS_PTSrc    <-zm1$DHS_PTSr    -mean(zm1$DHS_PTSr    ,na.rm=T)
zm1$DHS_HVPrc    <-zm1$DHS_HVPr    -mean(zm1$DHS_HVPr    ,na.rm=T)
zm1$IDHS_EIrc    <-zm1$IDHS_EIr    -mean(zm1$IDHS_EIr    ,na.rm=T)
zm1$MHV_C4c      <-zm1$MHV_C4      -mean(zm1$MHV_C4      ,na.rm=T)
zm1$MHV_P4c      <-zm1$MHV_P4      -mean(zm1$MHV_P4      ,na.rm=T)
zm1$MHV_C5c      <-zm1$MHV_C5      -mean(zm1$MHV_C5      ,na.rm=T)
zm1$MHV_P5c      <-zm1$MHV_P5      -mean(zm1$MHV_P5      ,na.rm=T)
zm1$FoodInsPc    <-zm1$FoodInsP    -mean(zm1$FoodInsP    ,na.rm=T)
zm1$FoodISc      <-zm1$FoodIS      -mean(zm1$FoodIS      ,na.rm=T)
zm1$RPovTc       <-zm1$RPovT       -mean(zm1$RPovT       ,na.rm=T)
zm1$PovTc        <-zm1$PovT        -mean(zm1$PovT        ,na.rm=T)
zm1$MHV_C4k <-zm1$MHV_C4 *10
zm1$MHV_C5k <-zm1$MHV_C5 *10
zm1$MHV_C4kc<-zm1$MHV_C4c*10
zm1$MHV_C5kc<-zm1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zm2$Yearc        <-zm2$Year        -mean(zm2$Year        ,na.rm=T)
zm2$CPopBPc      <-zm2$CPopBP      -mean(zm2$CPopBP      ,na.rm=T)
zm2$CPopHPc      <-zm2$CPopHP      -mean(zm2$CPopHP      ,na.rm=T)
zm2$ChildPTc     <-zm2$ChildPT     -mean(zm2$ChildPT     ,na.rm=T)
zm2$ChildPWc     <-zm2$ChildPW     -mean(zm2$ChildPW     ,na.rm=T)
zm2$ChildPBc     <-zm2$ChildPB     -mean(zm2$ChildPB     ,na.rm=T)
zm2$ChildPHc     <-zm2$ChildPH     -mean(zm2$ChildPH     ,na.rm=T)
zm2$CARatioT100c <-zm2$CARatioT100 -mean(zm2$CARatioT100 ,na.rm=T)
zm2$CARatioW100c <-zm2$CARatioW100 -mean(zm2$CARatioW100 ,na.rm=T)
zm2$CARatioB100c <-zm2$CARatioB100 -mean(zm2$CARatioB100 ,na.rm=T)
zm2$CARatioH100c <-zm2$CARatioH100 -mean(zm2$CARatioH100 ,na.rm=T)
zm2$MalePTc      <-zm2$MalePT      -mean(zm2$MalePT      ,na.rm=T)
zm2$MalePWc      <-zm2$MalePW      -mean(zm2$MalePW      ,na.rm=T)
zm2$MalePBc      <-zm2$MalePB      -mean(zm2$MalePB      ,na.rm=T)
zm2$MalePHc      <-zm2$MalePH      -mean(zm2$MalePH      ,na.rm=T)
zm2$MFRatioT100c <-zm2$MFRatioT100 -mean(zm2$MFRatioT100 ,na.rm=T)
zm2$MFRatioW100c <-zm2$MFRatioW100 -mean(zm2$MFRatioW100 ,na.rm=T)
zm2$MFRatioB100c <-zm2$MFRatioB100 -mean(zm2$MFRatioB100 ,na.rm=T)
zm2$MFRatioH100c <-zm2$MFRatioH100 -mean(zm2$MFRatioH100 ,na.rm=T)
zm2$ElderTc      <-zm2$ElderT      -mean(zm2$ElderT      ,na.rm=T)
zm2$ElderWc      <-zm2$ElderW      -mean(zm2$ElderW      ,na.rm=T)
zm2$ElderBc      <-zm2$ElderB      -mean(zm2$ElderB      ,na.rm=T)
zm2$ElderHc      <-zm2$ElderH      -mean(zm2$ElderH      ,na.rm=T)
zm2$SingleTc     <-zm2$SingleT     -mean(zm2$SingleT     ,na.rm=T)
zm2$SingleWc     <-zm2$SingleW     -mean(zm2$SingleW     ,na.rm=T)
zm2$SingleBc     <-zm2$SingleB     -mean(zm2$SingleB     ,na.rm=T)
zm2$SingleHc     <-zm2$SingleH     -mean(zm2$SingleH     ,na.rm=T)
zm2$FHeadTc      <-zm2$FHeadT      -mean(zm2$FHeadT      ,na.rm=T)
zm2$FHeadWc      <-zm2$FHeadW      -mean(zm2$FHeadW      ,na.rm=T)
zm2$FHeadBc      <-zm2$FHeadB      -mean(zm2$FHeadB      ,na.rm=T)
zm2$FHeadHc      <-zm2$FHeadH      -mean(zm2$FHeadH      ,na.rm=T)
zm2$NoHighTc     <-zm2$NoHighT     -mean(zm2$NoHighT     ,na.rm=T)
zm2$NoHighWc     <-zm2$NoHighW     -mean(zm2$NoHighW     ,na.rm=T)
zm2$NoHighBc     <-zm2$NoHighB     -mean(zm2$NoHighB     ,na.rm=T)
zm2$NoHighHc     <-zm2$NoHighH     -mean(zm2$NoHighH     ,na.rm=T)
zm2$UnempTc      <-zm2$UnempT      -mean(zm2$UnempT      ,na.rm=T)
zm2$UnempWc      <-zm2$UnempW      -mean(zm2$UnempW      ,na.rm=T)
zm2$UnempBc      <-zm2$UnempB      -mean(zm2$UnempB      ,na.rm=T)
zm2$UnempHc      <-zm2$UnempH      -mean(zm2$UnempH      ,na.rm=T)
zm2$CPovTc       <-zm2$CPovT       -mean(zm2$CPovT       ,na.rm=T)
zm2$CPovWc       <-zm2$CPovW       -mean(zm2$CPovW       ,na.rm=T)
zm2$CPovBc       <-zm2$CPovB       -mean(zm2$CPovB       ,na.rm=T)
zm2$CPovHc       <-zm2$CPovH       -mean(zm2$CPovH       ,na.rm=T)
zm2$CPov1c       <-zm2$CPov1       -mean(zm2$CPov1       ,na.rm=T)
zm2$CPov2c       <-zm2$CPov2       -mean(zm2$CPov2       ,na.rm=T)
zm2$CPov3c       <-zm2$CPov3       -mean(zm2$CPov3       ,na.rm=T)
zm2$PubAsTc      <-zm2$PubAsT      -mean(zm2$PubAsT      ,na.rm=T)
zm2$WelfarTc     <-zm2$WelfarT     -mean(zm2$WelfarT     ,na.rm=T)
zm2$SnapTc       <-zm2$SnapT       -mean(zm2$SnapT       ,na.rm=T)
zm2$SnapWc       <-zm2$SnapW       -mean(zm2$SnapW       ,na.rm=T)
zm2$SnapBc       <-zm2$SnapB       -mean(zm2$SnapB       ,na.rm=T)
zm2$SnapHc       <-zm2$SnapH       -mean(zm2$SnapH       ,na.rm=T)
zm2$IncomeT1kc   <-zm2$IncomeT1k   -mean(zm2$IncomeT1k   ,na.rm=T)
zm2$IncomeW1kc   <-zm2$IncomeW1k   -mean(zm2$IncomeW1k   ,na.rm=T)
zm2$IncomeB1kc   <-zm2$IncomeB1k   -mean(zm2$IncomeB1k   ,na.rm=T)
zm2$IncomeH1kc   <-zm2$IncomeH1k   -mean(zm2$IncomeH1k   ,na.rm=T)
zm2$GiniT100c    <-zm2$GiniT100    -mean(zm2$GiniT100    ,na.rm=T)
zm2$HValueT10kc  <-zm2$HValueT10k  -mean(zm2$HValueT10k  ,na.rm=T)
zm2$MCostT100c   <-zm2$MCostT100   -mean(zm2$MCostT100   ,na.rm=T)
zm2$OCostDT100c  <-zm2$OCostDT100  -mean(zm2$OCostDT100  ,na.rm=T)
zm2$MRentDT100c  <-zm2$MRentDT100  -mean(zm2$MRentDT100  ,na.rm=T)
zm2$OCostPTc     <-zm2$OCostPT     -mean(zm2$OCostPT     ,na.rm=T)
zm2$MRentPTc     <-zm2$MRentPT     -mean(zm2$MRentPT     ,na.rm=T)
zm2$MortgTc      <-zm2$MortgT      -mean(zm2$MortgT      ,na.rm=T)
zm2$LangAPTc     <-zm2$LangAPT     -mean(zm2$LangAPT     ,na.rm=T)
zm2$LangAPWc     <-zm2$LangAPW     -mean(zm2$LangAPW     ,na.rm=T)
zm2$LangAPBc     <-zm2$LangAPB     -mean(zm2$LangAPB     ,na.rm=T)
zm2$LangAPHc     <-zm2$LangAPH     -mean(zm2$LangAPH     ,na.rm=T)
zm2$LangBPTc     <-zm2$LangBPT     -mean(zm2$LangBPT     ,na.rm=T)
zm2$LangBPWc     <-zm2$LangBPW     -mean(zm2$LangBPW     ,na.rm=T)
zm2$LangBPBc     <-zm2$LangBPB     -mean(zm2$LangBPB     ,na.rm=T)
zm2$LangBPHc     <-zm2$LangBPH     -mean(zm2$LangBPH     ,na.rm=T)
zm2$LangCPTc     <-zm2$LangCPT     -mean(zm2$LangCPT     ,na.rm=T)
zm2$OutUsTc      <-zm2$OutUsT      -mean(zm2$OutUsT      ,na.rm=T)
zm2$OutUsWc      <-zm2$OutUsW      -mean(zm2$OutUsW      ,na.rm=T)
zm2$OutUsBc      <-zm2$OutUsB      -mean(zm2$OutUsB      ,na.rm=T)
zm2$OutUsHc      <-zm2$OutUsH      -mean(zm2$OutUsH      ,na.rm=T)
zm2$FBornTc      <-zm2$FBornT      -mean(zm2$FBornT      ,na.rm=T)
zm2$FBornWc      <-zm2$FBornW      -mean(zm2$FBornW      ,na.rm=T)
zm2$FBornBc      <-zm2$FBornB      -mean(zm2$FBornB      ,na.rm=T)
zm2$FBornHc      <-zm2$FBornH      -mean(zm2$FBornH      ,na.rm=T)
zm2$NotCtzTc     <-zm2$NotCtzT     -mean(zm2$NotCtzT     ,na.rm=T)
zm2$NotCtzWc     <-zm2$NotCtzW     -mean(zm2$NotCtzW     ,na.rm=T)
zm2$NotCtzBc     <-zm2$NotCtzB     -mean(zm2$NotCtzB     ,na.rm=T)
zm2$NotCtzHc     <-zm2$NotCtzH     -mean(zm2$NotCtzH     ,na.rm=T)
zm2$MoveTc       <-zm2$MoveT       -mean(zm2$MoveT       ,na.rm=T)
zm2$MoveWc       <-zm2$MoveW       -mean(zm2$MoveW       ,na.rm=T)
zm2$MoveBc       <-zm2$MoveB       -mean(zm2$MoveB       ,na.rm=T)
zm2$MoveHc       <-zm2$MoveH       -mean(zm2$MoveH       ,na.rm=T)
zm2$VacantTc     <-zm2$VacantT     -mean(zm2$VacantT     ,na.rm=T)
zm2$OwnerTc      <-zm2$OwnerT      -mean(zm2$OwnerT      ,na.rm=T)
zm2$OwnerWc      <-zm2$OwnerW      -mean(zm2$OwnerW      ,na.rm=T)
zm2$OwnerBc      <-zm2$OwnerB      -mean(zm2$OwnerB      ,na.rm=T)
zm2$OwnerHc      <-zm2$OwnerH      -mean(zm2$OwnerH      ,na.rm=T)
zm2$CrowdTc      <-zm2$CrowdT      -mean(zm2$CrowdT      ,na.rm=T)
zm2$CrowdWc      <-zm2$CrowdW      -mean(zm2$CrowdW      ,na.rm=T)
zm2$CrowdBc      <-zm2$CrowdB      -mean(zm2$CrowdB      ,na.rm=T)
zm2$CrowdHc      <-zm2$CrowdH      -mean(zm2$CrowdH      ,na.rm=T)
zm2$MobileTc     <-zm2$MobileT     -mean(zm2$MobileT     ,na.rm=T)
zm2$MobileWc     <-zm2$MobileW     -mean(zm2$MobileW     ,na.rm=T)
zm2$MobileBc     <-zm2$MobileB     -mean(zm2$MobileB     ,na.rm=T)
zm2$MobileHc     <-zm2$MobileH     -mean(zm2$MobileH     ,na.rm=T)
zm2$DisablTc     <-zm2$DisablT     -mean(zm2$DisablT     ,na.rm=T)
zm2$DisablWc     <-zm2$DisablW     -mean(zm2$DisablW     ,na.rm=T)
zm2$DisablBc     <-zm2$DisablB     -mean(zm2$DisablB     ,na.rm=T)
zm2$DisablHc     <-zm2$DisablH     -mean(zm2$DisablH     ,na.rm=T)
zm2$DisablTCc    <-zm2$DisablTC    -mean(zm2$DisablTC    ,na.rm=T)
zm2$DisablWCc    <-zm2$DisablWC    -mean(zm2$DisablWC    ,na.rm=T)
zm2$DisablBCc    <-zm2$DisablBC    -mean(zm2$DisablBC    ,na.rm=T)
zm2$DisablHCc    <-zm2$DisablHC    -mean(zm2$DisablHC    ,na.rm=T)
zm2$DisablTMc    <-zm2$DisablTM    -mean(zm2$DisablTM    ,na.rm=T)
zm2$DisablTFc    <-zm2$DisablTF    -mean(zm2$DisablTF    ,na.rm=T)
zm2$Urban1c      <-zm2$Urban1      -mean(zm2$Urban1      ,na.rm=T)
zm2$Urban2c      <-zm2$Urban2      -mean(zm2$Urban2      ,na.rm=T)
zm2$ISBE_PFAc    <-zm2$ISBE_PFA    -mean(zm2$ISBE_PFA    ,na.rm=T)
zm2$ISBE_PFAEc   <-zm2$ISBE_PFAE   -mean(zm2$ISBE_PFAE   ,na.rm=T)
zm2$ISBE_PIc     <-zm2$ISBE_PI     -mean(zm2$ISBE_PI     ,na.rm=T)
zm2$HeadStartc   <-zm2$HeadStart   -mean(zm2$HeadStart   ,na.rm=T)
zm2$ElyHeadSc    <-zm2$ElyHeadS    -mean(zm2$ElyHeadS    ,na.rm=T)
zm2$HeadSAllc    <-zm2$HeadSAll    -mean(zm2$HeadSAll    ,na.rm=T)
zm2$PFA_HS1c     <-zm2$PFA_HS1     -mean(zm2$PFA_HS1     ,na.rm=T)
zm2$PFA_HS2c     <-zm2$PFA_HS2     -mean(zm2$PFA_HS2     ,na.rm=T)
zm2$LCCCc        <-zm2$LCCC        -mean(zm2$LCCC        ,na.rm=T)
zm2$LECCCc       <-zm2$LECCC       -mean(zm2$LECCC       ,na.rm=T)
zm2$LFCCc        <-zm2$LFCC        -mean(zm2$LFCC        ,na.rm=T)
zm2$LLECCCc      <-zm2$LLECCC      -mean(zm2$LLECCC      ,na.rm=T)
zm2$LCLFCCc      <-zm2$LCLFCC      -mean(zm2$LCLFCC      ,na.rm=T)
zm2$LCCCB1c      <-zm2$LCCCB1      -mean(zm2$LCCCB1      ,na.rm=T)
zm2$LCCCB2c      <-zm2$LCCCB2      -mean(zm2$LCCCB2      ,na.rm=T)
zm2$LCCB1c       <-zm2$LCCB1       -mean(zm2$LCCB1       ,na.rm=T)
zm2$LCCB2c       <-zm2$LCCB2       -mean(zm2$LCCB2       ,na.rm=T)
zm2$LCCCS1c      <-zm2$LCCCS1      -mean(zm2$LCCCS1      ,na.rm=T)
zm2$LCCCS2c      <-zm2$LCCCS2      -mean(zm2$LCCCS2      ,na.rm=T)
zm2$LCCS1c       <-zm2$LCCS1       -mean(zm2$LCCS1       ,na.rm=T)
zm2$LCCS2c       <-zm2$LCCS2       -mean(zm2$LCCS2       ,na.rm=T)
zm2$LCCCG1c      <-zm2$LCCCG1      -mean(zm2$LCCCG1      ,na.rm=T)
zm2$LCCCG2c      <-zm2$LCCCG2      -mean(zm2$LCCCG2      ,na.rm=T)
zm2$LCCG1c       <-zm2$LCCG1       -mean(zm2$LCCG1       ,na.rm=T)
zm2$LCCG2c       <-zm2$LCCG2       -mean(zm2$LCCG2       ,na.rm=T)
zm2$ChildCare1c  <-zm2$ChildCare1  -mean(zm2$ChildCare1  ,na.rm=T)
zm2$ChildCare2c  <-zm2$ChildCare2  -mean(zm2$ChildCare2  ,na.rm=T)
zm2$ChildCare3c  <-zm2$ChildCare3  -mean(zm2$ChildCare3  ,na.rm=T)
zm2$CCAPc        <-zm2$CCAP        -mean(zm2$CCAP        ,na.rm=T)
zm2$Homelessc    <-zm2$Homeless    -mean(zm2$Homeless    ,na.rm=T)
zm2$Homeless2c   <-zm2$Homeless2   -mean(zm2$Homeless2   ,na.rm=T)
zm2$DHS_HFIrc    <-zm2$DHS_HFIr    -mean(zm2$DHS_HFIr    ,na.rm=T)
zm2$DHS_PTSrc    <-zm2$DHS_PTSr    -mean(zm2$DHS_PTSr    ,na.rm=T)
zm2$DHS_HVPrc    <-zm2$DHS_HVPr    -mean(zm2$DHS_HVPr    ,na.rm=T)
zm2$IDHS_EIrc    <-zm2$IDHS_EIr    -mean(zm2$IDHS_EIr    ,na.rm=T)
zm2$MHV_C4c      <-zm2$MHV_C4      -mean(zm2$MHV_C4      ,na.rm=T)
zm2$MHV_P4c      <-zm2$MHV_P4      -mean(zm2$MHV_P4      ,na.rm=T)
zm2$MHV_C5c      <-zm2$MHV_C5      -mean(zm2$MHV_C5      ,na.rm=T)
zm2$MHV_P5c      <-zm2$MHV_P5      -mean(zm2$MHV_P5      ,na.rm=T)
zm2$FoodInsPc    <-zm2$FoodInsP    -mean(zm2$FoodInsP    ,na.rm=T)
zm2$FoodISc      <-zm2$FoodIS      -mean(zm2$FoodIS      ,na.rm=T)
zm2$RPovTc       <-zm2$RPovT       -mean(zm2$RPovT       ,na.rm=T)
zm2$PovTc        <-zm2$PovT        -mean(zm2$PovT        ,na.rm=T)
zm2$MHV_C4k <-zm2$MHV_C4 *10
zm2$MHV_C5k <-zm2$MHV_C5 *10
zm2$MHV_C4kc<-zm2$MHV_C4c*10
zm2$MHV_C5kc<-zm2$MHV_C5c*10





# demean - within and between variables
zm<-cbind(zm,demean(zm,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zm1<-cbind(zm1,demean(zm1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zm2<-cbind(zm2,demean(zm2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Female Children
# Income - Female Children
# Income - Female Children
# Income - Female Children
# Income - Female Children
# Income - Female Children
# Income - Female Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zf$Yearc        <-zf$Year        -mean(zf$Year        ,na.rm=T)
zf$CPopBPc      <-zf$CPopBP      -mean(zf$CPopBP      ,na.rm=T)
zf$CPopHPc      <-zf$CPopHP      -mean(zf$CPopHP      ,na.rm=T)
zf$ChildPTc     <-zf$ChildPT     -mean(zf$ChildPT     ,na.rm=T)
zf$ChildPWc     <-zf$ChildPW     -mean(zf$ChildPW     ,na.rm=T)
zf$ChildPBc     <-zf$ChildPB     -mean(zf$ChildPB     ,na.rm=T)
zf$ChildPHc     <-zf$ChildPH     -mean(zf$ChildPH     ,na.rm=T)
zf$CARatioT100c <-zf$CARatioT100 -mean(zf$CARatioT100 ,na.rm=T)
zf$CARatioW100c <-zf$CARatioW100 -mean(zf$CARatioW100 ,na.rm=T)
zf$CARatioB100c <-zf$CARatioB100 -mean(zf$CARatioB100 ,na.rm=T)
zf$CARatioH100c <-zf$CARatioH100 -mean(zf$CARatioH100 ,na.rm=T)
zf$MalePTc      <-zf$MalePT      -mean(zf$MalePT      ,na.rm=T)
zf$MalePWc      <-zf$MalePW      -mean(zf$MalePW      ,na.rm=T)
zf$MalePBc      <-zf$MalePB      -mean(zf$MalePB      ,na.rm=T)
zf$MalePHc      <-zf$MalePH      -mean(zf$MalePH      ,na.rm=T)
zf$MFRatioT100c <-zf$MFRatioT100 -mean(zf$MFRatioT100 ,na.rm=T)
zf$MFRatioW100c <-zf$MFRatioW100 -mean(zf$MFRatioW100 ,na.rm=T)
zf$MFRatioB100c <-zf$MFRatioB100 -mean(zf$MFRatioB100 ,na.rm=T)
zf$MFRatioH100c <-zf$MFRatioH100 -mean(zf$MFRatioH100 ,na.rm=T)
zf$ElderTc      <-zf$ElderT      -mean(zf$ElderT      ,na.rm=T)
zf$ElderWc      <-zf$ElderW      -mean(zf$ElderW      ,na.rm=T)
zf$ElderBc      <-zf$ElderB      -mean(zf$ElderB      ,na.rm=T)
zf$ElderHc      <-zf$ElderH      -mean(zf$ElderH      ,na.rm=T)
zf$SingleTc     <-zf$SingleT     -mean(zf$SingleT     ,na.rm=T)
zf$SingleWc     <-zf$SingleW     -mean(zf$SingleW     ,na.rm=T)
zf$SingleBc     <-zf$SingleB     -mean(zf$SingleB     ,na.rm=T)
zf$SingleHc     <-zf$SingleH     -mean(zf$SingleH     ,na.rm=T)
zf$FHeadTc      <-zf$FHeadT      -mean(zf$FHeadT      ,na.rm=T)
zf$FHeadWc      <-zf$FHeadW      -mean(zf$FHeadW      ,na.rm=T)
zf$FHeadBc      <-zf$FHeadB      -mean(zf$FHeadB      ,na.rm=T)
zf$FHeadHc      <-zf$FHeadH      -mean(zf$FHeadH      ,na.rm=T)
zf$NoHighTc     <-zf$NoHighT     -mean(zf$NoHighT     ,na.rm=T)
zf$NoHighWc     <-zf$NoHighW     -mean(zf$NoHighW     ,na.rm=T)
zf$NoHighBc     <-zf$NoHighB     -mean(zf$NoHighB     ,na.rm=T)
zf$NoHighHc     <-zf$NoHighH     -mean(zf$NoHighH     ,na.rm=T)
zf$UnempTc      <-zf$UnempT      -mean(zf$UnempT      ,na.rm=T)
zf$UnempWc      <-zf$UnempW      -mean(zf$UnempW      ,na.rm=T)
zf$UnempBc      <-zf$UnempB      -mean(zf$UnempB      ,na.rm=T)
zf$UnempHc      <-zf$UnempH      -mean(zf$UnempH      ,na.rm=T)
zf$CPovTc       <-zf$CPovT       -mean(zf$CPovT       ,na.rm=T)
zf$CPovWc       <-zf$CPovW       -mean(zf$CPovW       ,na.rm=T)
zf$CPovBc       <-zf$CPovB       -mean(zf$CPovB       ,na.rm=T)
zf$CPovHc       <-zf$CPovH       -mean(zf$CPovH       ,na.rm=T)
zf$CPov1c       <-zf$CPov1       -mean(zf$CPov1       ,na.rm=T)
zf$CPov2c       <-zf$CPov2       -mean(zf$CPov2       ,na.rm=T)
zf$CPov3c       <-zf$CPov3       -mean(zf$CPov3       ,na.rm=T)
zf$PubAsTc      <-zf$PubAsT      -mean(zf$PubAsT      ,na.rm=T)
zf$WelfarTc     <-zf$WelfarT     -mean(zf$WelfarT     ,na.rm=T)
zf$SnapTc       <-zf$SnapT       -mean(zf$SnapT       ,na.rm=T)
zf$SnapWc       <-zf$SnapW       -mean(zf$SnapW       ,na.rm=T)
zf$SnapBc       <-zf$SnapB       -mean(zf$SnapB       ,na.rm=T)
zf$SnapHc       <-zf$SnapH       -mean(zf$SnapH       ,na.rm=T)
zf$IncomeT1kc   <-zf$IncomeT1k   -mean(zf$IncomeT1k   ,na.rm=T)
zf$IncomeW1kc   <-zf$IncomeW1k   -mean(zf$IncomeW1k   ,na.rm=T)
zf$IncomeB1kc   <-zf$IncomeB1k   -mean(zf$IncomeB1k   ,na.rm=T)
zf$IncomeH1kc   <-zf$IncomeH1k   -mean(zf$IncomeH1k   ,na.rm=T)
zf$GiniT100c    <-zf$GiniT100    -mean(zf$GiniT100    ,na.rm=T)
zf$HValueT10kc  <-zf$HValueT10k  -mean(zf$HValueT10k  ,na.rm=T)
zf$MCostT100c   <-zf$MCostT100   -mean(zf$MCostT100   ,na.rm=T)
zf$OCostDT100c  <-zf$OCostDT100  -mean(zf$OCostDT100  ,na.rm=T)
zf$MRentDT100c  <-zf$MRentDT100  -mean(zf$MRentDT100  ,na.rm=T)
zf$OCostPTc     <-zf$OCostPT     -mean(zf$OCostPT     ,na.rm=T)
zf$MRentPTc     <-zf$MRentPT     -mean(zf$MRentPT     ,na.rm=T)
zf$MortgTc      <-zf$MortgT      -mean(zf$MortgT      ,na.rm=T)
zf$LangAPTc     <-zf$LangAPT     -mean(zf$LangAPT     ,na.rm=T)
zf$LangAPWc     <-zf$LangAPW     -mean(zf$LangAPW     ,na.rm=T)
zf$LangAPBc     <-zf$LangAPB     -mean(zf$LangAPB     ,na.rm=T)
zf$LangAPHc     <-zf$LangAPH     -mean(zf$LangAPH     ,na.rm=T)
zf$LangBPTc     <-zf$LangBPT     -mean(zf$LangBPT     ,na.rm=T)
zf$LangBPWc     <-zf$LangBPW     -mean(zf$LangBPW     ,na.rm=T)
zf$LangBPBc     <-zf$LangBPB     -mean(zf$LangBPB     ,na.rm=T)
zf$LangBPHc     <-zf$LangBPH     -mean(zf$LangBPH     ,na.rm=T)
zf$LangCPTc     <-zf$LangCPT     -mean(zf$LangCPT     ,na.rm=T)
zf$OutUsTc      <-zf$OutUsT      -mean(zf$OutUsT      ,na.rm=T)
zf$OutUsWc      <-zf$OutUsW      -mean(zf$OutUsW      ,na.rm=T)
zf$OutUsBc      <-zf$OutUsB      -mean(zf$OutUsB      ,na.rm=T)
zf$OutUsHc      <-zf$OutUsH      -mean(zf$OutUsH      ,na.rm=T)
zf$FBornTc      <-zf$FBornT      -mean(zf$FBornT      ,na.rm=T)
zf$FBornWc      <-zf$FBornW      -mean(zf$FBornW      ,na.rm=T)
zf$FBornBc      <-zf$FBornB      -mean(zf$FBornB      ,na.rm=T)
zf$FBornHc      <-zf$FBornH      -mean(zf$FBornH      ,na.rm=T)
zf$NotCtzTc     <-zf$NotCtzT     -mean(zf$NotCtzT     ,na.rm=T)
zf$NotCtzWc     <-zf$NotCtzW     -mean(zf$NotCtzW     ,na.rm=T)
zf$NotCtzBc     <-zf$NotCtzB     -mean(zf$NotCtzB     ,na.rm=T)
zf$NotCtzHc     <-zf$NotCtzH     -mean(zf$NotCtzH     ,na.rm=T)
zf$MoveTc       <-zf$MoveT       -mean(zf$MoveT       ,na.rm=T)
zf$MoveWc       <-zf$MoveW       -mean(zf$MoveW       ,na.rm=T)
zf$MoveBc       <-zf$MoveB       -mean(zf$MoveB       ,na.rm=T)
zf$MoveHc       <-zf$MoveH       -mean(zf$MoveH       ,na.rm=T)
zf$VacantTc     <-zf$VacantT     -mean(zf$VacantT     ,na.rm=T)
zf$OwnerTc      <-zf$OwnerT      -mean(zf$OwnerT      ,na.rm=T)
zf$OwnerWc      <-zf$OwnerW      -mean(zf$OwnerW      ,na.rm=T)
zf$OwnerBc      <-zf$OwnerB      -mean(zf$OwnerB      ,na.rm=T)
zf$OwnerHc      <-zf$OwnerH      -mean(zf$OwnerH      ,na.rm=T)
zf$CrowdTc      <-zf$CrowdT      -mean(zf$CrowdT      ,na.rm=T)
zf$CrowdWc      <-zf$CrowdW      -mean(zf$CrowdW      ,na.rm=T)
zf$CrowdBc      <-zf$CrowdB      -mean(zf$CrowdB      ,na.rm=T)
zf$CrowdHc      <-zf$CrowdH      -mean(zf$CrowdH      ,na.rm=T)
zf$MobileTc     <-zf$MobileT     -mean(zf$MobileT     ,na.rm=T)
zf$MobileWc     <-zf$MobileW     -mean(zf$MobileW     ,na.rm=T)
zf$MobileBc     <-zf$MobileB     -mean(zf$MobileB     ,na.rm=T)
zf$MobileHc     <-zf$MobileH     -mean(zf$MobileH     ,na.rm=T)
zf$DisablTc     <-zf$DisablT     -mean(zf$DisablT     ,na.rm=T)
zf$DisablWc     <-zf$DisablW     -mean(zf$DisablW     ,na.rm=T)
zf$DisablBc     <-zf$DisablB     -mean(zf$DisablB     ,na.rm=T)
zf$DisablHc     <-zf$DisablH     -mean(zf$DisablH     ,na.rm=T)
zf$DisablTCc    <-zf$DisablTC    -mean(zf$DisablTC    ,na.rm=T)
zf$DisablWCc    <-zf$DisablWC    -mean(zf$DisablWC    ,na.rm=T)
zf$DisablBCc    <-zf$DisablBC    -mean(zf$DisablBC    ,na.rm=T)
zf$DisablHCc    <-zf$DisablHC    -mean(zf$DisablHC    ,na.rm=T)
zf$DisablTMc    <-zf$DisablTM    -mean(zf$DisablTM    ,na.rm=T)
zf$DisablTFc    <-zf$DisablTF    -mean(zf$DisablTF    ,na.rm=T)
zf$Urban1c      <-zf$Urban1      -mean(zf$Urban1      ,na.rm=T)
zf$Urban2c      <-zf$Urban2      -mean(zf$Urban2      ,na.rm=T)
zf$ISBE_PFAc    <-zf$ISBE_PFA    -mean(zf$ISBE_PFA    ,na.rm=T)
zf$ISBE_PFAEc   <-zf$ISBE_PFAE   -mean(zf$ISBE_PFAE   ,na.rm=T)
zf$ISBE_PIc     <-zf$ISBE_PI     -mean(zf$ISBE_PI     ,na.rm=T)
zf$HeadStartc   <-zf$HeadStart   -mean(zf$HeadStart   ,na.rm=T)
zf$ElyHeadSc    <-zf$ElyHeadS    -mean(zf$ElyHeadS    ,na.rm=T)
zf$HeadSAllc    <-zf$HeadSAll    -mean(zf$HeadSAll    ,na.rm=T)
zf$PFA_HS1c     <-zf$PFA_HS1     -mean(zf$PFA_HS1     ,na.rm=T)
zf$PFA_HS2c     <-zf$PFA_HS2     -mean(zf$PFA_HS2     ,na.rm=T)
zf$LCCCc        <-zf$LCCC        -mean(zf$LCCC        ,na.rm=T)
zf$LECCCc       <-zf$LECCC       -mean(zf$LECCC       ,na.rm=T)
zf$LFCCc        <-zf$LFCC        -mean(zf$LFCC        ,na.rm=T)
zf$LLECCCc      <-zf$LLECCC      -mean(zf$LLECCC      ,na.rm=T)
zf$LCLFCCc      <-zf$LCLFCC      -mean(zf$LCLFCC      ,na.rm=T)
zf$LCCCB1c      <-zf$LCCCB1      -mean(zf$LCCCB1      ,na.rm=T)
zf$LCCCB2c      <-zf$LCCCB2      -mean(zf$LCCCB2      ,na.rm=T)
zf$LCCB1c       <-zf$LCCB1       -mean(zf$LCCB1       ,na.rm=T)
zf$LCCB2c       <-zf$LCCB2       -mean(zf$LCCB2       ,na.rm=T)
zf$LCCCS1c      <-zf$LCCCS1      -mean(zf$LCCCS1      ,na.rm=T)
zf$LCCCS2c      <-zf$LCCCS2      -mean(zf$LCCCS2      ,na.rm=T)
zf$LCCS1c       <-zf$LCCS1       -mean(zf$LCCS1       ,na.rm=T)
zf$LCCS2c       <-zf$LCCS2       -mean(zf$LCCS2       ,na.rm=T)
zf$LCCCG1c      <-zf$LCCCG1      -mean(zf$LCCCG1      ,na.rm=T)
zf$LCCCG2c      <-zf$LCCCG2      -mean(zf$LCCCG2      ,na.rm=T)
zf$LCCG1c       <-zf$LCCG1       -mean(zf$LCCG1       ,na.rm=T)
zf$LCCG2c       <-zf$LCCG2       -mean(zf$LCCG2       ,na.rm=T)
zf$ChildCare1c  <-zf$ChildCare1  -mean(zf$ChildCare1  ,na.rm=T)
zf$ChildCare2c  <-zf$ChildCare2  -mean(zf$ChildCare2  ,na.rm=T)
zf$ChildCare3c  <-zf$ChildCare3  -mean(zf$ChildCare3  ,na.rm=T)
zf$CCAPc        <-zf$CCAP        -mean(zf$CCAP        ,na.rm=T)
zf$Homelessc    <-zf$Homeless    -mean(zf$Homeless    ,na.rm=T)
zf$Homeless2c   <-zf$Homeless2   -mean(zf$Homeless2   ,na.rm=T)
zf$DHS_HFIrc    <-zf$DHS_HFIr    -mean(zf$DHS_HFIr    ,na.rm=T)
zf$DHS_PTSrc    <-zf$DHS_PTSr    -mean(zf$DHS_PTSr    ,na.rm=T)
zf$DHS_HVPrc    <-zf$DHS_HVPr    -mean(zf$DHS_HVPr    ,na.rm=T)
zf$IDHS_EIrc    <-zf$IDHS_EIr    -mean(zf$IDHS_EIr    ,na.rm=T)
zf$MHV_C4c      <-zf$MHV_C4      -mean(zf$MHV_C4      ,na.rm=T)
zf$MHV_P4c      <-zf$MHV_P4      -mean(zf$MHV_P4      ,na.rm=T)
zf$MHV_C5c      <-zf$MHV_C5      -mean(zf$MHV_C5      ,na.rm=T)
zf$MHV_P5c      <-zf$MHV_P5      -mean(zf$MHV_P5      ,na.rm=T)
zf$FoodInsPc    <-zf$FoodInsP    -mean(zf$FoodInsP    ,na.rm=T)
zf$FoodISc      <-zf$FoodIS      -mean(zf$FoodIS      ,na.rm=T)
zf$RPovTc       <-zf$RPovT       -mean(zf$RPovT       ,na.rm=T)
zf$PovTc        <-zf$PovT        -mean(zf$PovT        ,na.rm=T)
zf$MHV_C4k <-zf$MHV_C4 *10
zf$MHV_C5k <-zf$MHV_C5 *10
zf$MHV_C4kc<-zf$MHV_C4c*10
zf$MHV_C5kc<-zf$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zf1$Yearc        <-zf1$Year        -mean(zf1$Year        ,na.rm=T)
zf1$CPopBPc      <-zf1$CPopBP      -mean(zf1$CPopBP      ,na.rm=T)
zf1$CPopHPc      <-zf1$CPopHP      -mean(zf1$CPopHP      ,na.rm=T)
zf1$ChildPTc     <-zf1$ChildPT     -mean(zf1$ChildPT     ,na.rm=T)
zf1$ChildPWc     <-zf1$ChildPW     -mean(zf1$ChildPW     ,na.rm=T)
zf1$ChildPBc     <-zf1$ChildPB     -mean(zf1$ChildPB     ,na.rm=T)
zf1$ChildPHc     <-zf1$ChildPH     -mean(zf1$ChildPH     ,na.rm=T)
zf1$CARatioT100c <-zf1$CARatioT100 -mean(zf1$CARatioT100 ,na.rm=T)
zf1$CARatioW100c <-zf1$CARatioW100 -mean(zf1$CARatioW100 ,na.rm=T)
zf1$CARatioB100c <-zf1$CARatioB100 -mean(zf1$CARatioB100 ,na.rm=T)
zf1$CARatioH100c <-zf1$CARatioH100 -mean(zf1$CARatioH100 ,na.rm=T)
zf1$MalePTc      <-zf1$MalePT      -mean(zf1$MalePT      ,na.rm=T)
zf1$MalePWc      <-zf1$MalePW      -mean(zf1$MalePW      ,na.rm=T)
zf1$MalePBc      <-zf1$MalePB      -mean(zf1$MalePB      ,na.rm=T)
zf1$MalePHc      <-zf1$MalePH      -mean(zf1$MalePH      ,na.rm=T)
zf1$MFRatioT100c <-zf1$MFRatioT100 -mean(zf1$MFRatioT100 ,na.rm=T)
zf1$MFRatioW100c <-zf1$MFRatioW100 -mean(zf1$MFRatioW100 ,na.rm=T)
zf1$MFRatioB100c <-zf1$MFRatioB100 -mean(zf1$MFRatioB100 ,na.rm=T)
zf1$MFRatioH100c <-zf1$MFRatioH100 -mean(zf1$MFRatioH100 ,na.rm=T)
zf1$ElderTc      <-zf1$ElderT      -mean(zf1$ElderT      ,na.rm=T)
zf1$ElderWc      <-zf1$ElderW      -mean(zf1$ElderW      ,na.rm=T)
zf1$ElderBc      <-zf1$ElderB      -mean(zf1$ElderB      ,na.rm=T)
zf1$ElderHc      <-zf1$ElderH      -mean(zf1$ElderH      ,na.rm=T)
zf1$SingleTc     <-zf1$SingleT     -mean(zf1$SingleT     ,na.rm=T)
zf1$SingleWc     <-zf1$SingleW     -mean(zf1$SingleW     ,na.rm=T)
zf1$SingleBc     <-zf1$SingleB     -mean(zf1$SingleB     ,na.rm=T)
zf1$SingleHc     <-zf1$SingleH     -mean(zf1$SingleH     ,na.rm=T)
zf1$FHeadTc      <-zf1$FHeadT      -mean(zf1$FHeadT      ,na.rm=T)
zf1$FHeadWc      <-zf1$FHeadW      -mean(zf1$FHeadW      ,na.rm=T)
zf1$FHeadBc      <-zf1$FHeadB      -mean(zf1$FHeadB      ,na.rm=T)
zf1$FHeadHc      <-zf1$FHeadH      -mean(zf1$FHeadH      ,na.rm=T)
zf1$NoHighTc     <-zf1$NoHighT     -mean(zf1$NoHighT     ,na.rm=T)
zf1$NoHighWc     <-zf1$NoHighW     -mean(zf1$NoHighW     ,na.rm=T)
zf1$NoHighBc     <-zf1$NoHighB     -mean(zf1$NoHighB     ,na.rm=T)
zf1$NoHighHc     <-zf1$NoHighH     -mean(zf1$NoHighH     ,na.rm=T)
zf1$UnempTc      <-zf1$UnempT      -mean(zf1$UnempT      ,na.rm=T)
zf1$UnempWc      <-zf1$UnempW      -mean(zf1$UnempW      ,na.rm=T)
zf1$UnempBc      <-zf1$UnempB      -mean(zf1$UnempB      ,na.rm=T)
zf1$UnempHc      <-zf1$UnempH      -mean(zf1$UnempH      ,na.rm=T)
zf1$CPovTc       <-zf1$CPovT       -mean(zf1$CPovT       ,na.rm=T)
zf1$CPovWc       <-zf1$CPovW       -mean(zf1$CPovW       ,na.rm=T)
zf1$CPovBc       <-zf1$CPovB       -mean(zf1$CPovB       ,na.rm=T)
zf1$CPovHc       <-zf1$CPovH       -mean(zf1$CPovH       ,na.rm=T)
zf1$CPov1c       <-zf1$CPov1       -mean(zf1$CPov1       ,na.rm=T)
zf1$CPov2c       <-zf1$CPov2       -mean(zf1$CPov2       ,na.rm=T)
zf1$CPov3c       <-zf1$CPov3       -mean(zf1$CPov3       ,na.rm=T)
zf1$PubAsTc      <-zf1$PubAsT      -mean(zf1$PubAsT      ,na.rm=T)
zf1$WelfarTc     <-zf1$WelfarT     -mean(zf1$WelfarT     ,na.rm=T)
zf1$SnapTc       <-zf1$SnapT       -mean(zf1$SnapT       ,na.rm=T)
zf1$SnapWc       <-zf1$SnapW       -mean(zf1$SnapW       ,na.rm=T)
zf1$SnapBc       <-zf1$SnapB       -mean(zf1$SnapB       ,na.rm=T)
zf1$SnapHc       <-zf1$SnapH       -mean(zf1$SnapH       ,na.rm=T)
zf1$IncomeT1kc   <-zf1$IncomeT1k   -mean(zf1$IncomeT1k   ,na.rm=T)
zf1$IncomeW1kc   <-zf1$IncomeW1k   -mean(zf1$IncomeW1k   ,na.rm=T)
zf1$IncomeB1kc   <-zf1$IncomeB1k   -mean(zf1$IncomeB1k   ,na.rm=T)
zf1$IncomeH1kc   <-zf1$IncomeH1k   -mean(zf1$IncomeH1k   ,na.rm=T)
zf1$GiniT100c    <-zf1$GiniT100    -mean(zf1$GiniT100    ,na.rm=T)
zf1$HValueT10kc  <-zf1$HValueT10k  -mean(zf1$HValueT10k  ,na.rm=T)
zf1$MCostT100c   <-zf1$MCostT100   -mean(zf1$MCostT100   ,na.rm=T)
zf1$OCostDT100c  <-zf1$OCostDT100  -mean(zf1$OCostDT100  ,na.rm=T)
zf1$MRentDT100c  <-zf1$MRentDT100  -mean(zf1$MRentDT100  ,na.rm=T)
zf1$OCostPTc     <-zf1$OCostPT     -mean(zf1$OCostPT     ,na.rm=T)
zf1$MRentPTc     <-zf1$MRentPT     -mean(zf1$MRentPT     ,na.rm=T)
zf1$MortgTc      <-zf1$MortgT      -mean(zf1$MortgT      ,na.rm=T)
zf1$LangAPTc     <-zf1$LangAPT     -mean(zf1$LangAPT     ,na.rm=T)
zf1$LangAPWc     <-zf1$LangAPW     -mean(zf1$LangAPW     ,na.rm=T)
zf1$LangAPBc     <-zf1$LangAPB     -mean(zf1$LangAPB     ,na.rm=T)
zf1$LangAPHc     <-zf1$LangAPH     -mean(zf1$LangAPH     ,na.rm=T)
zf1$LangBPTc     <-zf1$LangBPT     -mean(zf1$LangBPT     ,na.rm=T)
zf1$LangBPWc     <-zf1$LangBPW     -mean(zf1$LangBPW     ,na.rm=T)
zf1$LangBPBc     <-zf1$LangBPB     -mean(zf1$LangBPB     ,na.rm=T)
zf1$LangBPHc     <-zf1$LangBPH     -mean(zf1$LangBPH     ,na.rm=T)
zf1$LangCPTc     <-zf1$LangCPT     -mean(zf1$LangCPT     ,na.rm=T)
zf1$OutUsTc      <-zf1$OutUsT      -mean(zf1$OutUsT      ,na.rm=T)
zf1$OutUsWc      <-zf1$OutUsW      -mean(zf1$OutUsW      ,na.rm=T)
zf1$OutUsBc      <-zf1$OutUsB      -mean(zf1$OutUsB      ,na.rm=T)
zf1$OutUsHc      <-zf1$OutUsH      -mean(zf1$OutUsH      ,na.rm=T)
zf1$FBornTc      <-zf1$FBornT      -mean(zf1$FBornT      ,na.rm=T)
zf1$FBornWc      <-zf1$FBornW      -mean(zf1$FBornW      ,na.rm=T)
zf1$FBornBc      <-zf1$FBornB      -mean(zf1$FBornB      ,na.rm=T)
zf1$FBornHc      <-zf1$FBornH      -mean(zf1$FBornH      ,na.rm=T)
zf1$NotCtzTc     <-zf1$NotCtzT     -mean(zf1$NotCtzT     ,na.rm=T)
zf1$NotCtzWc     <-zf1$NotCtzW     -mean(zf1$NotCtzW     ,na.rm=T)
zf1$NotCtzBc     <-zf1$NotCtzB     -mean(zf1$NotCtzB     ,na.rm=T)
zf1$NotCtzHc     <-zf1$NotCtzH     -mean(zf1$NotCtzH     ,na.rm=T)
zf1$MoveTc       <-zf1$MoveT       -mean(zf1$MoveT       ,na.rm=T)
zf1$MoveWc       <-zf1$MoveW       -mean(zf1$MoveW       ,na.rm=T)
zf1$MoveBc       <-zf1$MoveB       -mean(zf1$MoveB       ,na.rm=T)
zf1$MoveHc       <-zf1$MoveH       -mean(zf1$MoveH       ,na.rm=T)
zf1$VacantTc     <-zf1$VacantT     -mean(zf1$VacantT     ,na.rm=T)
zf1$OwnerTc      <-zf1$OwnerT      -mean(zf1$OwnerT      ,na.rm=T)
zf1$OwnerWc      <-zf1$OwnerW      -mean(zf1$OwnerW      ,na.rm=T)
zf1$OwnerBc      <-zf1$OwnerB      -mean(zf1$OwnerB      ,na.rm=T)
zf1$OwnerHc      <-zf1$OwnerH      -mean(zf1$OwnerH      ,na.rm=T)
zf1$CrowdTc      <-zf1$CrowdT      -mean(zf1$CrowdT      ,na.rm=T)
zf1$CrowdWc      <-zf1$CrowdW      -mean(zf1$CrowdW      ,na.rm=T)
zf1$CrowdBc      <-zf1$CrowdB      -mean(zf1$CrowdB      ,na.rm=T)
zf1$CrowdHc      <-zf1$CrowdH      -mean(zf1$CrowdH      ,na.rm=T)
zf1$MobileTc     <-zf1$MobileT     -mean(zf1$MobileT     ,na.rm=T)
zf1$MobileWc     <-zf1$MobileW     -mean(zf1$MobileW     ,na.rm=T)
zf1$MobileBc     <-zf1$MobileB     -mean(zf1$MobileB     ,na.rm=T)
zf1$MobileHc     <-zf1$MobileH     -mean(zf1$MobileH     ,na.rm=T)
zf1$DisablTc     <-zf1$DisablT     -mean(zf1$DisablT     ,na.rm=T)
zf1$DisablWc     <-zf1$DisablW     -mean(zf1$DisablW     ,na.rm=T)
zf1$DisablBc     <-zf1$DisablB     -mean(zf1$DisablB     ,na.rm=T)
zf1$DisablHc     <-zf1$DisablH     -mean(zf1$DisablH     ,na.rm=T)
zf1$DisablTCc    <-zf1$DisablTC    -mean(zf1$DisablTC    ,na.rm=T)
zf1$DisablWCc    <-zf1$DisablWC    -mean(zf1$DisablWC    ,na.rm=T)
zf1$DisablBCc    <-zf1$DisablBC    -mean(zf1$DisablBC    ,na.rm=T)
zf1$DisablHCc    <-zf1$DisablHC    -mean(zf1$DisablHC    ,na.rm=T)
zf1$DisablTMc    <-zf1$DisablTM    -mean(zf1$DisablTM    ,na.rm=T)
zf1$DisablTFc    <-zf1$DisablTF    -mean(zf1$DisablTF    ,na.rm=T)
zf1$Urban1c      <-zf1$Urban1      -mean(zf1$Urban1      ,na.rm=T)
zf1$Urban2c      <-zf1$Urban2      -mean(zf1$Urban2      ,na.rm=T)
zf1$ISBE_PFAc    <-zf1$ISBE_PFA    -mean(zf1$ISBE_PFA    ,na.rm=T)
zf1$ISBE_PFAEc   <-zf1$ISBE_PFAE   -mean(zf1$ISBE_PFAE   ,na.rm=T)
zf1$ISBE_PIc     <-zf1$ISBE_PI     -mean(zf1$ISBE_PI     ,na.rm=T)
zf1$HeadStartc   <-zf1$HeadStart   -mean(zf1$HeadStart   ,na.rm=T)
zf1$ElyHeadSc    <-zf1$ElyHeadS    -mean(zf1$ElyHeadS    ,na.rm=T)
zf1$HeadSAllc    <-zf1$HeadSAll    -mean(zf1$HeadSAll    ,na.rm=T)
zf1$PFA_HS1c     <-zf1$PFA_HS1     -mean(zf1$PFA_HS1     ,na.rm=T)
zf1$PFA_HS2c     <-zf1$PFA_HS2     -mean(zf1$PFA_HS2     ,na.rm=T)
zf1$LCCCc        <-zf1$LCCC        -mean(zf1$LCCC        ,na.rm=T)
zf1$LECCCc       <-zf1$LECCC       -mean(zf1$LECCC       ,na.rm=T)
zf1$LFCCc        <-zf1$LFCC        -mean(zf1$LFCC        ,na.rm=T)
zf1$LLECCCc      <-zf1$LLECCC      -mean(zf1$LLECCC      ,na.rm=T)
zf1$LCLFCCc      <-zf1$LCLFCC      -mean(zf1$LCLFCC      ,na.rm=T)
zf1$LCCCB1c      <-zf1$LCCCB1      -mean(zf1$LCCCB1      ,na.rm=T)
zf1$LCCCB2c      <-zf1$LCCCB2      -mean(zf1$LCCCB2      ,na.rm=T)
zf1$LCCB1c       <-zf1$LCCB1       -mean(zf1$LCCB1       ,na.rm=T)
zf1$LCCB2c       <-zf1$LCCB2       -mean(zf1$LCCB2       ,na.rm=T)
zf1$LCCCS1c      <-zf1$LCCCS1      -mean(zf1$LCCCS1      ,na.rm=T)
zf1$LCCCS2c      <-zf1$LCCCS2      -mean(zf1$LCCCS2      ,na.rm=T)
zf1$LCCS1c       <-zf1$LCCS1       -mean(zf1$LCCS1       ,na.rm=T)
zf1$LCCS2c       <-zf1$LCCS2       -mean(zf1$LCCS2       ,na.rm=T)
zf1$LCCCG1c      <-zf1$LCCCG1      -mean(zf1$LCCCG1      ,na.rm=T)
zf1$LCCCG2c      <-zf1$LCCCG2      -mean(zf1$LCCCG2      ,na.rm=T)
zf1$LCCG1c       <-zf1$LCCG1       -mean(zf1$LCCG1       ,na.rm=T)
zf1$LCCG2c       <-zf1$LCCG2       -mean(zf1$LCCG2       ,na.rm=T)
zf1$ChildCare1c  <-zf1$ChildCare1  -mean(zf1$ChildCare1  ,na.rm=T)
zf1$ChildCare2c  <-zf1$ChildCare2  -mean(zf1$ChildCare2  ,na.rm=T)
zf1$ChildCare3c  <-zf1$ChildCare3  -mean(zf1$ChildCare3  ,na.rm=T)
zf1$CCAPc        <-zf1$CCAP        -mean(zf1$CCAP        ,na.rm=T)
zf1$Homelessc    <-zf1$Homeless    -mean(zf1$Homeless    ,na.rm=T)
zf1$Homeless2c   <-zf1$Homeless2   -mean(zf1$Homeless2   ,na.rm=T)
zf1$DHS_HFIrc    <-zf1$DHS_HFIr    -mean(zf1$DHS_HFIr    ,na.rm=T)
zf1$DHS_PTSrc    <-zf1$DHS_PTSr    -mean(zf1$DHS_PTSr    ,na.rm=T)
zf1$DHS_HVPrc    <-zf1$DHS_HVPr    -mean(zf1$DHS_HVPr    ,na.rm=T)
zf1$IDHS_EIrc    <-zf1$IDHS_EIr    -mean(zf1$IDHS_EIr    ,na.rm=T)
zf1$MHV_C4c      <-zf1$MHV_C4      -mean(zf1$MHV_C4      ,na.rm=T)
zf1$MHV_P4c      <-zf1$MHV_P4      -mean(zf1$MHV_P4      ,na.rm=T)
zf1$MHV_C5c      <-zf1$MHV_C5      -mean(zf1$MHV_C5      ,na.rm=T)
zf1$MHV_P5c      <-zf1$MHV_P5      -mean(zf1$MHV_P5      ,na.rm=T)
zf1$FoodInsPc    <-zf1$FoodInsP    -mean(zf1$FoodInsP    ,na.rm=T)
zf1$FoodISc      <-zf1$FoodIS      -mean(zf1$FoodIS      ,na.rm=T)
zf1$RPovTc       <-zf1$RPovT       -mean(zf1$RPovT       ,na.rm=T)
zf1$PovTc        <-zf1$PovT        -mean(zf1$PovT        ,na.rm=T)
zf1$MHV_C4k <-zf1$MHV_C4 *10
zf1$MHV_C5k <-zf1$MHV_C5 *10
zf1$MHV_C4kc<-zf1$MHV_C4c*10
zf1$MHV_C5kc<-zf1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zf2$Yearc        <-zf2$Year        -mean(zf2$Year        ,na.rm=T)
zf2$CPopBPc      <-zf2$CPopBP      -mean(zf2$CPopBP      ,na.rm=T)
zf2$CPopHPc      <-zf2$CPopHP      -mean(zf2$CPopHP      ,na.rm=T)
zf2$ChildPTc     <-zf2$ChildPT     -mean(zf2$ChildPT     ,na.rm=T)
zf2$ChildPWc     <-zf2$ChildPW     -mean(zf2$ChildPW     ,na.rm=T)
zf2$ChildPBc     <-zf2$ChildPB     -mean(zf2$ChildPB     ,na.rm=T)
zf2$ChildPHc     <-zf2$ChildPH     -mean(zf2$ChildPH     ,na.rm=T)
zf2$CARatioT100c <-zf2$CARatioT100 -mean(zf2$CARatioT100 ,na.rm=T)
zf2$CARatioW100c <-zf2$CARatioW100 -mean(zf2$CARatioW100 ,na.rm=T)
zf2$CARatioB100c <-zf2$CARatioB100 -mean(zf2$CARatioB100 ,na.rm=T)
zf2$CARatioH100c <-zf2$CARatioH100 -mean(zf2$CARatioH100 ,na.rm=T)
zf2$MalePTc      <-zf2$MalePT      -mean(zf2$MalePT      ,na.rm=T)
zf2$MalePWc      <-zf2$MalePW      -mean(zf2$MalePW      ,na.rm=T)
zf2$MalePBc      <-zf2$MalePB      -mean(zf2$MalePB      ,na.rm=T)
zf2$MalePHc      <-zf2$MalePH      -mean(zf2$MalePH      ,na.rm=T)
zf2$MFRatioT100c <-zf2$MFRatioT100 -mean(zf2$MFRatioT100 ,na.rm=T)
zf2$MFRatioW100c <-zf2$MFRatioW100 -mean(zf2$MFRatioW100 ,na.rm=T)
zf2$MFRatioB100c <-zf2$MFRatioB100 -mean(zf2$MFRatioB100 ,na.rm=T)
zf2$MFRatioH100c <-zf2$MFRatioH100 -mean(zf2$MFRatioH100 ,na.rm=T)
zf2$ElderTc      <-zf2$ElderT      -mean(zf2$ElderT      ,na.rm=T)
zf2$ElderWc      <-zf2$ElderW      -mean(zf2$ElderW      ,na.rm=T)
zf2$ElderBc      <-zf2$ElderB      -mean(zf2$ElderB      ,na.rm=T)
zf2$ElderHc      <-zf2$ElderH      -mean(zf2$ElderH      ,na.rm=T)
zf2$SingleTc     <-zf2$SingleT     -mean(zf2$SingleT     ,na.rm=T)
zf2$SingleWc     <-zf2$SingleW     -mean(zf2$SingleW     ,na.rm=T)
zf2$SingleBc     <-zf2$SingleB     -mean(zf2$SingleB     ,na.rm=T)
zf2$SingleHc     <-zf2$SingleH     -mean(zf2$SingleH     ,na.rm=T)
zf2$FHeadTc      <-zf2$FHeadT      -mean(zf2$FHeadT      ,na.rm=T)
zf2$FHeadWc      <-zf2$FHeadW      -mean(zf2$FHeadW      ,na.rm=T)
zf2$FHeadBc      <-zf2$FHeadB      -mean(zf2$FHeadB      ,na.rm=T)
zf2$FHeadHc      <-zf2$FHeadH      -mean(zf2$FHeadH      ,na.rm=T)
zf2$NoHighTc     <-zf2$NoHighT     -mean(zf2$NoHighT     ,na.rm=T)
zf2$NoHighWc     <-zf2$NoHighW     -mean(zf2$NoHighW     ,na.rm=T)
zf2$NoHighBc     <-zf2$NoHighB     -mean(zf2$NoHighB     ,na.rm=T)
zf2$NoHighHc     <-zf2$NoHighH     -mean(zf2$NoHighH     ,na.rm=T)
zf2$UnempTc      <-zf2$UnempT      -mean(zf2$UnempT      ,na.rm=T)
zf2$UnempWc      <-zf2$UnempW      -mean(zf2$UnempW      ,na.rm=T)
zf2$UnempBc      <-zf2$UnempB      -mean(zf2$UnempB      ,na.rm=T)
zf2$UnempHc      <-zf2$UnempH      -mean(zf2$UnempH      ,na.rm=T)
zf2$CPovTc       <-zf2$CPovT       -mean(zf2$CPovT       ,na.rm=T)
zf2$CPovWc       <-zf2$CPovW       -mean(zf2$CPovW       ,na.rm=T)
zf2$CPovBc       <-zf2$CPovB       -mean(zf2$CPovB       ,na.rm=T)
zf2$CPovHc       <-zf2$CPovH       -mean(zf2$CPovH       ,na.rm=T)
zf2$CPov1c       <-zf2$CPov1       -mean(zf2$CPov1       ,na.rm=T)
zf2$CPov2c       <-zf2$CPov2       -mean(zf2$CPov2       ,na.rm=T)
zf2$CPov3c       <-zf2$CPov3       -mean(zf2$CPov3       ,na.rm=T)
zf2$PubAsTc      <-zf2$PubAsT      -mean(zf2$PubAsT      ,na.rm=T)
zf2$WelfarTc     <-zf2$WelfarT     -mean(zf2$WelfarT     ,na.rm=T)
zf2$SnapTc       <-zf2$SnapT       -mean(zf2$SnapT       ,na.rm=T)
zf2$SnapWc       <-zf2$SnapW       -mean(zf2$SnapW       ,na.rm=T)
zf2$SnapBc       <-zf2$SnapB       -mean(zf2$SnapB       ,na.rm=T)
zf2$SnapHc       <-zf2$SnapH       -mean(zf2$SnapH       ,na.rm=T)
zf2$IncomeT1kc   <-zf2$IncomeT1k   -mean(zf2$IncomeT1k   ,na.rm=T)
zf2$IncomeW1kc   <-zf2$IncomeW1k   -mean(zf2$IncomeW1k   ,na.rm=T)
zf2$IncomeB1kc   <-zf2$IncomeB1k   -mean(zf2$IncomeB1k   ,na.rm=T)
zf2$IncomeH1kc   <-zf2$IncomeH1k   -mean(zf2$IncomeH1k   ,na.rm=T)
zf2$GiniT100c    <-zf2$GiniT100    -mean(zf2$GiniT100    ,na.rm=T)
zf2$HValueT10kc  <-zf2$HValueT10k  -mean(zf2$HValueT10k  ,na.rm=T)
zf2$MCostT100c   <-zf2$MCostT100   -mean(zf2$MCostT100   ,na.rm=T)
zf2$OCostDT100c  <-zf2$OCostDT100  -mean(zf2$OCostDT100  ,na.rm=T)
zf2$MRentDT100c  <-zf2$MRentDT100  -mean(zf2$MRentDT100  ,na.rm=T)
zf2$OCostPTc     <-zf2$OCostPT     -mean(zf2$OCostPT     ,na.rm=T)
zf2$MRentPTc     <-zf2$MRentPT     -mean(zf2$MRentPT     ,na.rm=T)
zf2$MortgTc      <-zf2$MortgT      -mean(zf2$MortgT      ,na.rm=T)
zf2$LangAPTc     <-zf2$LangAPT     -mean(zf2$LangAPT     ,na.rm=T)
zf2$LangAPWc     <-zf2$LangAPW     -mean(zf2$LangAPW     ,na.rm=T)
zf2$LangAPBc     <-zf2$LangAPB     -mean(zf2$LangAPB     ,na.rm=T)
zf2$LangAPHc     <-zf2$LangAPH     -mean(zf2$LangAPH     ,na.rm=T)
zf2$LangBPTc     <-zf2$LangBPT     -mean(zf2$LangBPT     ,na.rm=T)
zf2$LangBPWc     <-zf2$LangBPW     -mean(zf2$LangBPW     ,na.rm=T)
zf2$LangBPBc     <-zf2$LangBPB     -mean(zf2$LangBPB     ,na.rm=T)
zf2$LangBPHc     <-zf2$LangBPH     -mean(zf2$LangBPH     ,na.rm=T)
zf2$LangCPTc     <-zf2$LangCPT     -mean(zf2$LangCPT     ,na.rm=T)
zf2$OutUsTc      <-zf2$OutUsT      -mean(zf2$OutUsT      ,na.rm=T)
zf2$OutUsWc      <-zf2$OutUsW      -mean(zf2$OutUsW      ,na.rm=T)
zf2$OutUsBc      <-zf2$OutUsB      -mean(zf2$OutUsB      ,na.rm=T)
zf2$OutUsHc      <-zf2$OutUsH      -mean(zf2$OutUsH      ,na.rm=T)
zf2$FBornTc      <-zf2$FBornT      -mean(zf2$FBornT      ,na.rm=T)
zf2$FBornWc      <-zf2$FBornW      -mean(zf2$FBornW      ,na.rm=T)
zf2$FBornBc      <-zf2$FBornB      -mean(zf2$FBornB      ,na.rm=T)
zf2$FBornHc      <-zf2$FBornH      -mean(zf2$FBornH      ,na.rm=T)
zf2$NotCtzTc     <-zf2$NotCtzT     -mean(zf2$NotCtzT     ,na.rm=T)
zf2$NotCtzWc     <-zf2$NotCtzW     -mean(zf2$NotCtzW     ,na.rm=T)
zf2$NotCtzBc     <-zf2$NotCtzB     -mean(zf2$NotCtzB     ,na.rm=T)
zf2$NotCtzHc     <-zf2$NotCtzH     -mean(zf2$NotCtzH     ,na.rm=T)
zf2$MoveTc       <-zf2$MoveT       -mean(zf2$MoveT       ,na.rm=T)
zf2$MoveWc       <-zf2$MoveW       -mean(zf2$MoveW       ,na.rm=T)
zf2$MoveBc       <-zf2$MoveB       -mean(zf2$MoveB       ,na.rm=T)
zf2$MoveHc       <-zf2$MoveH       -mean(zf2$MoveH       ,na.rm=T)
zf2$VacantTc     <-zf2$VacantT     -mean(zf2$VacantT     ,na.rm=T)
zf2$OwnerTc      <-zf2$OwnerT      -mean(zf2$OwnerT      ,na.rm=T)
zf2$OwnerWc      <-zf2$OwnerW      -mean(zf2$OwnerW      ,na.rm=T)
zf2$OwnerBc      <-zf2$OwnerB      -mean(zf2$OwnerB      ,na.rm=T)
zf2$OwnerHc      <-zf2$OwnerH      -mean(zf2$OwnerH      ,na.rm=T)
zf2$CrowdTc      <-zf2$CrowdT      -mean(zf2$CrowdT      ,na.rm=T)
zf2$CrowdWc      <-zf2$CrowdW      -mean(zf2$CrowdW      ,na.rm=T)
zf2$CrowdBc      <-zf2$CrowdB      -mean(zf2$CrowdB      ,na.rm=T)
zf2$CrowdHc      <-zf2$CrowdH      -mean(zf2$CrowdH      ,na.rm=T)
zf2$MobileTc     <-zf2$MobileT     -mean(zf2$MobileT     ,na.rm=T)
zf2$MobileWc     <-zf2$MobileW     -mean(zf2$MobileW     ,na.rm=T)
zf2$MobileBc     <-zf2$MobileB     -mean(zf2$MobileB     ,na.rm=T)
zf2$MobileHc     <-zf2$MobileH     -mean(zf2$MobileH     ,na.rm=T)
zf2$DisablTc     <-zf2$DisablT     -mean(zf2$DisablT     ,na.rm=T)
zf2$DisablWc     <-zf2$DisablW     -mean(zf2$DisablW     ,na.rm=T)
zf2$DisablBc     <-zf2$DisablB     -mean(zf2$DisablB     ,na.rm=T)
zf2$DisablHc     <-zf2$DisablH     -mean(zf2$DisablH     ,na.rm=T)
zf2$DisablTCc    <-zf2$DisablTC    -mean(zf2$DisablTC    ,na.rm=T)
zf2$DisablWCc    <-zf2$DisablWC    -mean(zf2$DisablWC    ,na.rm=T)
zf2$DisablBCc    <-zf2$DisablBC    -mean(zf2$DisablBC    ,na.rm=T)
zf2$DisablHCc    <-zf2$DisablHC    -mean(zf2$DisablHC    ,na.rm=T)
zf2$DisablTMc    <-zf2$DisablTM    -mean(zf2$DisablTM    ,na.rm=T)
zf2$DisablTFc    <-zf2$DisablTF    -mean(zf2$DisablTF    ,na.rm=T)
zf2$Urban1c      <-zf2$Urban1      -mean(zf2$Urban1      ,na.rm=T)
zf2$Urban2c      <-zf2$Urban2      -mean(zf2$Urban2      ,na.rm=T)
zf2$ISBE_PFAc    <-zf2$ISBE_PFA    -mean(zf2$ISBE_PFA    ,na.rm=T)
zf2$ISBE_PFAEc   <-zf2$ISBE_PFAE   -mean(zf2$ISBE_PFAE   ,na.rm=T)
zf2$ISBE_PIc     <-zf2$ISBE_PI     -mean(zf2$ISBE_PI     ,na.rm=T)
zf2$HeadStartc   <-zf2$HeadStart   -mean(zf2$HeadStart   ,na.rm=T)
zf2$ElyHeadSc    <-zf2$ElyHeadS    -mean(zf2$ElyHeadS    ,na.rm=T)
zf2$HeadSAllc    <-zf2$HeadSAll    -mean(zf2$HeadSAll    ,na.rm=T)
zf2$PFA_HS1c     <-zf2$PFA_HS1     -mean(zf2$PFA_HS1     ,na.rm=T)
zf2$PFA_HS2c     <-zf2$PFA_HS2     -mean(zf2$PFA_HS2     ,na.rm=T)
zf2$LCCCc        <-zf2$LCCC        -mean(zf2$LCCC        ,na.rm=T)
zf2$LECCCc       <-zf2$LECCC       -mean(zf2$LECCC       ,na.rm=T)
zf2$LFCCc        <-zf2$LFCC        -mean(zf2$LFCC        ,na.rm=T)
zf2$LLECCCc      <-zf2$LLECCC      -mean(zf2$LLECCC      ,na.rm=T)
zf2$LCLFCCc      <-zf2$LCLFCC      -mean(zf2$LCLFCC      ,na.rm=T)
zf2$LCCCB1c      <-zf2$LCCCB1      -mean(zf2$LCCCB1      ,na.rm=T)
zf2$LCCCB2c      <-zf2$LCCCB2      -mean(zf2$LCCCB2      ,na.rm=T)
zf2$LCCB1c       <-zf2$LCCB1       -mean(zf2$LCCB1       ,na.rm=T)
zf2$LCCB2c       <-zf2$LCCB2       -mean(zf2$LCCB2       ,na.rm=T)
zf2$LCCCS1c      <-zf2$LCCCS1      -mean(zf2$LCCCS1      ,na.rm=T)
zf2$LCCCS2c      <-zf2$LCCCS2      -mean(zf2$LCCCS2      ,na.rm=T)
zf2$LCCS1c       <-zf2$LCCS1       -mean(zf2$LCCS1       ,na.rm=T)
zf2$LCCS2c       <-zf2$LCCS2       -mean(zf2$LCCS2       ,na.rm=T)
zf2$LCCCG1c      <-zf2$LCCCG1      -mean(zf2$LCCCG1      ,na.rm=T)
zf2$LCCCG2c      <-zf2$LCCCG2      -mean(zf2$LCCCG2      ,na.rm=T)
zf2$LCCG1c       <-zf2$LCCG1       -mean(zf2$LCCG1       ,na.rm=T)
zf2$LCCG2c       <-zf2$LCCG2       -mean(zf2$LCCG2       ,na.rm=T)
zf2$ChildCare1c  <-zf2$ChildCare1  -mean(zf2$ChildCare1  ,na.rm=T)
zf2$ChildCare2c  <-zf2$ChildCare2  -mean(zf2$ChildCare2  ,na.rm=T)
zf2$ChildCare3c  <-zf2$ChildCare3  -mean(zf2$ChildCare3  ,na.rm=T)
zf2$CCAPc        <-zf2$CCAP        -mean(zf2$CCAP        ,na.rm=T)
zf2$Homelessc    <-zf2$Homeless    -mean(zf2$Homeless    ,na.rm=T)
zf2$Homeless2c   <-zf2$Homeless2   -mean(zf2$Homeless2   ,na.rm=T)
zf2$DHS_HFIrc    <-zf2$DHS_HFIr    -mean(zf2$DHS_HFIr    ,na.rm=T)
zf2$DHS_PTSrc    <-zf2$DHS_PTSr    -mean(zf2$DHS_PTSr    ,na.rm=T)
zf2$DHS_HVPrc    <-zf2$DHS_HVPr    -mean(zf2$DHS_HVPr    ,na.rm=T)
zf2$IDHS_EIrc    <-zf2$IDHS_EIr    -mean(zf2$IDHS_EIr    ,na.rm=T)
zf2$MHV_C4c      <-zf2$MHV_C4      -mean(zf2$MHV_C4      ,na.rm=T)
zf2$MHV_P4c      <-zf2$MHV_P4      -mean(zf2$MHV_P4      ,na.rm=T)
zf2$MHV_C5c      <-zf2$MHV_C5      -mean(zf2$MHV_C5      ,na.rm=T)
zf2$MHV_P5c      <-zf2$MHV_P5      -mean(zf2$MHV_P5      ,na.rm=T)
zf2$FoodInsPc    <-zf2$FoodInsP    -mean(zf2$FoodInsP    ,na.rm=T)
zf2$FoodISc      <-zf2$FoodIS      -mean(zf2$FoodIS      ,na.rm=T)
zf2$RPovTc       <-zf2$RPovT       -mean(zf2$RPovT       ,na.rm=T)
zf2$PovTc        <-zf2$PovT        -mean(zf2$PovT        ,na.rm=T)
zf2$MHV_C4k <-zf2$MHV_C4 *10
zf2$MHV_C5k <-zf2$MHV_C5 *10
zf2$MHV_C4kc<-zf2$MHV_C4c*10
zf2$MHV_C5kc<-zf2$MHV_C5c*10





# demean - within and between variables
zf<-cbind(zf,demean(zf,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zf1<-cbind(zf1,demean(zf1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zf2<-cbind(zf2,demean(zf2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Neglect
# Income - Neglect
# Income - Neglect
# Income - Neglect
# Income - Neglect
# Income - Neglect
# Income - Neglect
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zn$Yearc        <-zn$Year        -mean(zn$Year        ,na.rm=T)
zn$CPopBPc      <-zn$CPopBP      -mean(zn$CPopBP      ,na.rm=T)
zn$CPopHPc      <-zn$CPopHP      -mean(zn$CPopHP      ,na.rm=T)
zn$ChildPTc     <-zn$ChildPT     -mean(zn$ChildPT     ,na.rm=T)
zn$ChildPWc     <-zn$ChildPW     -mean(zn$ChildPW     ,na.rm=T)
zn$ChildPBc     <-zn$ChildPB     -mean(zn$ChildPB     ,na.rm=T)
zn$ChildPHc     <-zn$ChildPH     -mean(zn$ChildPH     ,na.rm=T)
zn$CARatioT100c <-zn$CARatioT100 -mean(zn$CARatioT100 ,na.rm=T)
zn$CARatioW100c <-zn$CARatioW100 -mean(zn$CARatioW100 ,na.rm=T)
zn$CARatioB100c <-zn$CARatioB100 -mean(zn$CARatioB100 ,na.rm=T)
zn$CARatioH100c <-zn$CARatioH100 -mean(zn$CARatioH100 ,na.rm=T)
zn$MalePTc      <-zn$MalePT      -mean(zn$MalePT      ,na.rm=T)
zn$MalePWc      <-zn$MalePW      -mean(zn$MalePW      ,na.rm=T)
zn$MalePBc      <-zn$MalePB      -mean(zn$MalePB      ,na.rm=T)
zn$MalePHc      <-zn$MalePH      -mean(zn$MalePH      ,na.rm=T)
zn$MFRatioT100c <-zn$MFRatioT100 -mean(zn$MFRatioT100 ,na.rm=T)
zn$MFRatioW100c <-zn$MFRatioW100 -mean(zn$MFRatioW100 ,na.rm=T)
zn$MFRatioB100c <-zn$MFRatioB100 -mean(zn$MFRatioB100 ,na.rm=T)
zn$MFRatioH100c <-zn$MFRatioH100 -mean(zn$MFRatioH100 ,na.rm=T)
zn$ElderTc      <-zn$ElderT      -mean(zn$ElderT      ,na.rm=T)
zn$ElderWc      <-zn$ElderW      -mean(zn$ElderW      ,na.rm=T)
zn$ElderBc      <-zn$ElderB      -mean(zn$ElderB      ,na.rm=T)
zn$ElderHc      <-zn$ElderH      -mean(zn$ElderH      ,na.rm=T)
zn$SingleTc     <-zn$SingleT     -mean(zn$SingleT     ,na.rm=T)
zn$SingleWc     <-zn$SingleW     -mean(zn$SingleW     ,na.rm=T)
zn$SingleBc     <-zn$SingleB     -mean(zn$SingleB     ,na.rm=T)
zn$SingleHc     <-zn$SingleH     -mean(zn$SingleH     ,na.rm=T)
zn$FHeadTc      <-zn$FHeadT      -mean(zn$FHeadT      ,na.rm=T)
zn$FHeadWc      <-zn$FHeadW      -mean(zn$FHeadW      ,na.rm=T)
zn$FHeadBc      <-zn$FHeadB      -mean(zn$FHeadB      ,na.rm=T)
zn$FHeadHc      <-zn$FHeadH      -mean(zn$FHeadH      ,na.rm=T)
zn$NoHighTc     <-zn$NoHighT     -mean(zn$NoHighT     ,na.rm=T)
zn$NoHighWc     <-zn$NoHighW     -mean(zn$NoHighW     ,na.rm=T)
zn$NoHighBc     <-zn$NoHighB     -mean(zn$NoHighB     ,na.rm=T)
zn$NoHighHc     <-zn$NoHighH     -mean(zn$NoHighH     ,na.rm=T)
zn$UnempTc      <-zn$UnempT      -mean(zn$UnempT      ,na.rm=T)
zn$UnempWc      <-zn$UnempW      -mean(zn$UnempW      ,na.rm=T)
zn$UnempBc      <-zn$UnempB      -mean(zn$UnempB      ,na.rm=T)
zn$UnempHc      <-zn$UnempH      -mean(zn$UnempH      ,na.rm=T)
zn$CPovTc       <-zn$CPovT       -mean(zn$CPovT       ,na.rm=T)
zn$CPovWc       <-zn$CPovW       -mean(zn$CPovW       ,na.rm=T)
zn$CPovBc       <-zn$CPovB       -mean(zn$CPovB       ,na.rm=T)
zn$CPovHc       <-zn$CPovH       -mean(zn$CPovH       ,na.rm=T)
zn$CPov1c       <-zn$CPov1       -mean(zn$CPov1       ,na.rm=T)
zn$CPov2c       <-zn$CPov2       -mean(zn$CPov2       ,na.rm=T)
zn$CPov3c       <-zn$CPov3       -mean(zn$CPov3       ,na.rm=T)
zn$PubAsTc      <-zn$PubAsT      -mean(zn$PubAsT      ,na.rm=T)
zn$WelfarTc     <-zn$WelfarT     -mean(zn$WelfarT     ,na.rm=T)
zn$SnapTc       <-zn$SnapT       -mean(zn$SnapT       ,na.rm=T)
zn$SnapWc       <-zn$SnapW       -mean(zn$SnapW       ,na.rm=T)
zn$SnapBc       <-zn$SnapB       -mean(zn$SnapB       ,na.rm=T)
zn$SnapHc       <-zn$SnapH       -mean(zn$SnapH       ,na.rm=T)
zn$IncomeT1kc   <-zn$IncomeT1k   -mean(zn$IncomeT1k   ,na.rm=T)
zn$IncomeW1kc   <-zn$IncomeW1k   -mean(zn$IncomeW1k   ,na.rm=T)
zn$IncomeB1kc   <-zn$IncomeB1k   -mean(zn$IncomeB1k   ,na.rm=T)
zn$IncomeH1kc   <-zn$IncomeH1k   -mean(zn$IncomeH1k   ,na.rm=T)
zn$GiniT100c    <-zn$GiniT100    -mean(zn$GiniT100    ,na.rm=T)
zn$HValueT10kc  <-zn$HValueT10k  -mean(zn$HValueT10k  ,na.rm=T)
zn$MCostT100c   <-zn$MCostT100   -mean(zn$MCostT100   ,na.rm=T)
zn$OCostDT100c  <-zn$OCostDT100  -mean(zn$OCostDT100  ,na.rm=T)
zn$MRentDT100c  <-zn$MRentDT100  -mean(zn$MRentDT100  ,na.rm=T)
zn$OCostPTc     <-zn$OCostPT     -mean(zn$OCostPT     ,na.rm=T)
zn$MRentPTc     <-zn$MRentPT     -mean(zn$MRentPT     ,na.rm=T)
zn$MortgTc      <-zn$MortgT      -mean(zn$MortgT      ,na.rm=T)
zn$LangAPTc     <-zn$LangAPT     -mean(zn$LangAPT     ,na.rm=T)
zn$LangAPWc     <-zn$LangAPW     -mean(zn$LangAPW     ,na.rm=T)
zn$LangAPBc     <-zn$LangAPB     -mean(zn$LangAPB     ,na.rm=T)
zn$LangAPHc     <-zn$LangAPH     -mean(zn$LangAPH     ,na.rm=T)
zn$LangBPTc     <-zn$LangBPT     -mean(zn$LangBPT     ,na.rm=T)
zn$LangBPWc     <-zn$LangBPW     -mean(zn$LangBPW     ,na.rm=T)
zn$LangBPBc     <-zn$LangBPB     -mean(zn$LangBPB     ,na.rm=T)
zn$LangBPHc     <-zn$LangBPH     -mean(zn$LangBPH     ,na.rm=T)
zn$LangCPTc     <-zn$LangCPT     -mean(zn$LangCPT     ,na.rm=T)
zn$OutUsTc      <-zn$OutUsT      -mean(zn$OutUsT      ,na.rm=T)
zn$OutUsWc      <-zn$OutUsW      -mean(zn$OutUsW      ,na.rm=T)
zn$OutUsBc      <-zn$OutUsB      -mean(zn$OutUsB      ,na.rm=T)
zn$OutUsHc      <-zn$OutUsH      -mean(zn$OutUsH      ,na.rm=T)
zn$FBornTc      <-zn$FBornT      -mean(zn$FBornT      ,na.rm=T)
zn$FBornWc      <-zn$FBornW      -mean(zn$FBornW      ,na.rm=T)
zn$FBornBc      <-zn$FBornB      -mean(zn$FBornB      ,na.rm=T)
zn$FBornHc      <-zn$FBornH      -mean(zn$FBornH      ,na.rm=T)
zn$NotCtzTc     <-zn$NotCtzT     -mean(zn$NotCtzT     ,na.rm=T)
zn$NotCtzWc     <-zn$NotCtzW     -mean(zn$NotCtzW     ,na.rm=T)
zn$NotCtzBc     <-zn$NotCtzB     -mean(zn$NotCtzB     ,na.rm=T)
zn$NotCtzHc     <-zn$NotCtzH     -mean(zn$NotCtzH     ,na.rm=T)
zn$MoveTc       <-zn$MoveT       -mean(zn$MoveT       ,na.rm=T)
zn$MoveWc       <-zn$MoveW       -mean(zn$MoveW       ,na.rm=T)
zn$MoveBc       <-zn$MoveB       -mean(zn$MoveB       ,na.rm=T)
zn$MoveHc       <-zn$MoveH       -mean(zn$MoveH       ,na.rm=T)
zn$VacantTc     <-zn$VacantT     -mean(zn$VacantT     ,na.rm=T)
zn$OwnerTc      <-zn$OwnerT      -mean(zn$OwnerT      ,na.rm=T)
zn$OwnerWc      <-zn$OwnerW      -mean(zn$OwnerW      ,na.rm=T)
zn$OwnerBc      <-zn$OwnerB      -mean(zn$OwnerB      ,na.rm=T)
zn$OwnerHc      <-zn$OwnerH      -mean(zn$OwnerH      ,na.rm=T)
zn$CrowdTc      <-zn$CrowdT      -mean(zn$CrowdT      ,na.rm=T)
zn$CrowdWc      <-zn$CrowdW      -mean(zn$CrowdW      ,na.rm=T)
zn$CrowdBc      <-zn$CrowdB      -mean(zn$CrowdB      ,na.rm=T)
zn$CrowdHc      <-zn$CrowdH      -mean(zn$CrowdH      ,na.rm=T)
zn$MobileTc     <-zn$MobileT     -mean(zn$MobileT     ,na.rm=T)
zn$MobileWc     <-zn$MobileW     -mean(zn$MobileW     ,na.rm=T)
zn$MobileBc     <-zn$MobileB     -mean(zn$MobileB     ,na.rm=T)
zn$MobileHc     <-zn$MobileH     -mean(zn$MobileH     ,na.rm=T)
zn$DisablTc     <-zn$DisablT     -mean(zn$DisablT     ,na.rm=T)
zn$DisablWc     <-zn$DisablW     -mean(zn$DisablW     ,na.rm=T)
zn$DisablBc     <-zn$DisablB     -mean(zn$DisablB     ,na.rm=T)
zn$DisablHc     <-zn$DisablH     -mean(zn$DisablH     ,na.rm=T)
zn$DisablTCc    <-zn$DisablTC    -mean(zn$DisablTC    ,na.rm=T)
zn$DisablWCc    <-zn$DisablWC    -mean(zn$DisablWC    ,na.rm=T)
zn$DisablBCc    <-zn$DisablBC    -mean(zn$DisablBC    ,na.rm=T)
zn$DisablHCc    <-zn$DisablHC    -mean(zn$DisablHC    ,na.rm=T)
zn$DisablTMc    <-zn$DisablTM    -mean(zn$DisablTM    ,na.rm=T)
zn$DisablTFc    <-zn$DisablTF    -mean(zn$DisablTF    ,na.rm=T)
zn$Urban1c      <-zn$Urban1      -mean(zn$Urban1      ,na.rm=T)
zn$Urban2c      <-zn$Urban2      -mean(zn$Urban2      ,na.rm=T)
zn$ISBE_PFAc    <-zn$ISBE_PFA    -mean(zn$ISBE_PFA    ,na.rm=T)
zn$ISBE_PFAEc   <-zn$ISBE_PFAE   -mean(zn$ISBE_PFAE   ,na.rm=T)
zn$ISBE_PIc     <-zn$ISBE_PI     -mean(zn$ISBE_PI     ,na.rm=T)
zn$HeadStartc   <-zn$HeadStart   -mean(zn$HeadStart   ,na.rm=T)
zn$ElyHeadSc    <-zn$ElyHeadS    -mean(zn$ElyHeadS    ,na.rm=T)
zn$HeadSAllc    <-zn$HeadSAll    -mean(zn$HeadSAll    ,na.rm=T)
zn$PFA_HS1c     <-zn$PFA_HS1     -mean(zn$PFA_HS1     ,na.rm=T)
zn$PFA_HS2c     <-zn$PFA_HS2     -mean(zn$PFA_HS2     ,na.rm=T)
zn$LCCCc        <-zn$LCCC        -mean(zn$LCCC        ,na.rm=T)
zn$LECCCc       <-zn$LECCC       -mean(zn$LECCC       ,na.rm=T)
zn$LFCCc        <-zn$LFCC        -mean(zn$LFCC        ,na.rm=T)
zn$LLECCCc      <-zn$LLECCC      -mean(zn$LLECCC      ,na.rm=T)
zn$LCLFCCc      <-zn$LCLFCC      -mean(zn$LCLFCC      ,na.rm=T)
zn$LCCCB1c      <-zn$LCCCB1      -mean(zn$LCCCB1      ,na.rm=T)
zn$LCCCB2c      <-zn$LCCCB2      -mean(zn$LCCCB2      ,na.rm=T)
zn$LCCB1c       <-zn$LCCB1       -mean(zn$LCCB1       ,na.rm=T)
zn$LCCB2c       <-zn$LCCB2       -mean(zn$LCCB2       ,na.rm=T)
zn$LCCCS1c      <-zn$LCCCS1      -mean(zn$LCCCS1      ,na.rm=T)
zn$LCCCS2c      <-zn$LCCCS2      -mean(zn$LCCCS2      ,na.rm=T)
zn$LCCS1c       <-zn$LCCS1       -mean(zn$LCCS1       ,na.rm=T)
zn$LCCS2c       <-zn$LCCS2       -mean(zn$LCCS2       ,na.rm=T)
zn$LCCCG1c      <-zn$LCCCG1      -mean(zn$LCCCG1      ,na.rm=T)
zn$LCCCG2c      <-zn$LCCCG2      -mean(zn$LCCCG2      ,na.rm=T)
zn$LCCG1c       <-zn$LCCG1       -mean(zn$LCCG1       ,na.rm=T)
zn$LCCG2c       <-zn$LCCG2       -mean(zn$LCCG2       ,na.rm=T)
zn$ChildCare1c  <-zn$ChildCare1  -mean(zn$ChildCare1  ,na.rm=T)
zn$ChildCare2c  <-zn$ChildCare2  -mean(zn$ChildCare2  ,na.rm=T)
zn$ChildCare3c  <-zn$ChildCare3  -mean(zn$ChildCare3  ,na.rm=T)
zn$CCAPc        <-zn$CCAP        -mean(zn$CCAP        ,na.rm=T)
zn$Homelessc    <-zn$Homeless    -mean(zn$Homeless    ,na.rm=T)
zn$Homeless2c   <-zn$Homeless2   -mean(zn$Homeless2   ,na.rm=T)
zn$DHS_HFIrc    <-zn$DHS_HFIr    -mean(zn$DHS_HFIr    ,na.rm=T)
zn$DHS_PTSrc    <-zn$DHS_PTSr    -mean(zn$DHS_PTSr    ,na.rm=T)
zn$DHS_HVPrc    <-zn$DHS_HVPr    -mean(zn$DHS_HVPr    ,na.rm=T)
zn$IDHS_EIrc    <-zn$IDHS_EIr    -mean(zn$IDHS_EIr    ,na.rm=T)
zn$MHV_C4c      <-zn$MHV_C4      -mean(zn$MHV_C4      ,na.rm=T)
zn$MHV_P4c      <-zn$MHV_P4      -mean(zn$MHV_P4      ,na.rm=T)
zn$MHV_C5c      <-zn$MHV_C5      -mean(zn$MHV_C5      ,na.rm=T)
zn$MHV_P5c      <-zn$MHV_P5      -mean(zn$MHV_P5      ,na.rm=T)
zn$FoodInsPc    <-zn$FoodInsP    -mean(zn$FoodInsP    ,na.rm=T)
zn$FoodISc      <-zn$FoodIS      -mean(zn$FoodIS      ,na.rm=T)
zn$RPovTc       <-zn$RPovT       -mean(zn$RPovT       ,na.rm=T)
zn$PovTc        <-zn$PovT        -mean(zn$PovT        ,na.rm=T)
zn$MHV_C4k <-zn$MHV_C4 *10
zn$MHV_C5k <-zn$MHV_C5 *10
zn$MHV_C4kc<-zn$MHV_C4c*10
zn$MHV_C5kc<-zn$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zn1$Yearc        <-zn1$Year        -mean(zn1$Year        ,na.rm=T)
zn1$CPopBPc      <-zn1$CPopBP      -mean(zn1$CPopBP      ,na.rm=T)
zn1$CPopHPc      <-zn1$CPopHP      -mean(zn1$CPopHP      ,na.rm=T)
zn1$ChildPTc     <-zn1$ChildPT     -mean(zn1$ChildPT     ,na.rm=T)
zn1$ChildPWc     <-zn1$ChildPW     -mean(zn1$ChildPW     ,na.rm=T)
zn1$ChildPBc     <-zn1$ChildPB     -mean(zn1$ChildPB     ,na.rm=T)
zn1$ChildPHc     <-zn1$ChildPH     -mean(zn1$ChildPH     ,na.rm=T)
zn1$CARatioT100c <-zn1$CARatioT100 -mean(zn1$CARatioT100 ,na.rm=T)
zn1$CARatioW100c <-zn1$CARatioW100 -mean(zn1$CARatioW100 ,na.rm=T)
zn1$CARatioB100c <-zn1$CARatioB100 -mean(zn1$CARatioB100 ,na.rm=T)
zn1$CARatioH100c <-zn1$CARatioH100 -mean(zn1$CARatioH100 ,na.rm=T)
zn1$MalePTc      <-zn1$MalePT      -mean(zn1$MalePT      ,na.rm=T)
zn1$MalePWc      <-zn1$MalePW      -mean(zn1$MalePW      ,na.rm=T)
zn1$MalePBc      <-zn1$MalePB      -mean(zn1$MalePB      ,na.rm=T)
zn1$MalePHc      <-zn1$MalePH      -mean(zn1$MalePH      ,na.rm=T)
zn1$MFRatioT100c <-zn1$MFRatioT100 -mean(zn1$MFRatioT100 ,na.rm=T)
zn1$MFRatioW100c <-zn1$MFRatioW100 -mean(zn1$MFRatioW100 ,na.rm=T)
zn1$MFRatioB100c <-zn1$MFRatioB100 -mean(zn1$MFRatioB100 ,na.rm=T)
zn1$MFRatioH100c <-zn1$MFRatioH100 -mean(zn1$MFRatioH100 ,na.rm=T)
zn1$ElderTc      <-zn1$ElderT      -mean(zn1$ElderT      ,na.rm=T)
zn1$ElderWc      <-zn1$ElderW      -mean(zn1$ElderW      ,na.rm=T)
zn1$ElderBc      <-zn1$ElderB      -mean(zn1$ElderB      ,na.rm=T)
zn1$ElderHc      <-zn1$ElderH      -mean(zn1$ElderH      ,na.rm=T)
zn1$SingleTc     <-zn1$SingleT     -mean(zn1$SingleT     ,na.rm=T)
zn1$SingleWc     <-zn1$SingleW     -mean(zn1$SingleW     ,na.rm=T)
zn1$SingleBc     <-zn1$SingleB     -mean(zn1$SingleB     ,na.rm=T)
zn1$SingleHc     <-zn1$SingleH     -mean(zn1$SingleH     ,na.rm=T)
zn1$FHeadTc      <-zn1$FHeadT      -mean(zn1$FHeadT      ,na.rm=T)
zn1$FHeadWc      <-zn1$FHeadW      -mean(zn1$FHeadW      ,na.rm=T)
zn1$FHeadBc      <-zn1$FHeadB      -mean(zn1$FHeadB      ,na.rm=T)
zn1$FHeadHc      <-zn1$FHeadH      -mean(zn1$FHeadH      ,na.rm=T)
zn1$NoHighTc     <-zn1$NoHighT     -mean(zn1$NoHighT     ,na.rm=T)
zn1$NoHighWc     <-zn1$NoHighW     -mean(zn1$NoHighW     ,na.rm=T)
zn1$NoHighBc     <-zn1$NoHighB     -mean(zn1$NoHighB     ,na.rm=T)
zn1$NoHighHc     <-zn1$NoHighH     -mean(zn1$NoHighH     ,na.rm=T)
zn1$UnempTc      <-zn1$UnempT      -mean(zn1$UnempT      ,na.rm=T)
zn1$UnempWc      <-zn1$UnempW      -mean(zn1$UnempW      ,na.rm=T)
zn1$UnempBc      <-zn1$UnempB      -mean(zn1$UnempB      ,na.rm=T)
zn1$UnempHc      <-zn1$UnempH      -mean(zn1$UnempH      ,na.rm=T)
zn1$CPovTc       <-zn1$CPovT       -mean(zn1$CPovT       ,na.rm=T)
zn1$CPovWc       <-zn1$CPovW       -mean(zn1$CPovW       ,na.rm=T)
zn1$CPovBc       <-zn1$CPovB       -mean(zn1$CPovB       ,na.rm=T)
zn1$CPovHc       <-zn1$CPovH       -mean(zn1$CPovH       ,na.rm=T)
zn1$CPov1c       <-zn1$CPov1       -mean(zn1$CPov1       ,na.rm=T)
zn1$CPov2c       <-zn1$CPov2       -mean(zn1$CPov2       ,na.rm=T)
zn1$CPov3c       <-zn1$CPov3       -mean(zn1$CPov3       ,na.rm=T)
zn1$PubAsTc      <-zn1$PubAsT      -mean(zn1$PubAsT      ,na.rm=T)
zn1$WelfarTc     <-zn1$WelfarT     -mean(zn1$WelfarT     ,na.rm=T)
zn1$SnapTc       <-zn1$SnapT       -mean(zn1$SnapT       ,na.rm=T)
zn1$SnapWc       <-zn1$SnapW       -mean(zn1$SnapW       ,na.rm=T)
zn1$SnapBc       <-zn1$SnapB       -mean(zn1$SnapB       ,na.rm=T)
zn1$SnapHc       <-zn1$SnapH       -mean(zn1$SnapH       ,na.rm=T)
zn1$IncomeT1kc   <-zn1$IncomeT1k   -mean(zn1$IncomeT1k   ,na.rm=T)
zn1$IncomeW1kc   <-zn1$IncomeW1k   -mean(zn1$IncomeW1k   ,na.rm=T)
zn1$IncomeB1kc   <-zn1$IncomeB1k   -mean(zn1$IncomeB1k   ,na.rm=T)
zn1$IncomeH1kc   <-zn1$IncomeH1k   -mean(zn1$IncomeH1k   ,na.rm=T)
zn1$GiniT100c    <-zn1$GiniT100    -mean(zn1$GiniT100    ,na.rm=T)
zn1$HValueT10kc  <-zn1$HValueT10k  -mean(zn1$HValueT10k  ,na.rm=T)
zn1$MCostT100c   <-zn1$MCostT100   -mean(zn1$MCostT100   ,na.rm=T)
zn1$OCostDT100c  <-zn1$OCostDT100  -mean(zn1$OCostDT100  ,na.rm=T)
zn1$MRentDT100c  <-zn1$MRentDT100  -mean(zn1$MRentDT100  ,na.rm=T)
zn1$OCostPTc     <-zn1$OCostPT     -mean(zn1$OCostPT     ,na.rm=T)
zn1$MRentPTc     <-zn1$MRentPT     -mean(zn1$MRentPT     ,na.rm=T)
zn1$MortgTc      <-zn1$MortgT      -mean(zn1$MortgT      ,na.rm=T)
zn1$LangAPTc     <-zn1$LangAPT     -mean(zn1$LangAPT     ,na.rm=T)
zn1$LangAPWc     <-zn1$LangAPW     -mean(zn1$LangAPW     ,na.rm=T)
zn1$LangAPBc     <-zn1$LangAPB     -mean(zn1$LangAPB     ,na.rm=T)
zn1$LangAPHc     <-zn1$LangAPH     -mean(zn1$LangAPH     ,na.rm=T)
zn1$LangBPTc     <-zn1$LangBPT     -mean(zn1$LangBPT     ,na.rm=T)
zn1$LangBPWc     <-zn1$LangBPW     -mean(zn1$LangBPW     ,na.rm=T)
zn1$LangBPBc     <-zn1$LangBPB     -mean(zn1$LangBPB     ,na.rm=T)
zn1$LangBPHc     <-zn1$LangBPH     -mean(zn1$LangBPH     ,na.rm=T)
zn1$LangCPTc     <-zn1$LangCPT     -mean(zn1$LangCPT     ,na.rm=T)
zn1$OutUsTc      <-zn1$OutUsT      -mean(zn1$OutUsT      ,na.rm=T)
zn1$OutUsWc      <-zn1$OutUsW      -mean(zn1$OutUsW      ,na.rm=T)
zn1$OutUsBc      <-zn1$OutUsB      -mean(zn1$OutUsB      ,na.rm=T)
zn1$OutUsHc      <-zn1$OutUsH      -mean(zn1$OutUsH      ,na.rm=T)
zn1$FBornTc      <-zn1$FBornT      -mean(zn1$FBornT      ,na.rm=T)
zn1$FBornWc      <-zn1$FBornW      -mean(zn1$FBornW      ,na.rm=T)
zn1$FBornBc      <-zn1$FBornB      -mean(zn1$FBornB      ,na.rm=T)
zn1$FBornHc      <-zn1$FBornH      -mean(zn1$FBornH      ,na.rm=T)
zn1$NotCtzTc     <-zn1$NotCtzT     -mean(zn1$NotCtzT     ,na.rm=T)
zn1$NotCtzWc     <-zn1$NotCtzW     -mean(zn1$NotCtzW     ,na.rm=T)
zn1$NotCtzBc     <-zn1$NotCtzB     -mean(zn1$NotCtzB     ,na.rm=T)
zn1$NotCtzHc     <-zn1$NotCtzH     -mean(zn1$NotCtzH     ,na.rm=T)
zn1$MoveTc       <-zn1$MoveT       -mean(zn1$MoveT       ,na.rm=T)
zn1$MoveWc       <-zn1$MoveW       -mean(zn1$MoveW       ,na.rm=T)
zn1$MoveBc       <-zn1$MoveB       -mean(zn1$MoveB       ,na.rm=T)
zn1$MoveHc       <-zn1$MoveH       -mean(zn1$MoveH       ,na.rm=T)
zn1$VacantTc     <-zn1$VacantT     -mean(zn1$VacantT     ,na.rm=T)
zn1$OwnerTc      <-zn1$OwnerT      -mean(zn1$OwnerT      ,na.rm=T)
zn1$OwnerWc      <-zn1$OwnerW      -mean(zn1$OwnerW      ,na.rm=T)
zn1$OwnerBc      <-zn1$OwnerB      -mean(zn1$OwnerB      ,na.rm=T)
zn1$OwnerHc      <-zn1$OwnerH      -mean(zn1$OwnerH      ,na.rm=T)
zn1$CrowdTc      <-zn1$CrowdT      -mean(zn1$CrowdT      ,na.rm=T)
zn1$CrowdWc      <-zn1$CrowdW      -mean(zn1$CrowdW      ,na.rm=T)
zn1$CrowdBc      <-zn1$CrowdB      -mean(zn1$CrowdB      ,na.rm=T)
zn1$CrowdHc      <-zn1$CrowdH      -mean(zn1$CrowdH      ,na.rm=T)
zn1$MobileTc     <-zn1$MobileT     -mean(zn1$MobileT     ,na.rm=T)
zn1$MobileWc     <-zn1$MobileW     -mean(zn1$MobileW     ,na.rm=T)
zn1$MobileBc     <-zn1$MobileB     -mean(zn1$MobileB     ,na.rm=T)
zn1$MobileHc     <-zn1$MobileH     -mean(zn1$MobileH     ,na.rm=T)
zn1$DisablTc     <-zn1$DisablT     -mean(zn1$DisablT     ,na.rm=T)
zn1$DisablWc     <-zn1$DisablW     -mean(zn1$DisablW     ,na.rm=T)
zn1$DisablBc     <-zn1$DisablB     -mean(zn1$DisablB     ,na.rm=T)
zn1$DisablHc     <-zn1$DisablH     -mean(zn1$DisablH     ,na.rm=T)
zn1$DisablTCc    <-zn1$DisablTC    -mean(zn1$DisablTC    ,na.rm=T)
zn1$DisablWCc    <-zn1$DisablWC    -mean(zn1$DisablWC    ,na.rm=T)
zn1$DisablBCc    <-zn1$DisablBC    -mean(zn1$DisablBC    ,na.rm=T)
zn1$DisablHCc    <-zn1$DisablHC    -mean(zn1$DisablHC    ,na.rm=T)
zn1$DisablTMc    <-zn1$DisablTM    -mean(zn1$DisablTM    ,na.rm=T)
zn1$DisablTFc    <-zn1$DisablTF    -mean(zn1$DisablTF    ,na.rm=T)
zn1$Urban1c      <-zn1$Urban1      -mean(zn1$Urban1      ,na.rm=T)
zn1$Urban2c      <-zn1$Urban2      -mean(zn1$Urban2      ,na.rm=T)
zn1$ISBE_PFAc    <-zn1$ISBE_PFA    -mean(zn1$ISBE_PFA    ,na.rm=T)
zn1$ISBE_PFAEc   <-zn1$ISBE_PFAE   -mean(zn1$ISBE_PFAE   ,na.rm=T)
zn1$ISBE_PIc     <-zn1$ISBE_PI     -mean(zn1$ISBE_PI     ,na.rm=T)
zn1$HeadStartc   <-zn1$HeadStart   -mean(zn1$HeadStart   ,na.rm=T)
zn1$ElyHeadSc    <-zn1$ElyHeadS    -mean(zn1$ElyHeadS    ,na.rm=T)
zn1$HeadSAllc    <-zn1$HeadSAll    -mean(zn1$HeadSAll    ,na.rm=T)
zn1$PFA_HS1c     <-zn1$PFA_HS1     -mean(zn1$PFA_HS1     ,na.rm=T)
zn1$PFA_HS2c     <-zn1$PFA_HS2     -mean(zn1$PFA_HS2     ,na.rm=T)
zn1$LCCCc        <-zn1$LCCC        -mean(zn1$LCCC        ,na.rm=T)
zn1$LECCCc       <-zn1$LECCC       -mean(zn1$LECCC       ,na.rm=T)
zn1$LFCCc        <-zn1$LFCC        -mean(zn1$LFCC        ,na.rm=T)
zn1$LLECCCc      <-zn1$LLECCC      -mean(zn1$LLECCC      ,na.rm=T)
zn1$LCLFCCc      <-zn1$LCLFCC      -mean(zn1$LCLFCC      ,na.rm=T)
zn1$LCCCB1c      <-zn1$LCCCB1      -mean(zn1$LCCCB1      ,na.rm=T)
zn1$LCCCB2c      <-zn1$LCCCB2      -mean(zn1$LCCCB2      ,na.rm=T)
zn1$LCCB1c       <-zn1$LCCB1       -mean(zn1$LCCB1       ,na.rm=T)
zn1$LCCB2c       <-zn1$LCCB2       -mean(zn1$LCCB2       ,na.rm=T)
zn1$LCCCS1c      <-zn1$LCCCS1      -mean(zn1$LCCCS1      ,na.rm=T)
zn1$LCCCS2c      <-zn1$LCCCS2      -mean(zn1$LCCCS2      ,na.rm=T)
zn1$LCCS1c       <-zn1$LCCS1       -mean(zn1$LCCS1       ,na.rm=T)
zn1$LCCS2c       <-zn1$LCCS2       -mean(zn1$LCCS2       ,na.rm=T)
zn1$LCCCG1c      <-zn1$LCCCG1      -mean(zn1$LCCCG1      ,na.rm=T)
zn1$LCCCG2c      <-zn1$LCCCG2      -mean(zn1$LCCCG2      ,na.rm=T)
zn1$LCCG1c       <-zn1$LCCG1       -mean(zn1$LCCG1       ,na.rm=T)
zn1$LCCG2c       <-zn1$LCCG2       -mean(zn1$LCCG2       ,na.rm=T)
zn1$ChildCare1c  <-zn1$ChildCare1  -mean(zn1$ChildCare1  ,na.rm=T)
zn1$ChildCare2c  <-zn1$ChildCare2  -mean(zn1$ChildCare2  ,na.rm=T)
zn1$ChildCare3c  <-zn1$ChildCare3  -mean(zn1$ChildCare3  ,na.rm=T)
zn1$CCAPc        <-zn1$CCAP        -mean(zn1$CCAP        ,na.rm=T)
zn1$Homelessc    <-zn1$Homeless    -mean(zn1$Homeless    ,na.rm=T)
zn1$Homeless2c   <-zn1$Homeless2   -mean(zn1$Homeless2   ,na.rm=T)
zn1$DHS_HFIrc    <-zn1$DHS_HFIr    -mean(zn1$DHS_HFIr    ,na.rm=T)
zn1$DHS_PTSrc    <-zn1$DHS_PTSr    -mean(zn1$DHS_PTSr    ,na.rm=T)
zn1$DHS_HVPrc    <-zn1$DHS_HVPr    -mean(zn1$DHS_HVPr    ,na.rm=T)
zn1$IDHS_EIrc    <-zn1$IDHS_EIr    -mean(zn1$IDHS_EIr    ,na.rm=T)
zn1$MHV_C4c      <-zn1$MHV_C4      -mean(zn1$MHV_C4      ,na.rm=T)
zn1$MHV_P4c      <-zn1$MHV_P4      -mean(zn1$MHV_P4      ,na.rm=T)
zn1$MHV_C5c      <-zn1$MHV_C5      -mean(zn1$MHV_C5      ,na.rm=T)
zn1$MHV_P5c      <-zn1$MHV_P5      -mean(zn1$MHV_P5      ,na.rm=T)
zn1$FoodInsPc    <-zn1$FoodInsP    -mean(zn1$FoodInsP    ,na.rm=T)
zn1$FoodISc      <-zn1$FoodIS      -mean(zn1$FoodIS      ,na.rm=T)
zn1$RPovTc       <-zn1$RPovT       -mean(zn1$RPovT       ,na.rm=T)
zn1$PovTc        <-zn1$PovT        -mean(zn1$PovT        ,na.rm=T)
zn1$MHV_C4k <-zn1$MHV_C4 *10
zn1$MHV_C5k <-zn1$MHV_C5 *10
zn1$MHV_C4kc<-zn1$MHV_C4c*10
zn1$MHV_C5kc<-zn1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zn2$Yearc        <-zn2$Year        -mean(zn2$Year        ,na.rm=T)
zn2$CPopBPc      <-zn2$CPopBP      -mean(zn2$CPopBP      ,na.rm=T)
zn2$CPopHPc      <-zn2$CPopHP      -mean(zn2$CPopHP      ,na.rm=T)
zn2$ChildPTc     <-zn2$ChildPT     -mean(zn2$ChildPT     ,na.rm=T)
zn2$ChildPWc     <-zn2$ChildPW     -mean(zn2$ChildPW     ,na.rm=T)
zn2$ChildPBc     <-zn2$ChildPB     -mean(zn2$ChildPB     ,na.rm=T)
zn2$ChildPHc     <-zn2$ChildPH     -mean(zn2$ChildPH     ,na.rm=T)
zn2$CARatioT100c <-zn2$CARatioT100 -mean(zn2$CARatioT100 ,na.rm=T)
zn2$CARatioW100c <-zn2$CARatioW100 -mean(zn2$CARatioW100 ,na.rm=T)
zn2$CARatioB100c <-zn2$CARatioB100 -mean(zn2$CARatioB100 ,na.rm=T)
zn2$CARatioH100c <-zn2$CARatioH100 -mean(zn2$CARatioH100 ,na.rm=T)
zn2$MalePTc      <-zn2$MalePT      -mean(zn2$MalePT      ,na.rm=T)
zn2$MalePWc      <-zn2$MalePW      -mean(zn2$MalePW      ,na.rm=T)
zn2$MalePBc      <-zn2$MalePB      -mean(zn2$MalePB      ,na.rm=T)
zn2$MalePHc      <-zn2$MalePH      -mean(zn2$MalePH      ,na.rm=T)
zn2$MFRatioT100c <-zn2$MFRatioT100 -mean(zn2$MFRatioT100 ,na.rm=T)
zn2$MFRatioW100c <-zn2$MFRatioW100 -mean(zn2$MFRatioW100 ,na.rm=T)
zn2$MFRatioB100c <-zn2$MFRatioB100 -mean(zn2$MFRatioB100 ,na.rm=T)
zn2$MFRatioH100c <-zn2$MFRatioH100 -mean(zn2$MFRatioH100 ,na.rm=T)
zn2$ElderTc      <-zn2$ElderT      -mean(zn2$ElderT      ,na.rm=T)
zn2$ElderWc      <-zn2$ElderW      -mean(zn2$ElderW      ,na.rm=T)
zn2$ElderBc      <-zn2$ElderB      -mean(zn2$ElderB      ,na.rm=T)
zn2$ElderHc      <-zn2$ElderH      -mean(zn2$ElderH      ,na.rm=T)
zn2$SingleTc     <-zn2$SingleT     -mean(zn2$SingleT     ,na.rm=T)
zn2$SingleWc     <-zn2$SingleW     -mean(zn2$SingleW     ,na.rm=T)
zn2$SingleBc     <-zn2$SingleB     -mean(zn2$SingleB     ,na.rm=T)
zn2$SingleHc     <-zn2$SingleH     -mean(zn2$SingleH     ,na.rm=T)
zn2$FHeadTc      <-zn2$FHeadT      -mean(zn2$FHeadT      ,na.rm=T)
zn2$FHeadWc      <-zn2$FHeadW      -mean(zn2$FHeadW      ,na.rm=T)
zn2$FHeadBc      <-zn2$FHeadB      -mean(zn2$FHeadB      ,na.rm=T)
zn2$FHeadHc      <-zn2$FHeadH      -mean(zn2$FHeadH      ,na.rm=T)
zn2$NoHighTc     <-zn2$NoHighT     -mean(zn2$NoHighT     ,na.rm=T)
zn2$NoHighWc     <-zn2$NoHighW     -mean(zn2$NoHighW     ,na.rm=T)
zn2$NoHighBc     <-zn2$NoHighB     -mean(zn2$NoHighB     ,na.rm=T)
zn2$NoHighHc     <-zn2$NoHighH     -mean(zn2$NoHighH     ,na.rm=T)
zn2$UnempTc      <-zn2$UnempT      -mean(zn2$UnempT      ,na.rm=T)
zn2$UnempWc      <-zn2$UnempW      -mean(zn2$UnempW      ,na.rm=T)
zn2$UnempBc      <-zn2$UnempB      -mean(zn2$UnempB      ,na.rm=T)
zn2$UnempHc      <-zn2$UnempH      -mean(zn2$UnempH      ,na.rm=T)
zn2$CPovTc       <-zn2$CPovT       -mean(zn2$CPovT       ,na.rm=T)
zn2$CPovWc       <-zn2$CPovW       -mean(zn2$CPovW       ,na.rm=T)
zn2$CPovBc       <-zn2$CPovB       -mean(zn2$CPovB       ,na.rm=T)
zn2$CPovHc       <-zn2$CPovH       -mean(zn2$CPovH       ,na.rm=T)
zn2$CPov1c       <-zn2$CPov1       -mean(zn2$CPov1       ,na.rm=T)
zn2$CPov2c       <-zn2$CPov2       -mean(zn2$CPov2       ,na.rm=T)
zn2$CPov3c       <-zn2$CPov3       -mean(zn2$CPov3       ,na.rm=T)
zn2$PubAsTc      <-zn2$PubAsT      -mean(zn2$PubAsT      ,na.rm=T)
zn2$WelfarTc     <-zn2$WelfarT     -mean(zn2$WelfarT     ,na.rm=T)
zn2$SnapTc       <-zn2$SnapT       -mean(zn2$SnapT       ,na.rm=T)
zn2$SnapWc       <-zn2$SnapW       -mean(zn2$SnapW       ,na.rm=T)
zn2$SnapBc       <-zn2$SnapB       -mean(zn2$SnapB       ,na.rm=T)
zn2$SnapHc       <-zn2$SnapH       -mean(zn2$SnapH       ,na.rm=T)
zn2$IncomeT1kc   <-zn2$IncomeT1k   -mean(zn2$IncomeT1k   ,na.rm=T)
zn2$IncomeW1kc   <-zn2$IncomeW1k   -mean(zn2$IncomeW1k   ,na.rm=T)
zn2$IncomeB1kc   <-zn2$IncomeB1k   -mean(zn2$IncomeB1k   ,na.rm=T)
zn2$IncomeH1kc   <-zn2$IncomeH1k   -mean(zn2$IncomeH1k   ,na.rm=T)
zn2$GiniT100c    <-zn2$GiniT100    -mean(zn2$GiniT100    ,na.rm=T)
zn2$HValueT10kc  <-zn2$HValueT10k  -mean(zn2$HValueT10k  ,na.rm=T)
zn2$MCostT100c   <-zn2$MCostT100   -mean(zn2$MCostT100   ,na.rm=T)
zn2$OCostDT100c  <-zn2$OCostDT100  -mean(zn2$OCostDT100  ,na.rm=T)
zn2$MRentDT100c  <-zn2$MRentDT100  -mean(zn2$MRentDT100  ,na.rm=T)
zn2$OCostPTc     <-zn2$OCostPT     -mean(zn2$OCostPT     ,na.rm=T)
zn2$MRentPTc     <-zn2$MRentPT     -mean(zn2$MRentPT     ,na.rm=T)
zn2$MortgTc      <-zn2$MortgT      -mean(zn2$MortgT      ,na.rm=T)
zn2$LangAPTc     <-zn2$LangAPT     -mean(zn2$LangAPT     ,na.rm=T)
zn2$LangAPWc     <-zn2$LangAPW     -mean(zn2$LangAPW     ,na.rm=T)
zn2$LangAPBc     <-zn2$LangAPB     -mean(zn2$LangAPB     ,na.rm=T)
zn2$LangAPHc     <-zn2$LangAPH     -mean(zn2$LangAPH     ,na.rm=T)
zn2$LangBPTc     <-zn2$LangBPT     -mean(zn2$LangBPT     ,na.rm=T)
zn2$LangBPWc     <-zn2$LangBPW     -mean(zn2$LangBPW     ,na.rm=T)
zn2$LangBPBc     <-zn2$LangBPB     -mean(zn2$LangBPB     ,na.rm=T)
zn2$LangBPHc     <-zn2$LangBPH     -mean(zn2$LangBPH     ,na.rm=T)
zn2$LangCPTc     <-zn2$LangCPT     -mean(zn2$LangCPT     ,na.rm=T)
zn2$OutUsTc      <-zn2$OutUsT      -mean(zn2$OutUsT      ,na.rm=T)
zn2$OutUsWc      <-zn2$OutUsW      -mean(zn2$OutUsW      ,na.rm=T)
zn2$OutUsBc      <-zn2$OutUsB      -mean(zn2$OutUsB      ,na.rm=T)
zn2$OutUsHc      <-zn2$OutUsH      -mean(zn2$OutUsH      ,na.rm=T)
zn2$FBornTc      <-zn2$FBornT      -mean(zn2$FBornT      ,na.rm=T)
zn2$FBornWc      <-zn2$FBornW      -mean(zn2$FBornW      ,na.rm=T)
zn2$FBornBc      <-zn2$FBornB      -mean(zn2$FBornB      ,na.rm=T)
zn2$FBornHc      <-zn2$FBornH      -mean(zn2$FBornH      ,na.rm=T)
zn2$NotCtzTc     <-zn2$NotCtzT     -mean(zn2$NotCtzT     ,na.rm=T)
zn2$NotCtzWc     <-zn2$NotCtzW     -mean(zn2$NotCtzW     ,na.rm=T)
zn2$NotCtzBc     <-zn2$NotCtzB     -mean(zn2$NotCtzB     ,na.rm=T)
zn2$NotCtzHc     <-zn2$NotCtzH     -mean(zn2$NotCtzH     ,na.rm=T)
zn2$MoveTc       <-zn2$MoveT       -mean(zn2$MoveT       ,na.rm=T)
zn2$MoveWc       <-zn2$MoveW       -mean(zn2$MoveW       ,na.rm=T)
zn2$MoveBc       <-zn2$MoveB       -mean(zn2$MoveB       ,na.rm=T)
zn2$MoveHc       <-zn2$MoveH       -mean(zn2$MoveH       ,na.rm=T)
zn2$VacantTc     <-zn2$VacantT     -mean(zn2$VacantT     ,na.rm=T)
zn2$OwnerTc      <-zn2$OwnerT      -mean(zn2$OwnerT      ,na.rm=T)
zn2$OwnerWc      <-zn2$OwnerW      -mean(zn2$OwnerW      ,na.rm=T)
zn2$OwnerBc      <-zn2$OwnerB      -mean(zn2$OwnerB      ,na.rm=T)
zn2$OwnerHc      <-zn2$OwnerH      -mean(zn2$OwnerH      ,na.rm=T)
zn2$CrowdTc      <-zn2$CrowdT      -mean(zn2$CrowdT      ,na.rm=T)
zn2$CrowdWc      <-zn2$CrowdW      -mean(zn2$CrowdW      ,na.rm=T)
zn2$CrowdBc      <-zn2$CrowdB      -mean(zn2$CrowdB      ,na.rm=T)
zn2$CrowdHc      <-zn2$CrowdH      -mean(zn2$CrowdH      ,na.rm=T)
zn2$MobileTc     <-zn2$MobileT     -mean(zn2$MobileT     ,na.rm=T)
zn2$MobileWc     <-zn2$MobileW     -mean(zn2$MobileW     ,na.rm=T)
zn2$MobileBc     <-zn2$MobileB     -mean(zn2$MobileB     ,na.rm=T)
zn2$MobileHc     <-zn2$MobileH     -mean(zn2$MobileH     ,na.rm=T)
zn2$DisablTc     <-zn2$DisablT     -mean(zn2$DisablT     ,na.rm=T)
zn2$DisablWc     <-zn2$DisablW     -mean(zn2$DisablW     ,na.rm=T)
zn2$DisablBc     <-zn2$DisablB     -mean(zn2$DisablB     ,na.rm=T)
zn2$DisablHc     <-zn2$DisablH     -mean(zn2$DisablH     ,na.rm=T)
zn2$DisablTCc    <-zn2$DisablTC    -mean(zn2$DisablTC    ,na.rm=T)
zn2$DisablWCc    <-zn2$DisablWC    -mean(zn2$DisablWC    ,na.rm=T)
zn2$DisablBCc    <-zn2$DisablBC    -mean(zn2$DisablBC    ,na.rm=T)
zn2$DisablHCc    <-zn2$DisablHC    -mean(zn2$DisablHC    ,na.rm=T)
zn2$DisablTMc    <-zn2$DisablTM    -mean(zn2$DisablTM    ,na.rm=T)
zn2$DisablTFc    <-zn2$DisablTF    -mean(zn2$DisablTF    ,na.rm=T)
zn2$Urban1c      <-zn2$Urban1      -mean(zn2$Urban1      ,na.rm=T)
zn2$Urban2c      <-zn2$Urban2      -mean(zn2$Urban2      ,na.rm=T)
zn2$ISBE_PFAc    <-zn2$ISBE_PFA    -mean(zn2$ISBE_PFA    ,na.rm=T)
zn2$ISBE_PFAEc   <-zn2$ISBE_PFAE   -mean(zn2$ISBE_PFAE   ,na.rm=T)
zn2$ISBE_PIc     <-zn2$ISBE_PI     -mean(zn2$ISBE_PI     ,na.rm=T)
zn2$HeadStartc   <-zn2$HeadStart   -mean(zn2$HeadStart   ,na.rm=T)
zn2$ElyHeadSc    <-zn2$ElyHeadS    -mean(zn2$ElyHeadS    ,na.rm=T)
zn2$HeadSAllc    <-zn2$HeadSAll    -mean(zn2$HeadSAll    ,na.rm=T)
zn2$PFA_HS1c     <-zn2$PFA_HS1     -mean(zn2$PFA_HS1     ,na.rm=T)
zn2$PFA_HS2c     <-zn2$PFA_HS2     -mean(zn2$PFA_HS2     ,na.rm=T)
zn2$LCCCc        <-zn2$LCCC        -mean(zn2$LCCC        ,na.rm=T)
zn2$LECCCc       <-zn2$LECCC       -mean(zn2$LECCC       ,na.rm=T)
zn2$LFCCc        <-zn2$LFCC        -mean(zn2$LFCC        ,na.rm=T)
zn2$LLECCCc      <-zn2$LLECCC      -mean(zn2$LLECCC      ,na.rm=T)
zn2$LCLFCCc      <-zn2$LCLFCC      -mean(zn2$LCLFCC      ,na.rm=T)
zn2$LCCCB1c      <-zn2$LCCCB1      -mean(zn2$LCCCB1      ,na.rm=T)
zn2$LCCCB2c      <-zn2$LCCCB2      -mean(zn2$LCCCB2      ,na.rm=T)
zn2$LCCB1c       <-zn2$LCCB1       -mean(zn2$LCCB1       ,na.rm=T)
zn2$LCCB2c       <-zn2$LCCB2       -mean(zn2$LCCB2       ,na.rm=T)
zn2$LCCCS1c      <-zn2$LCCCS1      -mean(zn2$LCCCS1      ,na.rm=T)
zn2$LCCCS2c      <-zn2$LCCCS2      -mean(zn2$LCCCS2      ,na.rm=T)
zn2$LCCS1c       <-zn2$LCCS1       -mean(zn2$LCCS1       ,na.rm=T)
zn2$LCCS2c       <-zn2$LCCS2       -mean(zn2$LCCS2       ,na.rm=T)
zn2$LCCCG1c      <-zn2$LCCCG1      -mean(zn2$LCCCG1      ,na.rm=T)
zn2$LCCCG2c      <-zn2$LCCCG2      -mean(zn2$LCCCG2      ,na.rm=T)
zn2$LCCG1c       <-zn2$LCCG1       -mean(zn2$LCCG1       ,na.rm=T)
zn2$LCCG2c       <-zn2$LCCG2       -mean(zn2$LCCG2       ,na.rm=T)
zn2$ChildCare1c  <-zn2$ChildCare1  -mean(zn2$ChildCare1  ,na.rm=T)
zn2$ChildCare2c  <-zn2$ChildCare2  -mean(zn2$ChildCare2  ,na.rm=T)
zn2$ChildCare3c  <-zn2$ChildCare3  -mean(zn2$ChildCare3  ,na.rm=T)
zn2$CCAPc        <-zn2$CCAP        -mean(zn2$CCAP        ,na.rm=T)
zn2$Homelessc    <-zn2$Homeless    -mean(zn2$Homeless    ,na.rm=T)
zn2$Homeless2c   <-zn2$Homeless2   -mean(zn2$Homeless2   ,na.rm=T)
zn2$DHS_HFIrc    <-zn2$DHS_HFIr    -mean(zn2$DHS_HFIr    ,na.rm=T)
zn2$DHS_PTSrc    <-zn2$DHS_PTSr    -mean(zn2$DHS_PTSr    ,na.rm=T)
zn2$DHS_HVPrc    <-zn2$DHS_HVPr    -mean(zn2$DHS_HVPr    ,na.rm=T)
zn2$IDHS_EIrc    <-zn2$IDHS_EIr    -mean(zn2$IDHS_EIr    ,na.rm=T)
zn2$MHV_C4c      <-zn2$MHV_C4      -mean(zn2$MHV_C4      ,na.rm=T)
zn2$MHV_P4c      <-zn2$MHV_P4      -mean(zn2$MHV_P4      ,na.rm=T)
zn2$MHV_C5c      <-zn2$MHV_C5      -mean(zn2$MHV_C5      ,na.rm=T)
zn2$MHV_P5c      <-zn2$MHV_P5      -mean(zn2$MHV_P5      ,na.rm=T)
zn2$FoodInsPc    <-zn2$FoodInsP    -mean(zn2$FoodInsP    ,na.rm=T)
zn2$FoodISc      <-zn2$FoodIS      -mean(zn2$FoodIS      ,na.rm=T)
zn2$RPovTc       <-zn2$RPovT       -mean(zn2$RPovT       ,na.rm=T)
zn2$PovTc        <-zn2$PovT        -mean(zn2$PovT        ,na.rm=T)
zn2$MHV_C4k <-zn2$MHV_C4 *10
zn2$MHV_C5k <-zn2$MHV_C5 *10
zn2$MHV_C4kc<-zn2$MHV_C4c*10
zn2$MHV_C5kc<-zn2$MHV_C5c*10





# demean - within and between variables
zn<-cbind(zn,demean(zn,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zn1<-cbind(zn1,demean(zn1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zn2<-cbind(zn2,demean(zn2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Physical Abuse
# Income - Physical Abuse
# Income - Physical Abuse
# Income - Physical Abuse
# Income - Physical Abuse
# Income - Physical Abuse
# Income - Physical Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zp$Yearc        <-zp$Year        -mean(zp$Year        ,na.rm=T)
zp$CPopBPc      <-zp$CPopBP      -mean(zp$CPopBP      ,na.rm=T)
zp$CPopHPc      <-zp$CPopHP      -mean(zp$CPopHP      ,na.rm=T)
zp$ChildPTc     <-zp$ChildPT     -mean(zp$ChildPT     ,na.rm=T)
zp$ChildPWc     <-zp$ChildPW     -mean(zp$ChildPW     ,na.rm=T)
zp$ChildPBc     <-zp$ChildPB     -mean(zp$ChildPB     ,na.rm=T)
zp$ChildPHc     <-zp$ChildPH     -mean(zp$ChildPH     ,na.rm=T)
zp$CARatioT100c <-zp$CARatioT100 -mean(zp$CARatioT100 ,na.rm=T)
zp$CARatioW100c <-zp$CARatioW100 -mean(zp$CARatioW100 ,na.rm=T)
zp$CARatioB100c <-zp$CARatioB100 -mean(zp$CARatioB100 ,na.rm=T)
zp$CARatioH100c <-zp$CARatioH100 -mean(zp$CARatioH100 ,na.rm=T)
zp$MalePTc      <-zp$MalePT      -mean(zp$MalePT      ,na.rm=T)
zp$MalePWc      <-zp$MalePW      -mean(zp$MalePW      ,na.rm=T)
zp$MalePBc      <-zp$MalePB      -mean(zp$MalePB      ,na.rm=T)
zp$MalePHc      <-zp$MalePH      -mean(zp$MalePH      ,na.rm=T)
zp$MFRatioT100c <-zp$MFRatioT100 -mean(zp$MFRatioT100 ,na.rm=T)
zp$MFRatioW100c <-zp$MFRatioW100 -mean(zp$MFRatioW100 ,na.rm=T)
zp$MFRatioB100c <-zp$MFRatioB100 -mean(zp$MFRatioB100 ,na.rm=T)
zp$MFRatioH100c <-zp$MFRatioH100 -mean(zp$MFRatioH100 ,na.rm=T)
zp$ElderTc      <-zp$ElderT      -mean(zp$ElderT      ,na.rm=T)
zp$ElderWc      <-zp$ElderW      -mean(zp$ElderW      ,na.rm=T)
zp$ElderBc      <-zp$ElderB      -mean(zp$ElderB      ,na.rm=T)
zp$ElderHc      <-zp$ElderH      -mean(zp$ElderH      ,na.rm=T)
zp$SingleTc     <-zp$SingleT     -mean(zp$SingleT     ,na.rm=T)
zp$SingleWc     <-zp$SingleW     -mean(zp$SingleW     ,na.rm=T)
zp$SingleBc     <-zp$SingleB     -mean(zp$SingleB     ,na.rm=T)
zp$SingleHc     <-zp$SingleH     -mean(zp$SingleH     ,na.rm=T)
zp$FHeadTc      <-zp$FHeadT      -mean(zp$FHeadT      ,na.rm=T)
zp$FHeadWc      <-zp$FHeadW      -mean(zp$FHeadW      ,na.rm=T)
zp$FHeadBc      <-zp$FHeadB      -mean(zp$FHeadB      ,na.rm=T)
zp$FHeadHc      <-zp$FHeadH      -mean(zp$FHeadH      ,na.rm=T)
zp$NoHighTc     <-zp$NoHighT     -mean(zp$NoHighT     ,na.rm=T)
zp$NoHighWc     <-zp$NoHighW     -mean(zp$NoHighW     ,na.rm=T)
zp$NoHighBc     <-zp$NoHighB     -mean(zp$NoHighB     ,na.rm=T)
zp$NoHighHc     <-zp$NoHighH     -mean(zp$NoHighH     ,na.rm=T)
zp$UnempTc      <-zp$UnempT      -mean(zp$UnempT      ,na.rm=T)
zp$UnempWc      <-zp$UnempW      -mean(zp$UnempW      ,na.rm=T)
zp$UnempBc      <-zp$UnempB      -mean(zp$UnempB      ,na.rm=T)
zp$UnempHc      <-zp$UnempH      -mean(zp$UnempH      ,na.rm=T)
zp$CPovTc       <-zp$CPovT       -mean(zp$CPovT       ,na.rm=T)
zp$CPovWc       <-zp$CPovW       -mean(zp$CPovW       ,na.rm=T)
zp$CPovBc       <-zp$CPovB       -mean(zp$CPovB       ,na.rm=T)
zp$CPovHc       <-zp$CPovH       -mean(zp$CPovH       ,na.rm=T)
zp$CPov1c       <-zp$CPov1       -mean(zp$CPov1       ,na.rm=T)
zp$CPov2c       <-zp$CPov2       -mean(zp$CPov2       ,na.rm=T)
zp$CPov3c       <-zp$CPov3       -mean(zp$CPov3       ,na.rm=T)
zp$PubAsTc      <-zp$PubAsT      -mean(zp$PubAsT      ,na.rm=T)
zp$WelfarTc     <-zp$WelfarT     -mean(zp$WelfarT     ,na.rm=T)
zp$SnapTc       <-zp$SnapT       -mean(zp$SnapT       ,na.rm=T)
zp$SnapWc       <-zp$SnapW       -mean(zp$SnapW       ,na.rm=T)
zp$SnapBc       <-zp$SnapB       -mean(zp$SnapB       ,na.rm=T)
zp$SnapHc       <-zp$SnapH       -mean(zp$SnapH       ,na.rm=T)
zp$IncomeT1kc   <-zp$IncomeT1k   -mean(zp$IncomeT1k   ,na.rm=T)
zp$IncomeW1kc   <-zp$IncomeW1k   -mean(zp$IncomeW1k   ,na.rm=T)
zp$IncomeB1kc   <-zp$IncomeB1k   -mean(zp$IncomeB1k   ,na.rm=T)
zp$IncomeH1kc   <-zp$IncomeH1k   -mean(zp$IncomeH1k   ,na.rm=T)
zp$GiniT100c    <-zp$GiniT100    -mean(zp$GiniT100    ,na.rm=T)
zp$HValueT10kc  <-zp$HValueT10k  -mean(zp$HValueT10k  ,na.rm=T)
zp$MCostT100c   <-zp$MCostT100   -mean(zp$MCostT100   ,na.rm=T)
zp$OCostDT100c  <-zp$OCostDT100  -mean(zp$OCostDT100  ,na.rm=T)
zp$MRentDT100c  <-zp$MRentDT100  -mean(zp$MRentDT100  ,na.rm=T)
zp$OCostPTc     <-zp$OCostPT     -mean(zp$OCostPT     ,na.rm=T)
zp$MRentPTc     <-zp$MRentPT     -mean(zp$MRentPT     ,na.rm=T)
zp$MortgTc      <-zp$MortgT      -mean(zp$MortgT      ,na.rm=T)
zp$LangAPTc     <-zp$LangAPT     -mean(zp$LangAPT     ,na.rm=T)
zp$LangAPWc     <-zp$LangAPW     -mean(zp$LangAPW     ,na.rm=T)
zp$LangAPBc     <-zp$LangAPB     -mean(zp$LangAPB     ,na.rm=T)
zp$LangAPHc     <-zp$LangAPH     -mean(zp$LangAPH     ,na.rm=T)
zp$LangBPTc     <-zp$LangBPT     -mean(zp$LangBPT     ,na.rm=T)
zp$LangBPWc     <-zp$LangBPW     -mean(zp$LangBPW     ,na.rm=T)
zp$LangBPBc     <-zp$LangBPB     -mean(zp$LangBPB     ,na.rm=T)
zp$LangBPHc     <-zp$LangBPH     -mean(zp$LangBPH     ,na.rm=T)
zp$LangCPTc     <-zp$LangCPT     -mean(zp$LangCPT     ,na.rm=T)
zp$OutUsTc      <-zp$OutUsT      -mean(zp$OutUsT      ,na.rm=T)
zp$OutUsWc      <-zp$OutUsW      -mean(zp$OutUsW      ,na.rm=T)
zp$OutUsBc      <-zp$OutUsB      -mean(zp$OutUsB      ,na.rm=T)
zp$OutUsHc      <-zp$OutUsH      -mean(zp$OutUsH      ,na.rm=T)
zp$FBornTc      <-zp$FBornT      -mean(zp$FBornT      ,na.rm=T)
zp$FBornWc      <-zp$FBornW      -mean(zp$FBornW      ,na.rm=T)
zp$FBornBc      <-zp$FBornB      -mean(zp$FBornB      ,na.rm=T)
zp$FBornHc      <-zp$FBornH      -mean(zp$FBornH      ,na.rm=T)
zp$NotCtzTc     <-zp$NotCtzT     -mean(zp$NotCtzT     ,na.rm=T)
zp$NotCtzWc     <-zp$NotCtzW     -mean(zp$NotCtzW     ,na.rm=T)
zp$NotCtzBc     <-zp$NotCtzB     -mean(zp$NotCtzB     ,na.rm=T)
zp$NotCtzHc     <-zp$NotCtzH     -mean(zp$NotCtzH     ,na.rm=T)
zp$MoveTc       <-zp$MoveT       -mean(zp$MoveT       ,na.rm=T)
zp$MoveWc       <-zp$MoveW       -mean(zp$MoveW       ,na.rm=T)
zp$MoveBc       <-zp$MoveB       -mean(zp$MoveB       ,na.rm=T)
zp$MoveHc       <-zp$MoveH       -mean(zp$MoveH       ,na.rm=T)
zp$VacantTc     <-zp$VacantT     -mean(zp$VacantT     ,na.rm=T)
zp$OwnerTc      <-zp$OwnerT      -mean(zp$OwnerT      ,na.rm=T)
zp$OwnerWc      <-zp$OwnerW      -mean(zp$OwnerW      ,na.rm=T)
zp$OwnerBc      <-zp$OwnerB      -mean(zp$OwnerB      ,na.rm=T)
zp$OwnerHc      <-zp$OwnerH      -mean(zp$OwnerH      ,na.rm=T)
zp$CrowdTc      <-zp$CrowdT      -mean(zp$CrowdT      ,na.rm=T)
zp$CrowdWc      <-zp$CrowdW      -mean(zp$CrowdW      ,na.rm=T)
zp$CrowdBc      <-zp$CrowdB      -mean(zp$CrowdB      ,na.rm=T)
zp$CrowdHc      <-zp$CrowdH      -mean(zp$CrowdH      ,na.rm=T)
zp$MobileTc     <-zp$MobileT     -mean(zp$MobileT     ,na.rm=T)
zp$MobileWc     <-zp$MobileW     -mean(zp$MobileW     ,na.rm=T)
zp$MobileBc     <-zp$MobileB     -mean(zp$MobileB     ,na.rm=T)
zp$MobileHc     <-zp$MobileH     -mean(zp$MobileH     ,na.rm=T)
zp$DisablTc     <-zp$DisablT     -mean(zp$DisablT     ,na.rm=T)
zp$DisablWc     <-zp$DisablW     -mean(zp$DisablW     ,na.rm=T)
zp$DisablBc     <-zp$DisablB     -mean(zp$DisablB     ,na.rm=T)
zp$DisablHc     <-zp$DisablH     -mean(zp$DisablH     ,na.rm=T)
zp$DisablTCc    <-zp$DisablTC    -mean(zp$DisablTC    ,na.rm=T)
zp$DisablWCc    <-zp$DisablWC    -mean(zp$DisablWC    ,na.rm=T)
zp$DisablBCc    <-zp$DisablBC    -mean(zp$DisablBC    ,na.rm=T)
zp$DisablHCc    <-zp$DisablHC    -mean(zp$DisablHC    ,na.rm=T)
zp$DisablTMc    <-zp$DisablTM    -mean(zp$DisablTM    ,na.rm=T)
zp$DisablTFc    <-zp$DisablTF    -mean(zp$DisablTF    ,na.rm=T)
zp$Urban1c      <-zp$Urban1      -mean(zp$Urban1      ,na.rm=T)
zp$Urban2c      <-zp$Urban2      -mean(zp$Urban2      ,na.rm=T)
zp$ISBE_PFAc    <-zp$ISBE_PFA    -mean(zp$ISBE_PFA    ,na.rm=T)
zp$ISBE_PFAEc   <-zp$ISBE_PFAE   -mean(zp$ISBE_PFAE   ,na.rm=T)
zp$ISBE_PIc     <-zp$ISBE_PI     -mean(zp$ISBE_PI     ,na.rm=T)
zp$HeadStartc   <-zp$HeadStart   -mean(zp$HeadStart   ,na.rm=T)
zp$ElyHeadSc    <-zp$ElyHeadS    -mean(zp$ElyHeadS    ,na.rm=T)
zp$HeadSAllc    <-zp$HeadSAll    -mean(zp$HeadSAll    ,na.rm=T)
zp$PFA_HS1c     <-zp$PFA_HS1     -mean(zp$PFA_HS1     ,na.rm=T)
zp$PFA_HS2c     <-zp$PFA_HS2     -mean(zp$PFA_HS2     ,na.rm=T)
zp$LCCCc        <-zp$LCCC        -mean(zp$LCCC        ,na.rm=T)
zp$LECCCc       <-zp$LECCC       -mean(zp$LECCC       ,na.rm=T)
zp$LFCCc        <-zp$LFCC        -mean(zp$LFCC        ,na.rm=T)
zp$LLECCCc      <-zp$LLECCC      -mean(zp$LLECCC      ,na.rm=T)
zp$LCLFCCc      <-zp$LCLFCC      -mean(zp$LCLFCC      ,na.rm=T)
zp$LCCCB1c      <-zp$LCCCB1      -mean(zp$LCCCB1      ,na.rm=T)
zp$LCCCB2c      <-zp$LCCCB2      -mean(zp$LCCCB2      ,na.rm=T)
zp$LCCB1c       <-zp$LCCB1       -mean(zp$LCCB1       ,na.rm=T)
zp$LCCB2c       <-zp$LCCB2       -mean(zp$LCCB2       ,na.rm=T)
zp$LCCCS1c      <-zp$LCCCS1      -mean(zp$LCCCS1      ,na.rm=T)
zp$LCCCS2c      <-zp$LCCCS2      -mean(zp$LCCCS2      ,na.rm=T)
zp$LCCS1c       <-zp$LCCS1       -mean(zp$LCCS1       ,na.rm=T)
zp$LCCS2c       <-zp$LCCS2       -mean(zp$LCCS2       ,na.rm=T)
zp$LCCCG1c      <-zp$LCCCG1      -mean(zp$LCCCG1      ,na.rm=T)
zp$LCCCG2c      <-zp$LCCCG2      -mean(zp$LCCCG2      ,na.rm=T)
zp$LCCG1c       <-zp$LCCG1       -mean(zp$LCCG1       ,na.rm=T)
zp$LCCG2c       <-zp$LCCG2       -mean(zp$LCCG2       ,na.rm=T)
zp$ChildCare1c  <-zp$ChildCare1  -mean(zp$ChildCare1  ,na.rm=T)
zp$ChildCare2c  <-zp$ChildCare2  -mean(zp$ChildCare2  ,na.rm=T)
zp$ChildCare3c  <-zp$ChildCare3  -mean(zp$ChildCare3  ,na.rm=T)
zp$CCAPc        <-zp$CCAP        -mean(zp$CCAP        ,na.rm=T)
zp$Homelessc    <-zp$Homeless    -mean(zp$Homeless    ,na.rm=T)
zp$Homeless2c   <-zp$Homeless2   -mean(zp$Homeless2   ,na.rm=T)
zp$DHS_HFIrc    <-zp$DHS_HFIr    -mean(zp$DHS_HFIr    ,na.rm=T)
zp$DHS_PTSrc    <-zp$DHS_PTSr    -mean(zp$DHS_PTSr    ,na.rm=T)
zp$DHS_HVPrc    <-zp$DHS_HVPr    -mean(zp$DHS_HVPr    ,na.rm=T)
zp$IDHS_EIrc    <-zp$IDHS_EIr    -mean(zp$IDHS_EIr    ,na.rm=T)
zp$MHV_C4c      <-zp$MHV_C4      -mean(zp$MHV_C4      ,na.rm=T)
zp$MHV_P4c      <-zp$MHV_P4      -mean(zp$MHV_P4      ,na.rm=T)
zp$MHV_C5c      <-zp$MHV_C5      -mean(zp$MHV_C5      ,na.rm=T)
zp$MHV_P5c      <-zp$MHV_P5      -mean(zp$MHV_P5      ,na.rm=T)
zp$FoodInsPc    <-zp$FoodInsP    -mean(zp$FoodInsP    ,na.rm=T)
zp$FoodISc      <-zp$FoodIS      -mean(zp$FoodIS      ,na.rm=T)
zp$RPovTc       <-zp$RPovT       -mean(zp$RPovT       ,na.rm=T)
zp$PovTc        <-zp$PovT        -mean(zp$PovT        ,na.rm=T)
zp$MHV_C4k <-zp$MHV_C4 *10
zp$MHV_C5k <-zp$MHV_C5 *10
zp$MHV_C4kc<-zp$MHV_C4c*10
zp$MHV_C5kc<-zp$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zp1$Yearc        <-zp1$Year        -mean(zp1$Year        ,na.rm=T)
zp1$CPopBPc      <-zp1$CPopBP      -mean(zp1$CPopBP      ,na.rm=T)
zp1$CPopHPc      <-zp1$CPopHP      -mean(zp1$CPopHP      ,na.rm=T)
zp1$ChildPTc     <-zp1$ChildPT     -mean(zp1$ChildPT     ,na.rm=T)
zp1$ChildPWc     <-zp1$ChildPW     -mean(zp1$ChildPW     ,na.rm=T)
zp1$ChildPBc     <-zp1$ChildPB     -mean(zp1$ChildPB     ,na.rm=T)
zp1$ChildPHc     <-zp1$ChildPH     -mean(zp1$ChildPH     ,na.rm=T)
zp1$CARatioT100c <-zp1$CARatioT100 -mean(zp1$CARatioT100 ,na.rm=T)
zp1$CARatioW100c <-zp1$CARatioW100 -mean(zp1$CARatioW100 ,na.rm=T)
zp1$CARatioB100c <-zp1$CARatioB100 -mean(zp1$CARatioB100 ,na.rm=T)
zp1$CARatioH100c <-zp1$CARatioH100 -mean(zp1$CARatioH100 ,na.rm=T)
zp1$MalePTc      <-zp1$MalePT      -mean(zp1$MalePT      ,na.rm=T)
zp1$MalePWc      <-zp1$MalePW      -mean(zp1$MalePW      ,na.rm=T)
zp1$MalePBc      <-zp1$MalePB      -mean(zp1$MalePB      ,na.rm=T)
zp1$MalePHc      <-zp1$MalePH      -mean(zp1$MalePH      ,na.rm=T)
zp1$MFRatioT100c <-zp1$MFRatioT100 -mean(zp1$MFRatioT100 ,na.rm=T)
zp1$MFRatioW100c <-zp1$MFRatioW100 -mean(zp1$MFRatioW100 ,na.rm=T)
zp1$MFRatioB100c <-zp1$MFRatioB100 -mean(zp1$MFRatioB100 ,na.rm=T)
zp1$MFRatioH100c <-zp1$MFRatioH100 -mean(zp1$MFRatioH100 ,na.rm=T)
zp1$ElderTc      <-zp1$ElderT      -mean(zp1$ElderT      ,na.rm=T)
zp1$ElderWc      <-zp1$ElderW      -mean(zp1$ElderW      ,na.rm=T)
zp1$ElderBc      <-zp1$ElderB      -mean(zp1$ElderB      ,na.rm=T)
zp1$ElderHc      <-zp1$ElderH      -mean(zp1$ElderH      ,na.rm=T)
zp1$SingleTc     <-zp1$SingleT     -mean(zp1$SingleT     ,na.rm=T)
zp1$SingleWc     <-zp1$SingleW     -mean(zp1$SingleW     ,na.rm=T)
zp1$SingleBc     <-zp1$SingleB     -mean(zp1$SingleB     ,na.rm=T)
zp1$SingleHc     <-zp1$SingleH     -mean(zp1$SingleH     ,na.rm=T)
zp1$FHeadTc      <-zp1$FHeadT      -mean(zp1$FHeadT      ,na.rm=T)
zp1$FHeadWc      <-zp1$FHeadW      -mean(zp1$FHeadW      ,na.rm=T)
zp1$FHeadBc      <-zp1$FHeadB      -mean(zp1$FHeadB      ,na.rm=T)
zp1$FHeadHc      <-zp1$FHeadH      -mean(zp1$FHeadH      ,na.rm=T)
zp1$NoHighTc     <-zp1$NoHighT     -mean(zp1$NoHighT     ,na.rm=T)
zp1$NoHighWc     <-zp1$NoHighW     -mean(zp1$NoHighW     ,na.rm=T)
zp1$NoHighBc     <-zp1$NoHighB     -mean(zp1$NoHighB     ,na.rm=T)
zp1$NoHighHc     <-zp1$NoHighH     -mean(zp1$NoHighH     ,na.rm=T)
zp1$UnempTc      <-zp1$UnempT      -mean(zp1$UnempT      ,na.rm=T)
zp1$UnempWc      <-zp1$UnempW      -mean(zp1$UnempW      ,na.rm=T)
zp1$UnempBc      <-zp1$UnempB      -mean(zp1$UnempB      ,na.rm=T)
zp1$UnempHc      <-zp1$UnempH      -mean(zp1$UnempH      ,na.rm=T)
zp1$CPovTc       <-zp1$CPovT       -mean(zp1$CPovT       ,na.rm=T)
zp1$CPovWc       <-zp1$CPovW       -mean(zp1$CPovW       ,na.rm=T)
zp1$CPovBc       <-zp1$CPovB       -mean(zp1$CPovB       ,na.rm=T)
zp1$CPovHc       <-zp1$CPovH       -mean(zp1$CPovH       ,na.rm=T)
zp1$CPov1c       <-zp1$CPov1       -mean(zp1$CPov1       ,na.rm=T)
zp1$CPov2c       <-zp1$CPov2       -mean(zp1$CPov2       ,na.rm=T)
zp1$CPov3c       <-zp1$CPov3       -mean(zp1$CPov3       ,na.rm=T)
zp1$PubAsTc      <-zp1$PubAsT      -mean(zp1$PubAsT      ,na.rm=T)
zp1$WelfarTc     <-zp1$WelfarT     -mean(zp1$WelfarT     ,na.rm=T)
zp1$SnapTc       <-zp1$SnapT       -mean(zp1$SnapT       ,na.rm=T)
zp1$SnapWc       <-zp1$SnapW       -mean(zp1$SnapW       ,na.rm=T)
zp1$SnapBc       <-zp1$SnapB       -mean(zp1$SnapB       ,na.rm=T)
zp1$SnapHc       <-zp1$SnapH       -mean(zp1$SnapH       ,na.rm=T)
zp1$IncomeT1kc   <-zp1$IncomeT1k   -mean(zp1$IncomeT1k   ,na.rm=T)
zp1$IncomeW1kc   <-zp1$IncomeW1k   -mean(zp1$IncomeW1k   ,na.rm=T)
zp1$IncomeB1kc   <-zp1$IncomeB1k   -mean(zp1$IncomeB1k   ,na.rm=T)
zp1$IncomeH1kc   <-zp1$IncomeH1k   -mean(zp1$IncomeH1k   ,na.rm=T)
zp1$GiniT100c    <-zp1$GiniT100    -mean(zp1$GiniT100    ,na.rm=T)
zp1$HValueT10kc  <-zp1$HValueT10k  -mean(zp1$HValueT10k  ,na.rm=T)
zp1$MCostT100c   <-zp1$MCostT100   -mean(zp1$MCostT100   ,na.rm=T)
zp1$OCostDT100c  <-zp1$OCostDT100  -mean(zp1$OCostDT100  ,na.rm=T)
zp1$MRentDT100c  <-zp1$MRentDT100  -mean(zp1$MRentDT100  ,na.rm=T)
zp1$OCostPTc     <-zp1$OCostPT     -mean(zp1$OCostPT     ,na.rm=T)
zp1$MRentPTc     <-zp1$MRentPT     -mean(zp1$MRentPT     ,na.rm=T)
zp1$MortgTc      <-zp1$MortgT      -mean(zp1$MortgT      ,na.rm=T)
zp1$LangAPTc     <-zp1$LangAPT     -mean(zp1$LangAPT     ,na.rm=T)
zp1$LangAPWc     <-zp1$LangAPW     -mean(zp1$LangAPW     ,na.rm=T)
zp1$LangAPBc     <-zp1$LangAPB     -mean(zp1$LangAPB     ,na.rm=T)
zp1$LangAPHc     <-zp1$LangAPH     -mean(zp1$LangAPH     ,na.rm=T)
zp1$LangBPTc     <-zp1$LangBPT     -mean(zp1$LangBPT     ,na.rm=T)
zp1$LangBPWc     <-zp1$LangBPW     -mean(zp1$LangBPW     ,na.rm=T)
zp1$LangBPBc     <-zp1$LangBPB     -mean(zp1$LangBPB     ,na.rm=T)
zp1$LangBPHc     <-zp1$LangBPH     -mean(zp1$LangBPH     ,na.rm=T)
zp1$LangCPTc     <-zp1$LangCPT     -mean(zp1$LangCPT     ,na.rm=T)
zp1$OutUsTc      <-zp1$OutUsT      -mean(zp1$OutUsT      ,na.rm=T)
zp1$OutUsWc      <-zp1$OutUsW      -mean(zp1$OutUsW      ,na.rm=T)
zp1$OutUsBc      <-zp1$OutUsB      -mean(zp1$OutUsB      ,na.rm=T)
zp1$OutUsHc      <-zp1$OutUsH      -mean(zp1$OutUsH      ,na.rm=T)
zp1$FBornTc      <-zp1$FBornT      -mean(zp1$FBornT      ,na.rm=T)
zp1$FBornWc      <-zp1$FBornW      -mean(zp1$FBornW      ,na.rm=T)
zp1$FBornBc      <-zp1$FBornB      -mean(zp1$FBornB      ,na.rm=T)
zp1$FBornHc      <-zp1$FBornH      -mean(zp1$FBornH      ,na.rm=T)
zp1$NotCtzTc     <-zp1$NotCtzT     -mean(zp1$NotCtzT     ,na.rm=T)
zp1$NotCtzWc     <-zp1$NotCtzW     -mean(zp1$NotCtzW     ,na.rm=T)
zp1$NotCtzBc     <-zp1$NotCtzB     -mean(zp1$NotCtzB     ,na.rm=T)
zp1$NotCtzHc     <-zp1$NotCtzH     -mean(zp1$NotCtzH     ,na.rm=T)
zp1$MoveTc       <-zp1$MoveT       -mean(zp1$MoveT       ,na.rm=T)
zp1$MoveWc       <-zp1$MoveW       -mean(zp1$MoveW       ,na.rm=T)
zp1$MoveBc       <-zp1$MoveB       -mean(zp1$MoveB       ,na.rm=T)
zp1$MoveHc       <-zp1$MoveH       -mean(zp1$MoveH       ,na.rm=T)
zp1$VacantTc     <-zp1$VacantT     -mean(zp1$VacantT     ,na.rm=T)
zp1$OwnerTc      <-zp1$OwnerT      -mean(zp1$OwnerT      ,na.rm=T)
zp1$OwnerWc      <-zp1$OwnerW      -mean(zp1$OwnerW      ,na.rm=T)
zp1$OwnerBc      <-zp1$OwnerB      -mean(zp1$OwnerB      ,na.rm=T)
zp1$OwnerHc      <-zp1$OwnerH      -mean(zp1$OwnerH      ,na.rm=T)
zp1$CrowdTc      <-zp1$CrowdT      -mean(zp1$CrowdT      ,na.rm=T)
zp1$CrowdWc      <-zp1$CrowdW      -mean(zp1$CrowdW      ,na.rm=T)
zp1$CrowdBc      <-zp1$CrowdB      -mean(zp1$CrowdB      ,na.rm=T)
zp1$CrowdHc      <-zp1$CrowdH      -mean(zp1$CrowdH      ,na.rm=T)
zp1$MobileTc     <-zp1$MobileT     -mean(zp1$MobileT     ,na.rm=T)
zp1$MobileWc     <-zp1$MobileW     -mean(zp1$MobileW     ,na.rm=T)
zp1$MobileBc     <-zp1$MobileB     -mean(zp1$MobileB     ,na.rm=T)
zp1$MobileHc     <-zp1$MobileH     -mean(zp1$MobileH     ,na.rm=T)
zp1$DisablTc     <-zp1$DisablT     -mean(zp1$DisablT     ,na.rm=T)
zp1$DisablWc     <-zp1$DisablW     -mean(zp1$DisablW     ,na.rm=T)
zp1$DisablBc     <-zp1$DisablB     -mean(zp1$DisablB     ,na.rm=T)
zp1$DisablHc     <-zp1$DisablH     -mean(zp1$DisablH     ,na.rm=T)
zp1$DisablTCc    <-zp1$DisablTC    -mean(zp1$DisablTC    ,na.rm=T)
zp1$DisablWCc    <-zp1$DisablWC    -mean(zp1$DisablWC    ,na.rm=T)
zp1$DisablBCc    <-zp1$DisablBC    -mean(zp1$DisablBC    ,na.rm=T)
zp1$DisablHCc    <-zp1$DisablHC    -mean(zp1$DisablHC    ,na.rm=T)
zp1$DisablTMc    <-zp1$DisablTM    -mean(zp1$DisablTM    ,na.rm=T)
zp1$DisablTFc    <-zp1$DisablTF    -mean(zp1$DisablTF    ,na.rm=T)
zp1$Urban1c      <-zp1$Urban1      -mean(zp1$Urban1      ,na.rm=T)
zp1$Urban2c      <-zp1$Urban2      -mean(zp1$Urban2      ,na.rm=T)
zp1$ISBE_PFAc    <-zp1$ISBE_PFA    -mean(zp1$ISBE_PFA    ,na.rm=T)
zp1$ISBE_PFAEc   <-zp1$ISBE_PFAE   -mean(zp1$ISBE_PFAE   ,na.rm=T)
zp1$ISBE_PIc     <-zp1$ISBE_PI     -mean(zp1$ISBE_PI     ,na.rm=T)
zp1$HeadStartc   <-zp1$HeadStart   -mean(zp1$HeadStart   ,na.rm=T)
zp1$ElyHeadSc    <-zp1$ElyHeadS    -mean(zp1$ElyHeadS    ,na.rm=T)
zp1$HeadSAllc    <-zp1$HeadSAll    -mean(zp1$HeadSAll    ,na.rm=T)
zp1$PFA_HS1c     <-zp1$PFA_HS1     -mean(zp1$PFA_HS1     ,na.rm=T)
zp1$PFA_HS2c     <-zp1$PFA_HS2     -mean(zp1$PFA_HS2     ,na.rm=T)
zp1$LCCCc        <-zp1$LCCC        -mean(zp1$LCCC        ,na.rm=T)
zp1$LECCCc       <-zp1$LECCC       -mean(zp1$LECCC       ,na.rm=T)
zp1$LFCCc        <-zp1$LFCC        -mean(zp1$LFCC        ,na.rm=T)
zp1$LLECCCc      <-zp1$LLECCC      -mean(zp1$LLECCC      ,na.rm=T)
zp1$LCLFCCc      <-zp1$LCLFCC      -mean(zp1$LCLFCC      ,na.rm=T)
zp1$LCCCB1c      <-zp1$LCCCB1      -mean(zp1$LCCCB1      ,na.rm=T)
zp1$LCCCB2c      <-zp1$LCCCB2      -mean(zp1$LCCCB2      ,na.rm=T)
zp1$LCCB1c       <-zp1$LCCB1       -mean(zp1$LCCB1       ,na.rm=T)
zp1$LCCB2c       <-zp1$LCCB2       -mean(zp1$LCCB2       ,na.rm=T)
zp1$LCCCS1c      <-zp1$LCCCS1      -mean(zp1$LCCCS1      ,na.rm=T)
zp1$LCCCS2c      <-zp1$LCCCS2      -mean(zp1$LCCCS2      ,na.rm=T)
zp1$LCCS1c       <-zp1$LCCS1       -mean(zp1$LCCS1       ,na.rm=T)
zp1$LCCS2c       <-zp1$LCCS2       -mean(zp1$LCCS2       ,na.rm=T)
zp1$LCCCG1c      <-zp1$LCCCG1      -mean(zp1$LCCCG1      ,na.rm=T)
zp1$LCCCG2c      <-zp1$LCCCG2      -mean(zp1$LCCCG2      ,na.rm=T)
zp1$LCCG1c       <-zp1$LCCG1       -mean(zp1$LCCG1       ,na.rm=T)
zp1$LCCG2c       <-zp1$LCCG2       -mean(zp1$LCCG2       ,na.rm=T)
zp1$ChildCare1c  <-zp1$ChildCare1  -mean(zp1$ChildCare1  ,na.rm=T)
zp1$ChildCare2c  <-zp1$ChildCare2  -mean(zp1$ChildCare2  ,na.rm=T)
zp1$ChildCare3c  <-zp1$ChildCare3  -mean(zp1$ChildCare3  ,na.rm=T)
zp1$CCAPc        <-zp1$CCAP        -mean(zp1$CCAP        ,na.rm=T)
zp1$Homelessc    <-zp1$Homeless    -mean(zp1$Homeless    ,na.rm=T)
zp1$Homeless2c   <-zp1$Homeless2   -mean(zp1$Homeless2   ,na.rm=T)
zp1$DHS_HFIrc    <-zp1$DHS_HFIr    -mean(zp1$DHS_HFIr    ,na.rm=T)
zp1$DHS_PTSrc    <-zp1$DHS_PTSr    -mean(zp1$DHS_PTSr    ,na.rm=T)
zp1$DHS_HVPrc    <-zp1$DHS_HVPr    -mean(zp1$DHS_HVPr    ,na.rm=T)
zp1$IDHS_EIrc    <-zp1$IDHS_EIr    -mean(zp1$IDHS_EIr    ,na.rm=T)
zp1$MHV_C4c      <-zp1$MHV_C4      -mean(zp1$MHV_C4      ,na.rm=T)
zp1$MHV_P4c      <-zp1$MHV_P4      -mean(zp1$MHV_P4      ,na.rm=T)
zp1$MHV_C5c      <-zp1$MHV_C5      -mean(zp1$MHV_C5      ,na.rm=T)
zp1$MHV_P5c      <-zp1$MHV_P5      -mean(zp1$MHV_P5      ,na.rm=T)
zp1$FoodInsPc    <-zp1$FoodInsP    -mean(zp1$FoodInsP    ,na.rm=T)
zp1$FoodISc      <-zp1$FoodIS      -mean(zp1$FoodIS      ,na.rm=T)
zp1$RPovTc       <-zp1$RPovT       -mean(zp1$RPovT       ,na.rm=T)
zp1$PovTc        <-zp1$PovT        -mean(zp1$PovT        ,na.rm=T)
zp1$MHV_C4k <-zp1$MHV_C4 *10
zp1$MHV_C5k <-zp1$MHV_C5 *10
zp1$MHV_C4kc<-zp1$MHV_C4c*10
zp1$MHV_C5kc<-zp1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zp2$Yearc        <-zp2$Year        -mean(zp2$Year        ,na.rm=T)
zp2$CPopBPc      <-zp2$CPopBP      -mean(zp2$CPopBP      ,na.rm=T)
zp2$CPopHPc      <-zp2$CPopHP      -mean(zp2$CPopHP      ,na.rm=T)
zp2$ChildPTc     <-zp2$ChildPT     -mean(zp2$ChildPT     ,na.rm=T)
zp2$ChildPWc     <-zp2$ChildPW     -mean(zp2$ChildPW     ,na.rm=T)
zp2$ChildPBc     <-zp2$ChildPB     -mean(zp2$ChildPB     ,na.rm=T)
zp2$ChildPHc     <-zp2$ChildPH     -mean(zp2$ChildPH     ,na.rm=T)
zp2$CARatioT100c <-zp2$CARatioT100 -mean(zp2$CARatioT100 ,na.rm=T)
zp2$CARatioW100c <-zp2$CARatioW100 -mean(zp2$CARatioW100 ,na.rm=T)
zp2$CARatioB100c <-zp2$CARatioB100 -mean(zp2$CARatioB100 ,na.rm=T)
zp2$CARatioH100c <-zp2$CARatioH100 -mean(zp2$CARatioH100 ,na.rm=T)
zp2$MalePTc      <-zp2$MalePT      -mean(zp2$MalePT      ,na.rm=T)
zp2$MalePWc      <-zp2$MalePW      -mean(zp2$MalePW      ,na.rm=T)
zp2$MalePBc      <-zp2$MalePB      -mean(zp2$MalePB      ,na.rm=T)
zp2$MalePHc      <-zp2$MalePH      -mean(zp2$MalePH      ,na.rm=T)
zp2$MFRatioT100c <-zp2$MFRatioT100 -mean(zp2$MFRatioT100 ,na.rm=T)
zp2$MFRatioW100c <-zp2$MFRatioW100 -mean(zp2$MFRatioW100 ,na.rm=T)
zp2$MFRatioB100c <-zp2$MFRatioB100 -mean(zp2$MFRatioB100 ,na.rm=T)
zp2$MFRatioH100c <-zp2$MFRatioH100 -mean(zp2$MFRatioH100 ,na.rm=T)
zp2$ElderTc      <-zp2$ElderT      -mean(zp2$ElderT      ,na.rm=T)
zp2$ElderWc      <-zp2$ElderW      -mean(zp2$ElderW      ,na.rm=T)
zp2$ElderBc      <-zp2$ElderB      -mean(zp2$ElderB      ,na.rm=T)
zp2$ElderHc      <-zp2$ElderH      -mean(zp2$ElderH      ,na.rm=T)
zp2$SingleTc     <-zp2$SingleT     -mean(zp2$SingleT     ,na.rm=T)
zp2$SingleWc     <-zp2$SingleW     -mean(zp2$SingleW     ,na.rm=T)
zp2$SingleBc     <-zp2$SingleB     -mean(zp2$SingleB     ,na.rm=T)
zp2$SingleHc     <-zp2$SingleH     -mean(zp2$SingleH     ,na.rm=T)
zp2$FHeadTc      <-zp2$FHeadT      -mean(zp2$FHeadT      ,na.rm=T)
zp2$FHeadWc      <-zp2$FHeadW      -mean(zp2$FHeadW      ,na.rm=T)
zp2$FHeadBc      <-zp2$FHeadB      -mean(zp2$FHeadB      ,na.rm=T)
zp2$FHeadHc      <-zp2$FHeadH      -mean(zp2$FHeadH      ,na.rm=T)
zp2$NoHighTc     <-zp2$NoHighT     -mean(zp2$NoHighT     ,na.rm=T)
zp2$NoHighWc     <-zp2$NoHighW     -mean(zp2$NoHighW     ,na.rm=T)
zp2$NoHighBc     <-zp2$NoHighB     -mean(zp2$NoHighB     ,na.rm=T)
zp2$NoHighHc     <-zp2$NoHighH     -mean(zp2$NoHighH     ,na.rm=T)
zp2$UnempTc      <-zp2$UnempT      -mean(zp2$UnempT      ,na.rm=T)
zp2$UnempWc      <-zp2$UnempW      -mean(zp2$UnempW      ,na.rm=T)
zp2$UnempBc      <-zp2$UnempB      -mean(zp2$UnempB      ,na.rm=T)
zp2$UnempHc      <-zp2$UnempH      -mean(zp2$UnempH      ,na.rm=T)
zp2$CPovTc       <-zp2$CPovT       -mean(zp2$CPovT       ,na.rm=T)
zp2$CPovWc       <-zp2$CPovW       -mean(zp2$CPovW       ,na.rm=T)
zp2$CPovBc       <-zp2$CPovB       -mean(zp2$CPovB       ,na.rm=T)
zp2$CPovHc       <-zp2$CPovH       -mean(zp2$CPovH       ,na.rm=T)
zp2$CPov1c       <-zp2$CPov1       -mean(zp2$CPov1       ,na.rm=T)
zp2$CPov2c       <-zp2$CPov2       -mean(zp2$CPov2       ,na.rm=T)
zp2$CPov3c       <-zp2$CPov3       -mean(zp2$CPov3       ,na.rm=T)
zp2$PubAsTc      <-zp2$PubAsT      -mean(zp2$PubAsT      ,na.rm=T)
zp2$WelfarTc     <-zp2$WelfarT     -mean(zp2$WelfarT     ,na.rm=T)
zp2$SnapTc       <-zp2$SnapT       -mean(zp2$SnapT       ,na.rm=T)
zp2$SnapWc       <-zp2$SnapW       -mean(zp2$SnapW       ,na.rm=T)
zp2$SnapBc       <-zp2$SnapB       -mean(zp2$SnapB       ,na.rm=T)
zp2$SnapHc       <-zp2$SnapH       -mean(zp2$SnapH       ,na.rm=T)
zp2$IncomeT1kc   <-zp2$IncomeT1k   -mean(zp2$IncomeT1k   ,na.rm=T)
zp2$IncomeW1kc   <-zp2$IncomeW1k   -mean(zp2$IncomeW1k   ,na.rm=T)
zp2$IncomeB1kc   <-zp2$IncomeB1k   -mean(zp2$IncomeB1k   ,na.rm=T)
zp2$IncomeH1kc   <-zp2$IncomeH1k   -mean(zp2$IncomeH1k   ,na.rm=T)
zp2$GiniT100c    <-zp2$GiniT100    -mean(zp2$GiniT100    ,na.rm=T)
zp2$HValueT10kc  <-zp2$HValueT10k  -mean(zp2$HValueT10k  ,na.rm=T)
zp2$MCostT100c   <-zp2$MCostT100   -mean(zp2$MCostT100   ,na.rm=T)
zp2$OCostDT100c  <-zp2$OCostDT100  -mean(zp2$OCostDT100  ,na.rm=T)
zp2$MRentDT100c  <-zp2$MRentDT100  -mean(zp2$MRentDT100  ,na.rm=T)
zp2$OCostPTc     <-zp2$OCostPT     -mean(zp2$OCostPT     ,na.rm=T)
zp2$MRentPTc     <-zp2$MRentPT     -mean(zp2$MRentPT     ,na.rm=T)
zp2$MortgTc      <-zp2$MortgT      -mean(zp2$MortgT      ,na.rm=T)
zp2$LangAPTc     <-zp2$LangAPT     -mean(zp2$LangAPT     ,na.rm=T)
zp2$LangAPWc     <-zp2$LangAPW     -mean(zp2$LangAPW     ,na.rm=T)
zp2$LangAPBc     <-zp2$LangAPB     -mean(zp2$LangAPB     ,na.rm=T)
zp2$LangAPHc     <-zp2$LangAPH     -mean(zp2$LangAPH     ,na.rm=T)
zp2$LangBPTc     <-zp2$LangBPT     -mean(zp2$LangBPT     ,na.rm=T)
zp2$LangBPWc     <-zp2$LangBPW     -mean(zp2$LangBPW     ,na.rm=T)
zp2$LangBPBc     <-zp2$LangBPB     -mean(zp2$LangBPB     ,na.rm=T)
zp2$LangBPHc     <-zp2$LangBPH     -mean(zp2$LangBPH     ,na.rm=T)
zp2$LangCPTc     <-zp2$LangCPT     -mean(zp2$LangCPT     ,na.rm=T)
zp2$OutUsTc      <-zp2$OutUsT      -mean(zp2$OutUsT      ,na.rm=T)
zp2$OutUsWc      <-zp2$OutUsW      -mean(zp2$OutUsW      ,na.rm=T)
zp2$OutUsBc      <-zp2$OutUsB      -mean(zp2$OutUsB      ,na.rm=T)
zp2$OutUsHc      <-zp2$OutUsH      -mean(zp2$OutUsH      ,na.rm=T)
zp2$FBornTc      <-zp2$FBornT      -mean(zp2$FBornT      ,na.rm=T)
zp2$FBornWc      <-zp2$FBornW      -mean(zp2$FBornW      ,na.rm=T)
zp2$FBornBc      <-zp2$FBornB      -mean(zp2$FBornB      ,na.rm=T)
zp2$FBornHc      <-zp2$FBornH      -mean(zp2$FBornH      ,na.rm=T)
zp2$NotCtzTc     <-zp2$NotCtzT     -mean(zp2$NotCtzT     ,na.rm=T)
zp2$NotCtzWc     <-zp2$NotCtzW     -mean(zp2$NotCtzW     ,na.rm=T)
zp2$NotCtzBc     <-zp2$NotCtzB     -mean(zp2$NotCtzB     ,na.rm=T)
zp2$NotCtzHc     <-zp2$NotCtzH     -mean(zp2$NotCtzH     ,na.rm=T)
zp2$MoveTc       <-zp2$MoveT       -mean(zp2$MoveT       ,na.rm=T)
zp2$MoveWc       <-zp2$MoveW       -mean(zp2$MoveW       ,na.rm=T)
zp2$MoveBc       <-zp2$MoveB       -mean(zp2$MoveB       ,na.rm=T)
zp2$MoveHc       <-zp2$MoveH       -mean(zp2$MoveH       ,na.rm=T)
zp2$VacantTc     <-zp2$VacantT     -mean(zp2$VacantT     ,na.rm=T)
zp2$OwnerTc      <-zp2$OwnerT      -mean(zp2$OwnerT      ,na.rm=T)
zp2$OwnerWc      <-zp2$OwnerW      -mean(zp2$OwnerW      ,na.rm=T)
zp2$OwnerBc      <-zp2$OwnerB      -mean(zp2$OwnerB      ,na.rm=T)
zp2$OwnerHc      <-zp2$OwnerH      -mean(zp2$OwnerH      ,na.rm=T)
zp2$CrowdTc      <-zp2$CrowdT      -mean(zp2$CrowdT      ,na.rm=T)
zp2$CrowdWc      <-zp2$CrowdW      -mean(zp2$CrowdW      ,na.rm=T)
zp2$CrowdBc      <-zp2$CrowdB      -mean(zp2$CrowdB      ,na.rm=T)
zp2$CrowdHc      <-zp2$CrowdH      -mean(zp2$CrowdH      ,na.rm=T)
zp2$MobileTc     <-zp2$MobileT     -mean(zp2$MobileT     ,na.rm=T)
zp2$MobileWc     <-zp2$MobileW     -mean(zp2$MobileW     ,na.rm=T)
zp2$MobileBc     <-zp2$MobileB     -mean(zp2$MobileB     ,na.rm=T)
zp2$MobileHc     <-zp2$MobileH     -mean(zp2$MobileH     ,na.rm=T)
zp2$DisablTc     <-zp2$DisablT     -mean(zp2$DisablT     ,na.rm=T)
zp2$DisablWc     <-zp2$DisablW     -mean(zp2$DisablW     ,na.rm=T)
zp2$DisablBc     <-zp2$DisablB     -mean(zp2$DisablB     ,na.rm=T)
zp2$DisablHc     <-zp2$DisablH     -mean(zp2$DisablH     ,na.rm=T)
zp2$DisablTCc    <-zp2$DisablTC    -mean(zp2$DisablTC    ,na.rm=T)
zp2$DisablWCc    <-zp2$DisablWC    -mean(zp2$DisablWC    ,na.rm=T)
zp2$DisablBCc    <-zp2$DisablBC    -mean(zp2$DisablBC    ,na.rm=T)
zp2$DisablHCc    <-zp2$DisablHC    -mean(zp2$DisablHC    ,na.rm=T)
zp2$DisablTMc    <-zp2$DisablTM    -mean(zp2$DisablTM    ,na.rm=T)
zp2$DisablTFc    <-zp2$DisablTF    -mean(zp2$DisablTF    ,na.rm=T)
zp2$Urban1c      <-zp2$Urban1      -mean(zp2$Urban1      ,na.rm=T)
zp2$Urban2c      <-zp2$Urban2      -mean(zp2$Urban2      ,na.rm=T)
zp2$ISBE_PFAc    <-zp2$ISBE_PFA    -mean(zp2$ISBE_PFA    ,na.rm=T)
zp2$ISBE_PFAEc   <-zp2$ISBE_PFAE   -mean(zp2$ISBE_PFAE   ,na.rm=T)
zp2$ISBE_PIc     <-zp2$ISBE_PI     -mean(zp2$ISBE_PI     ,na.rm=T)
zp2$HeadStartc   <-zp2$HeadStart   -mean(zp2$HeadStart   ,na.rm=T)
zp2$ElyHeadSc    <-zp2$ElyHeadS    -mean(zp2$ElyHeadS    ,na.rm=T)
zp2$HeadSAllc    <-zp2$HeadSAll    -mean(zp2$HeadSAll    ,na.rm=T)
zp2$PFA_HS1c     <-zp2$PFA_HS1     -mean(zp2$PFA_HS1     ,na.rm=T)
zp2$PFA_HS2c     <-zp2$PFA_HS2     -mean(zp2$PFA_HS2     ,na.rm=T)
zp2$LCCCc        <-zp2$LCCC        -mean(zp2$LCCC        ,na.rm=T)
zp2$LECCCc       <-zp2$LECCC       -mean(zp2$LECCC       ,na.rm=T)
zp2$LFCCc        <-zp2$LFCC        -mean(zp2$LFCC        ,na.rm=T)
zp2$LLECCCc      <-zp2$LLECCC      -mean(zp2$LLECCC      ,na.rm=T)
zp2$LCLFCCc      <-zp2$LCLFCC      -mean(zp2$LCLFCC      ,na.rm=T)
zp2$LCCCB1c      <-zp2$LCCCB1      -mean(zp2$LCCCB1      ,na.rm=T)
zp2$LCCCB2c      <-zp2$LCCCB2      -mean(zp2$LCCCB2      ,na.rm=T)
zp2$LCCB1c       <-zp2$LCCB1       -mean(zp2$LCCB1       ,na.rm=T)
zp2$LCCB2c       <-zp2$LCCB2       -mean(zp2$LCCB2       ,na.rm=T)
zp2$LCCCS1c      <-zp2$LCCCS1      -mean(zp2$LCCCS1      ,na.rm=T)
zp2$LCCCS2c      <-zp2$LCCCS2      -mean(zp2$LCCCS2      ,na.rm=T)
zp2$LCCS1c       <-zp2$LCCS1       -mean(zp2$LCCS1       ,na.rm=T)
zp2$LCCS2c       <-zp2$LCCS2       -mean(zp2$LCCS2       ,na.rm=T)
zp2$LCCCG1c      <-zp2$LCCCG1      -mean(zp2$LCCCG1      ,na.rm=T)
zp2$LCCCG2c      <-zp2$LCCCG2      -mean(zp2$LCCCG2      ,na.rm=T)
zp2$LCCG1c       <-zp2$LCCG1       -mean(zp2$LCCG1       ,na.rm=T)
zp2$LCCG2c       <-zp2$LCCG2       -mean(zp2$LCCG2       ,na.rm=T)
zp2$ChildCare1c  <-zp2$ChildCare1  -mean(zp2$ChildCare1  ,na.rm=T)
zp2$ChildCare2c  <-zp2$ChildCare2  -mean(zp2$ChildCare2  ,na.rm=T)
zp2$ChildCare3c  <-zp2$ChildCare3  -mean(zp2$ChildCare3  ,na.rm=T)
zp2$CCAPc        <-zp2$CCAP        -mean(zp2$CCAP        ,na.rm=T)
zp2$Homelessc    <-zp2$Homeless    -mean(zp2$Homeless    ,na.rm=T)
zp2$Homeless2c   <-zp2$Homeless2   -mean(zp2$Homeless2   ,na.rm=T)
zp2$DHS_HFIrc    <-zp2$DHS_HFIr    -mean(zp2$DHS_HFIr    ,na.rm=T)
zp2$DHS_PTSrc    <-zp2$DHS_PTSr    -mean(zp2$DHS_PTSr    ,na.rm=T)
zp2$DHS_HVPrc    <-zp2$DHS_HVPr    -mean(zp2$DHS_HVPr    ,na.rm=T)
zp2$IDHS_EIrc    <-zp2$IDHS_EIr    -mean(zp2$IDHS_EIr    ,na.rm=T)
zp2$MHV_C4c      <-zp2$MHV_C4      -mean(zp2$MHV_C4      ,na.rm=T)
zp2$MHV_P4c      <-zp2$MHV_P4      -mean(zp2$MHV_P4      ,na.rm=T)
zp2$MHV_C5c      <-zp2$MHV_C5      -mean(zp2$MHV_C5      ,na.rm=T)
zp2$MHV_P5c      <-zp2$MHV_P5      -mean(zp2$MHV_P5      ,na.rm=T)
zp2$FoodInsPc    <-zp2$FoodInsP    -mean(zp2$FoodInsP    ,na.rm=T)
zp2$FoodISc      <-zp2$FoodIS      -mean(zp2$FoodIS      ,na.rm=T)
zp2$RPovTc       <-zp2$RPovT       -mean(zp2$RPovT       ,na.rm=T)
zp2$PovTc        <-zp2$PovT        -mean(zp2$PovT        ,na.rm=T)
zp2$MHV_C4k <-zp2$MHV_C4 *10
zp2$MHV_C5k <-zp2$MHV_C5 *10
zp2$MHV_C4kc<-zp2$MHV_C4c*10
zp2$MHV_C5kc<-zp2$MHV_C5c*10





# demean - within and between variables
zp<-cbind(zp,demean(zp,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zp1<-cbind(zp1,demean(zp1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zp2<-cbind(zp2,demean(zp2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Sexual Abuse
# Income - Sexual Abuse
# Income - Sexual Abuse
# Income - Sexual Abuse
# Income - Sexual Abuse
# Income - Sexual Abuse
# Income - Sexual Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zs$Yearc        <-zs$Year        -mean(zs$Year        ,na.rm=T)
zs$CPopBPc      <-zs$CPopBP      -mean(zs$CPopBP      ,na.rm=T)
zs$CPopHPc      <-zs$CPopHP      -mean(zs$CPopHP      ,na.rm=T)
zs$ChildPTc     <-zs$ChildPT     -mean(zs$ChildPT     ,na.rm=T)
zs$ChildPWc     <-zs$ChildPW     -mean(zs$ChildPW     ,na.rm=T)
zs$ChildPBc     <-zs$ChildPB     -mean(zs$ChildPB     ,na.rm=T)
zs$ChildPHc     <-zs$ChildPH     -mean(zs$ChildPH     ,na.rm=T)
zs$CARatioT100c <-zs$CARatioT100 -mean(zs$CARatioT100 ,na.rm=T)
zs$CARatioW100c <-zs$CARatioW100 -mean(zs$CARatioW100 ,na.rm=T)
zs$CARatioB100c <-zs$CARatioB100 -mean(zs$CARatioB100 ,na.rm=T)
zs$CARatioH100c <-zs$CARatioH100 -mean(zs$CARatioH100 ,na.rm=T)
zs$MalePTc      <-zs$MalePT      -mean(zs$MalePT      ,na.rm=T)
zs$MalePWc      <-zs$MalePW      -mean(zs$MalePW      ,na.rm=T)
zs$MalePBc      <-zs$MalePB      -mean(zs$MalePB      ,na.rm=T)
zs$MalePHc      <-zs$MalePH      -mean(zs$MalePH      ,na.rm=T)
zs$MFRatioT100c <-zs$MFRatioT100 -mean(zs$MFRatioT100 ,na.rm=T)
zs$MFRatioW100c <-zs$MFRatioW100 -mean(zs$MFRatioW100 ,na.rm=T)
zs$MFRatioB100c <-zs$MFRatioB100 -mean(zs$MFRatioB100 ,na.rm=T)
zs$MFRatioH100c <-zs$MFRatioH100 -mean(zs$MFRatioH100 ,na.rm=T)
zs$ElderTc      <-zs$ElderT      -mean(zs$ElderT      ,na.rm=T)
zs$ElderWc      <-zs$ElderW      -mean(zs$ElderW      ,na.rm=T)
zs$ElderBc      <-zs$ElderB      -mean(zs$ElderB      ,na.rm=T)
zs$ElderHc      <-zs$ElderH      -mean(zs$ElderH      ,na.rm=T)
zs$SingleTc     <-zs$SingleT     -mean(zs$SingleT     ,na.rm=T)
zs$SingleWc     <-zs$SingleW     -mean(zs$SingleW     ,na.rm=T)
zs$SingleBc     <-zs$SingleB     -mean(zs$SingleB     ,na.rm=T)
zs$SingleHc     <-zs$SingleH     -mean(zs$SingleH     ,na.rm=T)
zs$FHeadTc      <-zs$FHeadT      -mean(zs$FHeadT      ,na.rm=T)
zs$FHeadWc      <-zs$FHeadW      -mean(zs$FHeadW      ,na.rm=T)
zs$FHeadBc      <-zs$FHeadB      -mean(zs$FHeadB      ,na.rm=T)
zs$FHeadHc      <-zs$FHeadH      -mean(zs$FHeadH      ,na.rm=T)
zs$NoHighTc     <-zs$NoHighT     -mean(zs$NoHighT     ,na.rm=T)
zs$NoHighWc     <-zs$NoHighW     -mean(zs$NoHighW     ,na.rm=T)
zs$NoHighBc     <-zs$NoHighB     -mean(zs$NoHighB     ,na.rm=T)
zs$NoHighHc     <-zs$NoHighH     -mean(zs$NoHighH     ,na.rm=T)
zs$UnempTc      <-zs$UnempT      -mean(zs$UnempT      ,na.rm=T)
zs$UnempWc      <-zs$UnempW      -mean(zs$UnempW      ,na.rm=T)
zs$UnempBc      <-zs$UnempB      -mean(zs$UnempB      ,na.rm=T)
zs$UnempHc      <-zs$UnempH      -mean(zs$UnempH      ,na.rm=T)
zs$CPovTc       <-zs$CPovT       -mean(zs$CPovT       ,na.rm=T)
zs$CPovWc       <-zs$CPovW       -mean(zs$CPovW       ,na.rm=T)
zs$CPovBc       <-zs$CPovB       -mean(zs$CPovB       ,na.rm=T)
zs$CPovHc       <-zs$CPovH       -mean(zs$CPovH       ,na.rm=T)
zs$CPov1c       <-zs$CPov1       -mean(zs$CPov1       ,na.rm=T)
zs$CPov2c       <-zs$CPov2       -mean(zs$CPov2       ,na.rm=T)
zs$CPov3c       <-zs$CPov3       -mean(zs$CPov3       ,na.rm=T)
zs$PubAsTc      <-zs$PubAsT      -mean(zs$PubAsT      ,na.rm=T)
zs$WelfarTc     <-zs$WelfarT     -mean(zs$WelfarT     ,na.rm=T)
zs$SnapTc       <-zs$SnapT       -mean(zs$SnapT       ,na.rm=T)
zs$SnapWc       <-zs$SnapW       -mean(zs$SnapW       ,na.rm=T)
zs$SnapBc       <-zs$SnapB       -mean(zs$SnapB       ,na.rm=T)
zs$SnapHc       <-zs$SnapH       -mean(zs$SnapH       ,na.rm=T)
zs$IncomeT1kc   <-zs$IncomeT1k   -mean(zs$IncomeT1k   ,na.rm=T)
zs$IncomeW1kc   <-zs$IncomeW1k   -mean(zs$IncomeW1k   ,na.rm=T)
zs$IncomeB1kc   <-zs$IncomeB1k   -mean(zs$IncomeB1k   ,na.rm=T)
zs$IncomeH1kc   <-zs$IncomeH1k   -mean(zs$IncomeH1k   ,na.rm=T)
zs$GiniT100c    <-zs$GiniT100    -mean(zs$GiniT100    ,na.rm=T)
zs$HValueT10kc  <-zs$HValueT10k  -mean(zs$HValueT10k  ,na.rm=T)
zs$MCostT100c   <-zs$MCostT100   -mean(zs$MCostT100   ,na.rm=T)
zs$OCostDT100c  <-zs$OCostDT100  -mean(zs$OCostDT100  ,na.rm=T)
zs$MRentDT100c  <-zs$MRentDT100  -mean(zs$MRentDT100  ,na.rm=T)
zs$OCostPTc     <-zs$OCostPT     -mean(zs$OCostPT     ,na.rm=T)
zs$MRentPTc     <-zs$MRentPT     -mean(zs$MRentPT     ,na.rm=T)
zs$MortgTc      <-zs$MortgT      -mean(zs$MortgT      ,na.rm=T)
zs$LangAPTc     <-zs$LangAPT     -mean(zs$LangAPT     ,na.rm=T)
zs$LangAPWc     <-zs$LangAPW     -mean(zs$LangAPW     ,na.rm=T)
zs$LangAPBc     <-zs$LangAPB     -mean(zs$LangAPB     ,na.rm=T)
zs$LangAPHc     <-zs$LangAPH     -mean(zs$LangAPH     ,na.rm=T)
zs$LangBPTc     <-zs$LangBPT     -mean(zs$LangBPT     ,na.rm=T)
zs$LangBPWc     <-zs$LangBPW     -mean(zs$LangBPW     ,na.rm=T)
zs$LangBPBc     <-zs$LangBPB     -mean(zs$LangBPB     ,na.rm=T)
zs$LangBPHc     <-zs$LangBPH     -mean(zs$LangBPH     ,na.rm=T)
zs$LangCPTc     <-zs$LangCPT     -mean(zs$LangCPT     ,na.rm=T)
zs$OutUsTc      <-zs$OutUsT      -mean(zs$OutUsT      ,na.rm=T)
zs$OutUsWc      <-zs$OutUsW      -mean(zs$OutUsW      ,na.rm=T)
zs$OutUsBc      <-zs$OutUsB      -mean(zs$OutUsB      ,na.rm=T)
zs$OutUsHc      <-zs$OutUsH      -mean(zs$OutUsH      ,na.rm=T)
zs$FBornTc      <-zs$FBornT      -mean(zs$FBornT      ,na.rm=T)
zs$FBornWc      <-zs$FBornW      -mean(zs$FBornW      ,na.rm=T)
zs$FBornBc      <-zs$FBornB      -mean(zs$FBornB      ,na.rm=T)
zs$FBornHc      <-zs$FBornH      -mean(zs$FBornH      ,na.rm=T)
zs$NotCtzTc     <-zs$NotCtzT     -mean(zs$NotCtzT     ,na.rm=T)
zs$NotCtzWc     <-zs$NotCtzW     -mean(zs$NotCtzW     ,na.rm=T)
zs$NotCtzBc     <-zs$NotCtzB     -mean(zs$NotCtzB     ,na.rm=T)
zs$NotCtzHc     <-zs$NotCtzH     -mean(zs$NotCtzH     ,na.rm=T)
zs$MoveTc       <-zs$MoveT       -mean(zs$MoveT       ,na.rm=T)
zs$MoveWc       <-zs$MoveW       -mean(zs$MoveW       ,na.rm=T)
zs$MoveBc       <-zs$MoveB       -mean(zs$MoveB       ,na.rm=T)
zs$MoveHc       <-zs$MoveH       -mean(zs$MoveH       ,na.rm=T)
zs$VacantTc     <-zs$VacantT     -mean(zs$VacantT     ,na.rm=T)
zs$OwnerTc      <-zs$OwnerT      -mean(zs$OwnerT      ,na.rm=T)
zs$OwnerWc      <-zs$OwnerW      -mean(zs$OwnerW      ,na.rm=T)
zs$OwnerBc      <-zs$OwnerB      -mean(zs$OwnerB      ,na.rm=T)
zs$OwnerHc      <-zs$OwnerH      -mean(zs$OwnerH      ,na.rm=T)
zs$CrowdTc      <-zs$CrowdT      -mean(zs$CrowdT      ,na.rm=T)
zs$CrowdWc      <-zs$CrowdW      -mean(zs$CrowdW      ,na.rm=T)
zs$CrowdBc      <-zs$CrowdB      -mean(zs$CrowdB      ,na.rm=T)
zs$CrowdHc      <-zs$CrowdH      -mean(zs$CrowdH      ,na.rm=T)
zs$MobileTc     <-zs$MobileT     -mean(zs$MobileT     ,na.rm=T)
zs$MobileWc     <-zs$MobileW     -mean(zs$MobileW     ,na.rm=T)
zs$MobileBc     <-zs$MobileB     -mean(zs$MobileB     ,na.rm=T)
zs$MobileHc     <-zs$MobileH     -mean(zs$MobileH     ,na.rm=T)
zs$DisablTc     <-zs$DisablT     -mean(zs$DisablT     ,na.rm=T)
zs$DisablWc     <-zs$DisablW     -mean(zs$DisablW     ,na.rm=T)
zs$DisablBc     <-zs$DisablB     -mean(zs$DisablB     ,na.rm=T)
zs$DisablHc     <-zs$DisablH     -mean(zs$DisablH     ,na.rm=T)
zs$DisablTCc    <-zs$DisablTC    -mean(zs$DisablTC    ,na.rm=T)
zs$DisablWCc    <-zs$DisablWC    -mean(zs$DisablWC    ,na.rm=T)
zs$DisablBCc    <-zs$DisablBC    -mean(zs$DisablBC    ,na.rm=T)
zs$DisablHCc    <-zs$DisablHC    -mean(zs$DisablHC    ,na.rm=T)
zs$DisablTMc    <-zs$DisablTM    -mean(zs$DisablTM    ,na.rm=T)
zs$DisablTFc    <-zs$DisablTF    -mean(zs$DisablTF    ,na.rm=T)
zs$Urban1c      <-zs$Urban1      -mean(zs$Urban1      ,na.rm=T)
zs$Urban2c      <-zs$Urban2      -mean(zs$Urban2      ,na.rm=T)
zs$ISBE_PFAc    <-zs$ISBE_PFA    -mean(zs$ISBE_PFA    ,na.rm=T)
zs$ISBE_PFAEc   <-zs$ISBE_PFAE   -mean(zs$ISBE_PFAE   ,na.rm=T)
zs$ISBE_PIc     <-zs$ISBE_PI     -mean(zs$ISBE_PI     ,na.rm=T)
zs$HeadStartc   <-zs$HeadStart   -mean(zs$HeadStart   ,na.rm=T)
zs$ElyHeadSc    <-zs$ElyHeadS    -mean(zs$ElyHeadS    ,na.rm=T)
zs$HeadSAllc    <-zs$HeadSAll    -mean(zs$HeadSAll    ,na.rm=T)
zs$PFA_HS1c     <-zs$PFA_HS1     -mean(zs$PFA_HS1     ,na.rm=T)
zs$PFA_HS2c     <-zs$PFA_HS2     -mean(zs$PFA_HS2     ,na.rm=T)
zs$LCCCc        <-zs$LCCC        -mean(zs$LCCC        ,na.rm=T)
zs$LECCCc       <-zs$LECCC       -mean(zs$LECCC       ,na.rm=T)
zs$LFCCc        <-zs$LFCC        -mean(zs$LFCC        ,na.rm=T)
zs$LLECCCc      <-zs$LLECCC      -mean(zs$LLECCC      ,na.rm=T)
zs$LCLFCCc      <-zs$LCLFCC      -mean(zs$LCLFCC      ,na.rm=T)
zs$LCCCB1c      <-zs$LCCCB1      -mean(zs$LCCCB1      ,na.rm=T)
zs$LCCCB2c      <-zs$LCCCB2      -mean(zs$LCCCB2      ,na.rm=T)
zs$LCCB1c       <-zs$LCCB1       -mean(zs$LCCB1       ,na.rm=T)
zs$LCCB2c       <-zs$LCCB2       -mean(zs$LCCB2       ,na.rm=T)
zs$LCCCS1c      <-zs$LCCCS1      -mean(zs$LCCCS1      ,na.rm=T)
zs$LCCCS2c      <-zs$LCCCS2      -mean(zs$LCCCS2      ,na.rm=T)
zs$LCCS1c       <-zs$LCCS1       -mean(zs$LCCS1       ,na.rm=T)
zs$LCCS2c       <-zs$LCCS2       -mean(zs$LCCS2       ,na.rm=T)
zs$LCCCG1c      <-zs$LCCCG1      -mean(zs$LCCCG1      ,na.rm=T)
zs$LCCCG2c      <-zs$LCCCG2      -mean(zs$LCCCG2      ,na.rm=T)
zs$LCCG1c       <-zs$LCCG1       -mean(zs$LCCG1       ,na.rm=T)
zs$LCCG2c       <-zs$LCCG2       -mean(zs$LCCG2       ,na.rm=T)
zs$ChildCare1c  <-zs$ChildCare1  -mean(zs$ChildCare1  ,na.rm=T)
zs$ChildCare2c  <-zs$ChildCare2  -mean(zs$ChildCare2  ,na.rm=T)
zs$ChildCare3c  <-zs$ChildCare3  -mean(zs$ChildCare3  ,na.rm=T)
zs$CCAPc        <-zs$CCAP        -mean(zs$CCAP        ,na.rm=T)
zs$Homelessc    <-zs$Homeless    -mean(zs$Homeless    ,na.rm=T)
zs$Homeless2c   <-zs$Homeless2   -mean(zs$Homeless2   ,na.rm=T)
zs$DHS_HFIrc    <-zs$DHS_HFIr    -mean(zs$DHS_HFIr    ,na.rm=T)
zs$DHS_PTSrc    <-zs$DHS_PTSr    -mean(zs$DHS_PTSr    ,na.rm=T)
zs$DHS_HVPrc    <-zs$DHS_HVPr    -mean(zs$DHS_HVPr    ,na.rm=T)
zs$IDHS_EIrc    <-zs$IDHS_EIr    -mean(zs$IDHS_EIr    ,na.rm=T)
zs$MHV_C4c      <-zs$MHV_C4      -mean(zs$MHV_C4      ,na.rm=T)
zs$MHV_P4c      <-zs$MHV_P4      -mean(zs$MHV_P4      ,na.rm=T)
zs$MHV_C5c      <-zs$MHV_C5      -mean(zs$MHV_C5      ,na.rm=T)
zs$MHV_P5c      <-zs$MHV_P5      -mean(zs$MHV_P5      ,na.rm=T)
zs$FoodInsPc    <-zs$FoodInsP    -mean(zs$FoodInsP    ,na.rm=T)
zs$FoodISc      <-zs$FoodIS      -mean(zs$FoodIS      ,na.rm=T)
zs$RPovTc       <-zs$RPovT       -mean(zs$RPovT       ,na.rm=T)
zs$PovTc        <-zs$PovT        -mean(zs$PovT        ,na.rm=T)
zs$MHV_C4k <-zs$MHV_C4 *10
zs$MHV_C5k <-zs$MHV_C5 *10
zs$MHV_C4kc<-zs$MHV_C4c*10
zs$MHV_C5kc<-zs$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zs1$Yearc        <-zs1$Year        -mean(zs1$Year        ,na.rm=T)
zs1$CPopBPc      <-zs1$CPopBP      -mean(zs1$CPopBP      ,na.rm=T)
zs1$CPopHPc      <-zs1$CPopHP      -mean(zs1$CPopHP      ,na.rm=T)
zs1$ChildPTc     <-zs1$ChildPT     -mean(zs1$ChildPT     ,na.rm=T)
zs1$ChildPWc     <-zs1$ChildPW     -mean(zs1$ChildPW     ,na.rm=T)
zs1$ChildPBc     <-zs1$ChildPB     -mean(zs1$ChildPB     ,na.rm=T)
zs1$ChildPHc     <-zs1$ChildPH     -mean(zs1$ChildPH     ,na.rm=T)
zs1$CARatioT100c <-zs1$CARatioT100 -mean(zs1$CARatioT100 ,na.rm=T)
zs1$CARatioW100c <-zs1$CARatioW100 -mean(zs1$CARatioW100 ,na.rm=T)
zs1$CARatioB100c <-zs1$CARatioB100 -mean(zs1$CARatioB100 ,na.rm=T)
zs1$CARatioH100c <-zs1$CARatioH100 -mean(zs1$CARatioH100 ,na.rm=T)
zs1$MalePTc      <-zs1$MalePT      -mean(zs1$MalePT      ,na.rm=T)
zs1$MalePWc      <-zs1$MalePW      -mean(zs1$MalePW      ,na.rm=T)
zs1$MalePBc      <-zs1$MalePB      -mean(zs1$MalePB      ,na.rm=T)
zs1$MalePHc      <-zs1$MalePH      -mean(zs1$MalePH      ,na.rm=T)
zs1$MFRatioT100c <-zs1$MFRatioT100 -mean(zs1$MFRatioT100 ,na.rm=T)
zs1$MFRatioW100c <-zs1$MFRatioW100 -mean(zs1$MFRatioW100 ,na.rm=T)
zs1$MFRatioB100c <-zs1$MFRatioB100 -mean(zs1$MFRatioB100 ,na.rm=T)
zs1$MFRatioH100c <-zs1$MFRatioH100 -mean(zs1$MFRatioH100 ,na.rm=T)
zs1$ElderTc      <-zs1$ElderT      -mean(zs1$ElderT      ,na.rm=T)
zs1$ElderWc      <-zs1$ElderW      -mean(zs1$ElderW      ,na.rm=T)
zs1$ElderBc      <-zs1$ElderB      -mean(zs1$ElderB      ,na.rm=T)
zs1$ElderHc      <-zs1$ElderH      -mean(zs1$ElderH      ,na.rm=T)
zs1$SingleTc     <-zs1$SingleT     -mean(zs1$SingleT     ,na.rm=T)
zs1$SingleWc     <-zs1$SingleW     -mean(zs1$SingleW     ,na.rm=T)
zs1$SingleBc     <-zs1$SingleB     -mean(zs1$SingleB     ,na.rm=T)
zs1$SingleHc     <-zs1$SingleH     -mean(zs1$SingleH     ,na.rm=T)
zs1$FHeadTc      <-zs1$FHeadT      -mean(zs1$FHeadT      ,na.rm=T)
zs1$FHeadWc      <-zs1$FHeadW      -mean(zs1$FHeadW      ,na.rm=T)
zs1$FHeadBc      <-zs1$FHeadB      -mean(zs1$FHeadB      ,na.rm=T)
zs1$FHeadHc      <-zs1$FHeadH      -mean(zs1$FHeadH      ,na.rm=T)
zs1$NoHighTc     <-zs1$NoHighT     -mean(zs1$NoHighT     ,na.rm=T)
zs1$NoHighWc     <-zs1$NoHighW     -mean(zs1$NoHighW     ,na.rm=T)
zs1$NoHighBc     <-zs1$NoHighB     -mean(zs1$NoHighB     ,na.rm=T)
zs1$NoHighHc     <-zs1$NoHighH     -mean(zs1$NoHighH     ,na.rm=T)
zs1$UnempTc      <-zs1$UnempT      -mean(zs1$UnempT      ,na.rm=T)
zs1$UnempWc      <-zs1$UnempW      -mean(zs1$UnempW      ,na.rm=T)
zs1$UnempBc      <-zs1$UnempB      -mean(zs1$UnempB      ,na.rm=T)
zs1$UnempHc      <-zs1$UnempH      -mean(zs1$UnempH      ,na.rm=T)
zs1$CPovTc       <-zs1$CPovT       -mean(zs1$CPovT       ,na.rm=T)
zs1$CPovWc       <-zs1$CPovW       -mean(zs1$CPovW       ,na.rm=T)
zs1$CPovBc       <-zs1$CPovB       -mean(zs1$CPovB       ,na.rm=T)
zs1$CPovHc       <-zs1$CPovH       -mean(zs1$CPovH       ,na.rm=T)
zs1$CPov1c       <-zs1$CPov1       -mean(zs1$CPov1       ,na.rm=T)
zs1$CPov2c       <-zs1$CPov2       -mean(zs1$CPov2       ,na.rm=T)
zs1$CPov3c       <-zs1$CPov3       -mean(zs1$CPov3       ,na.rm=T)
zs1$PubAsTc      <-zs1$PubAsT      -mean(zs1$PubAsT      ,na.rm=T)
zs1$WelfarTc     <-zs1$WelfarT     -mean(zs1$WelfarT     ,na.rm=T)
zs1$SnapTc       <-zs1$SnapT       -mean(zs1$SnapT       ,na.rm=T)
zs1$SnapWc       <-zs1$SnapW       -mean(zs1$SnapW       ,na.rm=T)
zs1$SnapBc       <-zs1$SnapB       -mean(zs1$SnapB       ,na.rm=T)
zs1$SnapHc       <-zs1$SnapH       -mean(zs1$SnapH       ,na.rm=T)
zs1$IncomeT1kc   <-zs1$IncomeT1k   -mean(zs1$IncomeT1k   ,na.rm=T)
zs1$IncomeW1kc   <-zs1$IncomeW1k   -mean(zs1$IncomeW1k   ,na.rm=T)
zs1$IncomeB1kc   <-zs1$IncomeB1k   -mean(zs1$IncomeB1k   ,na.rm=T)
zs1$IncomeH1kc   <-zs1$IncomeH1k   -mean(zs1$IncomeH1k   ,na.rm=T)
zs1$GiniT100c    <-zs1$GiniT100    -mean(zs1$GiniT100    ,na.rm=T)
zs1$HValueT10kc  <-zs1$HValueT10k  -mean(zs1$HValueT10k  ,na.rm=T)
zs1$MCostT100c   <-zs1$MCostT100   -mean(zs1$MCostT100   ,na.rm=T)
zs1$OCostDT100c  <-zs1$OCostDT100  -mean(zs1$OCostDT100  ,na.rm=T)
zs1$MRentDT100c  <-zs1$MRentDT100  -mean(zs1$MRentDT100  ,na.rm=T)
zs1$OCostPTc     <-zs1$OCostPT     -mean(zs1$OCostPT     ,na.rm=T)
zs1$MRentPTc     <-zs1$MRentPT     -mean(zs1$MRentPT     ,na.rm=T)
zs1$MortgTc      <-zs1$MortgT      -mean(zs1$MortgT      ,na.rm=T)
zs1$LangAPTc     <-zs1$LangAPT     -mean(zs1$LangAPT     ,na.rm=T)
zs1$LangAPWc     <-zs1$LangAPW     -mean(zs1$LangAPW     ,na.rm=T)
zs1$LangAPBc     <-zs1$LangAPB     -mean(zs1$LangAPB     ,na.rm=T)
zs1$LangAPHc     <-zs1$LangAPH     -mean(zs1$LangAPH     ,na.rm=T)
zs1$LangBPTc     <-zs1$LangBPT     -mean(zs1$LangBPT     ,na.rm=T)
zs1$LangBPWc     <-zs1$LangBPW     -mean(zs1$LangBPW     ,na.rm=T)
zs1$LangBPBc     <-zs1$LangBPB     -mean(zs1$LangBPB     ,na.rm=T)
zs1$LangBPHc     <-zs1$LangBPH     -mean(zs1$LangBPH     ,na.rm=T)
zs1$LangCPTc     <-zs1$LangCPT     -mean(zs1$LangCPT     ,na.rm=T)
zs1$OutUsTc      <-zs1$OutUsT      -mean(zs1$OutUsT      ,na.rm=T)
zs1$OutUsWc      <-zs1$OutUsW      -mean(zs1$OutUsW      ,na.rm=T)
zs1$OutUsBc      <-zs1$OutUsB      -mean(zs1$OutUsB      ,na.rm=T)
zs1$OutUsHc      <-zs1$OutUsH      -mean(zs1$OutUsH      ,na.rm=T)
zs1$FBornTc      <-zs1$FBornT      -mean(zs1$FBornT      ,na.rm=T)
zs1$FBornWc      <-zs1$FBornW      -mean(zs1$FBornW      ,na.rm=T)
zs1$FBornBc      <-zs1$FBornB      -mean(zs1$FBornB      ,na.rm=T)
zs1$FBornHc      <-zs1$FBornH      -mean(zs1$FBornH      ,na.rm=T)
zs1$NotCtzTc     <-zs1$NotCtzT     -mean(zs1$NotCtzT     ,na.rm=T)
zs1$NotCtzWc     <-zs1$NotCtzW     -mean(zs1$NotCtzW     ,na.rm=T)
zs1$NotCtzBc     <-zs1$NotCtzB     -mean(zs1$NotCtzB     ,na.rm=T)
zs1$NotCtzHc     <-zs1$NotCtzH     -mean(zs1$NotCtzH     ,na.rm=T)
zs1$MoveTc       <-zs1$MoveT       -mean(zs1$MoveT       ,na.rm=T)
zs1$MoveWc       <-zs1$MoveW       -mean(zs1$MoveW       ,na.rm=T)
zs1$MoveBc       <-zs1$MoveB       -mean(zs1$MoveB       ,na.rm=T)
zs1$MoveHc       <-zs1$MoveH       -mean(zs1$MoveH       ,na.rm=T)
zs1$VacantTc     <-zs1$VacantT     -mean(zs1$VacantT     ,na.rm=T)
zs1$OwnerTc      <-zs1$OwnerT      -mean(zs1$OwnerT      ,na.rm=T)
zs1$OwnerWc      <-zs1$OwnerW      -mean(zs1$OwnerW      ,na.rm=T)
zs1$OwnerBc      <-zs1$OwnerB      -mean(zs1$OwnerB      ,na.rm=T)
zs1$OwnerHc      <-zs1$OwnerH      -mean(zs1$OwnerH      ,na.rm=T)
zs1$CrowdTc      <-zs1$CrowdT      -mean(zs1$CrowdT      ,na.rm=T)
zs1$CrowdWc      <-zs1$CrowdW      -mean(zs1$CrowdW      ,na.rm=T)
zs1$CrowdBc      <-zs1$CrowdB      -mean(zs1$CrowdB      ,na.rm=T)
zs1$CrowdHc      <-zs1$CrowdH      -mean(zs1$CrowdH      ,na.rm=T)
zs1$MobileTc     <-zs1$MobileT     -mean(zs1$MobileT     ,na.rm=T)
zs1$MobileWc     <-zs1$MobileW     -mean(zs1$MobileW     ,na.rm=T)
zs1$MobileBc     <-zs1$MobileB     -mean(zs1$MobileB     ,na.rm=T)
zs1$MobileHc     <-zs1$MobileH     -mean(zs1$MobileH     ,na.rm=T)
zs1$DisablTc     <-zs1$DisablT     -mean(zs1$DisablT     ,na.rm=T)
zs1$DisablWc     <-zs1$DisablW     -mean(zs1$DisablW     ,na.rm=T)
zs1$DisablBc     <-zs1$DisablB     -mean(zs1$DisablB     ,na.rm=T)
zs1$DisablHc     <-zs1$DisablH     -mean(zs1$DisablH     ,na.rm=T)
zs1$DisablTCc    <-zs1$DisablTC    -mean(zs1$DisablTC    ,na.rm=T)
zs1$DisablWCc    <-zs1$DisablWC    -mean(zs1$DisablWC    ,na.rm=T)
zs1$DisablBCc    <-zs1$DisablBC    -mean(zs1$DisablBC    ,na.rm=T)
zs1$DisablHCc    <-zs1$DisablHC    -mean(zs1$DisablHC    ,na.rm=T)
zs1$DisablTMc    <-zs1$DisablTM    -mean(zs1$DisablTM    ,na.rm=T)
zs1$DisablTFc    <-zs1$DisablTF    -mean(zs1$DisablTF    ,na.rm=T)
zs1$Urban1c      <-zs1$Urban1      -mean(zs1$Urban1      ,na.rm=T)
zs1$Urban2c      <-zs1$Urban2      -mean(zs1$Urban2      ,na.rm=T)
zs1$ISBE_PFAc    <-zs1$ISBE_PFA    -mean(zs1$ISBE_PFA    ,na.rm=T)
zs1$ISBE_PFAEc   <-zs1$ISBE_PFAE   -mean(zs1$ISBE_PFAE   ,na.rm=T)
zs1$ISBE_PIc     <-zs1$ISBE_PI     -mean(zs1$ISBE_PI     ,na.rm=T)
zs1$HeadStartc   <-zs1$HeadStart   -mean(zs1$HeadStart   ,na.rm=T)
zs1$ElyHeadSc    <-zs1$ElyHeadS    -mean(zs1$ElyHeadS    ,na.rm=T)
zs1$HeadSAllc    <-zs1$HeadSAll    -mean(zs1$HeadSAll    ,na.rm=T)
zs1$PFA_HS1c     <-zs1$PFA_HS1     -mean(zs1$PFA_HS1     ,na.rm=T)
zs1$PFA_HS2c     <-zs1$PFA_HS2     -mean(zs1$PFA_HS2     ,na.rm=T)
zs1$LCCCc        <-zs1$LCCC        -mean(zs1$LCCC        ,na.rm=T)
zs1$LECCCc       <-zs1$LECCC       -mean(zs1$LECCC       ,na.rm=T)
zs1$LFCCc        <-zs1$LFCC        -mean(zs1$LFCC        ,na.rm=T)
zs1$LLECCCc      <-zs1$LLECCC      -mean(zs1$LLECCC      ,na.rm=T)
zs1$LCLFCCc      <-zs1$LCLFCC      -mean(zs1$LCLFCC      ,na.rm=T)
zs1$LCCCB1c      <-zs1$LCCCB1      -mean(zs1$LCCCB1      ,na.rm=T)
zs1$LCCCB2c      <-zs1$LCCCB2      -mean(zs1$LCCCB2      ,na.rm=T)
zs1$LCCB1c       <-zs1$LCCB1       -mean(zs1$LCCB1       ,na.rm=T)
zs1$LCCB2c       <-zs1$LCCB2       -mean(zs1$LCCB2       ,na.rm=T)
zs1$LCCCS1c      <-zs1$LCCCS1      -mean(zs1$LCCCS1      ,na.rm=T)
zs1$LCCCS2c      <-zs1$LCCCS2      -mean(zs1$LCCCS2      ,na.rm=T)
zs1$LCCS1c       <-zs1$LCCS1       -mean(zs1$LCCS1       ,na.rm=T)
zs1$LCCS2c       <-zs1$LCCS2       -mean(zs1$LCCS2       ,na.rm=T)
zs1$LCCCG1c      <-zs1$LCCCG1      -mean(zs1$LCCCG1      ,na.rm=T)
zs1$LCCCG2c      <-zs1$LCCCG2      -mean(zs1$LCCCG2      ,na.rm=T)
zs1$LCCG1c       <-zs1$LCCG1       -mean(zs1$LCCG1       ,na.rm=T)
zs1$LCCG2c       <-zs1$LCCG2       -mean(zs1$LCCG2       ,na.rm=T)
zs1$ChildCare1c  <-zs1$ChildCare1  -mean(zs1$ChildCare1  ,na.rm=T)
zs1$ChildCare2c  <-zs1$ChildCare2  -mean(zs1$ChildCare2  ,na.rm=T)
zs1$ChildCare3c  <-zs1$ChildCare3  -mean(zs1$ChildCare3  ,na.rm=T)
zs1$CCAPc        <-zs1$CCAP        -mean(zs1$CCAP        ,na.rm=T)
zs1$Homelessc    <-zs1$Homeless    -mean(zs1$Homeless    ,na.rm=T)
zs1$Homeless2c   <-zs1$Homeless2   -mean(zs1$Homeless2   ,na.rm=T)
zs1$DHS_HFIrc    <-zs1$DHS_HFIr    -mean(zs1$DHS_HFIr    ,na.rm=T)
zs1$DHS_PTSrc    <-zs1$DHS_PTSr    -mean(zs1$DHS_PTSr    ,na.rm=T)
zs1$DHS_HVPrc    <-zs1$DHS_HVPr    -mean(zs1$DHS_HVPr    ,na.rm=T)
zs1$IDHS_EIrc    <-zs1$IDHS_EIr    -mean(zs1$IDHS_EIr    ,na.rm=T)
zs1$MHV_C4c      <-zs1$MHV_C4      -mean(zs1$MHV_C4      ,na.rm=T)
zs1$MHV_P4c      <-zs1$MHV_P4      -mean(zs1$MHV_P4      ,na.rm=T)
zs1$MHV_C5c      <-zs1$MHV_C5      -mean(zs1$MHV_C5      ,na.rm=T)
zs1$MHV_P5c      <-zs1$MHV_P5      -mean(zs1$MHV_P5      ,na.rm=T)
zs1$FoodInsPc    <-zs1$FoodInsP    -mean(zs1$FoodInsP    ,na.rm=T)
zs1$FoodISc      <-zs1$FoodIS      -mean(zs1$FoodIS      ,na.rm=T)
zs1$RPovTc       <-zs1$RPovT       -mean(zs1$RPovT       ,na.rm=T)
zs1$PovTc        <-zs1$PovT        -mean(zs1$PovT        ,na.rm=T)
zs1$MHV_C4k <-zs1$MHV_C4 *10
zs1$MHV_C5k <-zs1$MHV_C5 *10
zs1$MHV_C4kc<-zs1$MHV_C4c*10
zs1$MHV_C5kc<-zs1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zs2$Yearc        <-zs2$Year        -mean(zs2$Year        ,na.rm=T)
zs2$CPopBPc      <-zs2$CPopBP      -mean(zs2$CPopBP      ,na.rm=T)
zs2$CPopHPc      <-zs2$CPopHP      -mean(zs2$CPopHP      ,na.rm=T)
zs2$ChildPTc     <-zs2$ChildPT     -mean(zs2$ChildPT     ,na.rm=T)
zs2$ChildPWc     <-zs2$ChildPW     -mean(zs2$ChildPW     ,na.rm=T)
zs2$ChildPBc     <-zs2$ChildPB     -mean(zs2$ChildPB     ,na.rm=T)
zs2$ChildPHc     <-zs2$ChildPH     -mean(zs2$ChildPH     ,na.rm=T)
zs2$CARatioT100c <-zs2$CARatioT100 -mean(zs2$CARatioT100 ,na.rm=T)
zs2$CARatioW100c <-zs2$CARatioW100 -mean(zs2$CARatioW100 ,na.rm=T)
zs2$CARatioB100c <-zs2$CARatioB100 -mean(zs2$CARatioB100 ,na.rm=T)
zs2$CARatioH100c <-zs2$CARatioH100 -mean(zs2$CARatioH100 ,na.rm=T)
zs2$MalePTc      <-zs2$MalePT      -mean(zs2$MalePT      ,na.rm=T)
zs2$MalePWc      <-zs2$MalePW      -mean(zs2$MalePW      ,na.rm=T)
zs2$MalePBc      <-zs2$MalePB      -mean(zs2$MalePB      ,na.rm=T)
zs2$MalePHc      <-zs2$MalePH      -mean(zs2$MalePH      ,na.rm=T)
zs2$MFRatioT100c <-zs2$MFRatioT100 -mean(zs2$MFRatioT100 ,na.rm=T)
zs2$MFRatioW100c <-zs2$MFRatioW100 -mean(zs2$MFRatioW100 ,na.rm=T)
zs2$MFRatioB100c <-zs2$MFRatioB100 -mean(zs2$MFRatioB100 ,na.rm=T)
zs2$MFRatioH100c <-zs2$MFRatioH100 -mean(zs2$MFRatioH100 ,na.rm=T)
zs2$ElderTc      <-zs2$ElderT      -mean(zs2$ElderT      ,na.rm=T)
zs2$ElderWc      <-zs2$ElderW      -mean(zs2$ElderW      ,na.rm=T)
zs2$ElderBc      <-zs2$ElderB      -mean(zs2$ElderB      ,na.rm=T)
zs2$ElderHc      <-zs2$ElderH      -mean(zs2$ElderH      ,na.rm=T)
zs2$SingleTc     <-zs2$SingleT     -mean(zs2$SingleT     ,na.rm=T)
zs2$SingleWc     <-zs2$SingleW     -mean(zs2$SingleW     ,na.rm=T)
zs2$SingleBc     <-zs2$SingleB     -mean(zs2$SingleB     ,na.rm=T)
zs2$SingleHc     <-zs2$SingleH     -mean(zs2$SingleH     ,na.rm=T)
zs2$FHeadTc      <-zs2$FHeadT      -mean(zs2$FHeadT      ,na.rm=T)
zs2$FHeadWc      <-zs2$FHeadW      -mean(zs2$FHeadW      ,na.rm=T)
zs2$FHeadBc      <-zs2$FHeadB      -mean(zs2$FHeadB      ,na.rm=T)
zs2$FHeadHc      <-zs2$FHeadH      -mean(zs2$FHeadH      ,na.rm=T)
zs2$NoHighTc     <-zs2$NoHighT     -mean(zs2$NoHighT     ,na.rm=T)
zs2$NoHighWc     <-zs2$NoHighW     -mean(zs2$NoHighW     ,na.rm=T)
zs2$NoHighBc     <-zs2$NoHighB     -mean(zs2$NoHighB     ,na.rm=T)
zs2$NoHighHc     <-zs2$NoHighH     -mean(zs2$NoHighH     ,na.rm=T)
zs2$UnempTc      <-zs2$UnempT      -mean(zs2$UnempT      ,na.rm=T)
zs2$UnempWc      <-zs2$UnempW      -mean(zs2$UnempW      ,na.rm=T)
zs2$UnempBc      <-zs2$UnempB      -mean(zs2$UnempB      ,na.rm=T)
zs2$UnempHc      <-zs2$UnempH      -mean(zs2$UnempH      ,na.rm=T)
zs2$CPovTc       <-zs2$CPovT       -mean(zs2$CPovT       ,na.rm=T)
zs2$CPovWc       <-zs2$CPovW       -mean(zs2$CPovW       ,na.rm=T)
zs2$CPovBc       <-zs2$CPovB       -mean(zs2$CPovB       ,na.rm=T)
zs2$CPovHc       <-zs2$CPovH       -mean(zs2$CPovH       ,na.rm=T)
zs2$CPov1c       <-zs2$CPov1       -mean(zs2$CPov1       ,na.rm=T)
zs2$CPov2c       <-zs2$CPov2       -mean(zs2$CPov2       ,na.rm=T)
zs2$CPov3c       <-zs2$CPov3       -mean(zs2$CPov3       ,na.rm=T)
zs2$PubAsTc      <-zs2$PubAsT      -mean(zs2$PubAsT      ,na.rm=T)
zs2$WelfarTc     <-zs2$WelfarT     -mean(zs2$WelfarT     ,na.rm=T)
zs2$SnapTc       <-zs2$SnapT       -mean(zs2$SnapT       ,na.rm=T)
zs2$SnapWc       <-zs2$SnapW       -mean(zs2$SnapW       ,na.rm=T)
zs2$SnapBc       <-zs2$SnapB       -mean(zs2$SnapB       ,na.rm=T)
zs2$SnapHc       <-zs2$SnapH       -mean(zs2$SnapH       ,na.rm=T)
zs2$IncomeT1kc   <-zs2$IncomeT1k   -mean(zs2$IncomeT1k   ,na.rm=T)
zs2$IncomeW1kc   <-zs2$IncomeW1k   -mean(zs2$IncomeW1k   ,na.rm=T)
zs2$IncomeB1kc   <-zs2$IncomeB1k   -mean(zs2$IncomeB1k   ,na.rm=T)
zs2$IncomeH1kc   <-zs2$IncomeH1k   -mean(zs2$IncomeH1k   ,na.rm=T)
zs2$GiniT100c    <-zs2$GiniT100    -mean(zs2$GiniT100    ,na.rm=T)
zs2$HValueT10kc  <-zs2$HValueT10k  -mean(zs2$HValueT10k  ,na.rm=T)
zs2$MCostT100c   <-zs2$MCostT100   -mean(zs2$MCostT100   ,na.rm=T)
zs2$OCostDT100c  <-zs2$OCostDT100  -mean(zs2$OCostDT100  ,na.rm=T)
zs2$MRentDT100c  <-zs2$MRentDT100  -mean(zs2$MRentDT100  ,na.rm=T)
zs2$OCostPTc     <-zs2$OCostPT     -mean(zs2$OCostPT     ,na.rm=T)
zs2$MRentPTc     <-zs2$MRentPT     -mean(zs2$MRentPT     ,na.rm=T)
zs2$MortgTc      <-zs2$MortgT      -mean(zs2$MortgT      ,na.rm=T)
zs2$LangAPTc     <-zs2$LangAPT     -mean(zs2$LangAPT     ,na.rm=T)
zs2$LangAPWc     <-zs2$LangAPW     -mean(zs2$LangAPW     ,na.rm=T)
zs2$LangAPBc     <-zs2$LangAPB     -mean(zs2$LangAPB     ,na.rm=T)
zs2$LangAPHc     <-zs2$LangAPH     -mean(zs2$LangAPH     ,na.rm=T)
zs2$LangBPTc     <-zs2$LangBPT     -mean(zs2$LangBPT     ,na.rm=T)
zs2$LangBPWc     <-zs2$LangBPW     -mean(zs2$LangBPW     ,na.rm=T)
zs2$LangBPBc     <-zs2$LangBPB     -mean(zs2$LangBPB     ,na.rm=T)
zs2$LangBPHc     <-zs2$LangBPH     -mean(zs2$LangBPH     ,na.rm=T)
zs2$LangCPTc     <-zs2$LangCPT     -mean(zs2$LangCPT     ,na.rm=T)
zs2$OutUsTc      <-zs2$OutUsT      -mean(zs2$OutUsT      ,na.rm=T)
zs2$OutUsWc      <-zs2$OutUsW      -mean(zs2$OutUsW      ,na.rm=T)
zs2$OutUsBc      <-zs2$OutUsB      -mean(zs2$OutUsB      ,na.rm=T)
zs2$OutUsHc      <-zs2$OutUsH      -mean(zs2$OutUsH      ,na.rm=T)
zs2$FBornTc      <-zs2$FBornT      -mean(zs2$FBornT      ,na.rm=T)
zs2$FBornWc      <-zs2$FBornW      -mean(zs2$FBornW      ,na.rm=T)
zs2$FBornBc      <-zs2$FBornB      -mean(zs2$FBornB      ,na.rm=T)
zs2$FBornHc      <-zs2$FBornH      -mean(zs2$FBornH      ,na.rm=T)
zs2$NotCtzTc     <-zs2$NotCtzT     -mean(zs2$NotCtzT     ,na.rm=T)
zs2$NotCtzWc     <-zs2$NotCtzW     -mean(zs2$NotCtzW     ,na.rm=T)
zs2$NotCtzBc     <-zs2$NotCtzB     -mean(zs2$NotCtzB     ,na.rm=T)
zs2$NotCtzHc     <-zs2$NotCtzH     -mean(zs2$NotCtzH     ,na.rm=T)
zs2$MoveTc       <-zs2$MoveT       -mean(zs2$MoveT       ,na.rm=T)
zs2$MoveWc       <-zs2$MoveW       -mean(zs2$MoveW       ,na.rm=T)
zs2$MoveBc       <-zs2$MoveB       -mean(zs2$MoveB       ,na.rm=T)
zs2$MoveHc       <-zs2$MoveH       -mean(zs2$MoveH       ,na.rm=T)
zs2$VacantTc     <-zs2$VacantT     -mean(zs2$VacantT     ,na.rm=T)
zs2$OwnerTc      <-zs2$OwnerT      -mean(zs2$OwnerT      ,na.rm=T)
zs2$OwnerWc      <-zs2$OwnerW      -mean(zs2$OwnerW      ,na.rm=T)
zs2$OwnerBc      <-zs2$OwnerB      -mean(zs2$OwnerB      ,na.rm=T)
zs2$OwnerHc      <-zs2$OwnerH      -mean(zs2$OwnerH      ,na.rm=T)
zs2$CrowdTc      <-zs2$CrowdT      -mean(zs2$CrowdT      ,na.rm=T)
zs2$CrowdWc      <-zs2$CrowdW      -mean(zs2$CrowdW      ,na.rm=T)
zs2$CrowdBc      <-zs2$CrowdB      -mean(zs2$CrowdB      ,na.rm=T)
zs2$CrowdHc      <-zs2$CrowdH      -mean(zs2$CrowdH      ,na.rm=T)
zs2$MobileTc     <-zs2$MobileT     -mean(zs2$MobileT     ,na.rm=T)
zs2$MobileWc     <-zs2$MobileW     -mean(zs2$MobileW     ,na.rm=T)
zs2$MobileBc     <-zs2$MobileB     -mean(zs2$MobileB     ,na.rm=T)
zs2$MobileHc     <-zs2$MobileH     -mean(zs2$MobileH     ,na.rm=T)
zs2$DisablTc     <-zs2$DisablT     -mean(zs2$DisablT     ,na.rm=T)
zs2$DisablWc     <-zs2$DisablW     -mean(zs2$DisablW     ,na.rm=T)
zs2$DisablBc     <-zs2$DisablB     -mean(zs2$DisablB     ,na.rm=T)
zs2$DisablHc     <-zs2$DisablH     -mean(zs2$DisablH     ,na.rm=T)
zs2$DisablTCc    <-zs2$DisablTC    -mean(zs2$DisablTC    ,na.rm=T)
zs2$DisablWCc    <-zs2$DisablWC    -mean(zs2$DisablWC    ,na.rm=T)
zs2$DisablBCc    <-zs2$DisablBC    -mean(zs2$DisablBC    ,na.rm=T)
zs2$DisablHCc    <-zs2$DisablHC    -mean(zs2$DisablHC    ,na.rm=T)
zs2$DisablTMc    <-zs2$DisablTM    -mean(zs2$DisablTM    ,na.rm=T)
zs2$DisablTFc    <-zs2$DisablTF    -mean(zs2$DisablTF    ,na.rm=T)
zs2$Urban1c      <-zs2$Urban1      -mean(zs2$Urban1      ,na.rm=T)
zs2$Urban2c      <-zs2$Urban2      -mean(zs2$Urban2      ,na.rm=T)
zs2$ISBE_PFAc    <-zs2$ISBE_PFA    -mean(zs2$ISBE_PFA    ,na.rm=T)
zs2$ISBE_PFAEc   <-zs2$ISBE_PFAE   -mean(zs2$ISBE_PFAE   ,na.rm=T)
zs2$ISBE_PIc     <-zs2$ISBE_PI     -mean(zs2$ISBE_PI     ,na.rm=T)
zs2$HeadStartc   <-zs2$HeadStart   -mean(zs2$HeadStart   ,na.rm=T)
zs2$ElyHeadSc    <-zs2$ElyHeadS    -mean(zs2$ElyHeadS    ,na.rm=T)
zs2$HeadSAllc    <-zs2$HeadSAll    -mean(zs2$HeadSAll    ,na.rm=T)
zs2$PFA_HS1c     <-zs2$PFA_HS1     -mean(zs2$PFA_HS1     ,na.rm=T)
zs2$PFA_HS2c     <-zs2$PFA_HS2     -mean(zs2$PFA_HS2     ,na.rm=T)
zs2$LCCCc        <-zs2$LCCC        -mean(zs2$LCCC        ,na.rm=T)
zs2$LECCCc       <-zs2$LECCC       -mean(zs2$LECCC       ,na.rm=T)
zs2$LFCCc        <-zs2$LFCC        -mean(zs2$LFCC        ,na.rm=T)
zs2$LLECCCc      <-zs2$LLECCC      -mean(zs2$LLECCC      ,na.rm=T)
zs2$LCLFCCc      <-zs2$LCLFCC      -mean(zs2$LCLFCC      ,na.rm=T)
zs2$LCCCB1c      <-zs2$LCCCB1      -mean(zs2$LCCCB1      ,na.rm=T)
zs2$LCCCB2c      <-zs2$LCCCB2      -mean(zs2$LCCCB2      ,na.rm=T)
zs2$LCCB1c       <-zs2$LCCB1       -mean(zs2$LCCB1       ,na.rm=T)
zs2$LCCB2c       <-zs2$LCCB2       -mean(zs2$LCCB2       ,na.rm=T)
zs2$LCCCS1c      <-zs2$LCCCS1      -mean(zs2$LCCCS1      ,na.rm=T)
zs2$LCCCS2c      <-zs2$LCCCS2      -mean(zs2$LCCCS2      ,na.rm=T)
zs2$LCCS1c       <-zs2$LCCS1       -mean(zs2$LCCS1       ,na.rm=T)
zs2$LCCS2c       <-zs2$LCCS2       -mean(zs2$LCCS2       ,na.rm=T)
zs2$LCCCG1c      <-zs2$LCCCG1      -mean(zs2$LCCCG1      ,na.rm=T)
zs2$LCCCG2c      <-zs2$LCCCG2      -mean(zs2$LCCCG2      ,na.rm=T)
zs2$LCCG1c       <-zs2$LCCG1       -mean(zs2$LCCG1       ,na.rm=T)
zs2$LCCG2c       <-zs2$LCCG2       -mean(zs2$LCCG2       ,na.rm=T)
zs2$ChildCare1c  <-zs2$ChildCare1  -mean(zs2$ChildCare1  ,na.rm=T)
zs2$ChildCare2c  <-zs2$ChildCare2  -mean(zs2$ChildCare2  ,na.rm=T)
zs2$ChildCare3c  <-zs2$ChildCare3  -mean(zs2$ChildCare3  ,na.rm=T)
zs2$CCAPc        <-zs2$CCAP        -mean(zs2$CCAP        ,na.rm=T)
zs2$Homelessc    <-zs2$Homeless    -mean(zs2$Homeless    ,na.rm=T)
zs2$Homeless2c   <-zs2$Homeless2   -mean(zs2$Homeless2   ,na.rm=T)
zs2$DHS_HFIrc    <-zs2$DHS_HFIr    -mean(zs2$DHS_HFIr    ,na.rm=T)
zs2$DHS_PTSrc    <-zs2$DHS_PTSr    -mean(zs2$DHS_PTSr    ,na.rm=T)
zs2$DHS_HVPrc    <-zs2$DHS_HVPr    -mean(zs2$DHS_HVPr    ,na.rm=T)
zs2$IDHS_EIrc    <-zs2$IDHS_EIr    -mean(zs2$IDHS_EIr    ,na.rm=T)
zs2$MHV_C4c      <-zs2$MHV_C4      -mean(zs2$MHV_C4      ,na.rm=T)
zs2$MHV_P4c      <-zs2$MHV_P4      -mean(zs2$MHV_P4      ,na.rm=T)
zs2$MHV_C5c      <-zs2$MHV_C5      -mean(zs2$MHV_C5      ,na.rm=T)
zs2$MHV_P5c      <-zs2$MHV_P5      -mean(zs2$MHV_P5      ,na.rm=T)
zs2$FoodInsPc    <-zs2$FoodInsP    -mean(zs2$FoodInsP    ,na.rm=T)
zs2$FoodISc      <-zs2$FoodIS      -mean(zs2$FoodIS      ,na.rm=T)
zs2$RPovTc       <-zs2$RPovT       -mean(zs2$RPovT       ,na.rm=T)
zs2$PovTc        <-zs2$PovT        -mean(zs2$PovT        ,na.rm=T)
zs2$MHV_C4k <-zs2$MHV_C4 *10
zs2$MHV_C5k <-zs2$MHV_C5 *10
zs2$MHV_C4kc<-zs2$MHV_C4c*10
zs2$MHV_C5kc<-zs2$MHV_C5c*10





# demean - within and between variables
zs<-cbind(zs,demean(zs,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zs1<-cbind(zs1,demean(zs1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





# demean - within and between variables
zs2<-cbind(zs2,demean(zs2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","PovTc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - White
# Income - White
# Income - White
# Income - White
# Income - White
# Income - White
# Income - White
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zw$Yearc        <-zw$Year        -mean(zw$Year        ,na.rm=T)
zw$CPopBPc      <-zw$CPopBP      -mean(zw$CPopBP      ,na.rm=T)
zw$CPopHPc      <-zw$CPopHP      -mean(zw$CPopHP      ,na.rm=T)
zw$ChildPTc     <-zw$ChildPT     -mean(zw$ChildPT     ,na.rm=T)
zw$ChildPWc     <-zw$ChildPW     -mean(zw$ChildPW     ,na.rm=T)
zw$ChildPBc     <-zw$ChildPB     -mean(zw$ChildPB     ,na.rm=T)
zw$ChildPHc     <-zw$ChildPH     -mean(zw$ChildPH     ,na.rm=T)
zw$CARatioT100c <-zw$CARatioT100 -mean(zw$CARatioT100 ,na.rm=T)
zw$CARatioW100c <-zw$CARatioW100 -mean(zw$CARatioW100 ,na.rm=T)
zw$CARatioB100c <-zw$CARatioB100 -mean(zw$CARatioB100 ,na.rm=T)
zw$CARatioH100c <-zw$CARatioH100 -mean(zw$CARatioH100 ,na.rm=T)
zw$MalePTc      <-zw$MalePT      -mean(zw$MalePT      ,na.rm=T)
zw$MalePWc      <-zw$MalePW      -mean(zw$MalePW      ,na.rm=T)
zw$MalePBc      <-zw$MalePB      -mean(zw$MalePB      ,na.rm=T)
zw$MalePHc      <-zw$MalePH      -mean(zw$MalePH      ,na.rm=T)
zw$MFRatioT100c <-zw$MFRatioT100 -mean(zw$MFRatioT100 ,na.rm=T)
zw$MFRatioW100c <-zw$MFRatioW100 -mean(zw$MFRatioW100 ,na.rm=T)
zw$MFRatioB100c <-zw$MFRatioB100 -mean(zw$MFRatioB100 ,na.rm=T)
zw$MFRatioH100c <-zw$MFRatioH100 -mean(zw$MFRatioH100 ,na.rm=T)
zw$ElderTc      <-zw$ElderT      -mean(zw$ElderT      ,na.rm=T)
zw$ElderWc      <-zw$ElderW      -mean(zw$ElderW      ,na.rm=T)
zw$ElderBc      <-zw$ElderB      -mean(zw$ElderB      ,na.rm=T)
zw$ElderHc      <-zw$ElderH      -mean(zw$ElderH      ,na.rm=T)
zw$SingleTc     <-zw$SingleT     -mean(zw$SingleT     ,na.rm=T)
zw$SingleWc     <-zw$SingleW     -mean(zw$SingleW     ,na.rm=T)
zw$SingleBc     <-zw$SingleB     -mean(zw$SingleB     ,na.rm=T)
zw$SingleHc     <-zw$SingleH     -mean(zw$SingleH     ,na.rm=T)
zw$FHeadTc      <-zw$FHeadT      -mean(zw$FHeadT      ,na.rm=T)
zw$FHeadWc      <-zw$FHeadW      -mean(zw$FHeadW      ,na.rm=T)
zw$FHeadBc      <-zw$FHeadB      -mean(zw$FHeadB      ,na.rm=T)
zw$FHeadHc      <-zw$FHeadH      -mean(zw$FHeadH      ,na.rm=T)
zw$NoHighTc     <-zw$NoHighT     -mean(zw$NoHighT     ,na.rm=T)
zw$NoHighWc     <-zw$NoHighW     -mean(zw$NoHighW     ,na.rm=T)
zw$NoHighBc     <-zw$NoHighB     -mean(zw$NoHighB     ,na.rm=T)
zw$NoHighHc     <-zw$NoHighH     -mean(zw$NoHighH     ,na.rm=T)
zw$UnempTc      <-zw$UnempT      -mean(zw$UnempT      ,na.rm=T)
zw$UnempWc      <-zw$UnempW      -mean(zw$UnempW      ,na.rm=T)
zw$UnempBc      <-zw$UnempB      -mean(zw$UnempB      ,na.rm=T)
zw$UnempHc      <-zw$UnempH      -mean(zw$UnempH      ,na.rm=T)
zw$CPovTc       <-zw$CPovT       -mean(zw$CPovT       ,na.rm=T)
zw$CPovWc       <-zw$CPovW       -mean(zw$CPovW       ,na.rm=T)
zw$CPovBc       <-zw$CPovB       -mean(zw$CPovB       ,na.rm=T)
zw$CPovHc       <-zw$CPovH       -mean(zw$CPovH       ,na.rm=T)
zw$CPov1c       <-zw$CPov1       -mean(zw$CPov1       ,na.rm=T)
zw$CPov2c       <-zw$CPov2       -mean(zw$CPov2       ,na.rm=T)
zw$CPov3c       <-zw$CPov3       -mean(zw$CPov3       ,na.rm=T)
zw$PubAsTc      <-zw$PubAsT      -mean(zw$PubAsT      ,na.rm=T)
zw$WelfarTc     <-zw$WelfarT     -mean(zw$WelfarT     ,na.rm=T)
zw$SnapTc       <-zw$SnapT       -mean(zw$SnapT       ,na.rm=T)
zw$SnapWc       <-zw$SnapW       -mean(zw$SnapW       ,na.rm=T)
zw$SnapBc       <-zw$SnapB       -mean(zw$SnapB       ,na.rm=T)
zw$SnapHc       <-zw$SnapH       -mean(zw$SnapH       ,na.rm=T)
zw$IncomeT1kc   <-zw$IncomeT1k   -mean(zw$IncomeT1k   ,na.rm=T)
zw$IncomeW1kc   <-zw$IncomeW1k   -mean(zw$IncomeW1k   ,na.rm=T)
zw$IncomeB1kc   <-zw$IncomeB1k   -mean(zw$IncomeB1k   ,na.rm=T)
zw$IncomeH1kc   <-zw$IncomeH1k   -mean(zw$IncomeH1k   ,na.rm=T)
zw$GiniT100c    <-zw$GiniT100    -mean(zw$GiniT100    ,na.rm=T)
zw$HValueT10kc  <-zw$HValueT10k  -mean(zw$HValueT10k  ,na.rm=T)
zw$MCostT100c   <-zw$MCostT100   -mean(zw$MCostT100   ,na.rm=T)
zw$OCostDT100c  <-zw$OCostDT100  -mean(zw$OCostDT100  ,na.rm=T)
zw$MRentDT100c  <-zw$MRentDT100  -mean(zw$MRentDT100  ,na.rm=T)
zw$OCostPTc     <-zw$OCostPT     -mean(zw$OCostPT     ,na.rm=T)
zw$MRentPTc     <-zw$MRentPT     -mean(zw$MRentPT     ,na.rm=T)
zw$MortgTc      <-zw$MortgT      -mean(zw$MortgT      ,na.rm=T)
zw$LangAPTc     <-zw$LangAPT     -mean(zw$LangAPT     ,na.rm=T)
zw$LangAPWc     <-zw$LangAPW     -mean(zw$LangAPW     ,na.rm=T)
zw$LangAPBc     <-zw$LangAPB     -mean(zw$LangAPB     ,na.rm=T)
zw$LangAPHc     <-zw$LangAPH     -mean(zw$LangAPH     ,na.rm=T)
zw$LangBPTc     <-zw$LangBPT     -mean(zw$LangBPT     ,na.rm=T)
zw$LangBPWc     <-zw$LangBPW     -mean(zw$LangBPW     ,na.rm=T)
zw$LangBPBc     <-zw$LangBPB     -mean(zw$LangBPB     ,na.rm=T)
zw$LangBPHc     <-zw$LangBPH     -mean(zw$LangBPH     ,na.rm=T)
zw$LangCPTc     <-zw$LangCPT     -mean(zw$LangCPT     ,na.rm=T)
zw$OutUsTc      <-zw$OutUsT      -mean(zw$OutUsT      ,na.rm=T)
zw$OutUsWc      <-zw$OutUsW      -mean(zw$OutUsW      ,na.rm=T)
zw$OutUsBc      <-zw$OutUsB      -mean(zw$OutUsB      ,na.rm=T)
zw$OutUsHc      <-zw$OutUsH      -mean(zw$OutUsH      ,na.rm=T)
zw$FBornTc      <-zw$FBornT      -mean(zw$FBornT      ,na.rm=T)
zw$FBornWc      <-zw$FBornW      -mean(zw$FBornW      ,na.rm=T)
zw$FBornBc      <-zw$FBornB      -mean(zw$FBornB      ,na.rm=T)
zw$FBornHc      <-zw$FBornH      -mean(zw$FBornH      ,na.rm=T)
zw$NotCtzTc     <-zw$NotCtzT     -mean(zw$NotCtzT     ,na.rm=T)
zw$NotCtzWc     <-zw$NotCtzW     -mean(zw$NotCtzW     ,na.rm=T)
zw$NotCtzBc     <-zw$NotCtzB     -mean(zw$NotCtzB     ,na.rm=T)
zw$NotCtzHc     <-zw$NotCtzH     -mean(zw$NotCtzH     ,na.rm=T)
zw$MoveTc       <-zw$MoveT       -mean(zw$MoveT       ,na.rm=T)
zw$MoveWc       <-zw$MoveW       -mean(zw$MoveW       ,na.rm=T)
zw$MoveBc       <-zw$MoveB       -mean(zw$MoveB       ,na.rm=T)
zw$MoveHc       <-zw$MoveH       -mean(zw$MoveH       ,na.rm=T)
zw$VacantTc     <-zw$VacantT     -mean(zw$VacantT     ,na.rm=T)
zw$OwnerTc      <-zw$OwnerT      -mean(zw$OwnerT      ,na.rm=T)
zw$OwnerWc      <-zw$OwnerW      -mean(zw$OwnerW      ,na.rm=T)
zw$OwnerBc      <-zw$OwnerB      -mean(zw$OwnerB      ,na.rm=T)
zw$OwnerHc      <-zw$OwnerH      -mean(zw$OwnerH      ,na.rm=T)
zw$CrowdTc      <-zw$CrowdT      -mean(zw$CrowdT      ,na.rm=T)
zw$CrowdWc      <-zw$CrowdW      -mean(zw$CrowdW      ,na.rm=T)
zw$CrowdBc      <-zw$CrowdB      -mean(zw$CrowdB      ,na.rm=T)
zw$CrowdHc      <-zw$CrowdH      -mean(zw$CrowdH      ,na.rm=T)
zw$MobileTc     <-zw$MobileT     -mean(zw$MobileT     ,na.rm=T)
zw$MobileWc     <-zw$MobileW     -mean(zw$MobileW     ,na.rm=T)
zw$MobileBc     <-zw$MobileB     -mean(zw$MobileB     ,na.rm=T)
zw$MobileHc     <-zw$MobileH     -mean(zw$MobileH     ,na.rm=T)
zw$DisablTc     <-zw$DisablT     -mean(zw$DisablT     ,na.rm=T)
zw$DisablWc     <-zw$DisablW     -mean(zw$DisablW     ,na.rm=T)
zw$DisablBc     <-zw$DisablB     -mean(zw$DisablB     ,na.rm=T)
zw$DisablHc     <-zw$DisablH     -mean(zw$DisablH     ,na.rm=T)
zw$DisablTCc    <-zw$DisablTC    -mean(zw$DisablTC    ,na.rm=T)
zw$DisablWCc    <-zw$DisablWC    -mean(zw$DisablWC    ,na.rm=T)
zw$DisablBCc    <-zw$DisablBC    -mean(zw$DisablBC    ,na.rm=T)
zw$DisablHCc    <-zw$DisablHC    -mean(zw$DisablHC    ,na.rm=T)
zw$DisablTMc    <-zw$DisablTM    -mean(zw$DisablTM    ,na.rm=T)
zw$DisablTFc    <-zw$DisablTF    -mean(zw$DisablTF    ,na.rm=T)
zw$Urban1c      <-zw$Urban1      -mean(zw$Urban1      ,na.rm=T)
zw$Urban2c      <-zw$Urban2      -mean(zw$Urban2      ,na.rm=T)
zw$ISBE_PFAc    <-zw$ISBE_PFA    -mean(zw$ISBE_PFA    ,na.rm=T)
zw$ISBE_PFAEc   <-zw$ISBE_PFAE   -mean(zw$ISBE_PFAE   ,na.rm=T)
zw$ISBE_PIc     <-zw$ISBE_PI     -mean(zw$ISBE_PI     ,na.rm=T)
zw$HeadStartc   <-zw$HeadStart   -mean(zw$HeadStart   ,na.rm=T)
zw$ElyHeadSc    <-zw$ElyHeadS    -mean(zw$ElyHeadS    ,na.rm=T)
zw$HeadSAllc    <-zw$HeadSAll    -mean(zw$HeadSAll    ,na.rm=T)
zw$PFA_HS1c     <-zw$PFA_HS1     -mean(zw$PFA_HS1     ,na.rm=T)
zw$PFA_HS2c     <-zw$PFA_HS2     -mean(zw$PFA_HS2     ,na.rm=T)
zw$LCCCc        <-zw$LCCC        -mean(zw$LCCC        ,na.rm=T)
zw$LECCCc       <-zw$LECCC       -mean(zw$LECCC       ,na.rm=T)
zw$LFCCc        <-zw$LFCC        -mean(zw$LFCC        ,na.rm=T)
zw$LLECCCc      <-zw$LLECCC      -mean(zw$LLECCC      ,na.rm=T)
zw$LCLFCCc      <-zw$LCLFCC      -mean(zw$LCLFCC      ,na.rm=T)
zw$LCCCB1c      <-zw$LCCCB1      -mean(zw$LCCCB1      ,na.rm=T)
zw$LCCCB2c      <-zw$LCCCB2      -mean(zw$LCCCB2      ,na.rm=T)
zw$LCCB1c       <-zw$LCCB1       -mean(zw$LCCB1       ,na.rm=T)
zw$LCCB2c       <-zw$LCCB2       -mean(zw$LCCB2       ,na.rm=T)
zw$LCCCS1c      <-zw$LCCCS1      -mean(zw$LCCCS1      ,na.rm=T)
zw$LCCCS2c      <-zw$LCCCS2      -mean(zw$LCCCS2      ,na.rm=T)
zw$LCCS1c       <-zw$LCCS1       -mean(zw$LCCS1       ,na.rm=T)
zw$LCCS2c       <-zw$LCCS2       -mean(zw$LCCS2       ,na.rm=T)
zw$LCCCG1c      <-zw$LCCCG1      -mean(zw$LCCCG1      ,na.rm=T)
zw$LCCCG2c      <-zw$LCCCG2      -mean(zw$LCCCG2      ,na.rm=T)
zw$LCCG1c       <-zw$LCCG1       -mean(zw$LCCG1       ,na.rm=T)
zw$LCCG2c       <-zw$LCCG2       -mean(zw$LCCG2       ,na.rm=T)
zw$ChildCare1c  <-zw$ChildCare1  -mean(zw$ChildCare1  ,na.rm=T)
zw$ChildCare2c  <-zw$ChildCare2  -mean(zw$ChildCare2  ,na.rm=T)
zw$ChildCare3c  <-zw$ChildCare3  -mean(zw$ChildCare3  ,na.rm=T)
zw$CCAPc        <-zw$CCAP        -mean(zw$CCAP        ,na.rm=T)
zw$Homelessc    <-zw$Homeless    -mean(zw$Homeless    ,na.rm=T)
zw$Homeless2c   <-zw$Homeless2   -mean(zw$Homeless2   ,na.rm=T)
zw$DHS_HFIrc    <-zw$DHS_HFIr    -mean(zw$DHS_HFIr    ,na.rm=T)
zw$DHS_PTSrc    <-zw$DHS_PTSr    -mean(zw$DHS_PTSr    ,na.rm=T)
zw$DHS_HVPrc    <-zw$DHS_HVPr    -mean(zw$DHS_HVPr    ,na.rm=T)
zw$IDHS_EIrc    <-zw$IDHS_EIr    -mean(zw$IDHS_EIr    ,na.rm=T)
zw$MHV_C4c      <-zw$MHV_C4      -mean(zw$MHV_C4      ,na.rm=T)
zw$MHV_P4c      <-zw$MHV_P4      -mean(zw$MHV_P4      ,na.rm=T)
zw$MHV_C5c      <-zw$MHV_C5      -mean(zw$MHV_C5      ,na.rm=T)
zw$MHV_P5c      <-zw$MHV_P5      -mean(zw$MHV_P5      ,na.rm=T)
zw$FoodInsPc    <-zw$FoodInsP    -mean(zw$FoodInsP    ,na.rm=T)
zw$FoodISc      <-zw$FoodIS      -mean(zw$FoodIS      ,na.rm=T)
zw$RPovTc       <-zw$RPovT       -mean(zw$RPovT       ,na.rm=T)
zw$PovTc        <-zw$PovT        -mean(zw$PovT        ,na.rm=T)
zw$RPovWc       <-zw$RPovW       -mean(zw$RPovW       ,na.rm=T)
zw$PovWc        <-zw$PovW        -mean(zw$PovW        ,na.rm=T)
zw$MHV_C4k <-zw$MHV_C4 *10
zw$MHV_C5k <-zw$MHV_C5 *10
zw$MHV_C4kc<-zw$MHV_C4c*10
zw$MHV_C5kc<-zw$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zw1$Yearc        <-zw1$Year        -mean(zw1$Year        ,na.rm=T)
zw1$CPopBPc      <-zw1$CPopBP      -mean(zw1$CPopBP      ,na.rm=T)
zw1$CPopHPc      <-zw1$CPopHP      -mean(zw1$CPopHP      ,na.rm=T)
zw1$ChildPTc     <-zw1$ChildPT     -mean(zw1$ChildPT     ,na.rm=T)
zw1$ChildPWc     <-zw1$ChildPW     -mean(zw1$ChildPW     ,na.rm=T)
zw1$ChildPBc     <-zw1$ChildPB     -mean(zw1$ChildPB     ,na.rm=T)
zw1$ChildPHc     <-zw1$ChildPH     -mean(zw1$ChildPH     ,na.rm=T)
zw1$CARatioT100c <-zw1$CARatioT100 -mean(zw1$CARatioT100 ,na.rm=T)
zw1$CARatioW100c <-zw1$CARatioW100 -mean(zw1$CARatioW100 ,na.rm=T)
zw1$CARatioB100c <-zw1$CARatioB100 -mean(zw1$CARatioB100 ,na.rm=T)
zw1$CARatioH100c <-zw1$CARatioH100 -mean(zw1$CARatioH100 ,na.rm=T)
zw1$MalePTc      <-zw1$MalePT      -mean(zw1$MalePT      ,na.rm=T)
zw1$MalePWc      <-zw1$MalePW      -mean(zw1$MalePW      ,na.rm=T)
zw1$MalePBc      <-zw1$MalePB      -mean(zw1$MalePB      ,na.rm=T)
zw1$MalePHc      <-zw1$MalePH      -mean(zw1$MalePH      ,na.rm=T)
zw1$MFRatioT100c <-zw1$MFRatioT100 -mean(zw1$MFRatioT100 ,na.rm=T)
zw1$MFRatioW100c <-zw1$MFRatioW100 -mean(zw1$MFRatioW100 ,na.rm=T)
zw1$MFRatioB100c <-zw1$MFRatioB100 -mean(zw1$MFRatioB100 ,na.rm=T)
zw1$MFRatioH100c <-zw1$MFRatioH100 -mean(zw1$MFRatioH100 ,na.rm=T)
zw1$ElderTc      <-zw1$ElderT      -mean(zw1$ElderT      ,na.rm=T)
zw1$ElderWc      <-zw1$ElderW      -mean(zw1$ElderW      ,na.rm=T)
zw1$ElderBc      <-zw1$ElderB      -mean(zw1$ElderB      ,na.rm=T)
zw1$ElderHc      <-zw1$ElderH      -mean(zw1$ElderH      ,na.rm=T)
zw1$SingleTc     <-zw1$SingleT     -mean(zw1$SingleT     ,na.rm=T)
zw1$SingleWc     <-zw1$SingleW     -mean(zw1$SingleW     ,na.rm=T)
zw1$SingleBc     <-zw1$SingleB     -mean(zw1$SingleB     ,na.rm=T)
zw1$SingleHc     <-zw1$SingleH     -mean(zw1$SingleH     ,na.rm=T)
zw1$FHeadTc      <-zw1$FHeadT      -mean(zw1$FHeadT      ,na.rm=T)
zw1$FHeadWc      <-zw1$FHeadW      -mean(zw1$FHeadW      ,na.rm=T)
zw1$FHeadBc      <-zw1$FHeadB      -mean(zw1$FHeadB      ,na.rm=T)
zw1$FHeadHc      <-zw1$FHeadH      -mean(zw1$FHeadH      ,na.rm=T)
zw1$NoHighTc     <-zw1$NoHighT     -mean(zw1$NoHighT     ,na.rm=T)
zw1$NoHighWc     <-zw1$NoHighW     -mean(zw1$NoHighW     ,na.rm=T)
zw1$NoHighBc     <-zw1$NoHighB     -mean(zw1$NoHighB     ,na.rm=T)
zw1$NoHighHc     <-zw1$NoHighH     -mean(zw1$NoHighH     ,na.rm=T)
zw1$UnempTc      <-zw1$UnempT      -mean(zw1$UnempT      ,na.rm=T)
zw1$UnempWc      <-zw1$UnempW      -mean(zw1$UnempW      ,na.rm=T)
zw1$UnempBc      <-zw1$UnempB      -mean(zw1$UnempB      ,na.rm=T)
zw1$UnempHc      <-zw1$UnempH      -mean(zw1$UnempH      ,na.rm=T)
zw1$CPovTc       <-zw1$CPovT       -mean(zw1$CPovT       ,na.rm=T)
zw1$CPovWc       <-zw1$CPovW       -mean(zw1$CPovW       ,na.rm=T)
zw1$CPovBc       <-zw1$CPovB       -mean(zw1$CPovB       ,na.rm=T)
zw1$CPovHc       <-zw1$CPovH       -mean(zw1$CPovH       ,na.rm=T)
zw1$CPov1c       <-zw1$CPov1       -mean(zw1$CPov1       ,na.rm=T)
zw1$CPov2c       <-zw1$CPov2       -mean(zw1$CPov2       ,na.rm=T)
zw1$CPov3c       <-zw1$CPov3       -mean(zw1$CPov3       ,na.rm=T)
zw1$PubAsTc      <-zw1$PubAsT      -mean(zw1$PubAsT      ,na.rm=T)
zw1$WelfarTc     <-zw1$WelfarT     -mean(zw1$WelfarT     ,na.rm=T)
zw1$SnapTc       <-zw1$SnapT       -mean(zw1$SnapT       ,na.rm=T)
zw1$SnapWc       <-zw1$SnapW       -mean(zw1$SnapW       ,na.rm=T)
zw1$SnapBc       <-zw1$SnapB       -mean(zw1$SnapB       ,na.rm=T)
zw1$SnapHc       <-zw1$SnapH       -mean(zw1$SnapH       ,na.rm=T)
zw1$IncomeT1kc   <-zw1$IncomeT1k   -mean(zw1$IncomeT1k   ,na.rm=T)
zw1$IncomeW1kc   <-zw1$IncomeW1k   -mean(zw1$IncomeW1k   ,na.rm=T)
zw1$IncomeB1kc   <-zw1$IncomeB1k   -mean(zw1$IncomeB1k   ,na.rm=T)
zw1$IncomeH1kc   <-zw1$IncomeH1k   -mean(zw1$IncomeH1k   ,na.rm=T)
zw1$GiniT100c    <-zw1$GiniT100    -mean(zw1$GiniT100    ,na.rm=T)
zw1$HValueT10kc  <-zw1$HValueT10k  -mean(zw1$HValueT10k  ,na.rm=T)
zw1$MCostT100c   <-zw1$MCostT100   -mean(zw1$MCostT100   ,na.rm=T)
zw1$OCostDT100c  <-zw1$OCostDT100  -mean(zw1$OCostDT100  ,na.rm=T)
zw1$MRentDT100c  <-zw1$MRentDT100  -mean(zw1$MRentDT100  ,na.rm=T)
zw1$OCostPTc     <-zw1$OCostPT     -mean(zw1$OCostPT     ,na.rm=T)
zw1$MRentPTc     <-zw1$MRentPT     -mean(zw1$MRentPT     ,na.rm=T)
zw1$MortgTc      <-zw1$MortgT      -mean(zw1$MortgT      ,na.rm=T)
zw1$LangAPTc     <-zw1$LangAPT     -mean(zw1$LangAPT     ,na.rm=T)
zw1$LangAPWc     <-zw1$LangAPW     -mean(zw1$LangAPW     ,na.rm=T)
zw1$LangAPBc     <-zw1$LangAPB     -mean(zw1$LangAPB     ,na.rm=T)
zw1$LangAPHc     <-zw1$LangAPH     -mean(zw1$LangAPH     ,na.rm=T)
zw1$LangBPTc     <-zw1$LangBPT     -mean(zw1$LangBPT     ,na.rm=T)
zw1$LangBPWc     <-zw1$LangBPW     -mean(zw1$LangBPW     ,na.rm=T)
zw1$LangBPBc     <-zw1$LangBPB     -mean(zw1$LangBPB     ,na.rm=T)
zw1$LangBPHc     <-zw1$LangBPH     -mean(zw1$LangBPH     ,na.rm=T)
zw1$LangCPTc     <-zw1$LangCPT     -mean(zw1$LangCPT     ,na.rm=T)
zw1$OutUsTc      <-zw1$OutUsT      -mean(zw1$OutUsT      ,na.rm=T)
zw1$OutUsWc      <-zw1$OutUsW      -mean(zw1$OutUsW      ,na.rm=T)
zw1$OutUsBc      <-zw1$OutUsB      -mean(zw1$OutUsB      ,na.rm=T)
zw1$OutUsHc      <-zw1$OutUsH      -mean(zw1$OutUsH      ,na.rm=T)
zw1$FBornTc      <-zw1$FBornT      -mean(zw1$FBornT      ,na.rm=T)
zw1$FBornWc      <-zw1$FBornW      -mean(zw1$FBornW      ,na.rm=T)
zw1$FBornBc      <-zw1$FBornB      -mean(zw1$FBornB      ,na.rm=T)
zw1$FBornHc      <-zw1$FBornH      -mean(zw1$FBornH      ,na.rm=T)
zw1$NotCtzTc     <-zw1$NotCtzT     -mean(zw1$NotCtzT     ,na.rm=T)
zw1$NotCtzWc     <-zw1$NotCtzW     -mean(zw1$NotCtzW     ,na.rm=T)
zw1$NotCtzBc     <-zw1$NotCtzB     -mean(zw1$NotCtzB     ,na.rm=T)
zw1$NotCtzHc     <-zw1$NotCtzH     -mean(zw1$NotCtzH     ,na.rm=T)
zw1$MoveTc       <-zw1$MoveT       -mean(zw1$MoveT       ,na.rm=T)
zw1$MoveWc       <-zw1$MoveW       -mean(zw1$MoveW       ,na.rm=T)
zw1$MoveBc       <-zw1$MoveB       -mean(zw1$MoveB       ,na.rm=T)
zw1$MoveHc       <-zw1$MoveH       -mean(zw1$MoveH       ,na.rm=T)
zw1$VacantTc     <-zw1$VacantT     -mean(zw1$VacantT     ,na.rm=T)
zw1$OwnerTc      <-zw1$OwnerT      -mean(zw1$OwnerT      ,na.rm=T)
zw1$OwnerWc      <-zw1$OwnerW      -mean(zw1$OwnerW      ,na.rm=T)
zw1$OwnerBc      <-zw1$OwnerB      -mean(zw1$OwnerB      ,na.rm=T)
zw1$OwnerHc      <-zw1$OwnerH      -mean(zw1$OwnerH      ,na.rm=T)
zw1$CrowdTc      <-zw1$CrowdT      -mean(zw1$CrowdT      ,na.rm=T)
zw1$CrowdWc      <-zw1$CrowdW      -mean(zw1$CrowdW      ,na.rm=T)
zw1$CrowdBc      <-zw1$CrowdB      -mean(zw1$CrowdB      ,na.rm=T)
zw1$CrowdHc      <-zw1$CrowdH      -mean(zw1$CrowdH      ,na.rm=T)
zw1$MobileTc     <-zw1$MobileT     -mean(zw1$MobileT     ,na.rm=T)
zw1$MobileWc     <-zw1$MobileW     -mean(zw1$MobileW     ,na.rm=T)
zw1$MobileBc     <-zw1$MobileB     -mean(zw1$MobileB     ,na.rm=T)
zw1$MobileHc     <-zw1$MobileH     -mean(zw1$MobileH     ,na.rm=T)
zw1$DisablTc     <-zw1$DisablT     -mean(zw1$DisablT     ,na.rm=T)
zw1$DisablWc     <-zw1$DisablW     -mean(zw1$DisablW     ,na.rm=T)
zw1$DisablBc     <-zw1$DisablB     -mean(zw1$DisablB     ,na.rm=T)
zw1$DisablHc     <-zw1$DisablH     -mean(zw1$DisablH     ,na.rm=T)
zw1$DisablTCc    <-zw1$DisablTC    -mean(zw1$DisablTC    ,na.rm=T)
zw1$DisablWCc    <-zw1$DisablWC    -mean(zw1$DisablWC    ,na.rm=T)
zw1$DisablBCc    <-zw1$DisablBC    -mean(zw1$DisablBC    ,na.rm=T)
zw1$DisablHCc    <-zw1$DisablHC    -mean(zw1$DisablHC    ,na.rm=T)
zw1$DisablTMc    <-zw1$DisablTM    -mean(zw1$DisablTM    ,na.rm=T)
zw1$DisablTFc    <-zw1$DisablTF    -mean(zw1$DisablTF    ,na.rm=T)
zw1$Urban1c      <-zw1$Urban1      -mean(zw1$Urban1      ,na.rm=T)
zw1$Urban2c      <-zw1$Urban2      -mean(zw1$Urban2      ,na.rm=T)
zw1$ISBE_PFAc    <-zw1$ISBE_PFA    -mean(zw1$ISBE_PFA    ,na.rm=T)
zw1$ISBE_PFAEc   <-zw1$ISBE_PFAE   -mean(zw1$ISBE_PFAE   ,na.rm=T)
zw1$ISBE_PIc     <-zw1$ISBE_PI     -mean(zw1$ISBE_PI     ,na.rm=T)
zw1$HeadStartc   <-zw1$HeadStart   -mean(zw1$HeadStart   ,na.rm=T)
zw1$ElyHeadSc    <-zw1$ElyHeadS    -mean(zw1$ElyHeadS    ,na.rm=T)
zw1$HeadSAllc    <-zw1$HeadSAll    -mean(zw1$HeadSAll    ,na.rm=T)
zw1$PFA_HS1c     <-zw1$PFA_HS1     -mean(zw1$PFA_HS1     ,na.rm=T)
zw1$PFA_HS2c     <-zw1$PFA_HS2     -mean(zw1$PFA_HS2     ,na.rm=T)
zw1$LCCCc        <-zw1$LCCC        -mean(zw1$LCCC        ,na.rm=T)
zw1$LECCCc       <-zw1$LECCC       -mean(zw1$LECCC       ,na.rm=T)
zw1$LFCCc        <-zw1$LFCC        -mean(zw1$LFCC        ,na.rm=T)
zw1$LLECCCc      <-zw1$LLECCC      -mean(zw1$LLECCC      ,na.rm=T)
zw1$LCLFCCc      <-zw1$LCLFCC      -mean(zw1$LCLFCC      ,na.rm=T)
zw1$LCCCB1c      <-zw1$LCCCB1      -mean(zw1$LCCCB1      ,na.rm=T)
zw1$LCCCB2c      <-zw1$LCCCB2      -mean(zw1$LCCCB2      ,na.rm=T)
zw1$LCCB1c       <-zw1$LCCB1       -mean(zw1$LCCB1       ,na.rm=T)
zw1$LCCB2c       <-zw1$LCCB2       -mean(zw1$LCCB2       ,na.rm=T)
zw1$LCCCS1c      <-zw1$LCCCS1      -mean(zw1$LCCCS1      ,na.rm=T)
zw1$LCCCS2c      <-zw1$LCCCS2      -mean(zw1$LCCCS2      ,na.rm=T)
zw1$LCCS1c       <-zw1$LCCS1       -mean(zw1$LCCS1       ,na.rm=T)
zw1$LCCS2c       <-zw1$LCCS2       -mean(zw1$LCCS2       ,na.rm=T)
zw1$LCCCG1c      <-zw1$LCCCG1      -mean(zw1$LCCCG1      ,na.rm=T)
zw1$LCCCG2c      <-zw1$LCCCG2      -mean(zw1$LCCCG2      ,na.rm=T)
zw1$LCCG1c       <-zw1$LCCG1       -mean(zw1$LCCG1       ,na.rm=T)
zw1$LCCG2c       <-zw1$LCCG2       -mean(zw1$LCCG2       ,na.rm=T)
zw1$ChildCare1c  <-zw1$ChildCare1  -mean(zw1$ChildCare1  ,na.rm=T)
zw1$ChildCare2c  <-zw1$ChildCare2  -mean(zw1$ChildCare2  ,na.rm=T)
zw1$ChildCare3c  <-zw1$ChildCare3  -mean(zw1$ChildCare3  ,na.rm=T)
zw1$CCAPc        <-zw1$CCAP        -mean(zw1$CCAP        ,na.rm=T)
zw1$Homelessc    <-zw1$Homeless    -mean(zw1$Homeless    ,na.rm=T)
zw1$Homeless2c   <-zw1$Homeless2   -mean(zw1$Homeless2   ,na.rm=T)
zw1$DHS_HFIrc    <-zw1$DHS_HFIr    -mean(zw1$DHS_HFIr    ,na.rm=T)
zw1$DHS_PTSrc    <-zw1$DHS_PTSr    -mean(zw1$DHS_PTSr    ,na.rm=T)
zw1$DHS_HVPrc    <-zw1$DHS_HVPr    -mean(zw1$DHS_HVPr    ,na.rm=T)
zw1$IDHS_EIrc    <-zw1$IDHS_EIr    -mean(zw1$IDHS_EIr    ,na.rm=T)
zw1$MHV_C4c      <-zw1$MHV_C4      -mean(zw1$MHV_C4      ,na.rm=T)
zw1$MHV_P4c      <-zw1$MHV_P4      -mean(zw1$MHV_P4      ,na.rm=T)
zw1$MHV_C5c      <-zw1$MHV_C5      -mean(zw1$MHV_C5      ,na.rm=T)
zw1$MHV_P5c      <-zw1$MHV_P5      -mean(zw1$MHV_P5      ,na.rm=T)
zw1$FoodInsPc    <-zw1$FoodInsP    -mean(zw1$FoodInsP    ,na.rm=T)
zw1$FoodISc      <-zw1$FoodIS      -mean(zw1$FoodIS      ,na.rm=T)
zw1$RPovTc       <-zw1$RPovT       -mean(zw1$RPovT       ,na.rm=T)
zw1$PovTc        <-zw1$PovT        -mean(zw1$PovT        ,na.rm=T)
zw1$RPovWc       <-zw1$RPovW       -mean(zw1$RPovW       ,na.rm=T)
zw1$PovWc        <-zw1$PovW        -mean(zw1$PovW        ,na.rm=T)
zw1$MHV_C4k <-zw1$MHV_C4 *10
zw1$MHV_C5k <-zw1$MHV_C5 *10
zw1$MHV_C4kc<-zw1$MHV_C4c*10
zw1$MHV_C5kc<-zw1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zw2$Yearc        <-zw2$Year        -mean(zw2$Year        ,na.rm=T)
zw2$CPopBPc      <-zw2$CPopBP      -mean(zw2$CPopBP      ,na.rm=T)
zw2$CPopHPc      <-zw2$CPopHP      -mean(zw2$CPopHP      ,na.rm=T)
zw2$ChildPTc     <-zw2$ChildPT     -mean(zw2$ChildPT     ,na.rm=T)
zw2$ChildPWc     <-zw2$ChildPW     -mean(zw2$ChildPW     ,na.rm=T)
zw2$ChildPBc     <-zw2$ChildPB     -mean(zw2$ChildPB     ,na.rm=T)
zw2$ChildPHc     <-zw2$ChildPH     -mean(zw2$ChildPH     ,na.rm=T)
zw2$CARatioT100c <-zw2$CARatioT100 -mean(zw2$CARatioT100 ,na.rm=T)
zw2$CARatioW100c <-zw2$CARatioW100 -mean(zw2$CARatioW100 ,na.rm=T)
zw2$CARatioB100c <-zw2$CARatioB100 -mean(zw2$CARatioB100 ,na.rm=T)
zw2$CARatioH100c <-zw2$CARatioH100 -mean(zw2$CARatioH100 ,na.rm=T)
zw2$MalePTc      <-zw2$MalePT      -mean(zw2$MalePT      ,na.rm=T)
zw2$MalePWc      <-zw2$MalePW      -mean(zw2$MalePW      ,na.rm=T)
zw2$MalePBc      <-zw2$MalePB      -mean(zw2$MalePB      ,na.rm=T)
zw2$MalePHc      <-zw2$MalePH      -mean(zw2$MalePH      ,na.rm=T)
zw2$MFRatioT100c <-zw2$MFRatioT100 -mean(zw2$MFRatioT100 ,na.rm=T)
zw2$MFRatioW100c <-zw2$MFRatioW100 -mean(zw2$MFRatioW100 ,na.rm=T)
zw2$MFRatioB100c <-zw2$MFRatioB100 -mean(zw2$MFRatioB100 ,na.rm=T)
zw2$MFRatioH100c <-zw2$MFRatioH100 -mean(zw2$MFRatioH100 ,na.rm=T)
zw2$ElderTc      <-zw2$ElderT      -mean(zw2$ElderT      ,na.rm=T)
zw2$ElderWc      <-zw2$ElderW      -mean(zw2$ElderW      ,na.rm=T)
zw2$ElderBc      <-zw2$ElderB      -mean(zw2$ElderB      ,na.rm=T)
zw2$ElderHc      <-zw2$ElderH      -mean(zw2$ElderH      ,na.rm=T)
zw2$SingleTc     <-zw2$SingleT     -mean(zw2$SingleT     ,na.rm=T)
zw2$SingleWc     <-zw2$SingleW     -mean(zw2$SingleW     ,na.rm=T)
zw2$SingleBc     <-zw2$SingleB     -mean(zw2$SingleB     ,na.rm=T)
zw2$SingleHc     <-zw2$SingleH     -mean(zw2$SingleH     ,na.rm=T)
zw2$FHeadTc      <-zw2$FHeadT      -mean(zw2$FHeadT      ,na.rm=T)
zw2$FHeadWc      <-zw2$FHeadW      -mean(zw2$FHeadW      ,na.rm=T)
zw2$FHeadBc      <-zw2$FHeadB      -mean(zw2$FHeadB      ,na.rm=T)
zw2$FHeadHc      <-zw2$FHeadH      -mean(zw2$FHeadH      ,na.rm=T)
zw2$NoHighTc     <-zw2$NoHighT     -mean(zw2$NoHighT     ,na.rm=T)
zw2$NoHighWc     <-zw2$NoHighW     -mean(zw2$NoHighW     ,na.rm=T)
zw2$NoHighBc     <-zw2$NoHighB     -mean(zw2$NoHighB     ,na.rm=T)
zw2$NoHighHc     <-zw2$NoHighH     -mean(zw2$NoHighH     ,na.rm=T)
zw2$UnempTc      <-zw2$UnempT      -mean(zw2$UnempT      ,na.rm=T)
zw2$UnempWc      <-zw2$UnempW      -mean(zw2$UnempW      ,na.rm=T)
zw2$UnempBc      <-zw2$UnempB      -mean(zw2$UnempB      ,na.rm=T)
zw2$UnempHc      <-zw2$UnempH      -mean(zw2$UnempH      ,na.rm=T)
zw2$CPovTc       <-zw2$CPovT       -mean(zw2$CPovT       ,na.rm=T)
zw2$CPovWc       <-zw2$CPovW       -mean(zw2$CPovW       ,na.rm=T)
zw2$CPovBc       <-zw2$CPovB       -mean(zw2$CPovB       ,na.rm=T)
zw2$CPovHc       <-zw2$CPovH       -mean(zw2$CPovH       ,na.rm=T)
zw2$CPov1c       <-zw2$CPov1       -mean(zw2$CPov1       ,na.rm=T)
zw2$CPov2c       <-zw2$CPov2       -mean(zw2$CPov2       ,na.rm=T)
zw2$CPov3c       <-zw2$CPov3       -mean(zw2$CPov3       ,na.rm=T)
zw2$PubAsTc      <-zw2$PubAsT      -mean(zw2$PubAsT      ,na.rm=T)
zw2$WelfarTc     <-zw2$WelfarT     -mean(zw2$WelfarT     ,na.rm=T)
zw2$SnapTc       <-zw2$SnapT       -mean(zw2$SnapT       ,na.rm=T)
zw2$SnapWc       <-zw2$SnapW       -mean(zw2$SnapW       ,na.rm=T)
zw2$SnapBc       <-zw2$SnapB       -mean(zw2$SnapB       ,na.rm=T)
zw2$SnapHc       <-zw2$SnapH       -mean(zw2$SnapH       ,na.rm=T)
zw2$IncomeT1kc   <-zw2$IncomeT1k   -mean(zw2$IncomeT1k   ,na.rm=T)
zw2$IncomeW1kc   <-zw2$IncomeW1k   -mean(zw2$IncomeW1k   ,na.rm=T)
zw2$IncomeB1kc   <-zw2$IncomeB1k   -mean(zw2$IncomeB1k   ,na.rm=T)
zw2$IncomeH1kc   <-zw2$IncomeH1k   -mean(zw2$IncomeH1k   ,na.rm=T)
zw2$GiniT100c    <-zw2$GiniT100    -mean(zw2$GiniT100    ,na.rm=T)
zw2$HValueT10kc  <-zw2$HValueT10k  -mean(zw2$HValueT10k  ,na.rm=T)
zw2$MCostT100c   <-zw2$MCostT100   -mean(zw2$MCostT100   ,na.rm=T)
zw2$OCostDT100c  <-zw2$OCostDT100  -mean(zw2$OCostDT100  ,na.rm=T)
zw2$MRentDT100c  <-zw2$MRentDT100  -mean(zw2$MRentDT100  ,na.rm=T)
zw2$OCostPTc     <-zw2$OCostPT     -mean(zw2$OCostPT     ,na.rm=T)
zw2$MRentPTc     <-zw2$MRentPT     -mean(zw2$MRentPT     ,na.rm=T)
zw2$MortgTc      <-zw2$MortgT      -mean(zw2$MortgT      ,na.rm=T)
zw2$LangAPTc     <-zw2$LangAPT     -mean(zw2$LangAPT     ,na.rm=T)
zw2$LangAPWc     <-zw2$LangAPW     -mean(zw2$LangAPW     ,na.rm=T)
zw2$LangAPBc     <-zw2$LangAPB     -mean(zw2$LangAPB     ,na.rm=T)
zw2$LangAPHc     <-zw2$LangAPH     -mean(zw2$LangAPH     ,na.rm=T)
zw2$LangBPTc     <-zw2$LangBPT     -mean(zw2$LangBPT     ,na.rm=T)
zw2$LangBPWc     <-zw2$LangBPW     -mean(zw2$LangBPW     ,na.rm=T)
zw2$LangBPBc     <-zw2$LangBPB     -mean(zw2$LangBPB     ,na.rm=T)
zw2$LangBPHc     <-zw2$LangBPH     -mean(zw2$LangBPH     ,na.rm=T)
zw2$LangCPTc     <-zw2$LangCPT     -mean(zw2$LangCPT     ,na.rm=T)
zw2$OutUsTc      <-zw2$OutUsT      -mean(zw2$OutUsT      ,na.rm=T)
zw2$OutUsWc      <-zw2$OutUsW      -mean(zw2$OutUsW      ,na.rm=T)
zw2$OutUsBc      <-zw2$OutUsB      -mean(zw2$OutUsB      ,na.rm=T)
zw2$OutUsHc      <-zw2$OutUsH      -mean(zw2$OutUsH      ,na.rm=T)
zw2$FBornTc      <-zw2$FBornT      -mean(zw2$FBornT      ,na.rm=T)
zw2$FBornWc      <-zw2$FBornW      -mean(zw2$FBornW      ,na.rm=T)
zw2$FBornBc      <-zw2$FBornB      -mean(zw2$FBornB      ,na.rm=T)
zw2$FBornHc      <-zw2$FBornH      -mean(zw2$FBornH      ,na.rm=T)
zw2$NotCtzTc     <-zw2$NotCtzT     -mean(zw2$NotCtzT     ,na.rm=T)
zw2$NotCtzWc     <-zw2$NotCtzW     -mean(zw2$NotCtzW     ,na.rm=T)
zw2$NotCtzBc     <-zw2$NotCtzB     -mean(zw2$NotCtzB     ,na.rm=T)
zw2$NotCtzHc     <-zw2$NotCtzH     -mean(zw2$NotCtzH     ,na.rm=T)
zw2$MoveTc       <-zw2$MoveT       -mean(zw2$MoveT       ,na.rm=T)
zw2$MoveWc       <-zw2$MoveW       -mean(zw2$MoveW       ,na.rm=T)
zw2$MoveBc       <-zw2$MoveB       -mean(zw2$MoveB       ,na.rm=T)
zw2$MoveHc       <-zw2$MoveH       -mean(zw2$MoveH       ,na.rm=T)
zw2$VacantTc     <-zw2$VacantT     -mean(zw2$VacantT     ,na.rm=T)
zw2$OwnerTc      <-zw2$OwnerT      -mean(zw2$OwnerT      ,na.rm=T)
zw2$OwnerWc      <-zw2$OwnerW      -mean(zw2$OwnerW      ,na.rm=T)
zw2$OwnerBc      <-zw2$OwnerB      -mean(zw2$OwnerB      ,na.rm=T)
zw2$OwnerHc      <-zw2$OwnerH      -mean(zw2$OwnerH      ,na.rm=T)
zw2$CrowdTc      <-zw2$CrowdT      -mean(zw2$CrowdT      ,na.rm=T)
zw2$CrowdWc      <-zw2$CrowdW      -mean(zw2$CrowdW      ,na.rm=T)
zw2$CrowdBc      <-zw2$CrowdB      -mean(zw2$CrowdB      ,na.rm=T)
zw2$CrowdHc      <-zw2$CrowdH      -mean(zw2$CrowdH      ,na.rm=T)
zw2$MobileTc     <-zw2$MobileT     -mean(zw2$MobileT     ,na.rm=T)
zw2$MobileWc     <-zw2$MobileW     -mean(zw2$MobileW     ,na.rm=T)
zw2$MobileBc     <-zw2$MobileB     -mean(zw2$MobileB     ,na.rm=T)
zw2$MobileHc     <-zw2$MobileH     -mean(zw2$MobileH     ,na.rm=T)
zw2$DisablTc     <-zw2$DisablT     -mean(zw2$DisablT     ,na.rm=T)
zw2$DisablWc     <-zw2$DisablW     -mean(zw2$DisablW     ,na.rm=T)
zw2$DisablBc     <-zw2$DisablB     -mean(zw2$DisablB     ,na.rm=T)
zw2$DisablHc     <-zw2$DisablH     -mean(zw2$DisablH     ,na.rm=T)
zw2$DisablTCc    <-zw2$DisablTC    -mean(zw2$DisablTC    ,na.rm=T)
zw2$DisablWCc    <-zw2$DisablWC    -mean(zw2$DisablWC    ,na.rm=T)
zw2$DisablBCc    <-zw2$DisablBC    -mean(zw2$DisablBC    ,na.rm=T)
zw2$DisablHCc    <-zw2$DisablHC    -mean(zw2$DisablHC    ,na.rm=T)
zw2$DisablTMc    <-zw2$DisablTM    -mean(zw2$DisablTM    ,na.rm=T)
zw2$DisablTFc    <-zw2$DisablTF    -mean(zw2$DisablTF    ,na.rm=T)
zw2$Urban1c      <-zw2$Urban1      -mean(zw2$Urban1      ,na.rm=T)
zw2$Urban2c      <-zw2$Urban2      -mean(zw2$Urban2      ,na.rm=T)
zw2$ISBE_PFAc    <-zw2$ISBE_PFA    -mean(zw2$ISBE_PFA    ,na.rm=T)
zw2$ISBE_PFAEc   <-zw2$ISBE_PFAE   -mean(zw2$ISBE_PFAE   ,na.rm=T)
zw2$ISBE_PIc     <-zw2$ISBE_PI     -mean(zw2$ISBE_PI     ,na.rm=T)
zw2$HeadStartc   <-zw2$HeadStart   -mean(zw2$HeadStart   ,na.rm=T)
zw2$ElyHeadSc    <-zw2$ElyHeadS    -mean(zw2$ElyHeadS    ,na.rm=T)
zw2$HeadSAllc    <-zw2$HeadSAll    -mean(zw2$HeadSAll    ,na.rm=T)
zw2$PFA_HS1c     <-zw2$PFA_HS1     -mean(zw2$PFA_HS1     ,na.rm=T)
zw2$PFA_HS2c     <-zw2$PFA_HS2     -mean(zw2$PFA_HS2     ,na.rm=T)
zw2$LCCCc        <-zw2$LCCC        -mean(zw2$LCCC        ,na.rm=T)
zw2$LECCCc       <-zw2$LECCC       -mean(zw2$LECCC       ,na.rm=T)
zw2$LFCCc        <-zw2$LFCC        -mean(zw2$LFCC        ,na.rm=T)
zw2$LLECCCc      <-zw2$LLECCC      -mean(zw2$LLECCC      ,na.rm=T)
zw2$LCLFCCc      <-zw2$LCLFCC      -mean(zw2$LCLFCC      ,na.rm=T)
zw2$LCCCB1c      <-zw2$LCCCB1      -mean(zw2$LCCCB1      ,na.rm=T)
zw2$LCCCB2c      <-zw2$LCCCB2      -mean(zw2$LCCCB2      ,na.rm=T)
zw2$LCCB1c       <-zw2$LCCB1       -mean(zw2$LCCB1       ,na.rm=T)
zw2$LCCB2c       <-zw2$LCCB2       -mean(zw2$LCCB2       ,na.rm=T)
zw2$LCCCS1c      <-zw2$LCCCS1      -mean(zw2$LCCCS1      ,na.rm=T)
zw2$LCCCS2c      <-zw2$LCCCS2      -mean(zw2$LCCCS2      ,na.rm=T)
zw2$LCCS1c       <-zw2$LCCS1       -mean(zw2$LCCS1       ,na.rm=T)
zw2$LCCS2c       <-zw2$LCCS2       -mean(zw2$LCCS2       ,na.rm=T)
zw2$LCCCG1c      <-zw2$LCCCG1      -mean(zw2$LCCCG1      ,na.rm=T)
zw2$LCCCG2c      <-zw2$LCCCG2      -mean(zw2$LCCCG2      ,na.rm=T)
zw2$LCCG1c       <-zw2$LCCG1       -mean(zw2$LCCG1       ,na.rm=T)
zw2$LCCG2c       <-zw2$LCCG2       -mean(zw2$LCCG2       ,na.rm=T)
zw2$ChildCare1c  <-zw2$ChildCare1  -mean(zw2$ChildCare1  ,na.rm=T)
zw2$ChildCare2c  <-zw2$ChildCare2  -mean(zw2$ChildCare2  ,na.rm=T)
zw2$ChildCare3c  <-zw2$ChildCare3  -mean(zw2$ChildCare3  ,na.rm=T)
zw2$CCAPc        <-zw2$CCAP        -mean(zw2$CCAP        ,na.rm=T)
zw2$Homelessc    <-zw2$Homeless    -mean(zw2$Homeless    ,na.rm=T)
zw2$Homeless2c   <-zw2$Homeless2   -mean(zw2$Homeless2   ,na.rm=T)
zw2$DHS_HFIrc    <-zw2$DHS_HFIr    -mean(zw2$DHS_HFIr    ,na.rm=T)
zw2$DHS_PTSrc    <-zw2$DHS_PTSr    -mean(zw2$DHS_PTSr    ,na.rm=T)
zw2$DHS_HVPrc    <-zw2$DHS_HVPr    -mean(zw2$DHS_HVPr    ,na.rm=T)
zw2$IDHS_EIrc    <-zw2$IDHS_EIr    -mean(zw2$IDHS_EIr    ,na.rm=T)
zw2$MHV_C4c      <-zw2$MHV_C4      -mean(zw2$MHV_C4      ,na.rm=T)
zw2$MHV_P4c      <-zw2$MHV_P4      -mean(zw2$MHV_P4      ,na.rm=T)
zw2$MHV_C5c      <-zw2$MHV_C5      -mean(zw2$MHV_C5      ,na.rm=T)
zw2$MHV_P5c      <-zw2$MHV_P5      -mean(zw2$MHV_P5      ,na.rm=T)
zw2$FoodInsPc    <-zw2$FoodInsP    -mean(zw2$FoodInsP    ,na.rm=T)
zw2$FoodISc      <-zw2$FoodIS      -mean(zw2$FoodIS      ,na.rm=T)
zw2$RPovTc       <-zw2$RPovT       -mean(zw2$RPovT       ,na.rm=T)
zw2$PovTc        <-zw2$PovT        -mean(zw2$PovT        ,na.rm=T)
zw2$RPovWc       <-zw2$RPovW       -mean(zw2$RPovW       ,na.rm=T)
zw2$PovWc        <-zw2$PovW        -mean(zw2$PovW        ,na.rm=T)
zw2$MHV_C4k <-zw2$MHV_C4 *10
zw2$MHV_C5k <-zw2$MHV_C5 *10
zw2$MHV_C4kc<-zw2$MHV_C4c*10
zw2$MHV_C5kc<-zw2$MHV_C5c*10





# demean - within and between variables
zw<-cbind(zw,demean(zw,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovWc","PovTc","PovWc"
),group="CountyFIPS"))





# demean - within and between variables
zw1<-cbind(zw1,demean(zw1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovWc","PovTc","PovWc"
),group="CountyFIPS"))





# demean - within and between variables
zw2<-cbind(zw2,demean(zw2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovWc","PovTc","PovWc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Black
# Income - Black
# Income - Black
# Income - Black
# Income - Black
# Income - Black
# Income - Black
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zb$Yearc        <-zb$Year        -mean(zb$Year        ,na.rm=T)
zb$CPopBPc      <-zb$CPopBP      -mean(zb$CPopBP      ,na.rm=T)
zb$CPopHPc      <-zb$CPopHP      -mean(zb$CPopHP      ,na.rm=T)
zb$ChildPTc     <-zb$ChildPT     -mean(zb$ChildPT     ,na.rm=T)
zb$ChildPWc     <-zb$ChildPW     -mean(zb$ChildPW     ,na.rm=T)
zb$ChildPBc     <-zb$ChildPB     -mean(zb$ChildPB     ,na.rm=T)
zb$ChildPHc     <-zb$ChildPH     -mean(zb$ChildPH     ,na.rm=T)
zb$CARatioT100c <-zb$CARatioT100 -mean(zb$CARatioT100 ,na.rm=T)
zb$CARatioW100c <-zb$CARatioW100 -mean(zb$CARatioW100 ,na.rm=T)
zb$CARatioB100c <-zb$CARatioB100 -mean(zb$CARatioB100 ,na.rm=T)
zb$CARatioH100c <-zb$CARatioH100 -mean(zb$CARatioH100 ,na.rm=T)
zb$MalePTc      <-zb$MalePT      -mean(zb$MalePT      ,na.rm=T)
zb$MalePWc      <-zb$MalePW      -mean(zb$MalePW      ,na.rm=T)
zb$MalePBc      <-zb$MalePB      -mean(zb$MalePB      ,na.rm=T)
zb$MalePHc      <-zb$MalePH      -mean(zb$MalePH      ,na.rm=T)
zb$MFRatioT100c <-zb$MFRatioT100 -mean(zb$MFRatioT100 ,na.rm=T)
zb$MFRatioW100c <-zb$MFRatioW100 -mean(zb$MFRatioW100 ,na.rm=T)
zb$MFRatioB100c <-zb$MFRatioB100 -mean(zb$MFRatioB100 ,na.rm=T)
zb$MFRatioH100c <-zb$MFRatioH100 -mean(zb$MFRatioH100 ,na.rm=T)
zb$ElderTc      <-zb$ElderT      -mean(zb$ElderT      ,na.rm=T)
zb$ElderWc      <-zb$ElderW      -mean(zb$ElderW      ,na.rm=T)
zb$ElderBc      <-zb$ElderB      -mean(zb$ElderB      ,na.rm=T)
zb$ElderHc      <-zb$ElderH      -mean(zb$ElderH      ,na.rm=T)
zb$SingleTc     <-zb$SingleT     -mean(zb$SingleT     ,na.rm=T)
zb$SingleWc     <-zb$SingleW     -mean(zb$SingleW     ,na.rm=T)
zb$SingleBc     <-zb$SingleB     -mean(zb$SingleB     ,na.rm=T)
zb$SingleHc     <-zb$SingleH     -mean(zb$SingleH     ,na.rm=T)
zb$FHeadTc      <-zb$FHeadT      -mean(zb$FHeadT      ,na.rm=T)
zb$FHeadWc      <-zb$FHeadW      -mean(zb$FHeadW      ,na.rm=T)
zb$FHeadBc      <-zb$FHeadB      -mean(zb$FHeadB      ,na.rm=T)
zb$FHeadHc      <-zb$FHeadH      -mean(zb$FHeadH      ,na.rm=T)
zb$NoHighTc     <-zb$NoHighT     -mean(zb$NoHighT     ,na.rm=T)
zb$NoHighWc     <-zb$NoHighW     -mean(zb$NoHighW     ,na.rm=T)
zb$NoHighBc     <-zb$NoHighB     -mean(zb$NoHighB     ,na.rm=T)
zb$NoHighHc     <-zb$NoHighH     -mean(zb$NoHighH     ,na.rm=T)
zb$UnempTc      <-zb$UnempT      -mean(zb$UnempT      ,na.rm=T)
zb$UnempWc      <-zb$UnempW      -mean(zb$UnempW      ,na.rm=T)
zb$UnempBc      <-zb$UnempB      -mean(zb$UnempB      ,na.rm=T)
zb$UnempHc      <-zb$UnempH      -mean(zb$UnempH      ,na.rm=T)
zb$CPovTc       <-zb$CPovT       -mean(zb$CPovT       ,na.rm=T)
zb$CPovWc       <-zb$CPovW       -mean(zb$CPovW       ,na.rm=T)
zb$CPovBc       <-zb$CPovB       -mean(zb$CPovB       ,na.rm=T)
zb$CPovHc       <-zb$CPovH       -mean(zb$CPovH       ,na.rm=T)
zb$CPov1c       <-zb$CPov1       -mean(zb$CPov1       ,na.rm=T)
zb$CPov2c       <-zb$CPov2       -mean(zb$CPov2       ,na.rm=T)
zb$CPov3c       <-zb$CPov3       -mean(zb$CPov3       ,na.rm=T)
zb$PubAsTc      <-zb$PubAsT      -mean(zb$PubAsT      ,na.rm=T)
zb$WelfarTc     <-zb$WelfarT     -mean(zb$WelfarT     ,na.rm=T)
zb$SnapTc       <-zb$SnapT       -mean(zb$SnapT       ,na.rm=T)
zb$SnapWc       <-zb$SnapW       -mean(zb$SnapW       ,na.rm=T)
zb$SnapBc       <-zb$SnapB       -mean(zb$SnapB       ,na.rm=T)
zb$SnapHc       <-zb$SnapH       -mean(zb$SnapH       ,na.rm=T)
zb$IncomeT1kc   <-zb$IncomeT1k   -mean(zb$IncomeT1k   ,na.rm=T)
zb$IncomeW1kc   <-zb$IncomeW1k   -mean(zb$IncomeW1k   ,na.rm=T)
zb$IncomeB1kc   <-zb$IncomeB1k   -mean(zb$IncomeB1k   ,na.rm=T)
zb$IncomeH1kc   <-zb$IncomeH1k   -mean(zb$IncomeH1k   ,na.rm=T)
zb$GiniT100c    <-zb$GiniT100    -mean(zb$GiniT100    ,na.rm=T)
zb$HValueT10kc  <-zb$HValueT10k  -mean(zb$HValueT10k  ,na.rm=T)
zb$MCostT100c   <-zb$MCostT100   -mean(zb$MCostT100   ,na.rm=T)
zb$OCostDT100c  <-zb$OCostDT100  -mean(zb$OCostDT100  ,na.rm=T)
zb$MRentDT100c  <-zb$MRentDT100  -mean(zb$MRentDT100  ,na.rm=T)
zb$OCostPTc     <-zb$OCostPT     -mean(zb$OCostPT     ,na.rm=T)
zb$MRentPTc     <-zb$MRentPT     -mean(zb$MRentPT     ,na.rm=T)
zb$MortgTc      <-zb$MortgT      -mean(zb$MortgT      ,na.rm=T)
zb$LangAPTc     <-zb$LangAPT     -mean(zb$LangAPT     ,na.rm=T)
zb$LangAPWc     <-zb$LangAPW     -mean(zb$LangAPW     ,na.rm=T)
zb$LangAPBc     <-zb$LangAPB     -mean(zb$LangAPB     ,na.rm=T)
zb$LangAPHc     <-zb$LangAPH     -mean(zb$LangAPH     ,na.rm=T)
zb$LangBPTc     <-zb$LangBPT     -mean(zb$LangBPT     ,na.rm=T)
zb$LangBPWc     <-zb$LangBPW     -mean(zb$LangBPW     ,na.rm=T)
zb$LangBPBc     <-zb$LangBPB     -mean(zb$LangBPB     ,na.rm=T)
zb$LangBPHc     <-zb$LangBPH     -mean(zb$LangBPH     ,na.rm=T)
zb$LangCPTc     <-zb$LangCPT     -mean(zb$LangCPT     ,na.rm=T)
zb$OutUsTc      <-zb$OutUsT      -mean(zb$OutUsT      ,na.rm=T)
zb$OutUsWc      <-zb$OutUsW      -mean(zb$OutUsW      ,na.rm=T)
zb$OutUsBc      <-zb$OutUsB      -mean(zb$OutUsB      ,na.rm=T)
zb$OutUsHc      <-zb$OutUsH      -mean(zb$OutUsH      ,na.rm=T)
zb$FBornTc      <-zb$FBornT      -mean(zb$FBornT      ,na.rm=T)
zb$FBornWc      <-zb$FBornW      -mean(zb$FBornW      ,na.rm=T)
zb$FBornBc      <-zb$FBornB      -mean(zb$FBornB      ,na.rm=T)
zb$FBornHc      <-zb$FBornH      -mean(zb$FBornH      ,na.rm=T)
zb$NotCtzTc     <-zb$NotCtzT     -mean(zb$NotCtzT     ,na.rm=T)
zb$NotCtzWc     <-zb$NotCtzW     -mean(zb$NotCtzW     ,na.rm=T)
zb$NotCtzBc     <-zb$NotCtzB     -mean(zb$NotCtzB     ,na.rm=T)
zb$NotCtzHc     <-zb$NotCtzH     -mean(zb$NotCtzH     ,na.rm=T)
zb$MoveTc       <-zb$MoveT       -mean(zb$MoveT       ,na.rm=T)
zb$MoveWc       <-zb$MoveW       -mean(zb$MoveW       ,na.rm=T)
zb$MoveBc       <-zb$MoveB       -mean(zb$MoveB       ,na.rm=T)
zb$MoveHc       <-zb$MoveH       -mean(zb$MoveH       ,na.rm=T)
zb$VacantTc     <-zb$VacantT     -mean(zb$VacantT     ,na.rm=T)
zb$OwnerTc      <-zb$OwnerT      -mean(zb$OwnerT      ,na.rm=T)
zb$OwnerWc      <-zb$OwnerW      -mean(zb$OwnerW      ,na.rm=T)
zb$OwnerBc      <-zb$OwnerB      -mean(zb$OwnerB      ,na.rm=T)
zb$OwnerHc      <-zb$OwnerH      -mean(zb$OwnerH      ,na.rm=T)
zb$CrowdTc      <-zb$CrowdT      -mean(zb$CrowdT      ,na.rm=T)
zb$CrowdWc      <-zb$CrowdW      -mean(zb$CrowdW      ,na.rm=T)
zb$CrowdBc      <-zb$CrowdB      -mean(zb$CrowdB      ,na.rm=T)
zb$CrowdHc      <-zb$CrowdH      -mean(zb$CrowdH      ,na.rm=T)
zb$MobileTc     <-zb$MobileT     -mean(zb$MobileT     ,na.rm=T)
zb$MobileWc     <-zb$MobileW     -mean(zb$MobileW     ,na.rm=T)
zb$MobileBc     <-zb$MobileB     -mean(zb$MobileB     ,na.rm=T)
zb$MobileHc     <-zb$MobileH     -mean(zb$MobileH     ,na.rm=T)
zb$DisablTc     <-zb$DisablT     -mean(zb$DisablT     ,na.rm=T)
zb$DisablWc     <-zb$DisablW     -mean(zb$DisablW     ,na.rm=T)
zb$DisablBc     <-zb$DisablB     -mean(zb$DisablB     ,na.rm=T)
zb$DisablHc     <-zb$DisablH     -mean(zb$DisablH     ,na.rm=T)
zb$DisablTCc    <-zb$DisablTC    -mean(zb$DisablTC    ,na.rm=T)
zb$DisablWCc    <-zb$DisablWC    -mean(zb$DisablWC    ,na.rm=T)
zb$DisablBCc    <-zb$DisablBC    -mean(zb$DisablBC    ,na.rm=T)
zb$DisablHCc    <-zb$DisablHC    -mean(zb$DisablHC    ,na.rm=T)
zb$DisablTMc    <-zb$DisablTM    -mean(zb$DisablTM    ,na.rm=T)
zb$DisablTFc    <-zb$DisablTF    -mean(zb$DisablTF    ,na.rm=T)
zb$Urban1c      <-zb$Urban1      -mean(zb$Urban1      ,na.rm=T)
zb$Urban2c      <-zb$Urban2      -mean(zb$Urban2      ,na.rm=T)
zb$ISBE_PFAc    <-zb$ISBE_PFA    -mean(zb$ISBE_PFA    ,na.rm=T)
zb$ISBE_PFAEc   <-zb$ISBE_PFAE   -mean(zb$ISBE_PFAE   ,na.rm=T)
zb$ISBE_PIc     <-zb$ISBE_PI     -mean(zb$ISBE_PI     ,na.rm=T)
zb$HeadStartc   <-zb$HeadStart   -mean(zb$HeadStart   ,na.rm=T)
zb$ElyHeadSc    <-zb$ElyHeadS    -mean(zb$ElyHeadS    ,na.rm=T)
zb$HeadSAllc    <-zb$HeadSAll    -mean(zb$HeadSAll    ,na.rm=T)
zb$PFA_HS1c     <-zb$PFA_HS1     -mean(zb$PFA_HS1     ,na.rm=T)
zb$PFA_HS2c     <-zb$PFA_HS2     -mean(zb$PFA_HS2     ,na.rm=T)
zb$LCCCc        <-zb$LCCC        -mean(zb$LCCC        ,na.rm=T)
zb$LECCCc       <-zb$LECCC       -mean(zb$LECCC       ,na.rm=T)
zb$LFCCc        <-zb$LFCC        -mean(zb$LFCC        ,na.rm=T)
zb$LLECCCc      <-zb$LLECCC      -mean(zb$LLECCC      ,na.rm=T)
zb$LCLFCCc      <-zb$LCLFCC      -mean(zb$LCLFCC      ,na.rm=T)
zb$LCCCB1c      <-zb$LCCCB1      -mean(zb$LCCCB1      ,na.rm=T)
zb$LCCCB2c      <-zb$LCCCB2      -mean(zb$LCCCB2      ,na.rm=T)
zb$LCCB1c       <-zb$LCCB1       -mean(zb$LCCB1       ,na.rm=T)
zb$LCCB2c       <-zb$LCCB2       -mean(zb$LCCB2       ,na.rm=T)
zb$LCCCS1c      <-zb$LCCCS1      -mean(zb$LCCCS1      ,na.rm=T)
zb$LCCCS2c      <-zb$LCCCS2      -mean(zb$LCCCS2      ,na.rm=T)
zb$LCCS1c       <-zb$LCCS1       -mean(zb$LCCS1       ,na.rm=T)
zb$LCCS2c       <-zb$LCCS2       -mean(zb$LCCS2       ,na.rm=T)
zb$LCCCG1c      <-zb$LCCCG1      -mean(zb$LCCCG1      ,na.rm=T)
zb$LCCCG2c      <-zb$LCCCG2      -mean(zb$LCCCG2      ,na.rm=T)
zb$LCCG1c       <-zb$LCCG1       -mean(zb$LCCG1       ,na.rm=T)
zb$LCCG2c       <-zb$LCCG2       -mean(zb$LCCG2       ,na.rm=T)
zb$ChildCare1c  <-zb$ChildCare1  -mean(zb$ChildCare1  ,na.rm=T)
zb$ChildCare2c  <-zb$ChildCare2  -mean(zb$ChildCare2  ,na.rm=T)
zb$ChildCare3c  <-zb$ChildCare3  -mean(zb$ChildCare3  ,na.rm=T)
zb$CCAPc        <-zb$CCAP        -mean(zb$CCAP        ,na.rm=T)
zb$Homelessc    <-zb$Homeless    -mean(zb$Homeless    ,na.rm=T)
zb$Homeless2c   <-zb$Homeless2   -mean(zb$Homeless2   ,na.rm=T)
zb$DHS_HFIrc    <-zb$DHS_HFIr    -mean(zb$DHS_HFIr    ,na.rm=T)
zb$DHS_PTSrc    <-zb$DHS_PTSr    -mean(zb$DHS_PTSr    ,na.rm=T)
zb$DHS_HVPrc    <-zb$DHS_HVPr    -mean(zb$DHS_HVPr    ,na.rm=T)
zb$IDHS_EIrc    <-zb$IDHS_EIr    -mean(zb$IDHS_EIr    ,na.rm=T)
zb$MHV_C4c      <-zb$MHV_C4      -mean(zb$MHV_C4      ,na.rm=T)
zb$MHV_P4c      <-zb$MHV_P4      -mean(zb$MHV_P4      ,na.rm=T)
zb$MHV_C5c      <-zb$MHV_C5      -mean(zb$MHV_C5      ,na.rm=T)
zb$MHV_P5c      <-zb$MHV_P5      -mean(zb$MHV_P5      ,na.rm=T)
zb$FoodInsPc    <-zb$FoodInsP    -mean(zb$FoodInsP    ,na.rm=T)
zb$FoodISc      <-zb$FoodIS      -mean(zb$FoodIS      ,na.rm=T)
zb$RPovTc       <-zb$RPovT       -mean(zb$RPovT       ,na.rm=T)
zb$PovTc        <-zb$PovT        -mean(zb$PovT        ,na.rm=T)
zb$RPovBc       <-zb$RPovB       -mean(zb$RPovB       ,na.rm=T)
zb$PovBc        <-zb$PovB        -mean(zb$PovB        ,na.rm=T)
zb$MHV_C4k <-zb$MHV_C4 *10
zb$MHV_C5k <-zb$MHV_C5 *10
zb$MHV_C4kc<-zb$MHV_C4c*10
zb$MHV_C5kc<-zb$MHV_C5c*10




# Centering Variables - for sensitivity analysis (child population > 500)
zb1$Yearc        <-zb1$Year        -mean(zb1$Year        ,na.rm=T)
zb1$CPopBPc      <-zb1$CPopBP      -mean(zb1$CPopBP      ,na.rm=T)
zb1$CPopHPc      <-zb1$CPopHP      -mean(zb1$CPopHP      ,na.rm=T)
zb1$ChildPTc     <-zb1$ChildPT     -mean(zb1$ChildPT     ,na.rm=T)
zb1$ChildPWc     <-zb1$ChildPW     -mean(zb1$ChildPW     ,na.rm=T)
zb1$ChildPBc     <-zb1$ChildPB     -mean(zb1$ChildPB     ,na.rm=T)
zb1$ChildPHc     <-zb1$ChildPH     -mean(zb1$ChildPH     ,na.rm=T)
zb1$CARatioT100c <-zb1$CARatioT100 -mean(zb1$CARatioT100 ,na.rm=T)
zb1$CARatioW100c <-zb1$CARatioW100 -mean(zb1$CARatioW100 ,na.rm=T)
zb1$CARatioB100c <-zb1$CARatioB100 -mean(zb1$CARatioB100 ,na.rm=T)
zb1$CARatioH100c <-zb1$CARatioH100 -mean(zb1$CARatioH100 ,na.rm=T)
zb1$MalePTc      <-zb1$MalePT      -mean(zb1$MalePT      ,na.rm=T)
zb1$MalePWc      <-zb1$MalePW      -mean(zb1$MalePW      ,na.rm=T)
zb1$MalePBc      <-zb1$MalePB      -mean(zb1$MalePB      ,na.rm=T)
zb1$MalePHc      <-zb1$MalePH      -mean(zb1$MalePH      ,na.rm=T)
zb1$MFRatioT100c <-zb1$MFRatioT100 -mean(zb1$MFRatioT100 ,na.rm=T)
zb1$MFRatioW100c <-zb1$MFRatioW100 -mean(zb1$MFRatioW100 ,na.rm=T)
zb1$MFRatioB100c <-zb1$MFRatioB100 -mean(zb1$MFRatioB100 ,na.rm=T)
zb1$MFRatioH100c <-zb1$MFRatioH100 -mean(zb1$MFRatioH100 ,na.rm=T)
zb1$ElderTc      <-zb1$ElderT      -mean(zb1$ElderT      ,na.rm=T)
zb1$ElderWc      <-zb1$ElderW      -mean(zb1$ElderW      ,na.rm=T)
zb1$ElderBc      <-zb1$ElderB      -mean(zb1$ElderB      ,na.rm=T)
zb1$ElderHc      <-zb1$ElderH      -mean(zb1$ElderH      ,na.rm=T)
zb1$SingleTc     <-zb1$SingleT     -mean(zb1$SingleT     ,na.rm=T)
zb1$SingleWc     <-zb1$SingleW     -mean(zb1$SingleW     ,na.rm=T)
zb1$SingleBc     <-zb1$SingleB     -mean(zb1$SingleB     ,na.rm=T)
zb1$SingleHc     <-zb1$SingleH     -mean(zb1$SingleH     ,na.rm=T)
zb1$FHeadTc      <-zb1$FHeadT      -mean(zb1$FHeadT      ,na.rm=T)
zb1$FHeadWc      <-zb1$FHeadW      -mean(zb1$FHeadW      ,na.rm=T)
zb1$FHeadBc      <-zb1$FHeadB      -mean(zb1$FHeadB      ,na.rm=T)
zb1$FHeadHc      <-zb1$FHeadH      -mean(zb1$FHeadH      ,na.rm=T)
zb1$NoHighTc     <-zb1$NoHighT     -mean(zb1$NoHighT     ,na.rm=T)
zb1$NoHighWc     <-zb1$NoHighW     -mean(zb1$NoHighW     ,na.rm=T)
zb1$NoHighBc     <-zb1$NoHighB     -mean(zb1$NoHighB     ,na.rm=T)
zb1$NoHighHc     <-zb1$NoHighH     -mean(zb1$NoHighH     ,na.rm=T)
zb1$UnempTc      <-zb1$UnempT      -mean(zb1$UnempT      ,na.rm=T)
zb1$UnempWc      <-zb1$UnempW      -mean(zb1$UnempW      ,na.rm=T)
zb1$UnempBc      <-zb1$UnempB      -mean(zb1$UnempB      ,na.rm=T)
zb1$UnempHc      <-zb1$UnempH      -mean(zb1$UnempH      ,na.rm=T)
zb1$CPovTc       <-zb1$CPovT       -mean(zb1$CPovT       ,na.rm=T)
zb1$CPovWc       <-zb1$CPovW       -mean(zb1$CPovW       ,na.rm=T)
zb1$CPovBc       <-zb1$CPovB       -mean(zb1$CPovB       ,na.rm=T)
zb1$CPovHc       <-zb1$CPovH       -mean(zb1$CPovH       ,na.rm=T)
zb1$CPov1c       <-zb1$CPov1       -mean(zb1$CPov1       ,na.rm=T)
zb1$CPov2c       <-zb1$CPov2       -mean(zb1$CPov2       ,na.rm=T)
zb1$CPov3c       <-zb1$CPov3       -mean(zb1$CPov3       ,na.rm=T)
zb1$PubAsTc      <-zb1$PubAsT      -mean(zb1$PubAsT      ,na.rm=T)
zb1$WelfarTc     <-zb1$WelfarT     -mean(zb1$WelfarT     ,na.rm=T)
zb1$SnapTc       <-zb1$SnapT       -mean(zb1$SnapT       ,na.rm=T)
zb1$SnapWc       <-zb1$SnapW       -mean(zb1$SnapW       ,na.rm=T)
zb1$SnapBc       <-zb1$SnapB       -mean(zb1$SnapB       ,na.rm=T)
zb1$SnapHc       <-zb1$SnapH       -mean(zb1$SnapH       ,na.rm=T)
zb1$IncomeT1kc   <-zb1$IncomeT1k   -mean(zb1$IncomeT1k   ,na.rm=T)
zb1$IncomeW1kc   <-zb1$IncomeW1k   -mean(zb1$IncomeW1k   ,na.rm=T)
zb1$IncomeB1kc   <-zb1$IncomeB1k   -mean(zb1$IncomeB1k   ,na.rm=T)
zb1$IncomeH1kc   <-zb1$IncomeH1k   -mean(zb1$IncomeH1k   ,na.rm=T)
zb1$GiniT100c    <-zb1$GiniT100    -mean(zb1$GiniT100    ,na.rm=T)
zb1$HValueT10kc  <-zb1$HValueT10k  -mean(zb1$HValueT10k  ,na.rm=T)
zb1$MCostT100c   <-zb1$MCostT100   -mean(zb1$MCostT100   ,na.rm=T)
zb1$OCostDT100c  <-zb1$OCostDT100  -mean(zb1$OCostDT100  ,na.rm=T)
zb1$MRentDT100c  <-zb1$MRentDT100  -mean(zb1$MRentDT100  ,na.rm=T)
zb1$OCostPTc     <-zb1$OCostPT     -mean(zb1$OCostPT     ,na.rm=T)
zb1$MRentPTc     <-zb1$MRentPT     -mean(zb1$MRentPT     ,na.rm=T)
zb1$MortgTc      <-zb1$MortgT      -mean(zb1$MortgT      ,na.rm=T)
zb1$LangAPTc     <-zb1$LangAPT     -mean(zb1$LangAPT     ,na.rm=T)
zb1$LangAPWc     <-zb1$LangAPW     -mean(zb1$LangAPW     ,na.rm=T)
zb1$LangAPBc     <-zb1$LangAPB     -mean(zb1$LangAPB     ,na.rm=T)
zb1$LangAPHc     <-zb1$LangAPH     -mean(zb1$LangAPH     ,na.rm=T)
zb1$LangBPTc     <-zb1$LangBPT     -mean(zb1$LangBPT     ,na.rm=T)
zb1$LangBPWc     <-zb1$LangBPW     -mean(zb1$LangBPW     ,na.rm=T)
zb1$LangBPBc     <-zb1$LangBPB     -mean(zb1$LangBPB     ,na.rm=T)
zb1$LangBPHc     <-zb1$LangBPH     -mean(zb1$LangBPH     ,na.rm=T)
zb1$LangCPTc     <-zb1$LangCPT     -mean(zb1$LangCPT     ,na.rm=T)
zb1$OutUsTc      <-zb1$OutUsT      -mean(zb1$OutUsT      ,na.rm=T)
zb1$OutUsWc      <-zb1$OutUsW      -mean(zb1$OutUsW      ,na.rm=T)
zb1$OutUsBc      <-zb1$OutUsB      -mean(zb1$OutUsB      ,na.rm=T)
zb1$OutUsHc      <-zb1$OutUsH      -mean(zb1$OutUsH      ,na.rm=T)
zb1$FBornTc      <-zb1$FBornT      -mean(zb1$FBornT      ,na.rm=T)
zb1$FBornWc      <-zb1$FBornW      -mean(zb1$FBornW      ,na.rm=T)
zb1$FBornBc      <-zb1$FBornB      -mean(zb1$FBornB      ,na.rm=T)
zb1$FBornHc      <-zb1$FBornH      -mean(zb1$FBornH      ,na.rm=T)
zb1$NotCtzTc     <-zb1$NotCtzT     -mean(zb1$NotCtzT     ,na.rm=T)
zb1$NotCtzWc     <-zb1$NotCtzW     -mean(zb1$NotCtzW     ,na.rm=T)
zb1$NotCtzBc     <-zb1$NotCtzB     -mean(zb1$NotCtzB     ,na.rm=T)
zb1$NotCtzHc     <-zb1$NotCtzH     -mean(zb1$NotCtzH     ,na.rm=T)
zb1$MoveTc       <-zb1$MoveT       -mean(zb1$MoveT       ,na.rm=T)
zb1$MoveWc       <-zb1$MoveW       -mean(zb1$MoveW       ,na.rm=T)
zb1$MoveBc       <-zb1$MoveB       -mean(zb1$MoveB       ,na.rm=T)
zb1$MoveHc       <-zb1$MoveH       -mean(zb1$MoveH       ,na.rm=T)
zb1$VacantTc     <-zb1$VacantT     -mean(zb1$VacantT     ,na.rm=T)
zb1$OwnerTc      <-zb1$OwnerT      -mean(zb1$OwnerT      ,na.rm=T)
zb1$OwnerWc      <-zb1$OwnerW      -mean(zb1$OwnerW      ,na.rm=T)
zb1$OwnerBc      <-zb1$OwnerB      -mean(zb1$OwnerB      ,na.rm=T)
zb1$OwnerHc      <-zb1$OwnerH      -mean(zb1$OwnerH      ,na.rm=T)
zb1$CrowdTc      <-zb1$CrowdT      -mean(zb1$CrowdT      ,na.rm=T)
zb1$CrowdWc      <-zb1$CrowdW      -mean(zb1$CrowdW      ,na.rm=T)
zb1$CrowdBc      <-zb1$CrowdB      -mean(zb1$CrowdB      ,na.rm=T)
zb1$CrowdHc      <-zb1$CrowdH      -mean(zb1$CrowdH      ,na.rm=T)
zb1$MobileTc     <-zb1$MobileT     -mean(zb1$MobileT     ,na.rm=T)
zb1$MobileWc     <-zb1$MobileW     -mean(zb1$MobileW     ,na.rm=T)
zb1$MobileBc     <-zb1$MobileB     -mean(zb1$MobileB     ,na.rm=T)
zb1$MobileHc     <-zb1$MobileH     -mean(zb1$MobileH     ,na.rm=T)
zb1$DisablTc     <-zb1$DisablT     -mean(zb1$DisablT     ,na.rm=T)
zb1$DisablWc     <-zb1$DisablW     -mean(zb1$DisablW     ,na.rm=T)
zb1$DisablBc     <-zb1$DisablB     -mean(zb1$DisablB     ,na.rm=T)
zb1$DisablHc     <-zb1$DisablH     -mean(zb1$DisablH     ,na.rm=T)
zb1$DisablTCc    <-zb1$DisablTC    -mean(zb1$DisablTC    ,na.rm=T)
zb1$DisablWCc    <-zb1$DisablWC    -mean(zb1$DisablWC    ,na.rm=T)
zb1$DisablBCc    <-zb1$DisablBC    -mean(zb1$DisablBC    ,na.rm=T)
zb1$DisablHCc    <-zb1$DisablHC    -mean(zb1$DisablHC    ,na.rm=T)
zb1$DisablTMc    <-zb1$DisablTM    -mean(zb1$DisablTM    ,na.rm=T)
zb1$DisablTFc    <-zb1$DisablTF    -mean(zb1$DisablTF    ,na.rm=T)
zb1$Urban1c      <-zb1$Urban1      -mean(zb1$Urban1      ,na.rm=T)
zb1$Urban2c      <-zb1$Urban2      -mean(zb1$Urban2      ,na.rm=T)
zb1$ISBE_PFAc    <-zb1$ISBE_PFA    -mean(zb1$ISBE_PFA    ,na.rm=T)
zb1$ISBE_PFAEc   <-zb1$ISBE_PFAE   -mean(zb1$ISBE_PFAE   ,na.rm=T)
zb1$ISBE_PIc     <-zb1$ISBE_PI     -mean(zb1$ISBE_PI     ,na.rm=T)
zb1$HeadStartc   <-zb1$HeadStart   -mean(zb1$HeadStart   ,na.rm=T)
zb1$ElyHeadSc    <-zb1$ElyHeadS    -mean(zb1$ElyHeadS    ,na.rm=T)
zb1$HeadSAllc    <-zb1$HeadSAll    -mean(zb1$HeadSAll    ,na.rm=T)
zb1$PFA_HS1c     <-zb1$PFA_HS1     -mean(zb1$PFA_HS1     ,na.rm=T)
zb1$PFA_HS2c     <-zb1$PFA_HS2     -mean(zb1$PFA_HS2     ,na.rm=T)
zb1$LCCCc        <-zb1$LCCC        -mean(zb1$LCCC        ,na.rm=T)
zb1$LECCCc       <-zb1$LECCC       -mean(zb1$LECCC       ,na.rm=T)
zb1$LFCCc        <-zb1$LFCC        -mean(zb1$LFCC        ,na.rm=T)
zb1$LLECCCc      <-zb1$LLECCC      -mean(zb1$LLECCC      ,na.rm=T)
zb1$LCLFCCc      <-zb1$LCLFCC      -mean(zb1$LCLFCC      ,na.rm=T)
zb1$LCCCB1c      <-zb1$LCCCB1      -mean(zb1$LCCCB1      ,na.rm=T)
zb1$LCCCB2c      <-zb1$LCCCB2      -mean(zb1$LCCCB2      ,na.rm=T)
zb1$LCCB1c       <-zb1$LCCB1       -mean(zb1$LCCB1       ,na.rm=T)
zb1$LCCB2c       <-zb1$LCCB2       -mean(zb1$LCCB2       ,na.rm=T)
zb1$LCCCS1c      <-zb1$LCCCS1      -mean(zb1$LCCCS1      ,na.rm=T)
zb1$LCCCS2c      <-zb1$LCCCS2      -mean(zb1$LCCCS2      ,na.rm=T)
zb1$LCCS1c       <-zb1$LCCS1       -mean(zb1$LCCS1       ,na.rm=T)
zb1$LCCS2c       <-zb1$LCCS2       -mean(zb1$LCCS2       ,na.rm=T)
zb1$LCCCG1c      <-zb1$LCCCG1      -mean(zb1$LCCCG1      ,na.rm=T)
zb1$LCCCG2c      <-zb1$LCCCG2      -mean(zb1$LCCCG2      ,na.rm=T)
zb1$LCCG1c       <-zb1$LCCG1       -mean(zb1$LCCG1       ,na.rm=T)
zb1$LCCG2c       <-zb1$LCCG2       -mean(zb1$LCCG2       ,na.rm=T)
zb1$ChildCare1c  <-zb1$ChildCare1  -mean(zb1$ChildCare1  ,na.rm=T)
zb1$ChildCare2c  <-zb1$ChildCare2  -mean(zb1$ChildCare2  ,na.rm=T)
zb1$ChildCare3c  <-zb1$ChildCare3  -mean(zb1$ChildCare3  ,na.rm=T)
zb1$CCAPc        <-zb1$CCAP        -mean(zb1$CCAP        ,na.rm=T)
zb1$Homelessc    <-zb1$Homeless    -mean(zb1$Homeless    ,na.rm=T)
zb1$Homeless2c   <-zb1$Homeless2   -mean(zb1$Homeless2   ,na.rm=T)
zb1$DHS_HFIrc    <-zb1$DHS_HFIr    -mean(zb1$DHS_HFIr    ,na.rm=T)
zb1$DHS_PTSrc    <-zb1$DHS_PTSr    -mean(zb1$DHS_PTSr    ,na.rm=T)
zb1$DHS_HVPrc    <-zb1$DHS_HVPr    -mean(zb1$DHS_HVPr    ,na.rm=T)
zb1$IDHS_EIrc    <-zb1$IDHS_EIr    -mean(zb1$IDHS_EIr    ,na.rm=T)
zb1$MHV_C4c      <-zb1$MHV_C4      -mean(zb1$MHV_C4      ,na.rm=T)
zb1$MHV_P4c      <-zb1$MHV_P4      -mean(zb1$MHV_P4      ,na.rm=T)
zb1$MHV_C5c      <-zb1$MHV_C5      -mean(zb1$MHV_C5      ,na.rm=T)
zb1$MHV_P5c      <-zb1$MHV_P5      -mean(zb1$MHV_P5      ,na.rm=T)
zb1$FoodInsPc    <-zb1$FoodInsP    -mean(zb1$FoodInsP    ,na.rm=T)
zb1$FoodISc      <-zb1$FoodIS      -mean(zb1$FoodIS      ,na.rm=T)
zb1$RPovTc       <-zb1$RPovT       -mean(zb1$RPovT       ,na.rm=T)
zb1$PovTc        <-zb1$PovT        -mean(zb1$PovT        ,na.rm=T)
zb1$RPovBc       <-zb1$RPovB       -mean(zb1$RPovB       ,na.rm=T)
zb1$PovBc        <-zb1$PovB        -mean(zb1$PovB        ,na.rm=T)
zb1$MHV_C4k <-zb1$MHV_C4 *10
zb1$MHV_C5k <-zb1$MHV_C5 *10
zb1$MHV_C4kc<-zb1$MHV_C4c*10
zb1$MHV_C5kc<-zb1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zb2$Yearc        <-zb2$Year        -mean(zb2$Year        ,na.rm=T)
zb2$CPopBPc      <-zb2$CPopBP      -mean(zb2$CPopBP      ,na.rm=T)
zb2$CPopHPc      <-zb2$CPopHP      -mean(zb2$CPopHP      ,na.rm=T)
zb2$ChildPTc     <-zb2$ChildPT     -mean(zb2$ChildPT     ,na.rm=T)
zb2$ChildPWc     <-zb2$ChildPW     -mean(zb2$ChildPW     ,na.rm=T)
zb2$ChildPBc     <-zb2$ChildPB     -mean(zb2$ChildPB     ,na.rm=T)
zb2$ChildPHc     <-zb2$ChildPH     -mean(zb2$ChildPH     ,na.rm=T)
zb2$CARatioT100c <-zb2$CARatioT100 -mean(zb2$CARatioT100 ,na.rm=T)
zb2$CARatioW100c <-zb2$CARatioW100 -mean(zb2$CARatioW100 ,na.rm=T)
zb2$CARatioB100c <-zb2$CARatioB100 -mean(zb2$CARatioB100 ,na.rm=T)
zb2$CARatioH100c <-zb2$CARatioH100 -mean(zb2$CARatioH100 ,na.rm=T)
zb2$MalePTc      <-zb2$MalePT      -mean(zb2$MalePT      ,na.rm=T)
zb2$MalePWc      <-zb2$MalePW      -mean(zb2$MalePW      ,na.rm=T)
zb2$MalePBc      <-zb2$MalePB      -mean(zb2$MalePB      ,na.rm=T)
zb2$MalePHc      <-zb2$MalePH      -mean(zb2$MalePH      ,na.rm=T)
zb2$MFRatioT100c <-zb2$MFRatioT100 -mean(zb2$MFRatioT100 ,na.rm=T)
zb2$MFRatioW100c <-zb2$MFRatioW100 -mean(zb2$MFRatioW100 ,na.rm=T)
zb2$MFRatioB100c <-zb2$MFRatioB100 -mean(zb2$MFRatioB100 ,na.rm=T)
zb2$MFRatioH100c <-zb2$MFRatioH100 -mean(zb2$MFRatioH100 ,na.rm=T)
zb2$ElderTc      <-zb2$ElderT      -mean(zb2$ElderT      ,na.rm=T)
zb2$ElderWc      <-zb2$ElderW      -mean(zb2$ElderW      ,na.rm=T)
zb2$ElderBc      <-zb2$ElderB      -mean(zb2$ElderB      ,na.rm=T)
zb2$ElderHc      <-zb2$ElderH      -mean(zb2$ElderH      ,na.rm=T)
zb2$SingleTc     <-zb2$SingleT     -mean(zb2$SingleT     ,na.rm=T)
zb2$SingleWc     <-zb2$SingleW     -mean(zb2$SingleW     ,na.rm=T)
zb2$SingleBc     <-zb2$SingleB     -mean(zb2$SingleB     ,na.rm=T)
zb2$SingleHc     <-zb2$SingleH     -mean(zb2$SingleH     ,na.rm=T)
zb2$FHeadTc      <-zb2$FHeadT      -mean(zb2$FHeadT      ,na.rm=T)
zb2$FHeadWc      <-zb2$FHeadW      -mean(zb2$FHeadW      ,na.rm=T)
zb2$FHeadBc      <-zb2$FHeadB      -mean(zb2$FHeadB      ,na.rm=T)
zb2$FHeadHc      <-zb2$FHeadH      -mean(zb2$FHeadH      ,na.rm=T)
zb2$NoHighTc     <-zb2$NoHighT     -mean(zb2$NoHighT     ,na.rm=T)
zb2$NoHighWc     <-zb2$NoHighW     -mean(zb2$NoHighW     ,na.rm=T)
zb2$NoHighBc     <-zb2$NoHighB     -mean(zb2$NoHighB     ,na.rm=T)
zb2$NoHighHc     <-zb2$NoHighH     -mean(zb2$NoHighH     ,na.rm=T)
zb2$UnempTc      <-zb2$UnempT      -mean(zb2$UnempT      ,na.rm=T)
zb2$UnempWc      <-zb2$UnempW      -mean(zb2$UnempW      ,na.rm=T)
zb2$UnempBc      <-zb2$UnempB      -mean(zb2$UnempB      ,na.rm=T)
zb2$UnempHc      <-zb2$UnempH      -mean(zb2$UnempH      ,na.rm=T)
zb2$CPovTc       <-zb2$CPovT       -mean(zb2$CPovT       ,na.rm=T)
zb2$CPovWc       <-zb2$CPovW       -mean(zb2$CPovW       ,na.rm=T)
zb2$CPovBc       <-zb2$CPovB       -mean(zb2$CPovB       ,na.rm=T)
zb2$CPovHc       <-zb2$CPovH       -mean(zb2$CPovH       ,na.rm=T)
zb2$CPov1c       <-zb2$CPov1       -mean(zb2$CPov1       ,na.rm=T)
zb2$CPov2c       <-zb2$CPov2       -mean(zb2$CPov2       ,na.rm=T)
zb2$CPov3c       <-zb2$CPov3       -mean(zb2$CPov3       ,na.rm=T)
zb2$PubAsTc      <-zb2$PubAsT      -mean(zb2$PubAsT      ,na.rm=T)
zb2$WelfarTc     <-zb2$WelfarT     -mean(zb2$WelfarT     ,na.rm=T)
zb2$SnapTc       <-zb2$SnapT       -mean(zb2$SnapT       ,na.rm=T)
zb2$SnapWc       <-zb2$SnapW       -mean(zb2$SnapW       ,na.rm=T)
zb2$SnapBc       <-zb2$SnapB       -mean(zb2$SnapB       ,na.rm=T)
zb2$SnapHc       <-zb2$SnapH       -mean(zb2$SnapH       ,na.rm=T)
zb2$IncomeT1kc   <-zb2$IncomeT1k   -mean(zb2$IncomeT1k   ,na.rm=T)
zb2$IncomeW1kc   <-zb2$IncomeW1k   -mean(zb2$IncomeW1k   ,na.rm=T)
zb2$IncomeB1kc   <-zb2$IncomeB1k   -mean(zb2$IncomeB1k   ,na.rm=T)
zb2$IncomeH1kc   <-zb2$IncomeH1k   -mean(zb2$IncomeH1k   ,na.rm=T)
zb2$GiniT100c    <-zb2$GiniT100    -mean(zb2$GiniT100    ,na.rm=T)
zb2$HValueT10kc  <-zb2$HValueT10k  -mean(zb2$HValueT10k  ,na.rm=T)
zb2$MCostT100c   <-zb2$MCostT100   -mean(zb2$MCostT100   ,na.rm=T)
zb2$OCostDT100c  <-zb2$OCostDT100  -mean(zb2$OCostDT100  ,na.rm=T)
zb2$MRentDT100c  <-zb2$MRentDT100  -mean(zb2$MRentDT100  ,na.rm=T)
zb2$OCostPTc     <-zb2$OCostPT     -mean(zb2$OCostPT     ,na.rm=T)
zb2$MRentPTc     <-zb2$MRentPT     -mean(zb2$MRentPT     ,na.rm=T)
zb2$MortgTc      <-zb2$MortgT      -mean(zb2$MortgT      ,na.rm=T)
zb2$LangAPTc     <-zb2$LangAPT     -mean(zb2$LangAPT     ,na.rm=T)
zb2$LangAPWc     <-zb2$LangAPW     -mean(zb2$LangAPW     ,na.rm=T)
zb2$LangAPBc     <-zb2$LangAPB     -mean(zb2$LangAPB     ,na.rm=T)
zb2$LangAPHc     <-zb2$LangAPH     -mean(zb2$LangAPH     ,na.rm=T)
zb2$LangBPTc     <-zb2$LangBPT     -mean(zb2$LangBPT     ,na.rm=T)
zb2$LangBPWc     <-zb2$LangBPW     -mean(zb2$LangBPW     ,na.rm=T)
zb2$LangBPBc     <-zb2$LangBPB     -mean(zb2$LangBPB     ,na.rm=T)
zb2$LangBPHc     <-zb2$LangBPH     -mean(zb2$LangBPH     ,na.rm=T)
zb2$LangCPTc     <-zb2$LangCPT     -mean(zb2$LangCPT     ,na.rm=T)
zb2$OutUsTc      <-zb2$OutUsT      -mean(zb2$OutUsT      ,na.rm=T)
zb2$OutUsWc      <-zb2$OutUsW      -mean(zb2$OutUsW      ,na.rm=T)
zb2$OutUsBc      <-zb2$OutUsB      -mean(zb2$OutUsB      ,na.rm=T)
zb2$OutUsHc      <-zb2$OutUsH      -mean(zb2$OutUsH      ,na.rm=T)
zb2$FBornTc      <-zb2$FBornT      -mean(zb2$FBornT      ,na.rm=T)
zb2$FBornWc      <-zb2$FBornW      -mean(zb2$FBornW      ,na.rm=T)
zb2$FBornBc      <-zb2$FBornB      -mean(zb2$FBornB      ,na.rm=T)
zb2$FBornHc      <-zb2$FBornH      -mean(zb2$FBornH      ,na.rm=T)
zb2$NotCtzTc     <-zb2$NotCtzT     -mean(zb2$NotCtzT     ,na.rm=T)
zb2$NotCtzWc     <-zb2$NotCtzW     -mean(zb2$NotCtzW     ,na.rm=T)
zb2$NotCtzBc     <-zb2$NotCtzB     -mean(zb2$NotCtzB     ,na.rm=T)
zb2$NotCtzHc     <-zb2$NotCtzH     -mean(zb2$NotCtzH     ,na.rm=T)
zb2$MoveTc       <-zb2$MoveT       -mean(zb2$MoveT       ,na.rm=T)
zb2$MoveWc       <-zb2$MoveW       -mean(zb2$MoveW       ,na.rm=T)
zb2$MoveBc       <-zb2$MoveB       -mean(zb2$MoveB       ,na.rm=T)
zb2$MoveHc       <-zb2$MoveH       -mean(zb2$MoveH       ,na.rm=T)
zb2$VacantTc     <-zb2$VacantT     -mean(zb2$VacantT     ,na.rm=T)
zb2$OwnerTc      <-zb2$OwnerT      -mean(zb2$OwnerT      ,na.rm=T)
zb2$OwnerWc      <-zb2$OwnerW      -mean(zb2$OwnerW      ,na.rm=T)
zb2$OwnerBc      <-zb2$OwnerB      -mean(zb2$OwnerB      ,na.rm=T)
zb2$OwnerHc      <-zb2$OwnerH      -mean(zb2$OwnerH      ,na.rm=T)
zb2$CrowdTc      <-zb2$CrowdT      -mean(zb2$CrowdT      ,na.rm=T)
zb2$CrowdWc      <-zb2$CrowdW      -mean(zb2$CrowdW      ,na.rm=T)
zb2$CrowdBc      <-zb2$CrowdB      -mean(zb2$CrowdB      ,na.rm=T)
zb2$CrowdHc      <-zb2$CrowdH      -mean(zb2$CrowdH      ,na.rm=T)
zb2$MobileTc     <-zb2$MobileT     -mean(zb2$MobileT     ,na.rm=T)
zb2$MobileWc     <-zb2$MobileW     -mean(zb2$MobileW     ,na.rm=T)
zb2$MobileBc     <-zb2$MobileB     -mean(zb2$MobileB     ,na.rm=T)
zb2$MobileHc     <-zb2$MobileH     -mean(zb2$MobileH     ,na.rm=T)
zb2$DisablTc     <-zb2$DisablT     -mean(zb2$DisablT     ,na.rm=T)
zb2$DisablWc     <-zb2$DisablW     -mean(zb2$DisablW     ,na.rm=T)
zb2$DisablBc     <-zb2$DisablB     -mean(zb2$DisablB     ,na.rm=T)
zb2$DisablHc     <-zb2$DisablH     -mean(zb2$DisablH     ,na.rm=T)
zb2$DisablTCc    <-zb2$DisablTC    -mean(zb2$DisablTC    ,na.rm=T)
zb2$DisablWCc    <-zb2$DisablWC    -mean(zb2$DisablWC    ,na.rm=T)
zb2$DisablBCc    <-zb2$DisablBC    -mean(zb2$DisablBC    ,na.rm=T)
zb2$DisablHCc    <-zb2$DisablHC    -mean(zb2$DisablHC    ,na.rm=T)
zb2$DisablTMc    <-zb2$DisablTM    -mean(zb2$DisablTM    ,na.rm=T)
zb2$DisablTFc    <-zb2$DisablTF    -mean(zb2$DisablTF    ,na.rm=T)
zb2$Urban1c      <-zb2$Urban1      -mean(zb2$Urban1      ,na.rm=T)
zb2$Urban2c      <-zb2$Urban2      -mean(zb2$Urban2      ,na.rm=T)
zb2$ISBE_PFAc    <-zb2$ISBE_PFA    -mean(zb2$ISBE_PFA    ,na.rm=T)
zb2$ISBE_PFAEc   <-zb2$ISBE_PFAE   -mean(zb2$ISBE_PFAE   ,na.rm=T)
zb2$ISBE_PIc     <-zb2$ISBE_PI     -mean(zb2$ISBE_PI     ,na.rm=T)
zb2$HeadStartc   <-zb2$HeadStart   -mean(zb2$HeadStart   ,na.rm=T)
zb2$ElyHeadSc    <-zb2$ElyHeadS    -mean(zb2$ElyHeadS    ,na.rm=T)
zb2$HeadSAllc    <-zb2$HeadSAll    -mean(zb2$HeadSAll    ,na.rm=T)
zb2$PFA_HS1c     <-zb2$PFA_HS1     -mean(zb2$PFA_HS1     ,na.rm=T)
zb2$PFA_HS2c     <-zb2$PFA_HS2     -mean(zb2$PFA_HS2     ,na.rm=T)
zb2$LCCCc        <-zb2$LCCC        -mean(zb2$LCCC        ,na.rm=T)
zb2$LECCCc       <-zb2$LECCC       -mean(zb2$LECCC       ,na.rm=T)
zb2$LFCCc        <-zb2$LFCC        -mean(zb2$LFCC        ,na.rm=T)
zb2$LLECCCc      <-zb2$LLECCC      -mean(zb2$LLECCC      ,na.rm=T)
zb2$LCLFCCc      <-zb2$LCLFCC      -mean(zb2$LCLFCC      ,na.rm=T)
zb2$LCCCB1c      <-zb2$LCCCB1      -mean(zb2$LCCCB1      ,na.rm=T)
zb2$LCCCB2c      <-zb2$LCCCB2      -mean(zb2$LCCCB2      ,na.rm=T)
zb2$LCCB1c       <-zb2$LCCB1       -mean(zb2$LCCB1       ,na.rm=T)
zb2$LCCB2c       <-zb2$LCCB2       -mean(zb2$LCCB2       ,na.rm=T)
zb2$LCCCS1c      <-zb2$LCCCS1      -mean(zb2$LCCCS1      ,na.rm=T)
zb2$LCCCS2c      <-zb2$LCCCS2      -mean(zb2$LCCCS2      ,na.rm=T)
zb2$LCCS1c       <-zb2$LCCS1       -mean(zb2$LCCS1       ,na.rm=T)
zb2$LCCS2c       <-zb2$LCCS2       -mean(zb2$LCCS2       ,na.rm=T)
zb2$LCCCG1c      <-zb2$LCCCG1      -mean(zb2$LCCCG1      ,na.rm=T)
zb2$LCCCG2c      <-zb2$LCCCG2      -mean(zb2$LCCCG2      ,na.rm=T)
zb2$LCCG1c       <-zb2$LCCG1       -mean(zb2$LCCG1       ,na.rm=T)
zb2$LCCG2c       <-zb2$LCCG2       -mean(zb2$LCCG2       ,na.rm=T)
zb2$ChildCare1c  <-zb2$ChildCare1  -mean(zb2$ChildCare1  ,na.rm=T)
zb2$ChildCare2c  <-zb2$ChildCare2  -mean(zb2$ChildCare2  ,na.rm=T)
zb2$ChildCare3c  <-zb2$ChildCare3  -mean(zb2$ChildCare3  ,na.rm=T)
zb2$CCAPc        <-zb2$CCAP        -mean(zb2$CCAP        ,na.rm=T)
zb2$Homelessc    <-zb2$Homeless    -mean(zb2$Homeless    ,na.rm=T)
zb2$Homeless2c   <-zb2$Homeless2   -mean(zb2$Homeless2   ,na.rm=T)
zb2$DHS_HFIrc    <-zb2$DHS_HFIr    -mean(zb2$DHS_HFIr    ,na.rm=T)
zb2$DHS_PTSrc    <-zb2$DHS_PTSr    -mean(zb2$DHS_PTSr    ,na.rm=T)
zb2$DHS_HVPrc    <-zb2$DHS_HVPr    -mean(zb2$DHS_HVPr    ,na.rm=T)
zb2$IDHS_EIrc    <-zb2$IDHS_EIr    -mean(zb2$IDHS_EIr    ,na.rm=T)
zb2$MHV_C4c      <-zb2$MHV_C4      -mean(zb2$MHV_C4      ,na.rm=T)
zb2$MHV_P4c      <-zb2$MHV_P4      -mean(zb2$MHV_P4      ,na.rm=T)
zb2$MHV_C5c      <-zb2$MHV_C5      -mean(zb2$MHV_C5      ,na.rm=T)
zb2$MHV_P5c      <-zb2$MHV_P5      -mean(zb2$MHV_P5      ,na.rm=T)
zb2$FoodInsPc    <-zb2$FoodInsP    -mean(zb2$FoodInsP    ,na.rm=T)
zb2$FoodISc      <-zb2$FoodIS      -mean(zb2$FoodIS      ,na.rm=T)
zb2$RPovTc       <-zb2$RPovT       -mean(zb2$RPovT       ,na.rm=T)
zb2$PovTc        <-zb2$PovT        -mean(zb2$PovT        ,na.rm=T)
zb2$RPovBc       <-zb2$RPovB       -mean(zb2$RPovB       ,na.rm=T)
zb2$PovBc        <-zb2$PovB        -mean(zb2$PovB        ,na.rm=T)
zb2$MHV_C4k <-zb2$MHV_C4 *10
zb2$MHV_C5k <-zb2$MHV_C5 *10
zb2$MHV_C4kc<-zb2$MHV_C4c*10
zb2$MHV_C5kc<-zb2$MHV_C5c*10





# demean - within and between variables
zb<-cbind(zb,demean(zb,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovBc","PovTc","PovBc"
),group="CountyFIPS"))





# demean - within and between variables
zb1<-cbind(zb1,demean(zb1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovBc","PovTc","PovBc"
),group="CountyFIPS"))





# demean - within and between variables
zb2<-cbind(zb2,demean(zb2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovBc","PovTc","PovBc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Income - Hispanic
# Income - Hispanic
# Income - Hispanic
# Income - Hispanic
# Income - Hispanic
# Income - Hispanic
# Income - Hispanic
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zh$Yearc        <-zh$Year        -mean(zh$Year        ,na.rm=T)
zh$CPopBPc      <-zh$CPopBP      -mean(zh$CPopBP      ,na.rm=T)
zh$CPopHPc      <-zh$CPopHP      -mean(zh$CPopHP      ,na.rm=T)
zh$ChildPTc     <-zh$ChildPT     -mean(zh$ChildPT     ,na.rm=T)
zh$ChildPWc     <-zh$ChildPW     -mean(zh$ChildPW     ,na.rm=T)
zh$ChildPBc     <-zh$ChildPB     -mean(zh$ChildPB     ,na.rm=T)
zh$ChildPHc     <-zh$ChildPH     -mean(zh$ChildPH     ,na.rm=T)
zh$CARatioT100c <-zh$CARatioT100 -mean(zh$CARatioT100 ,na.rm=T)
zh$CARatioW100c <-zh$CARatioW100 -mean(zh$CARatioW100 ,na.rm=T)
zh$CARatioB100c <-zh$CARatioB100 -mean(zh$CARatioB100 ,na.rm=T)
zh$CARatioH100c <-zh$CARatioH100 -mean(zh$CARatioH100 ,na.rm=T)
zh$MalePTc      <-zh$MalePT      -mean(zh$MalePT      ,na.rm=T)
zh$MalePWc      <-zh$MalePW      -mean(zh$MalePW      ,na.rm=T)
zh$MalePBc      <-zh$MalePB      -mean(zh$MalePB      ,na.rm=T)
zh$MalePHc      <-zh$MalePH      -mean(zh$MalePH      ,na.rm=T)
zh$MFRatioT100c <-zh$MFRatioT100 -mean(zh$MFRatioT100 ,na.rm=T)
zh$MFRatioW100c <-zh$MFRatioW100 -mean(zh$MFRatioW100 ,na.rm=T)
zh$MFRatioB100c <-zh$MFRatioB100 -mean(zh$MFRatioB100 ,na.rm=T)
zh$MFRatioH100c <-zh$MFRatioH100 -mean(zh$MFRatioH100 ,na.rm=T)
zh$ElderTc      <-zh$ElderT      -mean(zh$ElderT      ,na.rm=T)
zh$ElderWc      <-zh$ElderW      -mean(zh$ElderW      ,na.rm=T)
zh$ElderBc      <-zh$ElderB      -mean(zh$ElderB      ,na.rm=T)
zh$ElderHc      <-zh$ElderH      -mean(zh$ElderH      ,na.rm=T)
zh$SingleTc     <-zh$SingleT     -mean(zh$SingleT     ,na.rm=T)
zh$SingleWc     <-zh$SingleW     -mean(zh$SingleW     ,na.rm=T)
zh$SingleBc     <-zh$SingleB     -mean(zh$SingleB     ,na.rm=T)
zh$SingleHc     <-zh$SingleH     -mean(zh$SingleH     ,na.rm=T)
zh$FHeadTc      <-zh$FHeadT      -mean(zh$FHeadT      ,na.rm=T)
zh$FHeadWc      <-zh$FHeadW      -mean(zh$FHeadW      ,na.rm=T)
zh$FHeadBc      <-zh$FHeadB      -mean(zh$FHeadB      ,na.rm=T)
zh$FHeadHc      <-zh$FHeadH      -mean(zh$FHeadH      ,na.rm=T)
zh$NoHighTc     <-zh$NoHighT     -mean(zh$NoHighT     ,na.rm=T)
zh$NoHighWc     <-zh$NoHighW     -mean(zh$NoHighW     ,na.rm=T)
zh$NoHighBc     <-zh$NoHighB     -mean(zh$NoHighB     ,na.rm=T)
zh$NoHighHc     <-zh$NoHighH     -mean(zh$NoHighH     ,na.rm=T)
zh$UnempTc      <-zh$UnempT      -mean(zh$UnempT      ,na.rm=T)
zh$UnempWc      <-zh$UnempW      -mean(zh$UnempW      ,na.rm=T)
zh$UnempBc      <-zh$UnempB      -mean(zh$UnempB      ,na.rm=T)
zh$UnempHc      <-zh$UnempH      -mean(zh$UnempH      ,na.rm=T)
zh$CPovTc       <-zh$CPovT       -mean(zh$CPovT       ,na.rm=T)
zh$CPovWc       <-zh$CPovW       -mean(zh$CPovW       ,na.rm=T)
zh$CPovBc       <-zh$CPovB       -mean(zh$CPovB       ,na.rm=T)
zh$CPovHc       <-zh$CPovH       -mean(zh$CPovH       ,na.rm=T)
zh$CPov1c       <-zh$CPov1       -mean(zh$CPov1       ,na.rm=T)
zh$CPov2c       <-zh$CPov2       -mean(zh$CPov2       ,na.rm=T)
zh$CPov3c       <-zh$CPov3       -mean(zh$CPov3       ,na.rm=T)
zh$PubAsTc      <-zh$PubAsT      -mean(zh$PubAsT      ,na.rm=T)
zh$WelfarTc     <-zh$WelfarT     -mean(zh$WelfarT     ,na.rm=T)
zh$SnapTc       <-zh$SnapT       -mean(zh$SnapT       ,na.rm=T)
zh$SnapWc       <-zh$SnapW       -mean(zh$SnapW       ,na.rm=T)
zh$SnapBc       <-zh$SnapB       -mean(zh$SnapB       ,na.rm=T)
zh$SnapHc       <-zh$SnapH       -mean(zh$SnapH       ,na.rm=T)
zh$IncomeT1kc   <-zh$IncomeT1k   -mean(zh$IncomeT1k   ,na.rm=T)
zh$IncomeW1kc   <-zh$IncomeW1k   -mean(zh$IncomeW1k   ,na.rm=T)
zh$IncomeB1kc   <-zh$IncomeB1k   -mean(zh$IncomeB1k   ,na.rm=T)
zh$IncomeH1kc   <-zh$IncomeH1k   -mean(zh$IncomeH1k   ,na.rm=T)
zh$GiniT100c    <-zh$GiniT100    -mean(zh$GiniT100    ,na.rm=T)
zh$HValueT10kc  <-zh$HValueT10k  -mean(zh$HValueT10k  ,na.rm=T)
zh$MCostT100c   <-zh$MCostT100   -mean(zh$MCostT100   ,na.rm=T)
zh$OCostDT100c  <-zh$OCostDT100  -mean(zh$OCostDT100  ,na.rm=T)
zh$MRentDT100c  <-zh$MRentDT100  -mean(zh$MRentDT100  ,na.rm=T)
zh$OCostPTc     <-zh$OCostPT     -mean(zh$OCostPT     ,na.rm=T)
zh$MRentPTc     <-zh$MRentPT     -mean(zh$MRentPT     ,na.rm=T)
zh$MortgTc      <-zh$MortgT      -mean(zh$MortgT      ,na.rm=T)
zh$LangAPTc     <-zh$LangAPT     -mean(zh$LangAPT     ,na.rm=T)
zh$LangAPWc     <-zh$LangAPW     -mean(zh$LangAPW     ,na.rm=T)
zh$LangAPBc     <-zh$LangAPB     -mean(zh$LangAPB     ,na.rm=T)
zh$LangAPHc     <-zh$LangAPH     -mean(zh$LangAPH     ,na.rm=T)
zh$LangBPTc     <-zh$LangBPT     -mean(zh$LangBPT     ,na.rm=T)
zh$LangBPWc     <-zh$LangBPW     -mean(zh$LangBPW     ,na.rm=T)
zh$LangBPBc     <-zh$LangBPB     -mean(zh$LangBPB     ,na.rm=T)
zh$LangBPHc     <-zh$LangBPH     -mean(zh$LangBPH     ,na.rm=T)
zh$LangCPTc     <-zh$LangCPT     -mean(zh$LangCPT     ,na.rm=T)
zh$OutUsTc      <-zh$OutUsT      -mean(zh$OutUsT      ,na.rm=T)
zh$OutUsWc      <-zh$OutUsW      -mean(zh$OutUsW      ,na.rm=T)
zh$OutUsBc      <-zh$OutUsB      -mean(zh$OutUsB      ,na.rm=T)
zh$OutUsHc      <-zh$OutUsH      -mean(zh$OutUsH      ,na.rm=T)
zh$FBornTc      <-zh$FBornT      -mean(zh$FBornT      ,na.rm=T)
zh$FBornWc      <-zh$FBornW      -mean(zh$FBornW      ,na.rm=T)
zh$FBornBc      <-zh$FBornB      -mean(zh$FBornB      ,na.rm=T)
zh$FBornHc      <-zh$FBornH      -mean(zh$FBornH      ,na.rm=T)
zh$NotCtzTc     <-zh$NotCtzT     -mean(zh$NotCtzT     ,na.rm=T)
zh$NotCtzWc     <-zh$NotCtzW     -mean(zh$NotCtzW     ,na.rm=T)
zh$NotCtzBc     <-zh$NotCtzB     -mean(zh$NotCtzB     ,na.rm=T)
zh$NotCtzHc     <-zh$NotCtzH     -mean(zh$NotCtzH     ,na.rm=T)
zh$MoveTc       <-zh$MoveT       -mean(zh$MoveT       ,na.rm=T)
zh$MoveWc       <-zh$MoveW       -mean(zh$MoveW       ,na.rm=T)
zh$MoveBc       <-zh$MoveB       -mean(zh$MoveB       ,na.rm=T)
zh$MoveHc       <-zh$MoveH       -mean(zh$MoveH       ,na.rm=T)
zh$VacantTc     <-zh$VacantT     -mean(zh$VacantT     ,na.rm=T)
zh$OwnerTc      <-zh$OwnerT      -mean(zh$OwnerT      ,na.rm=T)
zh$OwnerWc      <-zh$OwnerW      -mean(zh$OwnerW      ,na.rm=T)
zh$OwnerBc      <-zh$OwnerB      -mean(zh$OwnerB      ,na.rm=T)
zh$OwnerHc      <-zh$OwnerH      -mean(zh$OwnerH      ,na.rm=T)
zh$CrowdTc      <-zh$CrowdT      -mean(zh$CrowdT      ,na.rm=T)
zh$CrowdWc      <-zh$CrowdW      -mean(zh$CrowdW      ,na.rm=T)
zh$CrowdBc      <-zh$CrowdB      -mean(zh$CrowdB      ,na.rm=T)
zh$CrowdHc      <-zh$CrowdH      -mean(zh$CrowdH      ,na.rm=T)
zh$MobileTc     <-zh$MobileT     -mean(zh$MobileT     ,na.rm=T)
zh$MobileWc     <-zh$MobileW     -mean(zh$MobileW     ,na.rm=T)
zh$MobileBc     <-zh$MobileB     -mean(zh$MobileB     ,na.rm=T)
zh$MobileHc     <-zh$MobileH     -mean(zh$MobileH     ,na.rm=T)
zh$DisablTc     <-zh$DisablT     -mean(zh$DisablT     ,na.rm=T)
zh$DisablWc     <-zh$DisablW     -mean(zh$DisablW     ,na.rm=T)
zh$DisablBc     <-zh$DisablB     -mean(zh$DisablB     ,na.rm=T)
zh$DisablHc     <-zh$DisablH     -mean(zh$DisablH     ,na.rm=T)
zh$DisablTCc    <-zh$DisablTC    -mean(zh$DisablTC    ,na.rm=T)
zh$DisablWCc    <-zh$DisablWC    -mean(zh$DisablWC    ,na.rm=T)
zh$DisablBCc    <-zh$DisablBC    -mean(zh$DisablBC    ,na.rm=T)
zh$DisablHCc    <-zh$DisablHC    -mean(zh$DisablHC    ,na.rm=T)
zh$DisablTMc    <-zh$DisablTM    -mean(zh$DisablTM    ,na.rm=T)
zh$DisablTFc    <-zh$DisablTF    -mean(zh$DisablTF    ,na.rm=T)
zh$Urban1c      <-zh$Urban1      -mean(zh$Urban1      ,na.rm=T)
zh$Urban2c      <-zh$Urban2      -mean(zh$Urban2      ,na.rm=T)
zh$ISBE_PFAc    <-zh$ISBE_PFA    -mean(zh$ISBE_PFA    ,na.rm=T)
zh$ISBE_PFAEc   <-zh$ISBE_PFAE   -mean(zh$ISBE_PFAE   ,na.rm=T)
zh$ISBE_PIc     <-zh$ISBE_PI     -mean(zh$ISBE_PI     ,na.rm=T)
zh$HeadStartc   <-zh$HeadStart   -mean(zh$HeadStart   ,na.rm=T)
zh$ElyHeadSc    <-zh$ElyHeadS    -mean(zh$ElyHeadS    ,na.rm=T)
zh$HeadSAllc    <-zh$HeadSAll    -mean(zh$HeadSAll    ,na.rm=T)
zh$PFA_HS1c     <-zh$PFA_HS1     -mean(zh$PFA_HS1     ,na.rm=T)
zh$PFA_HS2c     <-zh$PFA_HS2     -mean(zh$PFA_HS2     ,na.rm=T)
zh$LCCCc        <-zh$LCCC        -mean(zh$LCCC        ,na.rm=T)
zh$LECCCc       <-zh$LECCC       -mean(zh$LECCC       ,na.rm=T)
zh$LFCCc        <-zh$LFCC        -mean(zh$LFCC        ,na.rm=T)
zh$LLECCCc      <-zh$LLECCC      -mean(zh$LLECCC      ,na.rm=T)
zh$LCLFCCc      <-zh$LCLFCC      -mean(zh$LCLFCC      ,na.rm=T)
zh$LCCCB1c      <-zh$LCCCB1      -mean(zh$LCCCB1      ,na.rm=T)
zh$LCCCB2c      <-zh$LCCCB2      -mean(zh$LCCCB2      ,na.rm=T)
zh$LCCB1c       <-zh$LCCB1       -mean(zh$LCCB1       ,na.rm=T)
zh$LCCB2c       <-zh$LCCB2       -mean(zh$LCCB2       ,na.rm=T)
zh$LCCCS1c      <-zh$LCCCS1      -mean(zh$LCCCS1      ,na.rm=T)
zh$LCCCS2c      <-zh$LCCCS2      -mean(zh$LCCCS2      ,na.rm=T)
zh$LCCS1c       <-zh$LCCS1       -mean(zh$LCCS1       ,na.rm=T)
zh$LCCS2c       <-zh$LCCS2       -mean(zh$LCCS2       ,na.rm=T)
zh$LCCCG1c      <-zh$LCCCG1      -mean(zh$LCCCG1      ,na.rm=T)
zh$LCCCG2c      <-zh$LCCCG2      -mean(zh$LCCCG2      ,na.rm=T)
zh$LCCG1c       <-zh$LCCG1       -mean(zh$LCCG1       ,na.rm=T)
zh$LCCG2c       <-zh$LCCG2       -mean(zh$LCCG2       ,na.rm=T)
zh$ChildCare1c  <-zh$ChildCare1  -mean(zh$ChildCare1  ,na.rm=T)
zh$ChildCare2c  <-zh$ChildCare2  -mean(zh$ChildCare2  ,na.rm=T)
zh$ChildCare3c  <-zh$ChildCare3  -mean(zh$ChildCare3  ,na.rm=T)
zh$CCAPc        <-zh$CCAP        -mean(zh$CCAP        ,na.rm=T)
zh$Homelessc    <-zh$Homeless    -mean(zh$Homeless    ,na.rm=T)
zh$Homeless2c   <-zh$Homeless2   -mean(zh$Homeless2   ,na.rm=T)
zh$DHS_HFIrc    <-zh$DHS_HFIr    -mean(zh$DHS_HFIr    ,na.rm=T)
zh$DHS_PTSrc    <-zh$DHS_PTSr    -mean(zh$DHS_PTSr    ,na.rm=T)
zh$DHS_HVPrc    <-zh$DHS_HVPr    -mean(zh$DHS_HVPr    ,na.rm=T)
zh$IDHS_EIrc    <-zh$IDHS_EIr    -mean(zh$IDHS_EIr    ,na.rm=T)
zh$MHV_C4c      <-zh$MHV_C4      -mean(zh$MHV_C4      ,na.rm=T)
zh$MHV_P4c      <-zh$MHV_P4      -mean(zh$MHV_P4      ,na.rm=T)
zh$MHV_C5c      <-zh$MHV_C5      -mean(zh$MHV_C5      ,na.rm=T)
zh$MHV_P5c      <-zh$MHV_P5      -mean(zh$MHV_P5      ,na.rm=T)
zh$FoodInsPc    <-zh$FoodInsP    -mean(zh$FoodInsP    ,na.rm=T)
zh$FoodISc      <-zh$FoodIS      -mean(zh$FoodIS      ,na.rm=T)
zh$RPovTc       <-zh$RPovT       -mean(zh$RPovT       ,na.rm=T)
zh$PovTc        <-zh$PovT        -mean(zh$PovT        ,na.rm=T)
zh$RPovHc       <-zh$RPovH       -mean(zh$RPovH       ,na.rm=T)
zh$PovHc        <-zh$PovH        -mean(zh$PovH        ,na.rm=T)
zh$MHV_C4k <-zh$MHV_C4 *10
zh$MHV_C5k <-zh$MHV_C5 *10
zh$MHV_C4kc<-zh$MHV_C4c*10
zh$MHV_C5kc<-zh$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 500)
zh1$Yearc        <-zh1$Year        -mean(zh1$Year        ,na.rm=T)
zh1$CPopBPc      <-zh1$CPopBP      -mean(zh1$CPopBP      ,na.rm=T)
zh1$CPopHPc      <-zh1$CPopHP      -mean(zh1$CPopHP      ,na.rm=T)
zh1$ChildPTc     <-zh1$ChildPT     -mean(zh1$ChildPT     ,na.rm=T)
zh1$ChildPWc     <-zh1$ChildPW     -mean(zh1$ChildPW     ,na.rm=T)
zh1$ChildPBc     <-zh1$ChildPB     -mean(zh1$ChildPB     ,na.rm=T)
zh1$ChildPHc     <-zh1$ChildPH     -mean(zh1$ChildPH     ,na.rm=T)
zh1$CARatioT100c <-zh1$CARatioT100 -mean(zh1$CARatioT100 ,na.rm=T)
zh1$CARatioW100c <-zh1$CARatioW100 -mean(zh1$CARatioW100 ,na.rm=T)
zh1$CARatioB100c <-zh1$CARatioB100 -mean(zh1$CARatioB100 ,na.rm=T)
zh1$CARatioH100c <-zh1$CARatioH100 -mean(zh1$CARatioH100 ,na.rm=T)
zh1$MalePTc      <-zh1$MalePT      -mean(zh1$MalePT      ,na.rm=T)
zh1$MalePWc      <-zh1$MalePW      -mean(zh1$MalePW      ,na.rm=T)
zh1$MalePBc      <-zh1$MalePB      -mean(zh1$MalePB      ,na.rm=T)
zh1$MalePHc      <-zh1$MalePH      -mean(zh1$MalePH      ,na.rm=T)
zh1$MFRatioT100c <-zh1$MFRatioT100 -mean(zh1$MFRatioT100 ,na.rm=T)
zh1$MFRatioW100c <-zh1$MFRatioW100 -mean(zh1$MFRatioW100 ,na.rm=T)
zh1$MFRatioB100c <-zh1$MFRatioB100 -mean(zh1$MFRatioB100 ,na.rm=T)
zh1$MFRatioH100c <-zh1$MFRatioH100 -mean(zh1$MFRatioH100 ,na.rm=T)
zh1$ElderTc      <-zh1$ElderT      -mean(zh1$ElderT      ,na.rm=T)
zh1$ElderWc      <-zh1$ElderW      -mean(zh1$ElderW      ,na.rm=T)
zh1$ElderBc      <-zh1$ElderB      -mean(zh1$ElderB      ,na.rm=T)
zh1$ElderHc      <-zh1$ElderH      -mean(zh1$ElderH      ,na.rm=T)
zh1$SingleTc     <-zh1$SingleT     -mean(zh1$SingleT     ,na.rm=T)
zh1$SingleWc     <-zh1$SingleW     -mean(zh1$SingleW     ,na.rm=T)
zh1$SingleBc     <-zh1$SingleB     -mean(zh1$SingleB     ,na.rm=T)
zh1$SingleHc     <-zh1$SingleH     -mean(zh1$SingleH     ,na.rm=T)
zh1$FHeadTc      <-zh1$FHeadT      -mean(zh1$FHeadT      ,na.rm=T)
zh1$FHeadWc      <-zh1$FHeadW      -mean(zh1$FHeadW      ,na.rm=T)
zh1$FHeadBc      <-zh1$FHeadB      -mean(zh1$FHeadB      ,na.rm=T)
zh1$FHeadHc      <-zh1$FHeadH      -mean(zh1$FHeadH      ,na.rm=T)
zh1$NoHighTc     <-zh1$NoHighT     -mean(zh1$NoHighT     ,na.rm=T)
zh1$NoHighWc     <-zh1$NoHighW     -mean(zh1$NoHighW     ,na.rm=T)
zh1$NoHighBc     <-zh1$NoHighB     -mean(zh1$NoHighB     ,na.rm=T)
zh1$NoHighHc     <-zh1$NoHighH     -mean(zh1$NoHighH     ,na.rm=T)
zh1$UnempTc      <-zh1$UnempT      -mean(zh1$UnempT      ,na.rm=T)
zh1$UnempWc      <-zh1$UnempW      -mean(zh1$UnempW      ,na.rm=T)
zh1$UnempBc      <-zh1$UnempB      -mean(zh1$UnempB      ,na.rm=T)
zh1$UnempHc      <-zh1$UnempH      -mean(zh1$UnempH      ,na.rm=T)
zh1$CPovTc       <-zh1$CPovT       -mean(zh1$CPovT       ,na.rm=T)
zh1$CPovWc       <-zh1$CPovW       -mean(zh1$CPovW       ,na.rm=T)
zh1$CPovBc       <-zh1$CPovB       -mean(zh1$CPovB       ,na.rm=T)
zh1$CPovHc       <-zh1$CPovH       -mean(zh1$CPovH       ,na.rm=T)
zh1$CPov1c       <-zh1$CPov1       -mean(zh1$CPov1       ,na.rm=T)
zh1$CPov2c       <-zh1$CPov2       -mean(zh1$CPov2       ,na.rm=T)
zh1$CPov3c       <-zh1$CPov3       -mean(zh1$CPov3       ,na.rm=T)
zh1$PubAsTc      <-zh1$PubAsT      -mean(zh1$PubAsT      ,na.rm=T)
zh1$WelfarTc     <-zh1$WelfarT     -mean(zh1$WelfarT     ,na.rm=T)
zh1$SnapTc       <-zh1$SnapT       -mean(zh1$SnapT       ,na.rm=T)
zh1$SnapWc       <-zh1$SnapW       -mean(zh1$SnapW       ,na.rm=T)
zh1$SnapBc       <-zh1$SnapB       -mean(zh1$SnapB       ,na.rm=T)
zh1$SnapHc       <-zh1$SnapH       -mean(zh1$SnapH       ,na.rm=T)
zh1$IncomeT1kc   <-zh1$IncomeT1k   -mean(zh1$IncomeT1k   ,na.rm=T)
zh1$IncomeW1kc   <-zh1$IncomeW1k   -mean(zh1$IncomeW1k   ,na.rm=T)
zh1$IncomeB1kc   <-zh1$IncomeB1k   -mean(zh1$IncomeB1k   ,na.rm=T)
zh1$IncomeH1kc   <-zh1$IncomeH1k   -mean(zh1$IncomeH1k   ,na.rm=T)
zh1$GiniT100c    <-zh1$GiniT100    -mean(zh1$GiniT100    ,na.rm=T)
zh1$HValueT10kc  <-zh1$HValueT10k  -mean(zh1$HValueT10k  ,na.rm=T)
zh1$MCostT100c   <-zh1$MCostT100   -mean(zh1$MCostT100   ,na.rm=T)
zh1$OCostDT100c  <-zh1$OCostDT100  -mean(zh1$OCostDT100  ,na.rm=T)
zh1$MRentDT100c  <-zh1$MRentDT100  -mean(zh1$MRentDT100  ,na.rm=T)
zh1$OCostPTc     <-zh1$OCostPT     -mean(zh1$OCostPT     ,na.rm=T)
zh1$MRentPTc     <-zh1$MRentPT     -mean(zh1$MRentPT     ,na.rm=T)
zh1$MortgTc      <-zh1$MortgT      -mean(zh1$MortgT      ,na.rm=T)
zh1$LangAPTc     <-zh1$LangAPT     -mean(zh1$LangAPT     ,na.rm=T)
zh1$LangAPWc     <-zh1$LangAPW     -mean(zh1$LangAPW     ,na.rm=T)
zh1$LangAPBc     <-zh1$LangAPB     -mean(zh1$LangAPB     ,na.rm=T)
zh1$LangAPHc     <-zh1$LangAPH     -mean(zh1$LangAPH     ,na.rm=T)
zh1$LangBPTc     <-zh1$LangBPT     -mean(zh1$LangBPT     ,na.rm=T)
zh1$LangBPWc     <-zh1$LangBPW     -mean(zh1$LangBPW     ,na.rm=T)
zh1$LangBPBc     <-zh1$LangBPB     -mean(zh1$LangBPB     ,na.rm=T)
zh1$LangBPHc     <-zh1$LangBPH     -mean(zh1$LangBPH     ,na.rm=T)
zh1$LangCPTc     <-zh1$LangCPT     -mean(zh1$LangCPT     ,na.rm=T)
zh1$OutUsTc      <-zh1$OutUsT      -mean(zh1$OutUsT      ,na.rm=T)
zh1$OutUsWc      <-zh1$OutUsW      -mean(zh1$OutUsW      ,na.rm=T)
zh1$OutUsBc      <-zh1$OutUsB      -mean(zh1$OutUsB      ,na.rm=T)
zh1$OutUsHc      <-zh1$OutUsH      -mean(zh1$OutUsH      ,na.rm=T)
zh1$FBornTc      <-zh1$FBornT      -mean(zh1$FBornT      ,na.rm=T)
zh1$FBornWc      <-zh1$FBornW      -mean(zh1$FBornW      ,na.rm=T)
zh1$FBornBc      <-zh1$FBornB      -mean(zh1$FBornB      ,na.rm=T)
zh1$FBornHc      <-zh1$FBornH      -mean(zh1$FBornH      ,na.rm=T)
zh1$NotCtzTc     <-zh1$NotCtzT     -mean(zh1$NotCtzT     ,na.rm=T)
zh1$NotCtzWc     <-zh1$NotCtzW     -mean(zh1$NotCtzW     ,na.rm=T)
zh1$NotCtzBc     <-zh1$NotCtzB     -mean(zh1$NotCtzB     ,na.rm=T)
zh1$NotCtzHc     <-zh1$NotCtzH     -mean(zh1$NotCtzH     ,na.rm=T)
zh1$MoveTc       <-zh1$MoveT       -mean(zh1$MoveT       ,na.rm=T)
zh1$MoveWc       <-zh1$MoveW       -mean(zh1$MoveW       ,na.rm=T)
zh1$MoveBc       <-zh1$MoveB       -mean(zh1$MoveB       ,na.rm=T)
zh1$MoveHc       <-zh1$MoveH       -mean(zh1$MoveH       ,na.rm=T)
zh1$VacantTc     <-zh1$VacantT     -mean(zh1$VacantT     ,na.rm=T)
zh1$OwnerTc      <-zh1$OwnerT      -mean(zh1$OwnerT      ,na.rm=T)
zh1$OwnerWc      <-zh1$OwnerW      -mean(zh1$OwnerW      ,na.rm=T)
zh1$OwnerBc      <-zh1$OwnerB      -mean(zh1$OwnerB      ,na.rm=T)
zh1$OwnerHc      <-zh1$OwnerH      -mean(zh1$OwnerH      ,na.rm=T)
zh1$CrowdTc      <-zh1$CrowdT      -mean(zh1$CrowdT      ,na.rm=T)
zh1$CrowdWc      <-zh1$CrowdW      -mean(zh1$CrowdW      ,na.rm=T)
zh1$CrowdBc      <-zh1$CrowdB      -mean(zh1$CrowdB      ,na.rm=T)
zh1$CrowdHc      <-zh1$CrowdH      -mean(zh1$CrowdH      ,na.rm=T)
zh1$MobileTc     <-zh1$MobileT     -mean(zh1$MobileT     ,na.rm=T)
zh1$MobileWc     <-zh1$MobileW     -mean(zh1$MobileW     ,na.rm=T)
zh1$MobileBc     <-zh1$MobileB     -mean(zh1$MobileB     ,na.rm=T)
zh1$MobileHc     <-zh1$MobileH     -mean(zh1$MobileH     ,na.rm=T)
zh1$DisablTc     <-zh1$DisablT     -mean(zh1$DisablT     ,na.rm=T)
zh1$DisablWc     <-zh1$DisablW     -mean(zh1$DisablW     ,na.rm=T)
zh1$DisablBc     <-zh1$DisablB     -mean(zh1$DisablB     ,na.rm=T)
zh1$DisablHc     <-zh1$DisablH     -mean(zh1$DisablH     ,na.rm=T)
zh1$DisablTCc    <-zh1$DisablTC    -mean(zh1$DisablTC    ,na.rm=T)
zh1$DisablWCc    <-zh1$DisablWC    -mean(zh1$DisablWC    ,na.rm=T)
zh1$DisablBCc    <-zh1$DisablBC    -mean(zh1$DisablBC    ,na.rm=T)
zh1$DisablHCc    <-zh1$DisablHC    -mean(zh1$DisablHC    ,na.rm=T)
zh1$DisablTMc    <-zh1$DisablTM    -mean(zh1$DisablTM    ,na.rm=T)
zh1$DisablTFc    <-zh1$DisablTF    -mean(zh1$DisablTF    ,na.rm=T)
zh1$Urban1c      <-zh1$Urban1      -mean(zh1$Urban1      ,na.rm=T)
zh1$Urban2c      <-zh1$Urban2      -mean(zh1$Urban2      ,na.rm=T)
zh1$ISBE_PFAc    <-zh1$ISBE_PFA    -mean(zh1$ISBE_PFA    ,na.rm=T)
zh1$ISBE_PFAEc   <-zh1$ISBE_PFAE   -mean(zh1$ISBE_PFAE   ,na.rm=T)
zh1$ISBE_PIc     <-zh1$ISBE_PI     -mean(zh1$ISBE_PI     ,na.rm=T)
zh1$HeadStartc   <-zh1$HeadStart   -mean(zh1$HeadStart   ,na.rm=T)
zh1$ElyHeadSc    <-zh1$ElyHeadS    -mean(zh1$ElyHeadS    ,na.rm=T)
zh1$HeadSAllc    <-zh1$HeadSAll    -mean(zh1$HeadSAll    ,na.rm=T)
zh1$PFA_HS1c     <-zh1$PFA_HS1     -mean(zh1$PFA_HS1     ,na.rm=T)
zh1$PFA_HS2c     <-zh1$PFA_HS2     -mean(zh1$PFA_HS2     ,na.rm=T)
zh1$LCCCc        <-zh1$LCCC        -mean(zh1$LCCC        ,na.rm=T)
zh1$LECCCc       <-zh1$LECCC       -mean(zh1$LECCC       ,na.rm=T)
zh1$LFCCc        <-zh1$LFCC        -mean(zh1$LFCC        ,na.rm=T)
zh1$LLECCCc      <-zh1$LLECCC      -mean(zh1$LLECCC      ,na.rm=T)
zh1$LCLFCCc      <-zh1$LCLFCC      -mean(zh1$LCLFCC      ,na.rm=T)
zh1$LCCCB1c      <-zh1$LCCCB1      -mean(zh1$LCCCB1      ,na.rm=T)
zh1$LCCCB2c      <-zh1$LCCCB2      -mean(zh1$LCCCB2      ,na.rm=T)
zh1$LCCB1c       <-zh1$LCCB1       -mean(zh1$LCCB1       ,na.rm=T)
zh1$LCCB2c       <-zh1$LCCB2       -mean(zh1$LCCB2       ,na.rm=T)
zh1$LCCCS1c      <-zh1$LCCCS1      -mean(zh1$LCCCS1      ,na.rm=T)
zh1$LCCCS2c      <-zh1$LCCCS2      -mean(zh1$LCCCS2      ,na.rm=T)
zh1$LCCS1c       <-zh1$LCCS1       -mean(zh1$LCCS1       ,na.rm=T)
zh1$LCCS2c       <-zh1$LCCS2       -mean(zh1$LCCS2       ,na.rm=T)
zh1$LCCCG1c      <-zh1$LCCCG1      -mean(zh1$LCCCG1      ,na.rm=T)
zh1$LCCCG2c      <-zh1$LCCCG2      -mean(zh1$LCCCG2      ,na.rm=T)
zh1$LCCG1c       <-zh1$LCCG1       -mean(zh1$LCCG1       ,na.rm=T)
zh1$LCCG2c       <-zh1$LCCG2       -mean(zh1$LCCG2       ,na.rm=T)
zh1$ChildCare1c  <-zh1$ChildCare1  -mean(zh1$ChildCare1  ,na.rm=T)
zh1$ChildCare2c  <-zh1$ChildCare2  -mean(zh1$ChildCare2  ,na.rm=T)
zh1$ChildCare3c  <-zh1$ChildCare3  -mean(zh1$ChildCare3  ,na.rm=T)
zh1$CCAPc        <-zh1$CCAP        -mean(zh1$CCAP        ,na.rm=T)
zh1$Homelessc    <-zh1$Homeless    -mean(zh1$Homeless    ,na.rm=T)
zh1$Homeless2c   <-zh1$Homeless2   -mean(zh1$Homeless2   ,na.rm=T)
zh1$DHS_HFIrc    <-zh1$DHS_HFIr    -mean(zh1$DHS_HFIr    ,na.rm=T)
zh1$DHS_PTSrc    <-zh1$DHS_PTSr    -mean(zh1$DHS_PTSr    ,na.rm=T)
zh1$DHS_HVPrc    <-zh1$DHS_HVPr    -mean(zh1$DHS_HVPr    ,na.rm=T)
zh1$IDHS_EIrc    <-zh1$IDHS_EIr    -mean(zh1$IDHS_EIr    ,na.rm=T)
zh1$MHV_C4c      <-zh1$MHV_C4      -mean(zh1$MHV_C4      ,na.rm=T)
zh1$MHV_P4c      <-zh1$MHV_P4      -mean(zh1$MHV_P4      ,na.rm=T)
zh1$MHV_C5c      <-zh1$MHV_C5      -mean(zh1$MHV_C5      ,na.rm=T)
zh1$MHV_P5c      <-zh1$MHV_P5      -mean(zh1$MHV_P5      ,na.rm=T)
zh1$FoodInsPc    <-zh1$FoodInsP    -mean(zh1$FoodInsP    ,na.rm=T)
zh1$FoodISc      <-zh1$FoodIS      -mean(zh1$FoodIS      ,na.rm=T)
zh1$RPovTc       <-zh1$RPovT       -mean(zh1$RPovT       ,na.rm=T)
zh1$PovTc        <-zh1$PovT        -mean(zh1$PovT        ,na.rm=T)
zh1$RPovHc       <-zh1$RPovH       -mean(zh1$RPovH       ,na.rm=T)
zh1$PovHc        <-zh1$PovH        -mean(zh1$PovH        ,na.rm=T)
zh1$MHV_C4k <-zh1$MHV_C4 *10
zh1$MHV_C5k <-zh1$MHV_C5 *10
zh1$MHV_C4kc<-zh1$MHV_C4c*10
zh1$MHV_C5kc<-zh1$MHV_C5c*10





# Centering Variables - for sensitivity analysis (child population > 1000)
zh2$Yearc        <-zh2$Year        -mean(zh2$Year        ,na.rm=T)
zh2$CPopBPc      <-zh2$CPopBP      -mean(zh2$CPopBP      ,na.rm=T)
zh2$CPopHPc      <-zh2$CPopHP      -mean(zh2$CPopHP      ,na.rm=T)
zh2$ChildPTc     <-zh2$ChildPT     -mean(zh2$ChildPT     ,na.rm=T)
zh2$ChildPWc     <-zh2$ChildPW     -mean(zh2$ChildPW     ,na.rm=T)
zh2$ChildPBc     <-zh2$ChildPB     -mean(zh2$ChildPB     ,na.rm=T)
zh2$ChildPHc     <-zh2$ChildPH     -mean(zh2$ChildPH     ,na.rm=T)
zh2$CARatioT100c <-zh2$CARatioT100 -mean(zh2$CARatioT100 ,na.rm=T)
zh2$CARatioW100c <-zh2$CARatioW100 -mean(zh2$CARatioW100 ,na.rm=T)
zh2$CARatioB100c <-zh2$CARatioB100 -mean(zh2$CARatioB100 ,na.rm=T)
zh2$CARatioH100c <-zh2$CARatioH100 -mean(zh2$CARatioH100 ,na.rm=T)
zh2$MalePTc      <-zh2$MalePT      -mean(zh2$MalePT      ,na.rm=T)
zh2$MalePWc      <-zh2$MalePW      -mean(zh2$MalePW      ,na.rm=T)
zh2$MalePBc      <-zh2$MalePB      -mean(zh2$MalePB      ,na.rm=T)
zh2$MalePHc      <-zh2$MalePH      -mean(zh2$MalePH      ,na.rm=T)
zh2$MFRatioT100c <-zh2$MFRatioT100 -mean(zh2$MFRatioT100 ,na.rm=T)
zh2$MFRatioW100c <-zh2$MFRatioW100 -mean(zh2$MFRatioW100 ,na.rm=T)
zh2$MFRatioB100c <-zh2$MFRatioB100 -mean(zh2$MFRatioB100 ,na.rm=T)
zh2$MFRatioH100c <-zh2$MFRatioH100 -mean(zh2$MFRatioH100 ,na.rm=T)
zh2$ElderTc      <-zh2$ElderT      -mean(zh2$ElderT      ,na.rm=T)
zh2$ElderWc      <-zh2$ElderW      -mean(zh2$ElderW      ,na.rm=T)
zh2$ElderBc      <-zh2$ElderB      -mean(zh2$ElderB      ,na.rm=T)
zh2$ElderHc      <-zh2$ElderH      -mean(zh2$ElderH      ,na.rm=T)
zh2$SingleTc     <-zh2$SingleT     -mean(zh2$SingleT     ,na.rm=T)
zh2$SingleWc     <-zh2$SingleW     -mean(zh2$SingleW     ,na.rm=T)
zh2$SingleBc     <-zh2$SingleB     -mean(zh2$SingleB     ,na.rm=T)
zh2$SingleHc     <-zh2$SingleH     -mean(zh2$SingleH     ,na.rm=T)
zh2$FHeadTc      <-zh2$FHeadT      -mean(zh2$FHeadT      ,na.rm=T)
zh2$FHeadWc      <-zh2$FHeadW      -mean(zh2$FHeadW      ,na.rm=T)
zh2$FHeadBc      <-zh2$FHeadB      -mean(zh2$FHeadB      ,na.rm=T)
zh2$FHeadHc      <-zh2$FHeadH      -mean(zh2$FHeadH      ,na.rm=T)
zh2$NoHighTc     <-zh2$NoHighT     -mean(zh2$NoHighT     ,na.rm=T)
zh2$NoHighWc     <-zh2$NoHighW     -mean(zh2$NoHighW     ,na.rm=T)
zh2$NoHighBc     <-zh2$NoHighB     -mean(zh2$NoHighB     ,na.rm=T)
zh2$NoHighHc     <-zh2$NoHighH     -mean(zh2$NoHighH     ,na.rm=T)
zh2$UnempTc      <-zh2$UnempT      -mean(zh2$UnempT      ,na.rm=T)
zh2$UnempWc      <-zh2$UnempW      -mean(zh2$UnempW      ,na.rm=T)
zh2$UnempBc      <-zh2$UnempB      -mean(zh2$UnempB      ,na.rm=T)
zh2$UnempHc      <-zh2$UnempH      -mean(zh2$UnempH      ,na.rm=T)
zh2$CPovTc       <-zh2$CPovT       -mean(zh2$CPovT       ,na.rm=T)
zh2$CPovWc       <-zh2$CPovW       -mean(zh2$CPovW       ,na.rm=T)
zh2$CPovBc       <-zh2$CPovB       -mean(zh2$CPovB       ,na.rm=T)
zh2$CPovHc       <-zh2$CPovH       -mean(zh2$CPovH       ,na.rm=T)
zh2$CPov1c       <-zh2$CPov1       -mean(zh2$CPov1       ,na.rm=T)
zh2$CPov2c       <-zh2$CPov2       -mean(zh2$CPov2       ,na.rm=T)
zh2$CPov3c       <-zh2$CPov3       -mean(zh2$CPov3       ,na.rm=T)
zh2$PubAsTc      <-zh2$PubAsT      -mean(zh2$PubAsT      ,na.rm=T)
zh2$WelfarTc     <-zh2$WelfarT     -mean(zh2$WelfarT     ,na.rm=T)
zh2$SnapTc       <-zh2$SnapT       -mean(zh2$SnapT       ,na.rm=T)
zh2$SnapWc       <-zh2$SnapW       -mean(zh2$SnapW       ,na.rm=T)
zh2$SnapBc       <-zh2$SnapB       -mean(zh2$SnapB       ,na.rm=T)
zh2$SnapHc       <-zh2$SnapH       -mean(zh2$SnapH       ,na.rm=T)
zh2$IncomeT1kc   <-zh2$IncomeT1k   -mean(zh2$IncomeT1k   ,na.rm=T)
zh2$IncomeW1kc   <-zh2$IncomeW1k   -mean(zh2$IncomeW1k   ,na.rm=T)
zh2$IncomeB1kc   <-zh2$IncomeB1k   -mean(zh2$IncomeB1k   ,na.rm=T)
zh2$IncomeH1kc   <-zh2$IncomeH1k   -mean(zh2$IncomeH1k   ,na.rm=T)
zh2$GiniT100c    <-zh2$GiniT100    -mean(zh2$GiniT100    ,na.rm=T)
zh2$HValueT10kc  <-zh2$HValueT10k  -mean(zh2$HValueT10k  ,na.rm=T)
zh2$MCostT100c   <-zh2$MCostT100   -mean(zh2$MCostT100   ,na.rm=T)
zh2$OCostDT100c  <-zh2$OCostDT100  -mean(zh2$OCostDT100  ,na.rm=T)
zh2$MRentDT100c  <-zh2$MRentDT100  -mean(zh2$MRentDT100  ,na.rm=T)
zh2$OCostPTc     <-zh2$OCostPT     -mean(zh2$OCostPT     ,na.rm=T)
zh2$MRentPTc     <-zh2$MRentPT     -mean(zh2$MRentPT     ,na.rm=T)
zh2$MortgTc      <-zh2$MortgT      -mean(zh2$MortgT      ,na.rm=T)
zh2$LangAPTc     <-zh2$LangAPT     -mean(zh2$LangAPT     ,na.rm=T)
zh2$LangAPWc     <-zh2$LangAPW     -mean(zh2$LangAPW     ,na.rm=T)
zh2$LangAPBc     <-zh2$LangAPB     -mean(zh2$LangAPB     ,na.rm=T)
zh2$LangAPHc     <-zh2$LangAPH     -mean(zh2$LangAPH     ,na.rm=T)
zh2$LangBPTc     <-zh2$LangBPT     -mean(zh2$LangBPT     ,na.rm=T)
zh2$LangBPWc     <-zh2$LangBPW     -mean(zh2$LangBPW     ,na.rm=T)
zh2$LangBPBc     <-zh2$LangBPB     -mean(zh2$LangBPB     ,na.rm=T)
zh2$LangBPHc     <-zh2$LangBPH     -mean(zh2$LangBPH     ,na.rm=T)
zh2$LangCPTc     <-zh2$LangCPT     -mean(zh2$LangCPT     ,na.rm=T)
zh2$OutUsTc      <-zh2$OutUsT      -mean(zh2$OutUsT      ,na.rm=T)
zh2$OutUsWc      <-zh2$OutUsW      -mean(zh2$OutUsW      ,na.rm=T)
zh2$OutUsBc      <-zh2$OutUsB      -mean(zh2$OutUsB      ,na.rm=T)
zh2$OutUsHc      <-zh2$OutUsH      -mean(zh2$OutUsH      ,na.rm=T)
zh2$FBornTc      <-zh2$FBornT      -mean(zh2$FBornT      ,na.rm=T)
zh2$FBornWc      <-zh2$FBornW      -mean(zh2$FBornW      ,na.rm=T)
zh2$FBornBc      <-zh2$FBornB      -mean(zh2$FBornB      ,na.rm=T)
zh2$FBornHc      <-zh2$FBornH      -mean(zh2$FBornH      ,na.rm=T)
zh2$NotCtzTc     <-zh2$NotCtzT     -mean(zh2$NotCtzT     ,na.rm=T)
zh2$NotCtzWc     <-zh2$NotCtzW     -mean(zh2$NotCtzW     ,na.rm=T)
zh2$NotCtzBc     <-zh2$NotCtzB     -mean(zh2$NotCtzB     ,na.rm=T)
zh2$NotCtzHc     <-zh2$NotCtzH     -mean(zh2$NotCtzH     ,na.rm=T)
zh2$MoveTc       <-zh2$MoveT       -mean(zh2$MoveT       ,na.rm=T)
zh2$MoveWc       <-zh2$MoveW       -mean(zh2$MoveW       ,na.rm=T)
zh2$MoveBc       <-zh2$MoveB       -mean(zh2$MoveB       ,na.rm=T)
zh2$MoveHc       <-zh2$MoveH       -mean(zh2$MoveH       ,na.rm=T)
zh2$VacantTc     <-zh2$VacantT     -mean(zh2$VacantT     ,na.rm=T)
zh2$OwnerTc      <-zh2$OwnerT      -mean(zh2$OwnerT      ,na.rm=T)
zh2$OwnerWc      <-zh2$OwnerW      -mean(zh2$OwnerW      ,na.rm=T)
zh2$OwnerBc      <-zh2$OwnerB      -mean(zh2$OwnerB      ,na.rm=T)
zh2$OwnerHc      <-zh2$OwnerH      -mean(zh2$OwnerH      ,na.rm=T)
zh2$CrowdTc      <-zh2$CrowdT      -mean(zh2$CrowdT      ,na.rm=T)
zh2$CrowdWc      <-zh2$CrowdW      -mean(zh2$CrowdW      ,na.rm=T)
zh2$CrowdBc      <-zh2$CrowdB      -mean(zh2$CrowdB      ,na.rm=T)
zh2$CrowdHc      <-zh2$CrowdH      -mean(zh2$CrowdH      ,na.rm=T)
zh2$MobileTc     <-zh2$MobileT     -mean(zh2$MobileT     ,na.rm=T)
zh2$MobileWc     <-zh2$MobileW     -mean(zh2$MobileW     ,na.rm=T)
zh2$MobileBc     <-zh2$MobileB     -mean(zh2$MobileB     ,na.rm=T)
zh2$MobileHc     <-zh2$MobileH     -mean(zh2$MobileH     ,na.rm=T)
zh2$DisablTc     <-zh2$DisablT     -mean(zh2$DisablT     ,na.rm=T)
zh2$DisablWc     <-zh2$DisablW     -mean(zh2$DisablW     ,na.rm=T)
zh2$DisablBc     <-zh2$DisablB     -mean(zh2$DisablB     ,na.rm=T)
zh2$DisablHc     <-zh2$DisablH     -mean(zh2$DisablH     ,na.rm=T)
zh2$DisablTCc    <-zh2$DisablTC    -mean(zh2$DisablTC    ,na.rm=T)
zh2$DisablWCc    <-zh2$DisablWC    -mean(zh2$DisablWC    ,na.rm=T)
zh2$DisablBCc    <-zh2$DisablBC    -mean(zh2$DisablBC    ,na.rm=T)
zh2$DisablHCc    <-zh2$DisablHC    -mean(zh2$DisablHC    ,na.rm=T)
zh2$DisablTMc    <-zh2$DisablTM    -mean(zh2$DisablTM    ,na.rm=T)
zh2$DisablTFc    <-zh2$DisablTF    -mean(zh2$DisablTF    ,na.rm=T)
zh2$Urban1c      <-zh2$Urban1      -mean(zh2$Urban1      ,na.rm=T)
zh2$Urban2c      <-zh2$Urban2      -mean(zh2$Urban2      ,na.rm=T)
zh2$ISBE_PFAc    <-zh2$ISBE_PFA    -mean(zh2$ISBE_PFA    ,na.rm=T)
zh2$ISBE_PFAEc   <-zh2$ISBE_PFAE   -mean(zh2$ISBE_PFAE   ,na.rm=T)
zh2$ISBE_PIc     <-zh2$ISBE_PI     -mean(zh2$ISBE_PI     ,na.rm=T)
zh2$HeadStartc   <-zh2$HeadStart   -mean(zh2$HeadStart   ,na.rm=T)
zh2$ElyHeadSc    <-zh2$ElyHeadS    -mean(zh2$ElyHeadS    ,na.rm=T)
zh2$HeadSAllc    <-zh2$HeadSAll    -mean(zh2$HeadSAll    ,na.rm=T)
zh2$PFA_HS1c     <-zh2$PFA_HS1     -mean(zh2$PFA_HS1     ,na.rm=T)
zh2$PFA_HS2c     <-zh2$PFA_HS2     -mean(zh2$PFA_HS2     ,na.rm=T)
zh2$LCCCc        <-zh2$LCCC        -mean(zh2$LCCC        ,na.rm=T)
zh2$LECCCc       <-zh2$LECCC       -mean(zh2$LECCC       ,na.rm=T)
zh2$LFCCc        <-zh2$LFCC        -mean(zh2$LFCC        ,na.rm=T)
zh2$LLECCCc      <-zh2$LLECCC      -mean(zh2$LLECCC      ,na.rm=T)
zh2$LCLFCCc      <-zh2$LCLFCC      -mean(zh2$LCLFCC      ,na.rm=T)
zh2$LCCCB1c      <-zh2$LCCCB1      -mean(zh2$LCCCB1      ,na.rm=T)
zh2$LCCCB2c      <-zh2$LCCCB2      -mean(zh2$LCCCB2      ,na.rm=T)
zh2$LCCB1c       <-zh2$LCCB1       -mean(zh2$LCCB1       ,na.rm=T)
zh2$LCCB2c       <-zh2$LCCB2       -mean(zh2$LCCB2       ,na.rm=T)
zh2$LCCCS1c      <-zh2$LCCCS1      -mean(zh2$LCCCS1      ,na.rm=T)
zh2$LCCCS2c      <-zh2$LCCCS2      -mean(zh2$LCCCS2      ,na.rm=T)
zh2$LCCS1c       <-zh2$LCCS1       -mean(zh2$LCCS1       ,na.rm=T)
zh2$LCCS2c       <-zh2$LCCS2       -mean(zh2$LCCS2       ,na.rm=T)
zh2$LCCCG1c      <-zh2$LCCCG1      -mean(zh2$LCCCG1      ,na.rm=T)
zh2$LCCCG2c      <-zh2$LCCCG2      -mean(zh2$LCCCG2      ,na.rm=T)
zh2$LCCG1c       <-zh2$LCCG1       -mean(zh2$LCCG1       ,na.rm=T)
zh2$LCCG2c       <-zh2$LCCG2       -mean(zh2$LCCG2       ,na.rm=T)
zh2$ChildCare1c  <-zh2$ChildCare1  -mean(zh2$ChildCare1  ,na.rm=T)
zh2$ChildCare2c  <-zh2$ChildCare2  -mean(zh2$ChildCare2  ,na.rm=T)
zh2$ChildCare3c  <-zh2$ChildCare3  -mean(zh2$ChildCare3  ,na.rm=T)
zh2$CCAPc        <-zh2$CCAP        -mean(zh2$CCAP        ,na.rm=T)
zh2$Homelessc    <-zh2$Homeless    -mean(zh2$Homeless    ,na.rm=T)
zh2$Homeless2c   <-zh2$Homeless2   -mean(zh2$Homeless2   ,na.rm=T)
zh2$DHS_HFIrc    <-zh2$DHS_HFIr    -mean(zh2$DHS_HFIr    ,na.rm=T)
zh2$DHS_PTSrc    <-zh2$DHS_PTSr    -mean(zh2$DHS_PTSr    ,na.rm=T)
zh2$DHS_HVPrc    <-zh2$DHS_HVPr    -mean(zh2$DHS_HVPr    ,na.rm=T)
zh2$IDHS_EIrc    <-zh2$IDHS_EIr    -mean(zh2$IDHS_EIr    ,na.rm=T)
zh2$MHV_C4c      <-zh2$MHV_C4      -mean(zh2$MHV_C4      ,na.rm=T)
zh2$MHV_P4c      <-zh2$MHV_P4      -mean(zh2$MHV_P4      ,na.rm=T)
zh2$MHV_C5c      <-zh2$MHV_C5      -mean(zh2$MHV_C5      ,na.rm=T)
zh2$MHV_P5c      <-zh2$MHV_P5      -mean(zh2$MHV_P5      ,na.rm=T)
zh2$FoodInsPc    <-zh2$FoodInsP    -mean(zh2$FoodInsP    ,na.rm=T)
zh2$FoodISc      <-zh2$FoodIS      -mean(zh2$FoodIS      ,na.rm=T)
zh2$RPovTc       <-zh2$RPovT       -mean(zh2$RPovT       ,na.rm=T)
zh2$PovTc        <-zh2$PovT        -mean(zh2$PovT        ,na.rm=T)
zh2$RPovHc       <-zh2$RPovH       -mean(zh2$RPovH       ,na.rm=T)
zh2$PovHc        <-zh2$PovH        -mean(zh2$PovH        ,na.rm=T)
zh2$MHV_C4k <-zh2$MHV_C4 *10
zh2$MHV_C5k <-zh2$MHV_C5 *10
zh2$MHV_C4kc<-zh2$MHV_C4c*10
zh2$MHV_C5kc<-zh2$MHV_C5c*10





# demean - within and between variables
zh<-cbind(zh,demean(zh,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovHc","PovTc","PovHc"
),group="CountyFIPS"))





# demean - within and between variables
zh1<-cbind(zh1,demean(zh1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovHc","PovTc","PovHc"
),group="CountyFIPS"))





# demean - within and between variables
zh2<-cbind(zh2,demean(zh2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "MHV_C4k","MHV_C5k","MHV_C4kc","MHV_C5kc",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc","RPovTc","RPovHc","PovTc","PovHc"
),group="CountyFIPS"))





save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit01_data_2.RData")
